@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -18,8 +18,9 @@
 
 package org.eclipse.jetty.embedded;
 
-import java.io.File;
 import java.io.IOException;
+import java.nio.file.Files;
+import java.nio.file.Path;
 import java.util.Map;
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
@@ -120,8 +121,8 @@ public class ManyHandlers
         gzipHandler.addIncludedMimeTypes("text/html");
 
         // configure request logging
-        File requestLogFile = File.createTempFile("demo", "log");
-        CustomRequestLog ncsaLog = new CustomRequestLog(requestLogFile.getAbsolutePath());
+        Path requestLogFile = Files.createTempFile("demo", "log");
+        CustomRequestLog ncsaLog = new CustomRequestLog(requestLogFile.toString());
         server.setRequestLog(ncsaLog);
 
         // create the handler collections
