@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -33,32 +33,32 @@ public class PostConstructAnnotationHandler extends AbstractIntrospectableAnnota
 {
     protected WebAppContext _context;
 
-    public PostConstructAnnotationHandler (WebAppContext wac)
+    public PostConstructAnnotationHandler(WebAppContext wac)
     {
         super(true);
         _context = wac;
     }
 
-
+    @Override
     public void doHandle(Class clazz)
     {
         //Check that the PostConstruct is on a class that we're interested in
-        if (Util.supportsPostConstructPreDestroy(clazz))
+        if (supportsPostConstruct(clazz))
         {
             Method[] methods = clazz.getDeclaredMethods();
-            for (int i=0; i<methods.length; i++)
+            for (int i = 0; i < methods.length; i++)
             {
-                Method m = (Method)methods[i];
+                Method m = methods[i];
                 if (m.isAnnotationPresent(PostConstruct.class))
                 {
-                    if (m.getParameterTypes().length != 0)
-                        throw new IllegalStateException(m+" has parameters");
+                    if (m.getParameterCount() != 0)
+                        throw new IllegalStateException(m + " has parameters");
                     if (m.getReturnType() != Void.TYPE)
-                        throw new IllegalStateException(m+" is not void");
+                        throw new IllegalStateException(m + " is not void");
                     if (m.getExceptionTypes().length != 0)
-                        throw new IllegalStateException(m+" throws checked exceptions");
+                        throw new IllegalStateException(m + " throws checked exceptions");
                     if (Modifier.isStatic(m.getModifiers()))
-                        throw new IllegalStateException(m+" is static");
+                        throw new IllegalStateException(m + " is static");
 
                     //ServletSpec 3.0 p80 If web.xml declares even one post-construct then all post-constructs
                     //in fragments must be ignored. Otherwise, they are additive.
@@ -66,21 +66,41 @@ public class PostConstructAnnotationHandler extends AbstractIntrospectableAnnota
                     Origin origin = metaData.getOrigin("post-construct");
                     if (origin != null &&
                         (origin == Origin.WebXml ||
-                         origin == Origin.WebDefaults ||
-                         origin == Origin.WebOverride))
+                            origin == Origin.WebDefaults ||
+                            origin == Origin.WebOverride))
                         return;
 
-                    PostConstructCallback callback = new PostConstructCallback();
-                    callback.setTarget(clazz.getName(), m.getName());
+                    PostConstructCallback callback = new PostConstructCallback(clazz, m.getName());
                     LifeCycleCallbackCollection lifecycles = (LifeCycleCallbackCollection)_context.getAttribute(LifeCycleCallbackCollection.LIFECYCLE_CALLBACK_COLLECTION);
                     if (lifecycles == null)
                     {
                         lifecycles = new LifeCycleCallbackCollection();
-                        _context.setAttribute(LifeCycleCallbackCollection.LIFECYCLE_CALLBACK_COLLECTION,lifecycles);
+                        _context.setAttribute(LifeCycleCallbackCollection.LIFECYCLE_CALLBACK_COLLECTION, lifecycles);
                     }
                     lifecycles.add(callback);
                 }
             }
         }
     }
+
+    /**
+     * Check if the given class is permitted to have PostConstruct annotation.
+     *
+     * @param c the class
+     * @return true if the spec permits the class to have PostConstruct, false otherwise
+     */
+    public boolean supportsPostConstruct(Class c)
+    {
+        return javax.servlet.Servlet.class.isAssignableFrom(c) ||
+            javax.servlet.Filter.class.isAssignableFrom(c) ||
+            javax.servlet.ServletContextListener.class.isAssignableFrom(c) ||
+            javax.servlet.ServletContextAttributeListener.class.isAssignableFrom(c) ||
+            javax.servlet.ServletRequestListener.class.isAssignableFrom(c) ||
+            javax.servlet.ServletRequestAttributeListener.class.isAssignableFrom(c) ||
+            javax.servlet.http.HttpSessionListener.class.isAssignableFrom(c) ||
+            javax.servlet.http.HttpSessionAttributeListener.class.isAssignableFrom(c) ||
+            javax.servlet.http.HttpSessionIdListener.class.isAssignableFrom(c) ||
+            javax.servlet.AsyncListener.class.isAssignableFrom(c) ||
+            javax.servlet.http.HttpUpgradeHandler.class.isAssignableFrom(c);
+    }
 }
