@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -24,7 +24,7 @@ import org.eclipse.jetty.servlet.ServletContextHandler;
 /**
  * A DecoratingListener that listens for "org.eclipse.jetty.cdi.decorator"
  */
-class CdiDecoratingListener extends DecoratingListener
+public class CdiDecoratingListener extends DecoratingListener
 {
     public static final String MODE = "CdiDecoratingListener";
     public static final String ATTRIBUTE = "org.eclipse.jetty.cdi.decorator";
@@ -32,5 +32,6 @@ class CdiDecoratingListener extends DecoratingListener
     public CdiDecoratingListener(ServletContextHandler contextHandler)
     {
         super(contextHandler, ATTRIBUTE);
+        contextHandler.setAttribute(CdiServletContainerInitializer.CDI_INTEGRATION_ATTRIBUTE, MODE);
     }
 }
