@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2019 Mort Bay Consulting Pty. Ltd.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -85,8 +85,8 @@ public abstract class AbstractConnectorHttpClientTransport extends AbstractHttpC
                 channel.bind(bindAddress);
             configure(client, channel);
 
-            context.put(SslClientConnectionFactory.SSL_PEER_HOST_CONTEXT_KEY, destination.getHost());
-            context.put(SslClientConnectionFactory.SSL_PEER_PORT_CONTEXT_KEY, destination.getPort());
+            context.put(SslClientConnectionFactory.SSL_PEER_HOST_CONTEXT_KEY, address.getHostString());
+            context.put(SslClientConnectionFactory.SSL_PEER_PORT_CONTEXT_KEY, address.getPort());
 
             boolean connected = true;
             if (client.isConnectBlocking())
@@ -118,9 +118,9 @@ public abstract class AbstractConnectorHttpClientTransport extends AbstractHttpC
                 if (channel != null)
                     channel.close();
             }
-            catch (IOException xx)
+            catch (IOException ignored)
             {
-                LOG.ignore(xx);
+                LOG.ignore(ignored);
             }
             finally
             {
