@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -27,11 +27,18 @@ public abstract class HttpChannel
     protected static final Logger LOG = Log.getLogger(HttpChannel.class);
 
     private final HttpDestination _destination;
+    private final TimeoutCompleteListener _totalTimeout;
     private HttpExchange _exchange;
 
     protected HttpChannel(HttpDestination destination)
     {
-        this._destination = destination;
+        _destination = destination;
+        _totalTimeout = new TimeoutCompleteListener(destination.getHttpClient().getScheduler());
+    }
+
+    public void destroy()
+    {
+        _totalTimeout.destroy();
     }
 
     public HttpDestination getHttpDestination()
@@ -63,10 +70,14 @@ public abstract class HttpChannel
         }
 
         if (abort)
+        {
             exchange.getRequest().abort(new UnsupportedOperationException("Pipelined requests not supported"));
-
-        if (LOG.isDebugEnabled())
-            LOG.debug("{} associated {} to {}", exchange, result, this);
+        }
+        else
+        {
+            if (LOG.isDebugEnabled())
+                LOG.debug("{} associated {} to {}", exchange, result, this);
+        }
 
         return result;
     }
@@ -102,7 +113,23 @@ public abstract class HttpChannel
 
     protected abstract HttpReceiver getHttpReceiver();
 
-    public abstract void send();
+    public void send()
+    {
+        HttpExchange exchange = getHttpExchange();
+        if (exchange != null)
+        {
+            HttpRequest request = exchange.getRequest();
+            long timeoutAt = request.getTimeoutAt();
+            if (timeoutAt != -1)
+            {
+                exchange.getResponseListeners().add(_totalTimeout);
+                _totalTimeout.schedule(request, timeoutAt);
+            }
+            send(exchange);
+        }
+    }
+
+    public abstract void send(HttpExchange exchange);
 
     public abstract void release();
 
@@ -129,6 +156,11 @@ public abstract class HttpChannel
         return getHttpReceiver().abort(exchange, failure);
     }
 
+    public Result exchangeTerminating(HttpExchange exchange, Result result)
+    {
+        return result;
+    }
+
     public void exchangeTerminated(HttpExchange exchange, Result result)
     {
         disassociate(exchange);
