@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -109,7 +109,7 @@ public abstract class HttpDestination extends ContainerLifeCycle implements Dest
     protected void doStart() throws Exception
     {
         this.connectionPool = newConnectionPool(client);
-        addBean(connectionPool);
+        addBean(connectionPool, true);
         super.doStart();
         Sweeper sweeper = client.getBean(Sweeper.class);
         if (sweeper != null && connectionPool instanceof Sweeper.Sweepable)
@@ -244,7 +244,7 @@ public abstract class HttpDestination extends ContainerLifeCycle implements Dest
     @Override
     public void succeeded()
     {
-        send();
+        send(false);
     }
 
     @Override
@@ -253,15 +253,13 @@ public abstract class HttpDestination extends ContainerLifeCycle implements Dest
         abort(x);
     }
 
+    public void send(Request request, Response.CompleteListener listener)
+    {
+        ((HttpRequest)request).sendAsync(this, listener);
+    }
+
     protected void send(HttpRequest request, List<Response.ResponseListener> listeners)
     {
-        if (!getScheme().equalsIgnoreCase(request.getScheme()))
-            throw new IllegalArgumentException("Invalid request scheme " + request.getScheme() + " for destination " + this);
-        if (!getHost().equalsIgnoreCase(request.getHost()))
-            throw new IllegalArgumentException("Invalid request host " + request.getHost() + " for destination " + this);
-        int port = request.getPort();
-        if (port >= 0 && getPort() != port)
-            throw new IllegalArgumentException("Invalid request port " + port + " for destination " + this);
         send(new HttpExchange(this, request, listeners));
     }
 
@@ -308,25 +306,42 @@ public abstract class HttpDestination extends ContainerLifeCycle implements Dest
 
     public void send()
     {
-        if (getHttpExchanges().isEmpty())
-            return;
-        process();
+        send(true);
     }
 
-    private void process()
+    private void send(boolean create)
     {
+        if (!getHttpExchanges().isEmpty())
+            process(create);
+    }
+
+    private void process(boolean create)
+    {
+        // The loop is necessary in case of a new multiplexed connection,
+        // when a single thread notified of the connection opening must
+        // process all queued exchanges.
+        // It is also necessary when thread T1 cannot acquire a connection
+        // (for example, it has been stolen by thread T2 and the pool has
+        // enough pending reservations). T1 returns without doing anything
+        // and therefore it is T2 that must send both queued requests.
         while (true)
         {
-            Connection connection = connectionPool.acquire();
+            Connection connection;
+            if (connectionPool instanceof AbstractConnectionPool)
+                connection = ((AbstractConnectionPool)connectionPool).acquire(create);
+            else
+                connection = connectionPool.acquire();
             if (connection == null)
                 break;
             boolean proceed = process(connection);
-            if (!proceed)
+            if (proceed)
+                create = false;
+            else
                 break;
         }
     }
 
-    public boolean process(Connection connection)
+    private boolean process(Connection connection)
     {
         HttpClient client = getHttpClient();
         HttpExchange exchange = getHttpExchanges().poll();
@@ -353,31 +368,35 @@ public abstract class HttpDestination extends ContainerLifeCycle implements Dest
                 if (LOG.isDebugEnabled())
                     LOG.debug("Aborted before processing {}: {}", exchange, cause);
                 // Won't use this connection, release it back.
-                if (!connectionPool.release(connection))
+                boolean released = connectionPool.release(connection);
+                if (!released)
                     connection.close();
                 // It may happen that the request is aborted before the exchange
                 // is created. Aborting the exchange a second time will result in
                 // a no-operation, so we just abort here to cover that edge case.
                 exchange.abort(cause);
+                return getQueuedRequestCount() > 0;
             }
-            else
+
+            SendFailure failure = send(connection, exchange);
+            if (failure == null)
             {
-                SendFailure result = send(connection, exchange);
-                if (result != null)
-                {
-                    if (LOG.isDebugEnabled())
-                        LOG.debug("Send failed {} for {}", result, exchange);
-                    if (result.retry)
-                    {
-                        // Resend this exchange, likely on another connection,
-                        // and return false to avoid to re-enter this method.
-                        send(exchange);
-                        return false;
-                    }
-                    request.abort(result.failure);
-                }
+                // Aggressively send other queued requests
+                // in case connections are multiplexed.
+                return getQueuedRequestCount() > 0;
             }
-            return getHttpExchanges().peek() != null;
+
+            if (LOG.isDebugEnabled())
+                LOG.debug("Send failed {} for {}", failure, exchange);
+            if (failure.retry)
+            {
+                // Resend this exchange, likely on another connection,
+                // and return false to avoid to re-enter this method.
+                send(exchange);
+                return false;
+            }
+            request.abort(failure.failure);
+            return getQueuedRequestCount() > 0;
         }
     }
 
@@ -418,10 +437,16 @@ public abstract class HttpDestination extends ContainerLifeCycle implements Dest
         {
             if (connectionPool.isActive(connection))
             {
+                // Trigger the next request after releasing the connection.
                 if (connectionPool.release(connection))
-                    send();
+                {
+                    send(false);
+                }
                 else
+                {
                     connection.close();
+                    send(true);
+                }
             }
             else
             {
@@ -439,25 +464,30 @@ public abstract class HttpDestination extends ContainerLifeCycle implements Dest
 
     public boolean remove(Connection connection)
     {
-        return connectionPool.remove(connection);
-    }
-
-    public void close(Connection connection)
-    {
-        boolean removed = remove(connection);
+        boolean removed = connectionPool.remove(connection);
 
         if (getHttpExchanges().isEmpty())
         {
             tryRemoveIdleDestination();
         }
-        else
+        else if (removed)
         {
-            // We need to execute queued requests even if this connection failed.
-            // We may create a connection that is not needed, but it will eventually
-            // idle timeout, so no worries.
-            if (removed)
-                process();
+            // Process queued requests that may be waiting.
+            // We may create a connection that is not
+            // needed, but it will eventually idle timeout.
+            send(true);
         }
+        return removed;
+    }
+
+    /**
+     * @param connection the connection to remove
+     * @deprecated use {@link #remove(Connection)} instead
+     */
+    @Deprecated
+    public void close(Connection connection)
+    {
+        remove(connection);
     }
 
     /**
@@ -512,8 +542,8 @@ public abstract class HttpDestination extends ContainerLifeCycle implements Dest
             asString(),
             hashCode(),
             proxy == null ? "" : "(via " + proxy + ")",
-            exchanges.size(),
-            connectionPool);
+            getQueuedRequestCount(),
+            getConnectionPool());
     }
 
     /**
