@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -21,6 +21,7 @@ package org.eclipse.jetty.client;
 import java.io.IOException;
 import java.net.URI;
 import java.nio.ByteBuffer;
+import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.Iterator;
@@ -31,7 +32,6 @@ import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.atomic.AtomicReference;
 import java.util.function.LongConsumer;
 import java.util.function.LongUnaryOperator;
-import java.util.stream.Collectors;
 
 import org.eclipse.jetty.client.api.Response;
 import org.eclipse.jetty.client.api.Result;
@@ -187,7 +187,7 @@ public abstract class HttpReceiver
         {
             handlerListener = protocolHandler.getResponseListener();
             if (LOG.isDebugEnabled())
-                LOG.debug("Found protocol handler {}", protocolHandler);
+                LOG.debug("Response {} found protocol handler {}", response, protocolHandler);
         }
         exchange.getConversation().updateResponseListeners(handlerListener);
 
@@ -199,6 +199,7 @@ public abstract class HttpReceiver
         if (updateResponseState(ResponseState.TRANSIENT, ResponseState.BEGIN))
             return true;
 
+        dispose();
         terminateResponse(exchange);
         return false;
     }
@@ -217,25 +218,8 @@ public abstract class HttpReceiver
      */
     protected boolean responseHeader(HttpExchange exchange, HttpField field)
     {
-        out:
-        while (true)
-        {
-            ResponseState current = responseState.get();
-            switch (current)
-            {
-                case BEGIN:
-                case HEADER:
-                {
-                    if (updateResponseState(current, ResponseState.TRANSIENT))
-                        break out;
-                    break;
-                }
-                default:
-                {
-                    return false;
-                }
-            }
-        }
+        if (!updateResponseState(ResponseState.BEGIN, ResponseState.HEADER, ResponseState.TRANSIENT))
+            return false;
 
         HttpResponse response = exchange.getResponse();
         ResponseNotifier notifier = getHttpDestination().getResponseNotifier();
@@ -267,6 +251,7 @@ public abstract class HttpReceiver
         if (updateResponseState(ResponseState.TRANSIENT, ResponseState.HEADER))
             return true;
 
+        dispose();
         terminateResponse(exchange);
         return false;
     }
@@ -300,19 +285,8 @@ public abstract class HttpReceiver
      */
     protected boolean responseHeaders(HttpExchange exchange)
     {
-        while (true)
-        {
-            ResponseState current = responseState.get();
-            if (current == ResponseState.BEGIN || current == ResponseState.HEADER)
-            {
-                if (updateResponseState(current, ResponseState.TRANSIENT))
-                    break;
-            }
-            else
-            {
-                return false;
-            }
-        }
+        if (!updateResponseState(ResponseState.BEGIN, ResponseState.HEADER, ResponseState.TRANSIENT))
+            return false;
 
         HttpResponse response = exchange.getResponse();
         if (LOG.isDebugEnabled())
@@ -334,7 +308,7 @@ public abstract class HttpReceiver
                     {
                         if (factory.getEncoding().equalsIgnoreCase(encoding))
                         {
-                            decoder = new Decoder(response, factory.newContentDecoder());
+                            decoder = new Decoder(exchange, factory.newContentDecoder());
                             break;
                         }
                     }
@@ -346,10 +320,11 @@ public abstract class HttpReceiver
         {
             boolean hasDemand = hasDemandOrStall();
             if (LOG.isDebugEnabled())
-                LOG.debug("Response headers {}, hasDemand={}", response, hasDemand);
+                LOG.debug("Response headers hasDemand={} {}", hasDemand, response);
             return hasDemand;
         }
 
+        dispose();
         terminateResponse(exchange);
         return false;
     }
@@ -366,88 +341,51 @@ public abstract class HttpReceiver
      */
     protected boolean responseContent(HttpExchange exchange, ByteBuffer buffer, Callback callback)
     {
-        while (true)
-        {
-            ResponseState current = responseState.get();
-            if (current == ResponseState.HEADERS || current == ResponseState.CONTENT)
-            {
-                if (updateResponseState(current, ResponseState.TRANSIENT))
-                    break;
-            }
-            else
-            {
-                callback.failed(new IllegalStateException("Invalid response state " + current));
-                return false;
-            }
-        }
-
-        boolean proceed = true;
+        if (LOG.isDebugEnabled())
+            LOG.debug("Response content {}{}{}", exchange.getResponse(), System.lineSeparator(), BufferUtil.toDetailString(buffer));
         if (demand() <= 0)
         {
             callback.failed(new IllegalStateException("No demand for response content"));
-            proceed = false;
+            return false;
+        }
+        if (decoder == null)
+            return plainResponseContent(exchange, buffer, callback);
+        else
+            return decodeResponseContent(buffer, callback);
+    }
+
+    private boolean plainResponseContent(HttpExchange exchange, ByteBuffer buffer, Callback callback)
+    {
+        if (!updateResponseState(ResponseState.HEADERS, ResponseState.CONTENT, ResponseState.TRANSIENT))
+        {
+            callback.failed(new IllegalStateException("Invalid response state " + responseState));
+            return false;
         }
 
         HttpResponse response = exchange.getResponse();
-        if (proceed)
-        {
-            if (LOG.isDebugEnabled())
-                LOG.debug("Response content {}{}{}", response, System.lineSeparator(), BufferUtil.toDetailString(buffer));
-
-            ContentListeners listeners = this.contentListeners;
-            if (listeners != null)
-            {
-                if (listeners.isEmpty())
-                {
-                    callback.succeeded();
-                }
-                else
-                {
-                    Decoder decoder = this.decoder;
-                    if (decoder == null)
-                    {
-                        listeners.notifyContent(response, buffer, callback);
-                    }
-                    else
-                    {
-                        try
-                        {
-                            proceed = decoder.decode(buffer, callback);
-                        }
-                        catch (Throwable x)
-                        {
-                            callback.failed(x);
-                            proceed = false;
-                        }
-                    }
-                }
-            }
-            else
-            {
-                // May happen in case of concurrent abort.
-                proceed = false;
-            }
-        }
+        if (contentListeners.isEmpty())
+            callback.succeeded();
+        else
+            contentListeners.notifyContent(response, buffer, callback);
 
         if (updateResponseState(ResponseState.TRANSIENT, ResponseState.CONTENT))
         {
-            if (proceed)
-            {
-                boolean hasDemand = hasDemandOrStall();
-                if (LOG.isDebugEnabled())
-                    LOG.debug("Response content {}, hasDemand={}", response, hasDemand);
-                return hasDemand;
-            }
-            else
-            {
-                return false;
-            }
+            boolean hasDemand = hasDemandOrStall();
+            if (LOG.isDebugEnabled())
+                LOG.debug("Response content {}, hasDemand={}", response, hasDemand);
+            return hasDemand;
         }
 
+        dispose();
         terminateResponse(exchange);
         return false;
     }
 
+    private boolean decodeResponseContent(ByteBuffer buffer, Callback callback)
+    {
+        return decoder.decode(buffer, callback);
+    }
+
     /**
      * Method to be invoked when the response is successful.
      * <p>
@@ -567,6 +505,7 @@ public abstract class HttpReceiver
      */
     protected void dispose()
     {
+        assert responseState.get() != ResponseState.TRANSIENT;
         cleanup();
     }
 
@@ -598,7 +537,8 @@ public abstract class HttpReceiver
 
         this.failure = failure;
 
-        dispose();
+        if (terminate)
+            dispose();
 
         HttpResponse response = exchange.getResponse();
         if (LOG.isDebugEnabled())
@@ -625,15 +565,42 @@ public abstract class HttpReceiver
         }
     }
 
+    private boolean updateResponseState(ResponseState from1, ResponseState from2, ResponseState to)
+    {
+        while (true)
+        {
+            ResponseState current = responseState.get();
+            if (current == from1 || current == from2)
+            {
+                if (updateResponseState(current, to))
+                    return true;
+            }
+            else
+            {
+                if (LOG.isDebugEnabled())
+                    LOG.debug("State update failed: [{},{}] -> {}: {}", from1, from2, to, current);
+                return false;
+            }
+        }
+    }
+
     private boolean updateResponseState(ResponseState from, ResponseState to)
     {
-        boolean updated = responseState.compareAndSet(from, to);
-        if (!updated)
+        while (true)
         {
-            if (LOG.isDebugEnabled())
-                LOG.debug("State update failed: {} -> {}: {}", from, to, responseState.get());
+            ResponseState current = responseState.get();
+            if (current == from)
+            {
+                if (responseState.compareAndSet(current, to))
+                    return true;
+            }
+            else
+            {
+                if (LOG.isDebugEnabled())
+                    LOG.debug("State update failed: {} -> {}: {}", from, to, current);
+                return false;
+            }
         }
-        return updated;
     }
 
     @Override
@@ -693,10 +660,11 @@ public abstract class HttpReceiver
 
         private ContentListeners(List<Response.ResponseListener> responseListeners)
         {
-            listeners = responseListeners.stream()
+            listeners = new ArrayList<>(responseListeners.size());
+            responseListeners.stream()
                 .filter(Response.DemandedContentListener.class::isInstance)
                 .map(Response.DemandedContentListener.class::cast)
-                .collect(Collectors.toList());
+                .forEach(listeners::add);
         }
 
         private boolean isEmpty()
@@ -775,27 +743,75 @@ public abstract class HttpReceiver
      */
     private class Decoder implements Destroyable
     {
-        private final HttpResponse response;
+        private final HttpExchange exchange;
         private final ContentDecoder decoder;
         private ByteBuffer encoded;
         private Callback callback;
 
-        private Decoder(HttpResponse response, ContentDecoder decoder)
+        private Decoder(HttpExchange exchange, ContentDecoder decoder)
         {
-            this.response = response;
+            this.exchange = exchange;
             this.decoder = Objects.requireNonNull(decoder);
         }
 
         private boolean decode(ByteBuffer encoded, Callback callback)
         {
+            // Store the buffer to decode in case the
+            // decoding produces multiple decoded buffers.
             this.encoded = encoded;
             this.callback = callback;
-            return decode();
+
+            HttpResponse response = exchange.getResponse();
+            if (LOG.isDebugEnabled())
+                LOG.debug("Response content decoding {} with {}{}{}", response, decoder, System.lineSeparator(), BufferUtil.toDetailString(encoded));
+
+            boolean needInput = decode();
+            if (!needInput)
+                return false;
+
+            boolean hasDemand = hasDemandOrStall();
+            if (LOG.isDebugEnabled())
+                LOG.debug("Response content decoded, hasDemand={} {}", hasDemand, response);
+            return hasDemand;
         }
 
         private boolean decode()
         {
             while (true)
+            {
+                if (!updateResponseState(ResponseState.HEADERS, ResponseState.CONTENT, ResponseState.TRANSIENT))
+                {
+                    callback.failed(new IllegalStateException("Invalid response state " + responseState));
+                    return false;
+                }
+
+                DecodeResult result = decodeChunk();
+
+                if (updateResponseState(ResponseState.TRANSIENT, ResponseState.CONTENT))
+                {
+                    if (result == DecodeResult.NEED_INPUT)
+                        return true;
+                    if (result == DecodeResult.ABORT)
+                        return false;
+
+                    boolean hasDemand = hasDemandOrStall();
+                    if (LOG.isDebugEnabled())
+                        LOG.debug("Response content decoded chunk, hasDemand={} {}", hasDemand, exchange.getResponse());
+                    if (hasDemand)
+                        continue;
+                    else
+                        return false;
+                }
+
+                dispose();
+                terminateResponse(exchange);
+                return false;
+            }
+        }
+
+        private DecodeResult decodeChunk()
+        {
+            try
             {
                 ByteBuffer buffer;
                 while (true)
@@ -808,28 +824,41 @@ public abstract class HttpReceiver
                         callback.succeeded();
                         encoded = null;
                         callback = null;
-                        return true;
+                        return DecodeResult.NEED_INPUT;
                     }
                 }
+
                 ByteBuffer decoded = buffer;
+                HttpResponse response = exchange.getResponse();
                 if (LOG.isDebugEnabled())
-                    LOG.debug("Response content decoded ({}) {}{}{}", decoder, response, System.lineSeparator(), BufferUtil.toDetailString(decoded));
+                    LOG.debug("Response content decoded chunk {}{}{}", response, System.lineSeparator(), BufferUtil.toDetailString(decoded));
 
                 contentListeners.notifyContent(response, decoded, Callback.from(() -> decoder.release(decoded), callback::failed));
 
-                boolean hasDemand = hasDemandOrStall();
-                if (LOG.isDebugEnabled())
-                    LOG.debug("Response content decoded {}, hasDemand={}", response, hasDemand);
-                if (!hasDemand)
-                    return false;
+                return DecodeResult.DECODE;
+            }
+            catch (Throwable x)
+            {
+                callback.failed(x);
+                return DecodeResult.ABORT;
             }
         }
 
         private void resume()
         {
             if (LOG.isDebugEnabled())
-                LOG.debug("Response content resuming decoding {}", response);
-            if (decode())
+                LOG.debug("Response content resume decoding {} with {}", exchange.getResponse(), decoder);
+
+            // The content and callback may be null
+            // if there is no initial content demand.
+            if (callback == null)
+            {
+                receive();
+                return;
+            }
+
+            boolean needInput = decode();
+            if (needInput)
                 receive();
         }
 
@@ -840,4 +869,9 @@ public abstract class HttpReceiver
                 ((Destroyable)decoder).destroy();
         }
     }
+
+    private enum DecodeResult
+    {
+        DECODE, NEED_INPUT, ABORT
+    }
 }
