@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -67,8 +67,10 @@ public class HttpClientURITest extends AbstractHttpClientServerTest
         Assumptions.assumeTrue(Net.isIpv6InterfaceAvailable());
         start(scenario, new EmptyServerHandler());
 
-        String host = "::1";
-        Request request = client.newRequest(host, connector.getLocalPort())
+        String hostAddress = "::1";
+        String host = "[" + hostAddress + "]";
+        // Explicitly use a non-bracketed IPv6 host.
+        Request request = client.newRequest(hostAddress, connector.getLocalPort())
             .scheme(scenario.getScheme())
             .timeout(5, TimeUnit.SECONDS);
 
@@ -131,6 +133,26 @@ public class HttpClientURITest extends AbstractHttpClientServerTest
         }
     }
 
+    @ParameterizedTest
+    @ArgumentsSource(ScenarioProvider.class)
+    public void testHostPort(Scenario scenario) throws Exception
+    {
+        start(scenario, new EmptyServerHandler());
+
+        Request request = client.newRequest("domain.com", 80)
+            .scheme(scenario.getScheme())
+            .host("localhost")
+            .port(connector.getLocalPort())
+            .timeout(1, TimeUnit.SECONDS);
+
+        assertEquals("localhost", request.getHost());
+        assertEquals(connector.getLocalPort(), request.getPort());
+
+        ContentResponse response = request.send();
+
+        assertEquals(HttpStatus.OK_200, response.getStatus());
+    }
+
     @ParameterizedTest
     @ArgumentsSource(ScenarioProvider.class)
     public void testPath(Scenario scenario) throws Exception
