@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -30,8 +30,6 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
 import org.eclipse.jetty.client.api.Connection;
-import org.eclipse.jetty.client.api.Response;
-import org.eclipse.jetty.client.api.Result;
 import org.eclipse.jetty.client.http.HttpChannelOverHTTP;
 import org.eclipse.jetty.client.http.HttpClientTransportOverHTTP;
 import org.eclipse.jetty.client.http.HttpConnectionOverHTTP;
@@ -44,8 +42,10 @@ import org.eclipse.jetty.server.ServerConnector;
 import org.eclipse.jetty.server.handler.AbstractHandler;
 import org.eclipse.jetty.util.Promise;
 import org.eclipse.jetty.util.thread.QueuedThreadPool;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
+
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 public class HttpClientUploadDuringServerShutdown
 {
@@ -119,15 +119,8 @@ public class HttpClientUploadDuringServerShutdown
                 {
                     int length = 16 * 1024 * 1024 + random.nextInt(16 * 1024 * 1024);
                     client.newRequest("localhost", 8888)
-                            .content(new BytesContentProvider(new byte[length]))
-                            .send(new Response.CompleteListener()
-                            {
-                                @Override
-                                public void onComplete(Result result)
-                                {
-                                    latch.countDown();
-                                }
-                            });
+                        .content(new BytesContentProvider(new byte[length]))
+                        .send(result -> latch.countDown());
                     long sleep = 1 + random.nextInt(10);
                     TimeUnit.MILLISECONDS.sleep(sleep);
                 }
@@ -180,9 +173,7 @@ public class HttpClientUploadDuringServerShutdown
                             public void send()
                             {
                                 if (afterSetup.get())
-                                {
                                     associateLatch.countDown();
-                                }
                                 super.send();
                             }
                         };
@@ -226,7 +217,7 @@ public class HttpClientUploadDuringServerShutdown
 
         // Create one connection.
         client.newRequest("localhost", connector.getLocalPort()).send();
-        Assert.assertTrue(serverLatch.await(5, TimeUnit.SECONDS));
+        assertTrue(serverLatch.await(5, TimeUnit.SECONDS));
 
         afterSetup.set(true);
         Thread.sleep(1000);
@@ -238,42 +229,31 @@ public class HttpClientUploadDuringServerShutdown
 
         // Wait for close() so that the connection that
         // is being closed is used to send the request.
-        Assert.assertTrue(sendLatch.await(5, TimeUnit.SECONDS));
+        assertTrue(sendLatch.await(5, TimeUnit.SECONDS));
 
         final CountDownLatch completeLatch = new CountDownLatch(1);
         client.newRequest("localhost", connector.getLocalPort())
-                .timeout(10, TimeUnit.SECONDS)
-                .onRequestBegin(new org.eclipse.jetty.client.api.Request.BeginListener()
+            .timeout(10, TimeUnit.SECONDS)
+            .onRequestBegin(request ->
+            {
+                try
                 {
-                    @Override
-                    public void onBegin(org.eclipse.jetty.client.api.Request request)
-                    {
-                        try
-                        {
-                            beginLatch.countDown();
-                            completeLatch.await(5, TimeUnit.SECONDS);
-                        }
-                        catch (InterruptedException x)
-                        {
-                            x.printStackTrace();
-                        }
-                    }
-                })
-                .send(new Response.CompleteListener()
+                    beginLatch.countDown();
+                    completeLatch.await(5, TimeUnit.SECONDS);
+                }
+                catch (InterruptedException x)
                 {
-                    @Override
-                    public void onComplete(Result result)
-                    {
-                        completeLatch.countDown();
-                    }
-                });
+                    x.printStackTrace();
+                }
+            })
+            .send(result -> completeLatch.countDown());
 
-        Assert.assertTrue(completeLatch.await(5, TimeUnit.SECONDS));
+        assertTrue(completeLatch.await(5, TimeUnit.SECONDS));
 
         HttpDestinationOverHTTP destination = (HttpDestinationOverHTTP)client.getDestination("http", "localhost", connector.getLocalPort());
-        ConnectionPool pool = destination.getConnectionPool();
-        Assert.assertEquals(0, pool.getConnectionCount());
-        Assert.assertEquals(0, pool.getIdleConnections().size());
-        Assert.assertEquals(0, pool.getActiveConnections().size());
+        DuplexConnectionPool pool = (DuplexConnectionPool)destination.getConnectionPool();
+        assertEquals(0, pool.getConnectionCount());
+        assertEquals(0, pool.getIdleConnections().size());
+        assertEquals(0, pool.getActiveConnections().size());
     }
 }
