@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -27,9 +27,6 @@ import javax.servlet.ServletException;
 import javax.servlet.ServletRequest;
 import javax.servlet.ServletResponse;
 
-
-
-/* ------------------------------------------------------------ */
 /**
  * <p>ContinuationFilter must be applied to servlet paths that make use of
  * the asynchronous features provided by {@link Continuation} APIs, but that
@@ -47,7 +44,10 @@ import javax.servlet.ServletResponse;
  * {@link Continuation#complete()} is called.</p>
  * <p>Faux continuations are not threadless continuations (they are "faux" - fake - for this reason)
  * and as such they will scale less than proper continuations.</p>
+ *
+ * @deprecated use Servlet 3.0 {@link javax.servlet.AsyncContext} instead
  */
+@Deprecated
 public class ContinuationFilter implements Filter
 {
     static boolean _initialized;
@@ -57,65 +57,68 @@ public class ContinuationFilter implements Filter
     ServletContext _context;
     private boolean _debug;
 
+    @Override
     public void init(FilterConfig filterConfig) throws ServletException
     {
-        boolean jetty_7_or_greater="org.eclipse.jetty.servlet".equals(filterConfig.getClass().getPackage().getName());
+        filterConfig.getServletContext().log("WARNING: " + this.getClass().getName() + " is now DEPRECATED, use Servlet 3.0 AsyncContext instead.");
+        boolean jetty7OrGreater = "org.eclipse.jetty.servlet".equals(filterConfig.getClass().getPackage().getName());
         _context = filterConfig.getServletContext();
 
-        String param=filterConfig.getInitParameter("debug");
-        _debug=param!=null&&Boolean.parseBoolean(param);
+        String param = filterConfig.getInitParameter("debug");
+        _debug = param != null && Boolean.parseBoolean(param);
         if (_debug)
-            __debug=true;
+            __debug = true;
 
-        param=filterConfig.getInitParameter("partial");
-        param=filterConfig.getInitParameter("faux");
-        if (param!=null)
-            _faux=Boolean.parseBoolean(param);
+        param = filterConfig.getInitParameter("partial");
+        param = filterConfig.getInitParameter("faux");
+        if (param != null)
+            _faux = Boolean.parseBoolean(param);
         else
-            _faux=!(jetty_7_or_greater || _context.getMajorVersion()>=3);
+            _faux = !(jetty7OrGreater || _context.getMajorVersion() >= 3);
 
-        _filtered=_faux;
+        _filtered = _faux;
         if (_debug)
-            _context.log("ContinuationFilter "+
-                    " jetty="+jetty_7_or_greater+
-                    " faux="+_faux+
-                    " filtered="+_filtered+
-                    " servlet3="+ContinuationSupport.__servlet3);
-        _initialized=true;
+            _context.log("ContinuationFilter " +
+                " jetty=" + jetty7OrGreater +
+                " faux=" + _faux +
+                " filtered=" + _filtered +
+                " servlet3=" + ContinuationSupport.__servlet3);
+        _initialized = true;
     }
 
+    @Override
     public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain) throws IOException, ServletException
     {
         if (_filtered)
         {
-            Continuation c = (Continuation) request.getAttribute(Continuation.ATTRIBUTE);
+            Continuation c = (Continuation)request.getAttribute(Continuation.ATTRIBUTE);
             FilteredContinuation fc;
-            if (_faux && (c==null || !(c instanceof FauxContinuation)))
+            if (_faux && (c == null || !(c instanceof FauxContinuation)))
             {
                 fc = new FauxContinuation(request);
-                request.setAttribute(Continuation.ATTRIBUTE,fc);
+                request.setAttribute(Continuation.ATTRIBUTE, fc);
             }
             else
-                fc=(FilteredContinuation)c;
+                fc = (FilteredContinuation)c;
 
-            boolean complete=false;
+            boolean complete = false;
             while (!complete)
             {
                 try
                 {
-                    if (fc==null || (fc).enter(response))
-                        chain.doFilter(request,response);
+                    if (fc == null || (fc).enter(response))
+                        chain.doFilter(request, response);
                 }
                 catch (ContinuationThrowable e)
                 {
-                    debug("faux",e);
+                    debug("faux", e);
                 }
                 finally
                 {
-                    if (fc==null)
-                        fc = (FilteredContinuation) request.getAttribute(Continuation.ATTRIBUTE);
+                    if (fc == null)
+                        fc = (FilteredContinuation)request.getAttribute(Continuation.ATTRIBUTE);
 
-                    complete=fc==null || (fc).exit();
+                    complete = fc == null || (fc).exit();
                 }
             }
         }
@@ -123,11 +126,11 @@ public class ContinuationFilter implements Filter
         {
             try
             {
-                chain.doFilter(request,response);
+                chain.doFilter(request, response);
             }
             catch (ContinuationThrowable e)
             {
-                debug("caught",e);
+                debug("caught", e);
             }
         }
     }
@@ -145,12 +148,13 @@ public class ContinuationFilter implements Filter
         if (_debug)
         {
             if (th instanceof ContinuationThrowable)
-                _context.log(string+":"+th);
+                _context.log(string + ":" + th);
             else
-                _context.log(string,th);
+                _context.log(string, th);
         }
     }
 
+    @Override
     public void destroy()
     {
     }
@@ -158,6 +162,7 @@ public class ContinuationFilter implements Filter
     public interface FilteredContinuation extends Continuation
     {
         boolean enter(ServletResponse response);
+
         boolean exit();
     }
 }
