@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2019 Mort Bay Consulting Pty. Ltd.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -18,14 +18,6 @@
 
 package org.eclipse.jetty.fcgi.server;
 
-import static org.hamcrest.MatcherAssert.assertThat;
-import static org.hamcrest.Matchers.instanceOf;
-import static org.junit.jupiter.api.Assertions.assertArrayEquals;
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertThrows;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-
 import java.io.EOFException;
 import java.io.IOException;
 import java.net.URI;
@@ -40,7 +32,6 @@ import java.util.concurrent.TimeoutException;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicReference;
 import java.util.zip.GZIPOutputStream;
-
 import javax.servlet.ServletException;
 import javax.servlet.ServletOutputStream;
 import javax.servlet.http.HttpServletRequest;
@@ -57,15 +48,25 @@ import org.eclipse.jetty.http.HttpMethod;
 import org.eclipse.jetty.io.MappedByteBufferPool;
 import org.eclipse.jetty.server.handler.AbstractHandler;
 import org.eclipse.jetty.toolchain.test.IO;
+import org.eclipse.jetty.toolchain.test.Net;
 import org.eclipse.jetty.util.Callback;
 import org.eclipse.jetty.util.log.StacklessLogging;
-
-import org.junit.jupiter.api.Tag;
+import org.junit.jupiter.api.Assumptions;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.condition.DisabledIfSystemProperty;
 
+import static org.hamcrest.MatcherAssert.assertThat;
+import static org.hamcrest.Matchers.instanceOf;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 public class HttpClientTest extends AbstractHttpClientServerTest
 {
+    // @checkstyle-disable-check : AvoidEscapedUnicodeCharactersCheck
+
     @Test
     public void testGETResponseWithoutContent() throws Exception
     {
@@ -181,7 +182,9 @@ public class HttpClientTest extends AbstractHttpClientServerTest
                 ServletOutputStream output = response.getOutputStream();
                 String[] paramValues1 = request.getParameterValues(paramName1);
                 for (String paramValue : paramValues1)
+                {
                     output.write(paramValue.getBytes("UTF-8"));
+                }
                 String paramValue2 = request.getParameter(paramName2);
                 output.write(paramValue2.getBytes("UTF-8"));
                 baseRequest.setHandled(true);
@@ -225,9 +228,9 @@ public class HttpClientTest extends AbstractHttpClientServerTest
         });
 
         ContentResponse response = client.POST(scheme + "://localhost:" + connector.getLocalPort())
-                .param(paramName, paramValue)
-                .timeout(5, TimeUnit.SECONDS)
-                .send();
+            .param(paramName, paramValue)
+            .timeout(5, TimeUnit.SECONDS)
+            .send();
 
         assertNotNull(response);
         assertEquals(200, response.getStatus());
@@ -256,10 +259,10 @@ public class HttpClientTest extends AbstractHttpClientServerTest
         });
 
         String uri = scheme + "://localhost:" + connector.getLocalPort() +
-                "/?" + paramName + "=" + URLEncoder.encode(paramValue, "UTF-8");
+            "/?" + paramName + "=" + URLEncoder.encode(paramValue, "UTF-8");
         ContentResponse response = client.POST(uri)
-                .timeout(5, TimeUnit.SECONDS)
-                .send();
+            .timeout(5, TimeUnit.SECONDS)
+            .send();
 
         assertNotNull(response);
         assertEquals(200, response.getStatus());
@@ -289,9 +292,9 @@ public class HttpClientTest extends AbstractHttpClientServerTest
 
         URI uri = URI.create(scheme + "://localhost:" + connector.getLocalPort() + "/path?" + paramName + "=" + paramValue);
         ContentResponse response = client.newRequest(uri)
-                .method(HttpMethod.PUT)
-                .timeout(5, TimeUnit.SECONDS)
-                .send();
+            .method(HttpMethod.PUT)
+            .timeout(5, TimeUnit.SECONDS)
+            .send();
 
         assertNotNull(response);
         assertEquals(200, response.getStatus());
@@ -323,10 +326,10 @@ public class HttpClientTest extends AbstractHttpClientServerTest
         for (int i = 0; i < 256; ++i)
         {
             ContentResponse response = client.POST(scheme + "://localhost:" + connector.getLocalPort() + "/?b=1")
-                    .param(paramName, paramValue)
-                    .content(new BytesContentProvider(content))
-                    .timeout(5, TimeUnit.SECONDS)
-                    .send();
+                .param(paramName, paramValue)
+                .content(new BytesContentProvider(content))
+                .timeout(5, TimeUnit.SECONDS)
+                .send();
 
             assertNotNull(response);
             assertEquals(200, response.getStatus());
@@ -341,20 +344,20 @@ public class HttpClientTest extends AbstractHttpClientServerTest
         start(new EmptyServerHandler());
 
         ContentResponse response = client.POST(scheme + "://localhost:" + connector.getLocalPort())
-                .onRequestContent(new Request.ContentListener()
+            .onRequestContent(new Request.ContentListener()
+            {
+                @Override
+                public void onContent(Request request, ByteBuffer buffer)
                 {
-                    @Override
-                    public void onContent(Request request, ByteBuffer buffer)
-                    {
-                        byte[] bytes = new byte[buffer.remaining()];
-                        buffer.get(bytes);
-                        if (!Arrays.equals(content, bytes))
-                            request.abort(new Exception());
-                    }
-                })
-                .content(new BytesContentProvider(content))
-                .timeout(5, TimeUnit.SECONDS)
-                .send();
+                    byte[] bytes = new byte[buffer.remaining()];
+                    buffer.get(bytes);
+                    if (!Arrays.equals(content, bytes))
+                        request.abort(new Exception());
+                }
+            })
+            .content(new BytesContentProvider(content))
+            .timeout(5, TimeUnit.SECONDS)
+            .send();
 
         assertNotNull(response);
         assertEquals(200, response.getStatus());
@@ -367,20 +370,20 @@ public class HttpClientTest extends AbstractHttpClientServerTest
 
         final AtomicInteger progress = new AtomicInteger();
         ContentResponse response = client.POST(scheme + "://localhost:" + connector.getLocalPort())
-                .onRequestContent(new Request.ContentListener()
+            .onRequestContent(new Request.ContentListener()
+            {
+                @Override
+                public void onContent(Request request, ByteBuffer buffer)
                 {
-                    @Override
-                    public void onContent(Request request, ByteBuffer buffer)
-                    {
-                        byte[] bytes = new byte[buffer.remaining()];
-                        assertEquals(1, bytes.length);
-                        buffer.get(bytes);
-                        assertEquals(bytes[0], progress.getAndIncrement());
-                    }
-                })
-                .content(new BytesContentProvider(new byte[]{0}, new byte[]{1}, new byte[]{2}, new byte[]{3}, new byte[]{4}))
-                .timeout(5, TimeUnit.SECONDS)
-                .send();
+                    byte[] bytes = new byte[buffer.remaining()];
+                    assertEquals(1, bytes.length);
+                    buffer.get(bytes);
+                    assertEquals(bytes[0], progress.getAndIncrement());
+                }
+            })
+            .content(new BytesContentProvider(new byte[]{0}, new byte[]{1}, new byte[]{2}, new byte[]{3}, new byte[]{4}))
+            .timeout(5, TimeUnit.SECONDS)
+            .send();
 
         assertNotNull(response);
         assertEquals(200, response.getStatus());
@@ -410,9 +413,9 @@ public class HttpClientTest extends AbstractHttpClientServerTest
         });
 
         ContentResponse response = client.newRequest("localhost", connector.getLocalPort())
-                .scheme(scheme)
-                .timeout(5, TimeUnit.SECONDS)
-                .send();
+            .scheme(scheme)
+            .timeout(5, TimeUnit.SECONDS)
+            .send();
 
         assertEquals(200, response.getStatus());
         assertArrayEquals(data, response.getContent());
@@ -442,19 +445,20 @@ public class HttpClientTest extends AbstractHttpClientServerTest
 
         final String host = "localhost";
         final int port = connector.getLocalPort();
-        assertThrows(TimeoutException.class, ()->{
+        assertThrows(TimeoutException.class, () ->
+        {
             client.newRequest(host, port)
-                    .scheme(scheme)
-                    .idleTimeout(idleTimeout, TimeUnit.MILLISECONDS)
-                    .timeout(3 * idleTimeout, TimeUnit.MILLISECONDS)
-                    .send();
+                .scheme(scheme)
+                .idleTimeout(idleTimeout, TimeUnit.MILLISECONDS)
+                .timeout(3 * idleTimeout, TimeUnit.MILLISECONDS)
+                .send();
         });
 
         // Make another request without specifying the idle timeout, should not fail
         ContentResponse response = client.newRequest(host, port)
-                .scheme(scheme)
-                .timeout(3 * idleTimeout, TimeUnit.MILLISECONDS)
-                .send();
+            .scheme(scheme)
+            .timeout(3 * idleTimeout, TimeUnit.MILLISECONDS)
+            .send();
 
         assertNotNull(response);
         assertEquals(200, response.getStatus());
@@ -483,12 +487,13 @@ public class HttpClientTest extends AbstractHttpClientServerTest
 
         connector.setIdleTimeout(idleTimeout);
 
-        ExecutionException x = assertThrows(ExecutionException.class, ()->{
+        ExecutionException x = assertThrows(ExecutionException.class, () ->
+        {
             client.newRequest("localhost", connector.getLocalPort())
-                    .scheme(scheme)
-                    .idleTimeout(4 * idleTimeout, TimeUnit.MILLISECONDS)
-                    .timeout(3 * idleTimeout, TimeUnit.MILLISECONDS)
-                    .send();
+                .scheme(scheme)
+                .idleTimeout(4 * idleTimeout, TimeUnit.MILLISECONDS)
+                .timeout(3 * idleTimeout, TimeUnit.MILLISECONDS)
+                .send();
         });
         assertThat(x.getCause(), instanceOf(EOFException.class));
 
@@ -496,25 +501,25 @@ public class HttpClientTest extends AbstractHttpClientServerTest
 
         // Make another request to be sure the connection is recreated
         ContentResponse response = client.newRequest("localhost", connector.getLocalPort())
-                .scheme(scheme)
-                .idleTimeout(4 * idleTimeout, TimeUnit.MILLISECONDS)
-                .timeout(3 * idleTimeout, TimeUnit.MILLISECONDS)
-                .send();
+            .scheme(scheme)
+            .idleTimeout(4 * idleTimeout, TimeUnit.MILLISECONDS)
+            .timeout(3 * idleTimeout, TimeUnit.MILLISECONDS)
+            .send();
 
         assertNotNull(response);
         assertEquals(200, response.getStatus());
     }
 
     @Test
-    @Tag("ipv6")
     public void testSendToIPv6Address() throws Exception
     {
+        Assumptions.assumeTrue(Net.isIpv6InterfaceAvailable());
         start(new EmptyServerHandler());
 
         ContentResponse response = client.newRequest("[::1]", connector.getLocalPort())
-                .scheme(scheme)
-                .timeout(5, TimeUnit.SECONDS)
-                .send();
+            .scheme(scheme)
+            .timeout(5, TimeUnit.SECONDS)
+            .send();
 
         assertNotNull(response);
         assertEquals(200, response.getStatus());
@@ -537,10 +542,10 @@ public class HttpClientTest extends AbstractHttpClientServerTest
         // HEAD requests receive a Content-Length header, but do not
         // receive the content so they must handle this case properly
         ContentResponse response = client.newRequest("localhost", connector.getLocalPort())
-                .scheme(scheme)
-                .method(HttpMethod.HEAD)
-                .timeout(5, TimeUnit.SECONDS)
-                .send();
+            .scheme(scheme)
+            .method(HttpMethod.HEAD)
+            .timeout(5, TimeUnit.SECONDS)
+            .send();
 
         assertNotNull(response);
         assertEquals(200, response.getStatus());
@@ -548,9 +553,9 @@ public class HttpClientTest extends AbstractHttpClientServerTest
 
         // Perform a normal GET request to be sure the content is now read
         response = client.newRequest("localhost", connector.getLocalPort())
-                .scheme(scheme)
-                .timeout(5, TimeUnit.SECONDS)
-                .send();
+            .scheme(scheme)
+            .timeout(5, TimeUnit.SECONDS)
+            .send();
 
         assertNotNull(response);
         assertEquals(200, response.getStatus());
@@ -574,16 +579,16 @@ public class HttpClientTest extends AbstractHttpClientServerTest
 
         final CountDownLatch completeLatch = new CountDownLatch(1);
         client.newRequest("localhost", connector.getLocalPort())
-                .scheme(scheme)
-                .send(new Response.CompleteListener()
+            .scheme(scheme)
+            .send(new Response.CompleteListener()
+            {
+                @Override
+                public void onComplete(Result result)
                 {
-                    @Override
-                    public void onComplete(Result result)
-                    {
-                        if (result.isFailed())
-                            completeLatch.countDown();
-                    }
-                });
+                    if (result.isFailed())
+                        completeLatch.countDown();
+                }
+            });
 
         assertTrue(latch.await(5, TimeUnit.SECONDS));
 
@@ -611,11 +616,12 @@ public class HttpClientTest extends AbstractHttpClientServerTest
 
         try (StacklessLogging ignore = new StacklessLogging(org.eclipse.jetty.server.HttpChannel.class))
         {
-            assertThrows(ExecutionException.class, () -> {
+            assertThrows(ExecutionException.class, () ->
+            {
                 client.newRequest("localhost", connector.getLocalPort())
-                        .scheme(scheme)
-                        .timeout(60, TimeUnit.SECONDS)
-                        .send();
+                    .scheme(scheme)
+                    .timeout(60, TimeUnit.SECONDS)
+                    .send();
             });
         }
     }
@@ -649,8 +655,8 @@ public class HttpClientTest extends AbstractHttpClientServerTest
 
         DeferredContentProvider content = new DeferredContentProvider(ByteBuffer.wrap(new byte[]{0}));
         Request request = client.newRequest("localhost", connector.getLocalPort())
-                .scheme(scheme)
-                .content(content);
+            .scheme(scheme)
+            .content(content);
         FutureResponseListener listener = new FutureResponseListener(request);
         request.send(listener);
         // Wait some time to simulate a slow request.
@@ -683,25 +689,25 @@ public class HttpClientTest extends AbstractHttpClientServerTest
         final AtomicReference<CountDownLatch> contentLatch = new AtomicReference<>(new CountDownLatch(1));
         final CountDownLatch completeLatch = new CountDownLatch(1);
         client.newRequest("localhost", connector.getLocalPort())
-                .scheme(scheme)
-                .onResponseContentAsync(new Response.AsyncContentListener()
+            .scheme(scheme)
+            .onResponseContentAsync(new Response.AsyncContentListener()
+            {
+                @Override
+                public void onContent(Response response, ByteBuffer content, Callback callback)
                 {
-                    @Override
-                    public void onContent(Response response, ByteBuffer content, Callback callback)
-                    {
-                        contentCount.incrementAndGet();
-                        callbackRef.set(callback);
-                        contentLatch.get().countDown();
-                    }
-                })
-                .send(new Response.CompleteListener()
+                    contentCount.incrementAndGet();
+                    callbackRef.set(callback);
+                    contentLatch.get().countDown();
+                }
+            })
+            .send(new Response.CompleteListener()
+            {
+                @Override
+                public void onComplete(Result result)
                 {
-                    @Override
-                    public void onComplete(Result result)
-                    {
-                        completeLatch.countDown();
-                    }
-                });
+                    completeLatch.countDown();
+                }
+            });
 
         assertTrue(contentLatch.get().await(5, TimeUnit.SECONDS));
         Callback callback = callbackRef.get();
