@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2019 Mort Bay Consulting Pty. Ltd.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -16,7 +16,6 @@
 //  ========================================================================
 //
 
-
 package org.eclipse.jetty.gcloud.session;
 
 import java.io.ByteArrayOutputStream;
@@ -24,18 +23,6 @@ import java.io.ObjectOutputStream;
 import java.util.HashSet;
 import java.util.Set;
 
-import org.eclipse.jetty.server.session.AbstractSessionDataStore;
-import org.eclipse.jetty.server.session.SessionContext;
-import org.eclipse.jetty.server.session.SessionData;
-import org.eclipse.jetty.server.session.UnreadableSessionDataException;
-import org.eclipse.jetty.server.session.UnwriteableSessionDataException;
-import org.eclipse.jetty.util.ClassLoadingObjectInputStream;
-import org.eclipse.jetty.util.StringUtil;
-import org.eclipse.jetty.util.annotation.ManagedAttribute;
-import org.eclipse.jetty.util.annotation.ManagedObject;
-import org.eclipse.jetty.util.log.Log;
-import org.eclipse.jetty.util.log.Logger;
-
 import com.google.cloud.datastore.Blob;
 import com.google.cloud.datastore.BlobValue;
 import com.google.cloud.datastore.Datastore;
@@ -49,17 +36,25 @@ import com.google.cloud.datastore.Query;
 import com.google.cloud.datastore.QueryResults;
 import com.google.cloud.datastore.StructuredQuery.CompositeFilter;
 import com.google.cloud.datastore.StructuredQuery.PropertyFilter;
+import org.eclipse.jetty.server.session.AbstractSessionDataStore;
+import org.eclipse.jetty.server.session.SessionContext;
+import org.eclipse.jetty.server.session.SessionData;
+import org.eclipse.jetty.server.session.UnreadableSessionDataException;
+import org.eclipse.jetty.server.session.UnwriteableSessionDataException;
+import org.eclipse.jetty.util.ClassLoadingObjectInputStream;
+import org.eclipse.jetty.util.StringUtil;
+import org.eclipse.jetty.util.annotation.ManagedAttribute;
+import org.eclipse.jetty.util.annotation.ManagedObject;
+import org.eclipse.jetty.util.log.Log;
+import org.eclipse.jetty.util.log.Logger;
 
 /**
  * GCloudSessionDataStore
- *
- *
  */
 @ManagedObject
 public class GCloudSessionDataStore extends AbstractSessionDataStore
 {
-    private  final static Logger LOG = Log.getLogger("org.eclipse.jetty.server.session");
-
+    private static final Logger LOG = Log.getLogger("org.eclipse.jetty.server.session");
 
     public static final int DEFAULT_MAX_QUERY_RESULTS = 100;
     public static final int DEFAULT_MAX_RETRIES = 5;
@@ -76,11 +71,8 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
     protected EntityDataModel _model;
     protected boolean _modelProvided;
 
-
     private String _namespace;
-    
-    
-    
+
     /**
      * EntityDataModel
      *
@@ -88,18 +80,18 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
      */
     public static class EntityDataModel
     {
-        public  static final String ID = "id";
-        public  static final String CONTEXTPATH = "contextPath";
-        public  static final String VHOST = "vhost";
-        public  static final String ACCESSED = "accessed";
-        public  static final String LASTACCESSED = "lastAccessed";
-        public  static final String CREATETIME = "createTime";
-        public  static final  String COOKIESETTIME = "cookieSetTime";
-        public  static final String LASTNODE = "lastNode";
-        public  static final String EXPIRY = "expiry";
-        public  static final  String MAXINACTIVE = "maxInactive";
-        public  static final  String ATTRIBUTES = "attributes";
-        public  static final String LASTSAVED = "lastSaved";
+        public static final String ID = "id";
+        public static final String CONTEXTPATH = "contextPath";
+        public static final String VHOST = "vhost";
+        public static final String ACCESSED = "accessed";
+        public static final String LASTACCESSED = "lastAccessed";
+        public static final String CREATETIME = "createTime";
+        public static final String COOKIESETTIME = "cookieSetTime";
+        public static final String LASTNODE = "lastNode";
+        public static final String EXPIRY = "expiry";
+        public static final String MAXINACTIVE = "maxInactive";
+        public static final String ATTRIBUTES = "attributes";
+        public static final String LASTSAVED = "lastSaved";
 
         public static final String KIND = "GCloudSession";
         protected String _kind = KIND;
@@ -115,14 +107,13 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
         protected String _expiry = EXPIRY;
         protected String _maxInactive = MAXINACTIVE;
         protected String _attributes = ATTRIBUTES;
-        
-        
+
         private void checkNotNull(String s)
         {
             if (s == null)
                 throw new IllegalArgumentException(s);
         }
-        
+
         /**
          * @return the lastNode
          */
@@ -146,6 +137,7 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
         {
             return _kind;
         }
+
         /**
          * @param kind the kind to set
          */
@@ -154,6 +146,7 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
             checkNotNull(kind);
             _kind = kind;
         }
+
         /**
          * @return the id
          */
@@ -161,6 +154,7 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
         {
             return _id;
         }
+
         /**
          * @param id the id to set
          */
@@ -169,6 +163,7 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
             checkNotNull(id);
             _id = id;
         }
+
         /**
          * @return the contextPath
          */
@@ -176,6 +171,7 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
         {
             return _contextPath;
         }
+
         /**
          * @param contextPath the contextPath to set
          */
@@ -184,6 +180,7 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
             checkNotNull(contextPath);
             _contextPath = contextPath;
         }
+
         /**
          * @return the vhost
          */
@@ -191,6 +188,7 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
         {
             return _vhost;
         }
+
         /**
          * @param vhost the vhost to set
          */
@@ -199,6 +197,7 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
             checkNotNull(vhost);
             _vhost = vhost;
         }
+
         /**
          * @return the accessed
          */
@@ -206,6 +205,7 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
         {
             return _accessed;
         }
+
         /**
          * @param accessed the accessed to set
          */
@@ -214,6 +214,7 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
             checkNotNull(accessed);
             _accessed = accessed;
         }
+
         /**
          * @return the lastAccessed
          */
@@ -221,6 +222,7 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
         {
             return _lastAccessed;
         }
+
         /**
          * @param lastAccessed the lastAccessed to set
          */
@@ -229,6 +231,7 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
             checkNotNull(lastAccessed);
             _lastAccessed = lastAccessed;
         }
+
         /**
          * @return the createTime
          */
@@ -236,6 +239,7 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
         {
             return _createTime;
         }
+
         /**
          * @param createTime the createTime to set
          */
@@ -244,6 +248,7 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
             checkNotNull(createTime);
             _createTime = createTime;
         }
+
         /**
          * @return the cookieSetTime
          */
@@ -251,6 +256,7 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
         {
             return _cookieSetTime;
         }
+
         /**
          * @param cookieSetTime the cookieSetTime to set
          */
@@ -259,6 +265,7 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
             checkNotNull(cookieSetTime);
             _cookieSetTime = cookieSetTime;
         }
+
         /**
          * @return the expiry
          */
@@ -266,6 +273,7 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
         {
             return _expiry;
         }
+
         /**
          * @param expiry the expiry to set
          */
@@ -274,6 +282,7 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
             checkNotNull(expiry);
             _expiry = expiry;
         }
+
         /**
          * @return the maxInactive
          */
@@ -281,6 +290,7 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
         {
             return _maxInactive;
         }
+
         /**
          * @param maxInactive the maxInactive to set
          */
@@ -289,6 +299,7 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
             checkNotNull(maxInactive);
             _maxInactive = maxInactive;
         }
+
         /**
          * @return the attributes
          */
@@ -296,6 +307,7 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
         {
             return _attributes;
         }
+
         /**
          * @param attributes the attributes to set
          */
@@ -322,17 +334,14 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
             _lastSaved = lastSaved;
         }
 
-
         @Override
         public String toString()
         {
-            return String.format("%s==%s:%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s",this.getClass().getName(),
-                                 _kind,_accessed,_attributes,_contextPath,_cookieSetTime,_createTime,_expiry,_id,_lastAccessed,_lastNode,_maxInactive,_vhost);
+            return String.format("%s==%s:%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s", this.getClass().getName(),
+                _kind, _accessed, _attributes, _contextPath, _cookieSetTime, _createTime, _expiry, _id, _lastAccessed, _lastNode, _maxInactive, _vhost);
         }
- 
     }
-    
-    
+
     /**
      * ExpiryInfo
      *
@@ -343,13 +352,13 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
         String _id;
         String _lastNode;
         long _expiry;
-        
+
         /**
          * @param id session id
-         * @param lastNode  last node id to manage the session
-         * @param expiry  timestamp of expiry
+         * @param lastNode last node id to manage the session
+         * @param expiry timestamp of expiry
          */
-        public ExpiryInfo (String id, String lastNode, long expiry)
+        public ExpiryInfo(String id, String lastNode, long expiry)
         {
             _id = id;
             _lastNode = lastNode;
@@ -379,59 +388,53 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
         {
             return _expiry;
         }
-        
-        
     }
-    
+
     public void setEntityDataModel(EntityDataModel model)
     {
         updateBean(_model, model);
         _model = model;
         _modelProvided = true;
     }
-    
-    
-    public EntityDataModel getEntityDataModel ()
+
+    public EntityDataModel getEntityDataModel()
     {
         return _model;
     }
-    
-    
-    public void setBackoffMs (int ms)
+
+    public void setBackoffMs(int ms)
     {
         _backoff = ms;
     }
-    
-    public void setNamespace (String namespace)
+
+    public void setNamespace(String namespace)
     {
         _namespace = namespace;
     }
-    
-    @ManagedAttribute(value="gclound namespace", readonly=true)
-    public String getNamespace ()
+
+    @ManagedAttribute(value = "gclound namespace", readonly = true)
+    public String getNamespace()
     {
         return _namespace;
     }
-    
-    @ManagedAttribute(value="unit in ms of exponential backoff")
-    public int getBackoffMs ()
+
+    @ManagedAttribute(value = "unit in ms of exponential backoff")
+    public int getBackoffMs()
     {
         return _backoff;
     }
-    
-    
-    public void setMaxRetries (int retries)
+
+    public void setMaxRetries(int retries)
     {
         _maxRetries = retries;
     }
-    
-    @ManagedAttribute(value="max number of retries for failed writes")
-    public int getMaxRetries ()
+
+    @ManagedAttribute(value = "max number of retries for failed writes")
+    public int getMaxRetries()
     {
         return _maxRetries;
     }
 
-
     @Override
     protected void doStart() throws Exception
     {
@@ -446,19 +449,18 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
         if (_model == null)
         {
             _model = new EntityDataModel();
-            addBean(_model,true);
+            addBean(_model, true);
         }
 
-        _keyFactory = _datastore.newKeyFactory().setKind(_model.getKind());   
-        
+        _keyFactory = _datastore.newKeyFactory().setKind(_model.getKind());
+
         _indexesPresent = checkIndexes();
         if (!_indexesPresent)
             LOG.warn("Session indexes not uploaded, falling back to less efficient queries");
-        
+
         super.doStart();
     }
 
-
     @Override
     protected void doStop() throws Exception
     {
@@ -468,20 +470,19 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
         if (!_modelProvided)
             _model = null;
     }
-    
-    public void setDatastore (Datastore datastore)
+
+    public void setDatastore(Datastore datastore)
     {
         _datastore = datastore;
         _dsProvided = true;
     }
-    
-    @ManagedAttribute(value="max number of results to return from gcloud searches")
+
+    @ManagedAttribute(value = "max number of results to return from gcloud searches")
     public int getMaxResults()
     {
         return _maxResults;
     }
 
-
     public void setMaxResults(int maxResults)
     {
         if (_maxResults <= 0)
@@ -489,19 +490,20 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
         else
             _maxResults = maxResults;
     }
-    
-    
+
     @Override
     public SessionData doLoad(String id) throws Exception
     {
-        if (LOG.isDebugEnabled()) LOG.debug("Loading session {} from DataStore", id);
+        if (LOG.isDebugEnabled())
+            LOG.debug("Loading session {} from DataStore", id);
 
         try
         {
             Entity entity = _datastore.get(makeKey(id, _context));
             if (entity == null)
             {
-                if (LOG.isDebugEnabled()) LOG.debug("No session {} in DataStore ", id);
+                if (LOG.isDebugEnabled())
+                    LOG.debug("No session {} in DataStore ", id);
                 return null;
             }
             else
@@ -515,16 +517,15 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
         }
     }
 
-
     @Override
     public boolean delete(String id) throws Exception
     {
-        if (LOG.isDebugEnabled()) LOG.debug("Removing session {} from DataStore", id);
+        if (LOG.isDebugEnabled())
+            LOG.debug("Removing session {} from DataStore", id);
         _datastore.delete(makeKey(id, _context));
         return true;
     }
 
-
     @Override
     public Set<String> doGetExpired(Set<String> candidates)
     {
@@ -532,14 +533,14 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
         Set<String> expired = new HashSet<String>();
 
         try
-        {        
+        {
             Set<ExpiryInfo> info = null;
             if (_indexesPresent)
                 info = queryExpiryByIndex();
             else
                 info = queryExpiryByEntity();
-   
-            for (ExpiryInfo item:info)
+
+            for (ExpiryInfo item : info)
             {
                 if (StringUtil.isBlank(item.getLastNode()))
                 {
@@ -558,7 +559,8 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
                             //our first check, just look for sessions that we managed by another node that
                             //expired at least 3 graceperiods ago
                             if (item.getExpiry() < (now - (1000L * (3 * _gracePeriodSec))))
-                                expired.add(item.getId());                        }
+                                expired.add(item.getId());
+                        }
                         else
                         {
                             //another node was last managing it, only expire it if it expired a graceperiod ago
@@ -571,22 +573,22 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
 
             //reconcile against ids that the SessionCache thinks are expired
             Set<String> tmp = new HashSet<String>(candidates);
-            tmp.removeAll(expired);       
+            tmp.removeAll(expired);
             if (!tmp.isEmpty())
             {
                 //sessionstore thinks these are expired, but they are either no
                 //longer in the db or not expired in the db, or we exceeded the
                 //number of records retrieved by the expiry query, so check them
                 //individually
-                for (String s:tmp)
+                for (String s : tmp)
                 {
                     try
                     {
                         Query<Key> q = Query.newKeyQueryBuilder()
-                                .setKind(_model.getKind())
-                                .setFilter(PropertyFilter.eq(_model.getId(), s))
-                                .build();
-                       QueryResults<Key> res = _datastore.run(q);
+                            .setKind(_model.getKind())
+                            .setFilter(PropertyFilter.eq(_model.getId(), s))
+                            .build();
+                        QueryResults<Key> res = _datastore.run(q);
                         if (!res.hasNext())
                             expired.add(s); //not in db, can be expired
                     }
@@ -604,70 +606,70 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
             LOG.warn(e);
             return expired; //return what we got
         }
-
     }
 
-
     /**
      * A less efficient query to find sessions whose expiry time has passed:
      * retrieves the whole Entity.
-     * @return set of ExpiryInfo representing the id, lastNode and expiry time of 
+     *
+     * @return set of ExpiryInfo representing the id, lastNode and expiry time of
      * sessions that are expired
      * @throws Exception if datastore experiences a problem
      */
-    protected Set<ExpiryInfo> queryExpiryByEntity () throws Exception
+    protected Set<ExpiryInfo> queryExpiryByEntity() throws Exception
     {
         Set<ExpiryInfo> info = new HashSet<>();
 
         //get up to maxResult number of sessions that have expired
         Query<Entity> query = Query.newEntityQueryBuilder()
-                .setKind(_model.getKind())
-                .setFilter(CompositeFilter.and(PropertyFilter.gt(_model.getExpiry(), 0), PropertyFilter.le(_model.getExpiry(), System.currentTimeMillis())))
-                .setLimit(_maxResults)
-                .build();
+            .setKind(_model.getKind())
+            .setFilter(CompositeFilter.and(PropertyFilter.gt(_model.getExpiry(), 0), PropertyFilter.le(_model.getExpiry(), System.currentTimeMillis())))
+            .setLimit(_maxResults)
+            .build();
 
         QueryResults<Entity> results;
         if (LOG.isDebugEnabled())
         {
             long start = System.currentTimeMillis();
             results = _datastore.run(query);
-            LOG.debug("Expiry query no index in {}ms", System.currentTimeMillis()-start);
+            LOG.debug("Expiry query no index in {}ms", System.currentTimeMillis() - start);
         }
         else
             results = _datastore.run(query);
         while (results.hasNext())
         {
             Entity entity = results.next();
-            info.add(new ExpiryInfo(entity.getString(_model.getId()),entity.getString(_model.getLastNode()), entity.getLong(_model.getExpiry())));
+            info.add(new ExpiryInfo(entity.getString(_model.getId()), entity.getString(_model.getLastNode()), entity.getLong(_model.getExpiry())));
         }
 
         return info;
     }
 
-    
-    /** An efficient query to find sessions whose expiry time has passed:
+    /**
+     * An efficient query to find sessions whose expiry time has passed:
      * uses a projection query, which requires indexes to be uploaded.
-     * @return id,lastnode and expiry time of sessions that have expired
+     *
+     * @return id, lastnode and expiry time of sessions that have expired
      * @throws Exception if datastore experiences a problem
      */
-    protected Set<ExpiryInfo>  queryExpiryByIndex () throws Exception
+    protected Set<ExpiryInfo> queryExpiryByIndex() throws Exception
     {
         long now = System.currentTimeMillis();
         Set<ExpiryInfo> info = new HashSet<>();
         Query<ProjectionEntity> query = Query.newProjectionEntityQueryBuilder()
-                .setKind(_model.getKind())
-                .setProjection(_model.getId(), _model.getLastNode(), _model.getExpiry())
-                .setFilter(CompositeFilter.and(PropertyFilter.gt(_model.getExpiry(), 0), PropertyFilter.le(_model.getExpiry(), now)))
-                .setLimit(_maxResults)
-                .build();
+            .setKind(_model.getKind())
+            .setProjection(_model.getId(), _model.getLastNode(), _model.getExpiry())
+            .setFilter(CompositeFilter.and(PropertyFilter.gt(_model.getExpiry(), 0), PropertyFilter.le(_model.getExpiry(), now)))
+            .setLimit(_maxResults)
+            .build();
 
         QueryResults<ProjectionEntity> presults;
-        
+
         if (LOG.isDebugEnabled())
         {
             long start = System.currentTimeMillis();
             presults = _datastore.run(query);
-            LOG.debug("Expiry query by index in {}ms", System.currentTimeMillis()-start);
+            LOG.debug("Expiry query by index in {}ms", System.currentTimeMillis() - start);
         }
         else
             presults = _datastore.run(query);
@@ -675,34 +677,32 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
         while (presults.hasNext())
         {
             ProjectionEntity pe = presults.next();
-            info.add(new ExpiryInfo(pe.getString(_model.getId()),pe.getString(_model.getLastNode()), pe.getLong(_model.getExpiry())));
+            info.add(new ExpiryInfo(pe.getString(_model.getId()), pe.getString(_model.getLastNode()), pe.getLong(_model.getExpiry())));
         }
 
         return info;
     }
 
-
-
     @Override
     public boolean exists(String id) throws Exception
     {
         if (_indexesPresent)
         {
             Query<ProjectionEntity> query = Query.newProjectionEntityQueryBuilder()
-                    .setKind(_model.getKind())
-                    .setProjection(_model.getExpiry())
-                    .setFilter(CompositeFilter.and(PropertyFilter.eq(_model.getId(), id), 
-                                                   PropertyFilter.eq(_model.getContextPath(), _context.getCanonicalContextPath()),
-                                                   PropertyFilter.eq(_model.getVhost(), _context.getVhost())))
-                    //.setFilter(PropertyFilter.eq(_model.getId(), id))
-                    .build();
+                .setKind(_model.getKind())
+                .setProjection(_model.getExpiry())
+                .setFilter(CompositeFilter.and(PropertyFilter.eq(_model.getId(), id),
+                    PropertyFilter.eq(_model.getContextPath(), _context.getCanonicalContextPath()),
+                    PropertyFilter.eq(_model.getVhost(), _context.getVhost())))
+                //.setFilter(PropertyFilter.eq(_model.getId(), id))
+                .build();
 
             QueryResults<ProjectionEntity> presults;
             if (LOG.isDebugEnabled())
             {
                 long start = System.currentTimeMillis();
                 presults = _datastore.run(query);
-                LOG.debug("Exists query by index in {}ms", System.currentTimeMillis()-start);
+                LOG.debug("Exists query by index in {}ms", System.currentTimeMillis() - start);
             }
             else
                 presults = _datastore.run(query);
@@ -718,23 +718,23 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
         else
         {
             Query<Entity> query = Query.newEntityQueryBuilder()
-                    .setKind(_model.getKind())
-                    .setFilter(CompositeFilter.and(PropertyFilter.eq(_model.getId(), id), 
-                                                   PropertyFilter.eq(_model.getContextPath(), _context.getCanonicalContextPath()),
-                                                   PropertyFilter.eq(_model.getVhost(), _context.getVhost())))
-                    //.setFilter(PropertyFilter.eq(_model.getId(), id))
-                    .build();
-            
+                .setKind(_model.getKind())
+                .setFilter(CompositeFilter.and(PropertyFilter.eq(_model.getId(), id),
+                    PropertyFilter.eq(_model.getContextPath(), _context.getCanonicalContextPath()),
+                    PropertyFilter.eq(_model.getVhost(), _context.getVhost())))
+                //.setFilter(PropertyFilter.eq(_model.getId(), id))
+                .build();
+
             QueryResults<Entity> results;
             if (LOG.isDebugEnabled())
             {
                 long start = System.currentTimeMillis();
                 results = _datastore.run(query);
-                LOG.debug("Exists query no index in {}ms", System.currentTimeMillis()-start);
+                LOG.debug("Exists query no index in {}ms", System.currentTimeMillis() - start);
             }
             else
                 results = _datastore.run(query);
-           
+
             if (results.hasNext())
             {
                 Entity entity = results.next();
@@ -744,27 +744,26 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
                 return false;
         }
     }
-    
-    
+
     /**
      * Check to see if the given time is in the past.
-     * 
+     *
      * @param timestamp the time to check
      * @return false if the timestamp is 0 or less, true if it is in the past
      */
-    protected boolean isExpired (long timestamp)
+    protected boolean isExpired(long timestamp)
     {
         if (timestamp <= 0)
             return false;
-        else 
-            return timestamp < System.currentTimeMillis(); 
+        else
+            return timestamp < System.currentTimeMillis();
     }
 
-
     @Override
     public void doStore(String id, SessionData data, long lastSaveTime) throws Exception
     {
-        if (LOG.isDebugEnabled()) LOG.debug("Writing session {} to DataStore", data.getId());
+        if (LOG.isDebugEnabled())
+            LOG.debug("Writing session {} to DataStore", data.getId());
         Entity entity = entityFromSession(data, makeKey(id, _context));
 
         //attempt the update with exponential back-off
@@ -781,24 +780,25 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
             {
                 if (e.isRetryable())
                 {
-                    if (LOG.isDebugEnabled()) LOG.debug("Datastore put retry {} waiting {}ms", attempts, backoff);
-                        
+                    if (LOG.isDebugEnabled())
+                        LOG.debug(String.format("Datastore put retry=%s backoff=%s", attempts, backoff), e);
+
                     try
                     {
-                        Thread.currentThread().sleep(backoff);
+                        Thread.sleep(backoff);
                     }
-                    catch (InterruptedException x)
+                    catch (InterruptedException ignored)
                     {
                     }
                     backoff *= 2;
                 }
                 else
                 {
-                   throw e;
+                    throw e;
                 }
             }
         }
-        
+
         //retries have been exceeded
         throw new UnwriteableSessionDataException(id, _context, null);
     }
@@ -812,22 +812,21 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
      * <li>the context path</li>
      * <li>the virtual hosts</li>
      * </ol>
-     * 
      *
      * @param id the id
      * @param context the session context
      * @return the key
      */
-    protected Key makeKey (String id, SessionContext context)
+    protected Key makeKey(String id, SessionContext context)
     {
-        String key = context.getCanonicalContextPath()+"_"+context.getVhost()+"_"+id;
+        String key = context.getCanonicalContextPath() + "_" + context.getVhost() + "_" + id;
         return _keyFactory.newKey(key);
     }
 
-
     /**
      * Check to see if indexes are available, in which case
      * we can do more performant queries.
+     *
      * @return <code>true</code> if indexes are available
      */
     protected boolean checkIndexes()
@@ -835,10 +834,10 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
         try
         {
             Query<ProjectionEntity> query = Query.newProjectionEntityQueryBuilder()
-                    .setKind(_model.getKind())
-                    .setProjection(_model.getExpiry())
-                    .setFilter(PropertyFilter.eq(_model.getId(), "-"))
-                    .build();
+                .setKind(_model.getKind())
+                .setProjection(_model.getExpiry())
+                .setFilter(PropertyFilter.eq(_model.getId(), "-"))
+                .build();
             _datastore.run(query);
             return true;
         }
@@ -852,22 +851,22 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
             return false;
         }
     }
-    
-    
+
     /**
      * Generate a gcloud datastore Entity from SessionData
+     *
      * @param session the session data
      * @param key the key
      * @return the entity
      * @throws Exception if there is a deserialization error
      */
-    protected Entity entityFromSession (SessionData session, Key key) throws Exception
+    protected Entity entityFromSession(SessionData session, Key key) throws Exception
     {
         if (session == null)
             return null;
-        
+
         Entity entity = null;
-        
+
         //serialize the attribute map
         try (ByteArrayOutputStream baos = new ByteArrayOutputStream();
              ObjectOutputStream oos = new ObjectOutputStream(baos))
@@ -876,29 +875,30 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
 
             //turn a session into an entity         
             entity = Entity.newBuilder(key)
-                    .set(_model.getId(), session.getId())
-                    .set(_model.getContextPath(), session.getContextPath())
-                    .set(_model.getVhost(), session.getVhost())
-                    .set(_model.getAccessed(), session.getAccessed())
-                    .set(_model.getLastAccessed(), session.getLastAccessed())
-                    .set(_model.getCreateTime(), session.getCreated())
-                    .set(_model.getCookieSetTime(), session.getCookieSet())
-                    .set(_model.getLastNode(),session.getLastNode())
-                    .set(_model.getExpiry(), session.getExpiry())
-                    .set(_model.getMaxInactive(), session.getMaxInactiveMs())
-                    .set(_model.getLastSaved(), session.getLastSaved())
-                    .set(_model.getAttributes(), BlobValue.newBuilder(Blob.copyFrom(baos.toByteArray())).setExcludeFromIndexes(true).build()).build();
+                .set(_model.getId(), session.getId())
+                .set(_model.getContextPath(), session.getContextPath())
+                .set(_model.getVhost(), session.getVhost())
+                .set(_model.getAccessed(), session.getAccessed())
+                .set(_model.getLastAccessed(), session.getLastAccessed())
+                .set(_model.getCreateTime(), session.getCreated())
+                .set(_model.getCookieSetTime(), session.getCookieSet())
+                .set(_model.getLastNode(), session.getLastNode())
+                .set(_model.getExpiry(), session.getExpiry())
+                .set(_model.getMaxInactive(), session.getMaxInactiveMs())
+                .set(_model.getLastSaved(), session.getLastSaved())
+                .set(_model.getAttributes(), BlobValue.newBuilder(Blob.copyFrom(baos.toByteArray())).setExcludeFromIndexes(true).build()).build();
             return entity;
         }
     }
-    
+
     /**
      * Generate SessionData from an Entity retrieved from gcloud datastore.
+     *
      * @param entity the entity
      * @return the session data
      * @throws Exception if unable to get the entity
      */
-    protected SessionData sessionFromEntity (Entity entity) throws Exception
+    protected SessionData sessionFromEntity(Entity entity) throws Exception
     {
         if (entity == null)
             return null;
@@ -925,9 +925,9 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
         }
         long expiry = entity.getLong(_model.getExpiry());
         long maxInactive = entity.getLong(_model.getMaxInactive());
-        Blob blob = (Blob) entity.getBlob(_model.getAttributes());
+        Blob blob = entity.getBlob(_model.getAttributes());
 
-        SessionData session = newSessionData (id, createTime, accessed, lastAccessed, maxInactive);
+        SessionData session = newSessionData(id, createTime, accessed, lastAccessed, maxInactive);
         session.setLastNode(lastNode);
         session.setContextPath(contextPath);
         session.setVhost(vhost);
@@ -941,25 +941,21 @@ public class GCloudSessionDataStore extends AbstractSessionDataStore
         }
         catch (Exception e)
         {
-            throw new UnreadableSessionDataException (id, _context, e);
+            throw new UnreadableSessionDataException(id, _context, e);
         }
         return session;
-
     }
 
-
-    @ManagedAttribute(value="does gcloud serialize session data", readonly=true)
+    @ManagedAttribute(value = "does gcloud serialize session data", readonly = true)
     @Override
     public boolean isPassivating()
     {
-       return true;
+        return true;
     }
 
-
     @Override
     public String toString()
     {
-        return String.format("%s[namespace=%s,backoff=%d,maxRetries=%d,maxResults=%d,indexes=%b]",super.toString(), _namespace, _backoff, _maxRetries, _maxResults,_indexesPresent);
+        return String.format("%s[namespace=%s,backoff=%d,maxRetries=%d,maxResults=%d,indexes=%b]", super.toString(), _namespace, _backoff, _maxRetries, _maxResults, _indexesPresent);
     }
-    
 }
