@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -19,6 +19,7 @@
 package org.eclipse.jetty.hazelcast.session;
 
 import java.io.IOException;
+import java.util.Arrays;
 
 import com.hazelcast.client.HazelcastClient;
 import com.hazelcast.client.config.ClientConfig;
@@ -34,6 +35,7 @@ import org.eclipse.jetty.server.session.SessionData;
 import org.eclipse.jetty.server.session.SessionDataStore;
 import org.eclipse.jetty.server.session.SessionDataStoreFactory;
 import org.eclipse.jetty.server.session.SessionHandler;
+import org.eclipse.jetty.util.StringUtil;
 
 /**
  * Factory to construct {@link HazelcastSessionDataStore}
@@ -57,6 +59,8 @@ public class HazelcastSessionDataStoreFactory
 
     private boolean scavengeZombies = false;
 
+    private String addresses;
+
     public boolean isScavengeZombies()
     {
         return scavengeZombies;
@@ -78,9 +82,15 @@ public class HazelcastSessionDataStoreFactory
             {
                 if (onlyClient)
                 {
-                    if (configurationLocation == null)
+                    if (StringUtil.isEmpty(configurationLocation))
                     {
                         ClientConfig config = new ClientConfig();
+
+                        if (addresses != null && !addresses.isEmpty())
+                        {
+                            config.getNetworkConfig().setAddresses(Arrays.asList(addresses.split(",")));
+                        }
+
                         SerializerConfig sc = new SerializerConfig()
                             .setImplementation(new SessionDataSerializer())
                             .setTypeClass(SessionData.class);
@@ -96,7 +106,7 @@ public class HazelcastSessionDataStoreFactory
                 else
                 {
                     Config config;
-                    if (configurationLocation == null)
+                    if (StringUtil.isEmpty(configurationLocation))
                     {
 
                         SerializerConfig sc = new SerializerConfig()
@@ -201,4 +211,14 @@ public class HazelcastSessionDataStoreFactory
     {
         this.hazelcastInstanceName = hazelcastInstanceName;
     }
+
+    public String getAddresses()
+    {
+        return addresses;
+    }
+
+    public void setAddresses(String addresses)
+    {
+        this.addresses = addresses;
+    }
 }
