@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -18,8 +18,29 @@
 
 package org.eclipse.jetty.http;
 
+import java.io.InputStream;
+import java.net.MalformedURLException;
+import java.net.URL;
+import java.util.Collections;
+import java.util.Enumeration;
+import java.util.EventListener;
+import java.util.HashMap;
+import java.util.Map;
+import java.util.Set;
 import java.util.stream.Stream;
+import javax.servlet.Filter;
+import javax.servlet.FilterRegistration;
+import javax.servlet.RequestDispatcher;
+import javax.servlet.Servlet;
+import javax.servlet.ServletContext;
+import javax.servlet.ServletException;
+import javax.servlet.ServletRegistration;
+import javax.servlet.ServletRegistration.Dynamic;
+import javax.servlet.SessionCookieConfig;
+import javax.servlet.SessionTrackingMode;
+import javax.servlet.descriptor.JspConfigDescriptor;
 
+import org.eclipse.jetty.http.HttpCookie.SameSite;
 import org.hamcrest.Matchers;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.params.ParameterizedTest;
@@ -40,7 +61,340 @@ import static org.junit.jupiter.api.Assertions.assertTrue;
 
 public class HttpCookieTest
 {
+    public static class TestServletContext implements ServletContext
+    {
+        private Map<String, Object> _attributes = new HashMap<>();
+        
+        @Override
+        public String getContextPath()
+        {
+            return null;
+        }
 
+        @Override
+        public ServletContext getContext(String uripath)
+        {
+            return null;
+        }
+
+        @Override
+        public int getMajorVersion()
+        {
+            return 0;
+        }
+
+        @Override
+        public int getMinorVersion()
+        {
+            return 0;
+        }
+
+        @Override
+        public int getEffectiveMajorVersion()
+        {
+            return 0;
+        }
+
+        @Override
+        public int getEffectiveMinorVersion()
+        {
+            return 0;
+        }
+
+        @Override
+        public String getMimeType(String file)
+        {
+            return null;
+        }
+
+        @Override
+        public Set<String> getResourcePaths(String path)
+        {
+            return null;
+        }
+
+        @Override
+        public URL getResource(String path) throws MalformedURLException
+        {
+            return null;
+        }
+
+        @Override
+        public InputStream getResourceAsStream(String path)
+        {
+            return null;
+        }
+
+        @Override
+        public RequestDispatcher getRequestDispatcher(String path)
+        {
+            return null;
+        }
+
+        @Override
+        public RequestDispatcher getNamedDispatcher(String name)
+        {
+            return null;
+        }
+
+        @Override
+        public Servlet getServlet(String name) throws ServletException
+        {
+            return null;
+        }
+
+        @Override
+        public Enumeration<Servlet> getServlets()
+        {
+            return null;
+        }
+
+        @Override
+        public Enumeration<String> getServletNames()
+        {
+            return null;
+        }
+
+        @Override
+        public void log(String msg)
+        {        
+        }
+
+        @Override
+        public void log(Exception exception, String msg)
+        {
+        }
+
+        @Override
+        public void log(String message, Throwable throwable)
+        { 
+        }
+
+        @Override
+        public String getRealPath(String path)
+        {
+            return null;
+        }
+
+        @Override
+        public String getServerInfo()
+        {
+            return null;
+        }
+
+        @Override
+        public String getInitParameter(String name)
+        {
+            return null;
+        }
+
+        @Override
+        public Enumeration<String> getInitParameterNames()
+        {
+            return null;
+        }
+
+        @Override
+        public boolean setInitParameter(String name, String value)
+        {
+            return false;
+        }
+
+        @Override
+        public Object getAttribute(String name)
+        {
+            return _attributes.get(name);
+        }
+
+        @Override
+        public Enumeration<String> getAttributeNames()
+        {
+            return Collections.enumeration(_attributes.keySet());
+        }
+
+        @Override
+        public void setAttribute(String name, Object object)
+        {
+            _attributes.put(name, object);
+        }
+
+        @Override
+        public void removeAttribute(String name)
+        {
+            _attributes.remove(name);
+        }
+
+        @Override
+        public String getServletContextName()
+        {
+            return null;
+        }
+
+        @Override
+        public Dynamic addServlet(String servletName, String className)
+        {
+            return null;
+        }
+
+        @Override
+        public Dynamic addServlet(String servletName, Servlet servlet)
+        {
+            return null;
+        }
+
+        @Override
+        public Dynamic addServlet(String servletName, Class<? extends Servlet> servletClass)
+        {
+            return null;
+        }
+
+        @Override
+        public <T extends Servlet> T createServlet(Class<T> clazz) throws ServletException
+        {
+            return null;
+        }
+
+        @Override
+        public ServletRegistration getServletRegistration(String servletName)
+        {
+            return null;
+        }
+
+        @Override
+        public Map<String, ? extends ServletRegistration> getServletRegistrations()
+        {
+            return null;
+        }
+
+        @Override
+        public javax.servlet.FilterRegistration.Dynamic addFilter(String filterName, String className)
+        {
+            return null;
+        }
+
+        @Override
+        public javax.servlet.FilterRegistration.Dynamic addFilter(String filterName, Filter filter)
+        {
+            return null;
+        }
+
+        @Override
+        public javax.servlet.FilterRegistration.Dynamic addFilter(String filterName, Class<? extends Filter> filterClass)
+        {
+            return null;
+        }
+
+        @Override
+        public <T extends Filter> T createFilter(Class<T> clazz) throws ServletException
+        {
+            return null;
+        }
+
+        @Override
+        public FilterRegistration getFilterRegistration(String filterName)
+        {
+            return null;
+        }
+
+        @Override
+        public Map<String, ? extends FilterRegistration> getFilterRegistrations()
+        {
+            return null;
+        }
+
+        @Override
+        public SessionCookieConfig getSessionCookieConfig()
+        {
+            return null;
+        }
+
+        @Override
+        public void setSessionTrackingModes(Set<SessionTrackingMode> sessionTrackingModes)
+        {
+        }
+
+        @Override
+        public Set<SessionTrackingMode> getDefaultSessionTrackingModes()
+        {
+            return null;
+        }
+
+        @Override
+        public Set<SessionTrackingMode> getEffectiveSessionTrackingModes()
+        {
+            return null;
+        }
+
+        @Override
+        public void addListener(String className)
+        {
+        }
+
+        @Override
+        public <T extends EventListener> void addListener(T t)
+        { 
+        }
+
+        @Override
+        public void addListener(Class<? extends EventListener> listenerClass)
+        {
+        }
+
+        @Override
+        public <T extends EventListener> T createListener(Class<T> clazz) throws ServletException
+        {
+            return null;
+        }
+
+        @Override
+        public JspConfigDescriptor getJspConfigDescriptor()
+        {
+            return null;
+        }
+
+        @Override
+        public ClassLoader getClassLoader()
+        {
+            return null;
+        }
+
+        @Override
+        public void declareRoles(String... roleNames)
+        {
+        }
+
+        @Override
+        public String getVirtualServerName()
+        {
+            return null;
+        }
+    }
+
+    @Test
+    public void testDefaultSameSite()
+    {
+        TestServletContext context = new TestServletContext();
+        //test null value for default
+        assertNull(HttpCookie.getSameSiteDefault(context));
+        
+        //test good value for default as SameSite enum
+        context.setAttribute(HttpCookie.SAME_SITE_DEFAULT_ATTRIBUTE, SameSite.LAX);
+        assertEquals(SameSite.LAX, HttpCookie.getSameSiteDefault(context));
+        
+        //test good value for default as String
+        context.setAttribute(HttpCookie.SAME_SITE_DEFAULT_ATTRIBUTE, "NONE");
+        assertEquals(SameSite.NONE, HttpCookie.getSameSiteDefault(context));
+        
+        //test case for default as String
+        context.setAttribute(HttpCookie.SAME_SITE_DEFAULT_ATTRIBUTE, "sTrIcT");
+        assertEquals(SameSite.STRICT, HttpCookie.getSameSiteDefault(context));
+        
+        //test bad value for default as String
+        context.setAttribute(HttpCookie.SAME_SITE_DEFAULT_ATTRIBUTE, "fooBAR");
+        assertThrows(IllegalStateException.class,
+            () -> HttpCookie.getSameSiteDefault(context));
+    }
+    
     @Test
     public void testConstructFromSetCookie()
     {
