@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -451,6 +451,12 @@ public class HttpTester
                             header = BufferUtil.allocate(8192);
                             continue;
 
+                        case HEADER_OVERFLOW:
+                            if (header.capacity() >= 32 * 1024)
+                                throw new BadMessageException(500, "Header too large");
+                            header = BufferUtil.allocate(32 * 1024);
+                            continue;
+
                         case NEED_CHUNK:
                             chunk = BufferUtil.allocate(HttpGenerator.CHUNK_SIZE);
                             continue;
