@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -23,15 +23,20 @@ import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
+import java.nio.ByteBuffer;
+import java.nio.charset.StandardCharsets;
 import java.util.Base64;
 import java.util.Collection;
-import java.util.concurrent.TimeUnit;
+import java.util.concurrent.atomic.AtomicInteger;
 import javax.servlet.MultipartConfigElement;
 import javax.servlet.ReadListener;
 import javax.servlet.ServletInputStream;
 import javax.servlet.http.Part;
 
 import org.eclipse.jetty.http.MultiPartFormInputStream.MultiPart;
+import org.eclipse.jetty.toolchain.test.MavenTestingUtils;
+import org.eclipse.jetty.util.BlockingArrayQueue;
+import org.eclipse.jetty.util.BufferUtil;
 import org.eclipse.jetty.util.IO;
 import org.junit.jupiter.api.Test;
 
@@ -51,17 +56,14 @@ import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.junit.jupiter.api.Assertions.fail;
 
-/**
- * MultiPartInputStreamTest
- */
 public class MultiPartFormInputStreamTest
 {
+    private static final AtomicInteger testCounter = new AtomicInteger();
     private static final String FILENAME = "stuff.txt";
     protected String _contentType = "multipart/form-data, boundary=AaB03x";
     protected String _multi = createMultipartRequestString(FILENAME);
-    // TODO: move to testing dir concept
-    protected String _dirname = System.getProperty("java.io.tmpdir") + File.separator + "myfiles-" + TimeUnit.NANOSECONDS.toMillis(System.nanoTime());
-    protected File _tmpDir = new File(_dirname);
+    protected File _tmpDir = MavenTestingUtils.getTargetTestingDir(String.valueOf(testCounter.incrementAndGet()));
+    protected String _dirname = _tmpDir.getAbsolutePath();
 
     public MultiPartFormInputStreamTest()
     {
@@ -70,7 +72,6 @@ public class MultiPartFormInputStreamTest
 
     @Test
     public void testBadMultiPartRequest()
-        throws Exception
     {
         String boundary = "X0Y0";
         String str = "--" + boundary + "\r\n" +
@@ -89,14 +90,13 @@ public class MultiPartFormInputStreamTest
         mpis.setDeleteOnExit(true);
 
         IOException x = assertThrows(IOException.class,
-            () -> mpis.getParts(),
+            mpis::getParts,
             "Incomplete Multipart");
         assertThat(x.getMessage(), startsWith("Incomplete"));
     }
 
     @Test
-    public void testFinalBoundaryOnly()
-        throws Exception
+    public void testFinalBoundaryOnly() throws Exception
     {
         String delimiter = "\r\n";
         final String boundary = "MockMultiPartTestBoundary";
@@ -119,8 +119,7 @@ public class MultiPartFormInputStreamTest
     }
 
     @Test
-    public void testEmpty()
-        throws Exception
+    public void testEmpty() throws Exception
     {
         String delimiter = "\r\n";
         final String boundary = "MockMultiPartTestBoundary";
@@ -139,8 +138,7 @@ public class MultiPartFormInputStreamTest
     }
 
     @Test
-    public void testNoBoundaryRequest()
-        throws Exception
+    public void testNoBoundaryRequest() throws Exception
     {
         String str = "--\r\n" +
             "Content-Disposition: form-data; name=\"fileName\"\r\n" +
@@ -200,8 +198,7 @@ public class MultiPartFormInputStreamTest
     }
 
     @Test
-    public void testNonMultiPartRequest()
-        throws Exception
+    public void testNonMultiPartRequest() throws Exception
     {
         MultipartConfigElement config = new MultipartConfigElement(_dirname, 1024, 3072, 50);
         MultiPartFormInputStream mpis = new MultiPartFormInputStream(new ByteArrayInputStream(_multi.getBytes()),
@@ -214,7 +211,6 @@ public class MultiPartFormInputStreamTest
 
     @Test
     public void testNoBody()
-        throws Exception
     {
         String body = "";
 
@@ -225,13 +221,12 @@ public class MultiPartFormInputStreamTest
             _tmpDir);
         mpis.setDeleteOnExit(true);
 
-        IOException x = assertThrows(IOException.class, () -> mpis.getParts());
+        IOException x = assertThrows(IOException.class, mpis::getParts);
         assertThat(x.getMessage(), containsString("Missing initial multi part boundary"));
     }
 
     @Test
-    public void testBodyAlreadyConsumed()
-        throws Exception
+    public void testBodyAlreadyConsumed() throws Exception
     {
         ServletInputStream is = new ServletInputStream()
         {
@@ -272,7 +267,6 @@ public class MultiPartFormInputStreamTest
 
     @Test
     public void testWhitespaceBodyWithCRLF()
-        throws Exception
     {
         String whitespace = "              \n\n\n\r\n\r\n\r\n\r\n";
 
@@ -282,13 +276,12 @@ public class MultiPartFormInputStreamTest
             config,
             _tmpDir);
         mpis.setDeleteOnExit(true);
-        IOException x = assertThrows(IOException.class, () -> mpis.getParts());
+        IOException x = assertThrows(IOException.class, mpis::getParts);
         assertThat(x.getMessage(), containsString("Missing initial multi part boundary"));
     }
 
     @Test
     public void testWhitespaceBody()
-        throws Exception
     {
         String whitespace = " ";
 
@@ -298,13 +291,12 @@ public class MultiPartFormInputStreamTest
             config,
             _tmpDir);
         mpis.setDeleteOnExit(true);
-        IOException x = assertThrows(IOException.class, () -> mpis.getParts());
+        IOException x = assertThrows(IOException.class, mpis::getParts);
         assertThat(x.getMessage(), containsString("Missing initial"));
     }
 
     @Test
-    public void testLeadingWhitespaceBodyWithCRLF()
-        throws Exception
+    public void testLeadingWhitespaceBodyWithCRLF() throws Exception
     {
         String body = "              \n\n\n\r\n\r\n\r\n\r\n" +
             "--AaB03x\r\n" +
@@ -380,8 +372,7 @@ public class MultiPartFormInputStreamTest
     }
 
     @Test
-    public void testNoLimits()
-        throws Exception
+    public void testNoLimits() throws Exception
     {
         MultipartConfigElement config = new MultipartConfigElement(_dirname);
         MultiPartFormInputStream mpis = new MultiPartFormInputStream(new ByteArrayInputStream(_multi.getBytes()),
@@ -395,7 +386,6 @@ public class MultiPartFormInputStreamTest
 
     @Test
     public void testRequestTooBig()
-        throws Exception
     {
         MultipartConfigElement config = new MultipartConfigElement(_dirname, 60, 100, 50);
         MultiPartFormInputStream mpis = new MultiPartFormInputStream(new ByteArrayInputStream(_multi.getBytes()),
@@ -404,13 +394,12 @@ public class MultiPartFormInputStreamTest
             _tmpDir);
         mpis.setDeleteOnExit(true);
 
-        IllegalStateException x = assertThrows(IllegalStateException.class, () -> mpis.getParts());
+        IllegalStateException x = assertThrows(IllegalStateException.class, mpis::getParts);
         assertThat(x.getMessage(), containsString("Request exceeds maxRequestSize"));
     }
 
     @Test
     public void testRequestTooBigThrowsErrorOnGetParts()
-        throws Exception
     {
         MultipartConfigElement config = new MultipartConfigElement(_dirname, 60, 100, 50);
         MultiPartFormInputStream mpis = new MultiPartFormInputStream(new ByteArrayInputStream(_multi.getBytes()),
@@ -420,17 +409,16 @@ public class MultiPartFormInputStreamTest
         mpis.setDeleteOnExit(true);
 
         //cause parsing
-        IllegalStateException x = assertThrows(IllegalStateException.class, () -> mpis.getParts());
+        IllegalStateException x = assertThrows(IllegalStateException.class, mpis::getParts);
         assertThat(x.getMessage(), containsString("Request exceeds maxRequestSize"));
 
         //try again
-        x = assertThrows(IllegalStateException.class, () -> mpis.getParts());
+        x = assertThrows(IllegalStateException.class, mpis::getParts);
         assertThat(x.getMessage(), containsString("Request exceeds maxRequestSize"));
     }
 
     @Test
     public void testFileTooBig()
-        throws Exception
     {
         MultipartConfigElement config = new MultipartConfigElement(_dirname, 40, 1024, 30);
         MultiPartFormInputStream mpis = new MultiPartFormInputStream(new ByteArrayInputStream(_multi.getBytes()),
@@ -439,14 +427,13 @@ public class MultiPartFormInputStreamTest
             _tmpDir);
         mpis.setDeleteOnExit(true);
         IllegalStateException x = assertThrows(IllegalStateException.class,
-            () -> mpis.getParts(),
+            mpis::getParts,
             "stuff.txt should have been larger than maxFileSize");
         assertThat(x.getMessage(), startsWith("Multipart Mime part"));
     }
 
     @Test
     public void testFileTooBigThrowsErrorOnGetParts()
-        throws Exception
     {
         MultipartConfigElement config = new MultipartConfigElement(_dirname, 40, 1024, 30);
         MultiPartFormInputStream mpis = new MultiPartFormInputStream(new ByteArrayInputStream(_multi.getBytes()),
@@ -456,13 +443,13 @@ public class MultiPartFormInputStreamTest
         mpis.setDeleteOnExit(true);
         // Caused parsing
         IllegalStateException x = assertThrows(IllegalStateException.class,
-            () -> mpis.getParts(),
+            mpis::getParts,
             "stuff.txt should have been larger than maxFileSize");
         assertThat(x.getMessage(), startsWith("Multipart Mime part"));
 
         //test again after the parsing
         x = assertThrows(IllegalStateException.class,
-            () -> mpis.getParts(),
+            mpis::getParts,
             "stuff.txt should have been larger than maxFileSize");
         assertThat(x.getMessage(), startsWith("Multipart Mime part"));
     }
@@ -520,8 +507,7 @@ public class MultiPartFormInputStreamTest
     }
 
     @Test
-    public void testLFOnlyRequest()
-        throws Exception
+    public void testLFOnlyRequest() throws Exception
     {
         String str = "--AaB03x\n" +
             "content-disposition: form-data; name=\"field1\"\n" +
@@ -556,7 +542,6 @@ public class MultiPartFormInputStreamTest
 
     @Test
     public void testCROnlyRequest()
-        throws Exception
     {
         String str = "--AaB03x\r" +
             "content-disposition: form-data; name=\"field1\"\r" +
@@ -576,14 +561,13 @@ public class MultiPartFormInputStreamTest
         mpis.setDeleteOnExit(true);
 
         IllegalStateException x = assertThrows(IllegalStateException.class,
-            () -> mpis.getParts(),
+            mpis::getParts,
             "Improper EOL");
         assertThat(x.getMessage(), containsString("Bad EOL"));
     }
 
     @Test
     public void testCRandLFMixRequest()
-        throws Exception
     {
         String str = "--AaB03x\r" +
             "content-disposition: form-data; name=\"field1\"\r" +
@@ -604,7 +588,7 @@ public class MultiPartFormInputStreamTest
         mpis.setDeleteOnExit(true);
 
         IllegalStateException x = assertThrows(IllegalStateException.class,
-            () -> mpis.getParts(),
+            mpis::getParts,
             "Improper EOL");
         assertThat(x.getMessage(), containsString("Bad EOL"));
     }
@@ -626,7 +610,7 @@ public class MultiPartFormInputStreamTest
             _tmpDir);
         mpis.setDeleteOnExit(true);
         IllegalStateException x = assertThrows(IllegalStateException.class,
-            () -> mpis.getParts(),
+            mpis::getParts,
             "Header Line Exceeded Max Length");
         assertThat(x.getMessage(), containsString("Header Line Exceeded Max Length"));
     }
@@ -724,8 +708,7 @@ public class MultiPartFormInputStreamTest
     }
 
     @Test
-    public void testWriteFilesIfContentDispositionFilename()
-        throws Exception
+    public void testWriteFilesIfContentDispositionFilename() throws Exception
     {
         String s = "--AaB03x\r\n" +
             "content-disposition: form-data; name=\"field1\"; filename=\"frooble.txt\"\r\n" +
@@ -778,9 +761,9 @@ public class MultiPartFormInputStreamTest
         assertEquals("Joe Blow", new String(os.toByteArray()));
         assertEquals(8, field1.getSize());
 
-        assertNotNull(((MultiPartFormInputStream.MultiPart)field1).getBytes());//in internal buffer
+        assertNotNull(((MultiPartFormInputStream.MultiPart)field1).getBytes()); //in internal buffer
         field1.write("field1.txt");
-        assertNull(((MultiPartFormInputStream.MultiPart)field1).getBytes());//no longer in internal buffer
+        assertNull(((MultiPartFormInputStream.MultiPart)field1).getBytes()); //no longer in internal buffer
         File f = new File(_dirname + File.separator + "field1.txt");
         assertTrue(f.exists());
         field1.write("another_field1.txt"); //write after having already written
@@ -823,8 +806,7 @@ public class MultiPartFormInputStreamTest
     }
 
     @Test
-    public void testMultiSameNames()
-        throws Exception
+    public void testMultiSameNames() throws Exception
     {
         String sameNames = "--AaB03x\r\n" +
             "content-disposition: form-data; name=\"stuff\"; filename=\"stuff1.txt\"\r\n" +
@@ -907,6 +889,97 @@ public class MultiPartFormInputStreamTest
         assertEquals("the end", baos.toString("US-ASCII"));
     }
 
+    @Test
+    public void testFragmentation() throws IOException
+    {
+        String contentType = "multipart/form-data, boundary=----WebKitFormBoundaryhXfFAMfUnUKhmqT8";
+        String payload1 =
+            "------WebKitFormBoundaryhXfFAMfUnUKhmqT8\r\n" +
+                "Content-Disposition: form-data; name=\"field1\"\r\n\r\n" +
+                "value1" +
+                "\r\n--";
+        String payload2 = "----WebKitFormBoundaryhXfFAMfUnUKhmqT8\r\n" +
+            "Content-Disposition: form-data; name=\"field2\"\r\n\r\n" +
+            "value2" +
+            "\r\n------WebKitFormBoundaryhXfFAMfUnUKhmqT8--\r\n";
+
+        // Split the content into separate reads, with the content broken up on the boundary string.
+        AppendableInputStream stream = new AppendableInputStream();
+        stream.append(payload1);
+        stream.append("");
+        stream.append(payload2);
+        stream.endOfContent();
+
+        MultipartConfigElement config = new MultipartConfigElement(_dirname);
+        MultiPartFormInputStream mpis = new MultiPartFormInputStream(stream, contentType, config, _tmpDir);
+        mpis.setDeleteOnExit(true);
+
+        // Check size.
+        Collection<Part> parts = mpis.getParts();
+        assertThat(parts.size(), is(2));
+
+        // Check part content.
+        assertThat(IO.toString(mpis.getPart("field1").getInputStream()), is("value1"));
+        assertThat(IO.toString(mpis.getPart("field2").getInputStream()), is("value2"));
+    }
+
+    static class AppendableInputStream extends InputStream
+    {
+        private static final ByteBuffer EOF = ByteBuffer.allocate(0);
+        private final BlockingArrayQueue<ByteBuffer> buffers = new BlockingArrayQueue<>();
+        private ByteBuffer current;
+
+        public void append(String data)
+        {
+            append(data.getBytes(StandardCharsets.US_ASCII));
+        }
+
+        public void append(byte[] data)
+        {
+            buffers.add(BufferUtil.toBuffer(data));
+        }
+
+        public void endOfContent()
+        {
+            buffers.add(EOF);
+        }
+
+        @Override
+        public int read() throws IOException
+        {
+            byte[] buf = new byte[1];
+            while (true)
+            {
+                int len = read(buf, 0, 1);
+                if (len < 0)
+                    return -1;
+                if (len > 0)
+                    return buf[0];
+            }
+        }
+
+        @Override
+        public int read(byte[] b, int off, int len) throws IOException
+        {
+            if (current == null)
+                current = buffers.poll();
+            if (current == EOF)
+                return -1;
+            if (BufferUtil.isEmpty(current))
+            {
+                current = null;
+                return 0;
+            }
+
+            ByteBuffer buffer = ByteBuffer.wrap(b, off, len);
+            buffer.flip();
+            int read = BufferUtil.append(buffer, current);
+            if (BufferUtil.isEmpty(current))
+                current = buffers.poll();
+            return read;
+        }
+    }
+
     @Test
     public void testQuotedPrintableEncoding() throws Exception
     {
@@ -946,8 +1019,7 @@ public class MultiPartFormInputStreamTest
     }
 
     @Test
-    public void testGeneratedForm()
-        throws Exception
+    public void testGeneratedForm() throws Exception
     {
         String contentType = "multipart/form-data, boundary=WebKitFormBoundary7MA4YWf7OaKlSxkTrZu0gW";
         String body = "Content-Type: multipart/form-data; boundary=WebKitFormBoundary7MA4YWf7OaKlSxkTrZu0gW\r\n" +
