@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -21,7 +21,9 @@ package org.eclipse.jetty.http.pathmap;
 import org.junit.jupiter.api.Test;
 
 import static org.hamcrest.MatcherAssert.assertThat;
+import static org.hamcrest.Matchers.equalTo;
 import static org.hamcrest.Matchers.is;
+import static org.hamcrest.Matchers.not;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 
 public class RegexPathSpecTest
@@ -45,7 +47,7 @@ public class RegexPathSpecTest
         assertEquals("^/a$", spec.getDeclaration(), "Spec.pathSpec");
         assertEquals("^/a$", spec.getPattern().pattern(), "Spec.pattern");
         assertEquals(1, spec.getPathDepth(), "Spec.pathDepth");
-        assertEquals(PathSpecGroup.EXACT, spec.group, "Spec.group");
+        assertEquals(PathSpecGroup.EXACT, spec.getGroup(), "Spec.group");
 
         assertMatches(spec, "/a");
 
@@ -60,7 +62,7 @@ public class RegexPathSpecTest
         assertEquals("^/rest/([^/]*)/list$", spec.getDeclaration(), "Spec.pathSpec");
         assertEquals("^/rest/([^/]*)/list$", spec.getPattern().pattern(), "Spec.pattern");
         assertEquals(3, spec.getPathDepth(), "Spec.pathDepth");
-        assertEquals(PathSpecGroup.MIDDLE_GLOB, spec.group, "Spec.group");
+        assertEquals(PathSpecGroup.MIDDLE_GLOB, spec.getGroup(), "Spec.group");
 
         assertMatches(spec, "/rest/api/list");
         assertMatches(spec, "/rest/1.0/list");
@@ -81,7 +83,7 @@ public class RegexPathSpecTest
         assertEquals("^/rest/[^/]+/list$", spec.getDeclaration(), "Spec.pathSpec");
         assertEquals("^/rest/[^/]+/list$", spec.getPattern().pattern(), "Spec.pattern");
         assertEquals(3, spec.getPathDepth(), "Spec.pathDepth");
-        assertEquals(PathSpecGroup.MIDDLE_GLOB, spec.group, "Spec.group");
+        assertEquals(PathSpecGroup.MIDDLE_GLOB, spec.getGroup(), "Spec.group");
 
         assertMatches(spec, "/rest/api/list");
         assertMatches(spec, "/rest/1.0/list");
@@ -102,7 +104,7 @@ public class RegexPathSpecTest
         assertEquals("^/a/(.*)$", spec.getDeclaration(), "Spec.pathSpec");
         assertEquals("^/a/(.*)$", spec.getPattern().pattern(), "Spec.pattern");
         assertEquals(2, spec.getPathDepth(), "Spec.pathDepth");
-        assertEquals(PathSpecGroup.PREFIX_GLOB, spec.group, "Spec.group");
+        assertEquals(PathSpecGroup.PREFIX_GLOB, spec.getGroup(), "Spec.group");
 
         assertMatches(spec, "/a/");
         assertMatches(spec, "/a/b");
@@ -120,7 +122,7 @@ public class RegexPathSpecTest
         assertEquals("^(.*).do$", spec.getDeclaration(), "Spec.pathSpec");
         assertEquals("^(.*).do$", spec.getPattern().pattern(), "Spec.pattern");
         assertEquals(0, spec.getPathDepth(), "Spec.pathDepth");
-        assertEquals(PathSpecGroup.SUFFIX_GLOB, spec.group, "Spec.group");
+        assertEquals(PathSpecGroup.SUFFIX_GLOB, spec.getGroup(), "Spec.group");
 
         assertMatches(spec, "/a.do");
         assertMatches(spec, "/a/b/c.do");
@@ -132,4 +134,14 @@ public class RegexPathSpecTest
         assertNotMatches(spec, "/aa/bb");
         assertNotMatches(spec, "/aa/bb.do/more");
     }
+
+    @Test
+    public void testEquals()
+    {
+        assertThat(new RegexPathSpec("^(.*).do$"), equalTo(new RegexPathSpec("^(.*).do$")));
+        assertThat(new RegexPathSpec("/foo"), equalTo(new RegexPathSpec("/foo")));
+        assertThat(new RegexPathSpec("^(.*).do$"), not(equalTo(new RegexPathSpec("^(.*).gz$"))));
+        assertThat(new RegexPathSpec("^(.*).do$"), not(equalTo(new RegexPathSpec("^.*.do$"))));
+        assertThat(new RegexPathSpec("/foo"), not(equalTo(new ServletPathSpec("/foo"))));
+    }
 }
