@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -27,6 +27,7 @@ import java.nio.charset.Charset;
 import java.nio.charset.StandardCharsets;
 import java.util.ArrayDeque;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.Deque;
 import java.util.HashMap;
 import java.util.List;
@@ -38,6 +39,7 @@ import java.util.concurrent.TimeUnit;
 import java.util.concurrent.TimeoutException;
 import java.util.concurrent.atomic.AtomicLong;
 import java.util.concurrent.atomic.AtomicReference;
+import java.util.function.Consumer;
 import javax.servlet.AsyncContext;
 import javax.servlet.ServletOutputStream;
 import javax.servlet.WriteListener;
@@ -51,6 +53,7 @@ import org.eclipse.jetty.http.HttpStatus;
 import org.eclipse.jetty.http.HttpURI;
 import org.eclipse.jetty.http.HttpVersion;
 import org.eclipse.jetty.http.MetaData;
+import org.eclipse.jetty.http2.BufferingFlowControlStrategy;
 import org.eclipse.jetty.http2.ErrorCode;
 import org.eclipse.jetty.http2.FlowControlStrategy;
 import org.eclipse.jetty.http2.HTTP2Flusher;
@@ -61,6 +64,7 @@ import org.eclipse.jetty.http2.api.Session;
 import org.eclipse.jetty.http2.api.Stream;
 import org.eclipse.jetty.http2.api.server.ServerSessionListener;
 import org.eclipse.jetty.http2.frames.DataFrame;
+import org.eclipse.jetty.http2.frames.Frame;
 import org.eclipse.jetty.http2.frames.HeadersFrame;
 import org.eclipse.jetty.http2.frames.PrefaceFrame;
 import org.eclipse.jetty.http2.frames.ResetFrame;
@@ -196,14 +200,15 @@ public class StreamResetTest extends AbstractTest
                     {
                         // Simulate that there is pending data to send.
                         IStream stream = (IStream)s;
-                        stream.getSession().frames(stream, new Callback()
+                        List<Frame> frames = Collections.singletonList(new DataFrame(s.getId(), ByteBuffer.allocate(16), true));
+                        stream.getSession().frames(stream, frames, new Callback()
                         {
                             @Override
                             public void failed(Throwable x)
                             {
                                 serverResetLatch.countDown();
                             }
-                        }, new DataFrame(s.getId(), ByteBuffer.allocate(16), true));
+                        });
                     }
                 };
             }
@@ -1042,6 +1047,64 @@ public class StreamResetTest extends AbstractTest
         }
     }
 
+    @Test
+    public void testResetBeforeReceivingWindowUpdate() throws Exception
+    {
+        int window = FlowControlStrategy.DEFAULT_WINDOW_SIZE;
+        float ratio = 0.5F;
+        AtomicReference<Stream> streamRef = new AtomicReference<>();
+        Consumer<AbstractHTTP2ServerConnectionFactory> http2Factory = http2 ->
+        {
+            http2.setInitialSessionRecvWindow(window);
+            http2.setInitialStreamRecvWindow(window);
+            http2.setFlowControlStrategyFactory(() -> new BufferingFlowControlStrategy(ratio)
+            {
+                @Override
+                protected void sendWindowUpdate(IStream stream, ISession session, WindowUpdateFrame frame)
+                {
+                    // Before sending the window update, reset from the client side.
+                    if (stream != null)
+                        streamRef.get().reset(new ResetFrame(stream.getId(), ErrorCode.CANCEL_STREAM_ERROR.code), Callback.NOOP);
+                    super.sendWindowUpdate(stream, session, frame);
+                }
+            });
+        };
+        start(new ServerSessionListener.Adapter()
+        {
+            @Override
+            public Stream.Listener onNewStream(Stream stream, HeadersFrame frame)
+            {
+                MetaData.Response response = new MetaData.Response(HttpVersion.HTTP_2, 200, new HttpFields());
+                HeadersFrame responseFrame = new HeadersFrame(stream.getId(), response, null, false);
+                Callback.Completable completable = new Callback.Completable();
+                stream.headers(responseFrame, completable);
+                // Consume the request content as it arrives.
+                return new Stream.Listener.Adapter();
+            }
+        }, http2Factory);
+
+        CountDownLatch failureLatch = new CountDownLatch(1);
+        Session client = newClient(new Session.Listener.Adapter()
+        {
+            @Override
+            public void onFailure(Session session, Throwable failure)
+            {
+                failureLatch.countDown();
+            }
+        });
+        MetaData.Request request = newRequest("GET", new HttpFields());
+        HeadersFrame requestFrame = new HeadersFrame(request, null, false);
+        FuturePromise<Stream> promise = new FuturePromise<>();
+        client.newStream(requestFrame, promise, new Stream.Listener.Adapter());
+        Stream stream = promise.get(5, TimeUnit.SECONDS);
+        streamRef.set(stream);
+        // Send enough bytes to trigger the server to send a window update.
+        ByteBuffer content = ByteBuffer.allocate((int)(window * ratio) + 1024);
+        stream.data(new DataFrame(stream.getId(), content, false), Callback.NOOP);
+
+        assertFalse(failureLatch.await(1, TimeUnit.SECONDS));
+    }
+
     private void waitUntilTCPCongested(WriteFlusher flusher) throws TimeoutException, InterruptedException
     {
         long start = System.nanoTime();
