@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -71,6 +71,20 @@ public class HTTP2Connection extends AbstractConnection implements WriteFlusher.
         parser.init(ParserListener::new);
     }
 
+    @Override
+    public long getMessagesIn()
+    {
+        HTTP2Session session = (HTTP2Session)getSession();
+        return session.getStreamsOpened();
+    }
+
+    @Override
+    public long getMessagesOut()
+    {
+        HTTP2Session session = (HTTP2Session)getSession();
+        return session.getStreamsClosed();
+    }
+
     @Override
     public long getBytesIn()
     {
@@ -95,8 +109,7 @@ public class HTTP2Connection extends AbstractConnection implements WriteFlusher.
 
     protected void setInputBuffer(ByteBuffer buffer)
     {
-        if (buffer != null)
-            producer.setInputBuffer(buffer);
+        producer.setInputBuffer(buffer);
     }
 
     @Override
@@ -226,7 +239,7 @@ public class HTTP2Connection extends AbstractConnection implements WriteFlusher.
         {
             Runnable task = pollTask();
             if (LOG.isDebugEnabled())
-                LOG.debug("Dequeued task {}", task);
+                LOG.debug("Dequeued task {}", String.valueOf(task));
             if (task != null)
                 return task;
 
