@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -39,6 +39,7 @@ import org.eclipse.jetty.http2.frames.HeadersFrame;
 import org.eclipse.jetty.http2.frames.PushPromiseFrame;
 import org.eclipse.jetty.http2.frames.ResetFrame;
 import org.eclipse.jetty.http2.frames.WindowUpdateFrame;
+import org.eclipse.jetty.io.EofException;
 import org.eclipse.jetty.io.IdleTimeout;
 import org.eclipse.jetty.util.Callback;
 import org.eclipse.jetty.util.Promise;
@@ -54,16 +55,17 @@ public class HTTP2Stream extends IdleTimeout implements IStream, Callback, Dumpa
     private final AtomicReference<Object> attachment = new AtomicReference<>();
     private final AtomicReference<ConcurrentMap<String, Object>> attributes = new AtomicReference<>();
     private final AtomicReference<CloseState> closeState = new AtomicReference<>(CloseState.NOT_CLOSED);
-    private final AtomicReference<Callback> writing = new AtomicReference<>();
     private final AtomicInteger sendWindow = new AtomicInteger();
     private final AtomicInteger recvWindow = new AtomicInteger();
     private final long timeStamp = System.nanoTime();
     private final ISession session;
     private final int streamId;
     private final boolean local;
+    private Callback sendCallback;
+    private Throwable failure;
     private boolean localReset;
-    private Listener listener;
     private boolean remoteReset;
+    private Listener listener;
     private long dataLength;
 
     public HTTP2Stream(Scheduler scheduler, ISession session, int streamId, boolean local)
@@ -106,10 +108,16 @@ public class HTTP2Stream extends IdleTimeout implements IStream, Callback, Dumpa
     }
 
     @Override
-    public void headers(HeadersFrame frame, Callback callback)
+    public void send(FrameList frameList, Callback callback)
     {
         if (startWrite(callback))
-            session.frames(this, this, frame, Frame.EMPTY_ARRAY);
+            session.frames(this, frameList.getFrames(), this);
+    }
+
+    @Override
+    public void headers(HeadersFrame frame, Callback callback)
+    {
+        send(new FrameList(frame), callback);
     }
 
     @Override
@@ -128,18 +136,31 @@ public class HTTP2Stream extends IdleTimeout implements IStream, Callback, Dumpa
     @Override
     public void reset(ResetFrame frame, Callback callback)
     {
-        if (isReset())
-            return;
-        localReset = true;
-        session.frames(this, callback, frame, Frame.EMPTY_ARRAY);
+        synchronized (this)
+        {
+            if (isReset())
+                return;
+            localReset = true;
+            failure = new EOFException("reset");
+        }
+        ((HTTP2Session)session).reset(this, frame, callback);
     }
 
     private boolean startWrite(Callback callback)
     {
-        if (writing.compareAndSet(null, callback))
-            return true;
-        close();
-        callback.failed(new WritePendingException());
+        Throwable failure;
+        synchronized (this)
+        {
+            failure = this.failure;
+            if (failure == null && sendCallback == null)
+            {
+                sendCallback = callback;
+                return true;
+            }
+        }
+        if (failure == null)
+            failure = new WritePendingException();
+        callback.failed(failure);
         return false;
     }
 
@@ -164,7 +185,27 @@ public class HTTP2Stream extends IdleTimeout implements IStream, Callback, Dumpa
     @Override
     public boolean isReset()
     {
-        return localReset || remoteReset;
+        synchronized (this)
+        {
+            return localReset || remoteReset;
+        }
+    }
+
+    private boolean isFailed()
+    {
+        synchronized (this)
+        {
+            return failure != null;
+        }
+    }
+
+    @Override
+    public boolean isResetOrFailed()
+    {
+        synchronized (this)
+        {
+            return isReset() || isFailed();
+        }
     }
 
     @Override
@@ -177,7 +218,7 @@ public class HTTP2Stream extends IdleTimeout implements IStream, Callback, Dumpa
     public boolean isRemotelyClosed()
     {
         CloseState state = closeState.get();
-        return state == CloseState.REMOTELY_CLOSED || state == CloseState.CLOSING;
+        return state == CloseState.REMOTELY_CLOSED || state == CloseState.CLOSING || state == CloseState.CLOSED;
     }
 
     public boolean isLocallyClosed()
@@ -285,24 +326,11 @@ public class HTTP2Stream extends IdleTimeout implements IStream, Callback, Dumpa
                 length = fields.getLongField(HttpHeader.CONTENT_LENGTH.asString());
             dataLength = length >= 0 ? length : Long.MIN_VALUE;
         }
-
-        if (updateClose(frame.isEndStream(), CloseState.Event.RECEIVED))
-            session.removeStream(this);
-
         callback.succeeded();
     }
 
     private void onData(DataFrame frame, Callback callback)
     {
-        if (getRecvWindow() < 0)
-        {
-            // It's a bad client, it does not deserve to be
-            // treated gently by just resetting the stream.
-            session.close(ErrorCode.FLOW_CONTROL_ERROR.code, "stream_window_exceeded", Callback.NOOP);
-            callback.failed(new IOException("stream_window_exceeded"));
-            return;
-        }
-
         // SPEC: remotely closed streams must be replied with a reset.
         if (isRemotelyClosed())
         {
@@ -321,7 +349,7 @@ public class HTTP2Stream extends IdleTimeout implements IStream, Callback, Dumpa
         if (dataLength != Long.MIN_VALUE)
         {
             dataLength -= frame.remaining();
-            if (frame.isEndStream() && dataLength != 0)
+            if (dataLength < 0 || (frame.isEndStream() && dataLength != 0))
             {
                 reset(new ResetFrame(streamId, ErrorCode.PROTOCOL_ERROR.code), Callback.NOOP);
                 callback.failed(new IOException("invalid_data_length"));
@@ -337,10 +365,14 @@ public class HTTP2Stream extends IdleTimeout implements IStream, Callback, Dumpa
 
     private void onReset(ResetFrame frame, Callback callback)
     {
-        remoteReset = true;
+        synchronized (this)
+        {
+            remoteReset = true;
+            failure = new EofException("reset");
+        }
         close();
-        session.removeStream(this);
-        notifyReset(this, frame, callback);
+        if (session.removeStream(this))
+            notifyReset(this, frame, callback);
     }
 
     private void onPush(PushPromiseFrame frame, Callback callback)
@@ -358,7 +390,13 @@ public class HTTP2Stream extends IdleTimeout implements IStream, Callback, Dumpa
 
     private void onFailure(FailureFrame frame, Callback callback)
     {
-        notifyFailure(this, frame, callback);
+        synchronized (this)
+        {
+            failure = frame.getFailure();
+        }
+        close();
+        if (session.removeStream(this))
+            notifyFailure(this, frame, callback);
     }
 
     @Override
@@ -540,7 +578,12 @@ public class HTTP2Stream extends IdleTimeout implements IStream, Callback, Dumpa
 
     private Callback endWrite()
     {
-        return writing.getAndSet(null);
+        synchronized (this)
+        {
+            Callback callback = sendCallback;
+            sendCallback = null;
+            return callback;
+        }
     }
 
     private void notifyData(Stream stream, DataFrame frame, Callback callback)
@@ -608,7 +651,7 @@ public class HTTP2Stream extends IdleTimeout implements IStream, Callback, Dumpa
         {
             try
             {
-                listener.onFailure(stream, frame.getError(), frame.getReason(), callback);
+                listener.onFailure(stream, frame.getError(), frame.getReason(), frame.getFailure(), callback);
             }
             catch (Throwable x)
             {
@@ -652,10 +695,11 @@ public class HTTP2Stream extends IdleTimeout implements IStream, Callback, Dumpa
     @Override
     public String toString()
     {
-        return String.format("%s@%x#%d{sendWindow=%s,recvWindow=%s,reset=%b/%b,%s,age=%d,attachment=%s}",
+        return String.format("%s@%x#%d@%x{sendWindow=%s,recvWindow=%s,reset=%b/%b,%s,age=%d,attachment=%s}",
             getClass().getSimpleName(),
             hashCode(),
             getId(),
+            session.hashCode(),
             sendWindow,
             recvWindow,
             localReset,
