@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -19,6 +19,7 @@
 package org.eclipse.jetty.http2;
 
 import java.io.IOException;
+import java.util.List;
 
 import org.eclipse.jetty.http2.api.Session;
 import org.eclipse.jetty.http2.api.Stream;
@@ -43,22 +44,30 @@ public interface ISession extends Session
      * <p>Removes the given {@code stream}.</p>
      *
      * @param stream the stream to remove
+     * @return whether the stream was removed
      */
-    void removeStream(IStream stream);
+    boolean removeStream(IStream stream);
+
+    /**
+     * <p>Sends the given list of frames to create a new {@link Stream}.</p>
+     *
+     * @param frames the list of frames to send
+     * @param promise the promise that gets notified of the stream creation
+     * @param listener the listener that gets notified of stream events
+     */
+    void newStream(IStream.FrameList frames, Promise<Stream> promise, Stream.Listener listener);
 
     /**
      * <p>Enqueues the given frames to be written to the connection.</p>
-     *
      * @param stream the stream the frames belong to
+     * @param frames the frames to enqueue
      * @param callback the callback that gets notified when the frames have been sent
-     * @param frame the first frame to enqueue
-     * @param frames additional frames to enqueue
      */
-    void frames(IStream stream, Callback callback, Frame frame, Frame... frames);
+    void frames(IStream stream, List<? extends Frame> frames, Callback callback);
 
     /**
      * <p>Enqueues the given PUSH_PROMISE frame to be written to the connection.</p>
-     * <p>Differently from {@link #frames(IStream, Callback, Frame, Frame...)}, this method
+     * <p>Differently from {@link #frames(IStream, List, Callback)}, this method
      * generates atomically the stream id for the pushed stream.</p>
      *
      * @param stream the stream associated to the pushed stream
