@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -51,7 +51,8 @@ public interface Stream
     Session getSession();
 
     /**
-     * <p>Sends the given HEADERS {@code frame} representing an HTTP response.</p>
+     * <p>Sends the given HEADERS {@code frame}.</p>
+     * <p>Typically used to send an HTTP response or to send the HTTP response trailers.</p>
      *
      * @param frame the HEADERS frame to send
      * @param callback the callback that gets notified when the frame has been sent
@@ -227,8 +228,24 @@ public interface Stream
          * @param stream the stream
          * @param error the error code
          * @param reason the error reason, or null
+         * @param failure the failure
          * @param callback the callback to complete when the failure has been handled
          */
+        default void onFailure(Stream stream, int error, String reason, Throwable failure, Callback callback)
+        {
+            onFailure(stream, error, reason, callback);
+        }
+
+        /**
+         * <p>Callback method invoked when the stream failed.</p>
+         *
+         * @param stream the stream
+         * @param error the error code
+         * @param reason the error reason, or null
+         * @param callback the callback to complete when the failure has been handled
+         * @deprecated use {@link #onFailure(Stream, int, String, Throwable, Callback)} instead
+         */
+        @Deprecated
         default void onFailure(Stream stream, int error, String reason, Callback callback)
         {
             callback.succeeded();
