@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -22,12 +22,14 @@ public class FailureFrame extends Frame
 {
     private final int error;
     private final String reason;
+    private final Throwable failure;
 
-    public FailureFrame(int error, String reason)
+    public FailureFrame(int error, String reason, Throwable failure)
     {
         super(FrameType.FAILURE);
         this.error = error;
         this.reason = reason;
+        this.failure = failure;
     }
 
     public int getError()
@@ -39,4 +41,9 @@ public class FailureFrame extends Frame
     {
         return reason;
     }
+
+    public Throwable getFailure()
+    {
+        return failure;
+    }
 }
