@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -20,30 +20,33 @@ package org.eclipse.jetty.http2.frames;
 
 import java.nio.charset.StandardCharsets;
 
-import org.eclipse.jetty.http2.CloseState;
 import org.eclipse.jetty.http2.ErrorCode;
 
 public class GoAwayFrame extends Frame
 {
-    private final CloseState closeState;
+    public static final GoAwayFrame GRACEFUL = new GoAwayFrame(Integer.MAX_VALUE, ErrorCode.NO_ERROR.code, new byte[]{'g', 'r', 'a', 'c', 'e', 'f', 'u', 'l'});
+
     private final int lastStreamId;
     private final int error;
     private final byte[] payload;
 
     public GoAwayFrame(int lastStreamId, int error, byte[] payload)
-    {
-        this(CloseState.REMOTELY_CLOSED, lastStreamId, error, payload);
-    }
-
-    public GoAwayFrame(CloseState closeState, int lastStreamId, int error, byte[] payload)
     {
         super(FrameType.GO_AWAY);
-        this.closeState = closeState;
         this.lastStreamId = lastStreamId;
         this.error = error;
         this.payload = payload;
     }
 
+    /**
+     * @return whether this GOAWAY frame is graceful, i.e. its {@code lastStreamId == Integer.MAX_VALUE}
+     */
+    public boolean isGraceful()
+    {
+        // SPEC: section 6.8.
+        return lastStreamId == Integer.MAX_VALUE;
+    }
+
     public int getLastStreamId()
     {
         return lastStreamId;
@@ -76,11 +79,10 @@ public class GoAwayFrame extends Frame
     @Override
     public String toString()
     {
-        return String.format("%s,%d/%s/%s/%s",
+        return String.format("%s{%d/%s/%s}",
             super.toString(),
             lastStreamId,
             ErrorCode.toString(error, null),
-            tryConvertPayload(),
-            closeState);
+            tryConvertPayload());
     }
 }
