@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2019 Mort Bay Consulting Pty. Ltd.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -16,28 +16,26 @@
 //  ========================================================================
 //
 
-
 package org.eclipse.jetty.http2.hpack;
 
 import org.eclipse.jetty.http.HostPortHttpField;
 import org.eclipse.jetty.http.HttpHeader;
 
-
-/* ------------------------------------------------------------ */
 /**
+ *
  */
 public class AuthorityHttpField extends HostPortHttpField
 {
-    public final static String AUTHORITY = HpackContext.STATIC_TABLE[1][0];
-    
+    public static final String AUTHORITY = HpackContext.STATIC_TABLE[1][0];
+
     public AuthorityHttpField(String authority)
     {
-        super(HttpHeader.C_AUTHORITY,AUTHORITY,authority);
+        super(HttpHeader.C_AUTHORITY, AUTHORITY, authority);
     }
-    
+
     @Override
     public String toString()
     {
-        return String.format("%s(preparsed h=%s p=%d)",super.toString(),getHost(),getPort());
+        return String.format("%s(preparsed h=%s p=%d)", super.toString(), getHost(), getPort());
     }
 }
