@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -37,6 +37,7 @@ import org.eclipse.jetty.client.AbstractConnectionPool;
 import org.eclipse.jetty.client.HttpClient;
 import org.eclipse.jetty.client.HttpDestination;
 import org.eclipse.jetty.client.HttpResponseException;
+import org.eclipse.jetty.client.MultiplexConnectionPool;
 import org.eclipse.jetty.client.api.ContentResponse;
 import org.eclipse.jetty.client.api.Response;
 import org.eclipse.jetty.client.api.Result;
@@ -176,6 +177,7 @@ public class MaxConcurrentStreamsTest extends AbstractTest
                     @Override
                     public void onSettings(Session session, SettingsFrame frame)
                     {
+                        super.onSettings(session, frame);
                         // Send another request to simulate a request being
                         // sent concurrently with connection establishment.
                         // Sending this request will trigger the creation of
@@ -200,7 +202,6 @@ public class MaxConcurrentStreamsTest extends AbstractTest
                                     }
                                 });
                         }
-                        super.onSettings(session, frame);
                     }
                 }, promise, context);
             }
@@ -338,12 +339,28 @@ public class MaxConcurrentStreamsTest extends AbstractTest
             }
         });
 
+        int parallelism = 4;
+        int runs = 1;
+        int iterations = 32;
+
         client.setMaxConnectionsPerDestination(32768);
         client.setMaxRequestsQueuedPerDestination(1024 * 1024);
+        client.getTransport().setConnectionPoolFactory(destination ->
+        {
+            try
+            {
+                MultiplexConnectionPool pool = new MultiplexConnectionPool(destination, client.getMaxConnectionsPerDestination(), false, destination, 1);
+                pool.preCreateConnections(parallelism * 2).get();
+                return pool;
+            }
+            catch (Exception e)
+            {
+                throw new RuntimeException(e);
+            }
+        });
+        // Prime the destination to pre-create connections.
+        client.GET("http://localhost:" + connector.getLocalPort());
 
-        int parallelism = 16;
-        int runs = 1;
-        int iterations = 256;
         int total = parallelism * runs * iterations;
         CountDownLatch latch = new CountDownLatch(total);
         Queue<Result> failures = new ConcurrentLinkedQueue<>();
