@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -23,6 +23,7 @@ import java.util.Arrays;
 import java.util.Objects;
 
 import org.eclipse.jetty.io.ByteBufferPool.Bucket;
+import org.eclipse.jetty.util.StringUtil;
 import org.junit.jupiter.api.Test;
 
 import static org.hamcrest.MatcherAssert.assertThat;
@@ -150,6 +151,17 @@ public class ArrayByteBufferPoolTest
         }
     }
 
+    @Test
+    public void testReleaseNonPooledBuffer()
+    {
+        ArrayByteBufferPool bufferPool = new ArrayByteBufferPool();
+
+        // Release a few small non-pool buffers
+        bufferPool.release(ByteBuffer.wrap(StringUtil.getUtf8Bytes("Hello")));
+
+        assertEquals(0, bufferPool.getHeapByteBufferCount());
+    }
+
     @Test
     public void testMaxQueue()
     {
