@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -35,17 +35,24 @@ import java.nio.channels.Selector;
 import java.nio.channels.ServerSocketChannel;
 import java.nio.channels.SocketChannel;
 import java.nio.charset.StandardCharsets;
+import java.nio.file.Files;
+import java.nio.file.Path;
 import java.nio.file.StandardOpenOption;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.Future;
 import java.util.concurrent.TimeUnit;
 
+import org.eclipse.jetty.toolchain.test.FS;
 import org.eclipse.jetty.toolchain.test.MavenTestingUtils;
+import org.eclipse.jetty.toolchain.test.jupiter.WorkDir;
+import org.eclipse.jetty.toolchain.test.jupiter.WorkDirExtension;
 import org.eclipse.jetty.util.BufferUtil;
 import org.eclipse.jetty.util.IO;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.TestInfo;
 import org.junit.jupiter.api.condition.OS;
+import org.junit.jupiter.api.extension.ExtendWith;
 
 import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.is;
@@ -54,10 +61,12 @@ import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
 
+@ExtendWith(WorkDirExtension.class)
 public class IOTest
 {
+    public WorkDir workDir;
+
     @Test
     public void testIO() throws Exception
     {
@@ -96,7 +105,6 @@ public class IOTest
             // but cannot write
             Assertions.assertThrows(SocketException.class, () -> client.getOutputStream().write(1));
 
-
             // but can still write in opposite direction.
             server.getOutputStream().write(1);
             assertEquals(1, client.getInputStream().read());
@@ -419,13 +427,9 @@ public class IOTest
     @Test
     public void testGatherWrite() throws Exception
     {
-        File dir = MavenTestingUtils.getTargetTestingDir();
-        if (!dir.exists())
-            dir.mkdir();
-
-        File file = File.createTempFile("test", ".txt", dir);
-        file.deleteOnExit();
-        FileChannel out = FileChannel.open(file.toPath(),
+        Path dir = workDir.getEmptyPathDir();
+        Path file = Files.createTempFile(dir, "test", ".txt");
+        FileChannel out = FileChannel.open(file,
             StandardOpenOption.CREATE,
             StandardOpenOption.READ,
             StandardOpenOption.WRITE,
@@ -449,6 +453,64 @@ public class IOTest
         }
     }
 
+    @Test
+    public void testDeleteNull()
+    {
+        assertFalse(IO.delete(null));
+    }
+
+    @Test
+    public void testDeleteNonExistentFile(TestInfo testInfo)
+    {
+        File dir = MavenTestingUtils.getTargetTestingDir(testInfo.getDisplayName());
+        FS.ensureEmpty(dir);
+        File noFile = new File(dir, "nada");
+        assertFalse(IO.delete(noFile));
+    }
+
+    @Test
+    public void testIsEmptyNull()
+    {
+        assertTrue(IO.isEmptyDir(null));
+    }
+
+    @Test
+    public void testIsEmptyDoesNotExist(TestInfo testInfo)
+    {
+        File dir = MavenTestingUtils.getTargetTestingDir(testInfo.getDisplayName());
+        FS.ensureEmpty(dir);
+        File noFile = new File(dir, "nada");
+        assertTrue(IO.isEmptyDir(noFile));
+    }
+
+    @Test
+    public void testIsEmptyExistButAsFile(TestInfo testInfo) throws IOException
+    {
+        File dir = MavenTestingUtils.getTargetTestingDir(testInfo.getDisplayName());
+        FS.ensureEmpty(dir);
+        File file = new File(dir, "nada");
+        FS.touch(file);
+        assertFalse(IO.isEmptyDir(file));
+    }
+
+    @Test
+    public void testIsEmptyExistAndIsEmpty(TestInfo testInfo)
+    {
+        File dir = MavenTestingUtils.getTargetTestingDir(testInfo.getDisplayName());
+        FS.ensureEmpty(dir);
+        assertTrue(IO.isEmptyDir(dir));
+    }
+
+    @Test
+    public void testIsEmptyExistAndHasContent(TestInfo testInfo) throws IOException
+    {
+        File dir = MavenTestingUtils.getTargetTestingDir(testInfo.getDisplayName());
+        FS.ensureEmpty(dir);
+        File file = new File(dir, "nada");
+        FS.touch(file);
+        assertFalse(IO.isEmptyDir(dir));
+    }
+
     @Test
     public void testSelectorWakeup() throws Exception
     {
