@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -35,7 +35,6 @@ import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertSame;
 import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
 
 public class MappedByteBufferPoolTest
 {
@@ -95,34 +94,15 @@ public class MappedByteBufferPoolTest
         assertTrue(buckets.isEmpty());
     }
 
-    /**
-     * In a scenario where MappedByteBufferPool is being used improperly,
-     * such as releasing a buffer that wasn't created/acquired by the
-     * MappedByteBufferPool, an assertion is tested for.
-     */
     @Test
-    public void testReleaseAssertion()
+    public void testReleaseNonPooledBuffer()
     {
-        int factor = 1024;
-        MappedByteBufferPool bufferPool = new MappedByteBufferPool(factor);
+        MappedByteBufferPool bufferPool = new MappedByteBufferPool();
 
-        try
-        {
-            // Release a few small non-pool buffers
-            bufferPool.release(ByteBuffer.wrap(StringUtil.getUtf8Bytes("Hello")));
+        // Release a few small non-pool buffers
+        bufferPool.release(ByteBuffer.wrap(StringUtil.getUtf8Bytes("Hello")));
 
-            /* NOTES:
-             *
-             * 1) This test will pass on command line maven build, as its surefire setup uses "-ea" already.
-             * 2) In Eclipse, goto the "Run Configuration" for this test case.
-             *    Select the "Arguments" tab, and make sure "-ea" is present in the text box titled "VM arguments"
-             */
-            fail("Expected java.lang.AssertionError, do you have '-ea' JVM command line option enabled?");
-        }
-        catch (java.lang.AssertionError e)
-        {
-            // Expected path.
-        }
+        assertEquals(0, bufferPool.getHeapByteBufferCount());
     }
 
     @Test
