@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -22,15 +22,11 @@ import java.security.Principal;
 import javax.security.auth.Subject;
 import javax.security.auth.login.LoginContext;
 
-
-
-/* ---------------------------------------------------- */
-/** JAASUserPrincipal
- * <p>Implements the JAAS version of the
- *  org.eclipse.jetty.http.UserPrincipal interface.
- *
- * @version $Id: JAASUserPrincipal.java 4780 2009-03-17 15:36:08Z jesse $
- *
+/**
+ * JAASUserPrincipal
+ * <p>
+ * Implements the JAAS version of the
+ * org.eclipse.jetty.http.UserPrincipal interface.
  */
 public class JAASUserPrincipal implements Principal
 {
@@ -38,8 +34,6 @@ public class JAASUserPrincipal implements Principal
     private final Subject _subject;
     private final LoginContext _loginContext;
 
-    /* ------------------------------------------------ */
-
     public JAASUserPrincipal(String name, Subject subject, LoginContext loginContext)
     {
         this._name = name;
@@ -47,32 +41,33 @@ public class JAASUserPrincipal implements Principal
         this._loginContext = loginContext;
     }
 
-    /* ------------------------------------------------ */
-    /** Get the name identifying the user
+    /**
+     * Get the name identifying the user
      */
-    public String getName ()
+    @Override
+    public String getName()
     {
         return _name;
     }
 
-
-    /* ------------------------------------------------ */
-    /** Provide access to the Subject
+    /**
+     * Provide access to the Subject
+     *
      * @return subject
      */
-    public Subject getSubject ()
+    public Subject getSubject()
     {
         return this._subject;
     }
 
-    LoginContext getLoginContext ()
+    LoginContext getLoginContext()
     {
         return this._loginContext;
     }
 
+    @Override
     public String toString()
     {
         return getName();
     }
-
 }
