@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -21,12 +21,12 @@ package org.eclipse.jetty.jaas.spi;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-import java.util.concurrent.ConcurrentHashMap;
 import java.util.stream.Collectors;
-
 import javax.security.auth.Subject;
 import javax.security.auth.callback.CallbackHandler;
 
+import org.eclipse.jetty.jaas.JAASLoginService;
+import org.eclipse.jetty.jaas.PropertyUserStoreManager;
 import org.eclipse.jetty.security.AbstractLoginService;
 import org.eclipse.jetty.security.PropertyUserStore;
 import org.eclipse.jetty.server.UserIdentity;
@@ -42,14 +42,12 @@ public class PropertyFileLoginModule extends AbstractLoginModule
     public static final String DEFAULT_FILENAME = "realm.properties";
 
     private static final Logger LOG = Log.getLogger(PropertyFileLoginModule.class);
-
-    private static ConcurrentHashMap<String, PropertyUserStore> _propertyUserStores = new ConcurrentHashMap<String, PropertyUserStore>();
-
-    private int _refreshInterval = 0;
-    private String _filename = DEFAULT_FILENAME;
+    
+    private PropertyUserStore _store;
 
     /**
-     * Read contents of the configured property file.
+     * Use a PropertyUserStore to read the authentication and authorizaton information contained in
+     * the file named by the option "file".
      *
      * @param subject the subject
      * @param callbackHandler the callback handler
@@ -65,40 +63,61 @@ public class PropertyFileLoginModule extends AbstractLoginModule
         setupPropertyUserStore(options);
     }
 
+    /**
+     * Get an existing, or create a new PropertyUserStore to read the 
+     * authentication and authorization information from the file named by
+     * the option "file".
+     * 
+     * @param options configuration options
+     */
     private void setupPropertyUserStore(Map<String, ?> options)
     {
-        parseConfig(options);
+        String filename = (String)options.get("file");
+        filename = (filename == null ? DEFAULT_FILENAME : filename);
 
-        if (_propertyUserStores.get(_filename) == null)
+        PropertyUserStoreManager mgr = JAASLoginService.INSTANCE.get().getBean(PropertyUserStoreManager.class);
+        if (mgr == null)
+            throw new IllegalStateException("No PropertyUserStoreManager");
+
+        _store = mgr.getPropertyUserStore(filename);
+        if (_store == null)
         {
-            PropertyUserStore propertyUserStore = new PropertyUserStore();
-            propertyUserStore.setConfig(_filename);
-
-            PropertyUserStore prev = _propertyUserStores.putIfAbsent(_filename, propertyUserStore);
-            if (prev == null)
+            boolean hotReload = false;  
+            String tmp = (String)options.get("hotReload");
+            if (tmp != null)
+                hotReload = Boolean.parseBoolean(tmp);
+            else
             {
-                LOG.debug("setupPropertyUserStore: Starting new PropertyUserStore. PropertiesFile: " + _filename + " refreshInterval: " + _refreshInterval);
-
-                try
+                //refreshInterval is deprecated, use hotReload instead
+                tmp = (String)options.get("refreshInterval");
+                if (tmp != null)
                 {
-                    propertyUserStore.start();
-                }
-                catch (Exception e)
-                {
-                    LOG.warn("Exception while starting propertyUserStore: ", e);
+                    LOG.warn("Use 'hotReload' boolean property instead of 'refreshInterval'");
+                    try
+                    {
+                        hotReload = (Integer.parseInt(tmp) > 0);
+                    }
+                    catch (NumberFormatException e)
+                    {
+                        LOG.warn("'refreshInterval' is not an integer");
+                    }
                 }
             }
+            PropertyUserStore newStore = new PropertyUserStore();
+            newStore.setConfig(filename);
+            newStore.setHotReload(hotReload);
+            _store = mgr.addPropertyUserStore(filename, newStore);
+            try
+            {
+                _store.start();
+            }
+            catch (Exception e)
+            {
+                LOG.warn("Exception starting propertyUserStore {} ", filename, e);
+            }
         }
     }
 
-    private void parseConfig(Map<String, ?> options)
-    {
-        String tmp = (String)options.get("file");
-        _filename = (tmp == null ? DEFAULT_FILENAME : tmp);
-        tmp = (String)options.get("refreshInterval");
-        _refreshInterval = (tmp == null ? _refreshInterval : Integer.parseInt(tmp));
-    }
-
     /**
      * @param userName the user name
      * @throws Exception if unable to get the user information
@@ -106,12 +125,8 @@ public class PropertyFileLoginModule extends AbstractLoginModule
     @Override
     public UserInfo getUserInfo(String userName) throws Exception
     {
-        PropertyUserStore propertyUserStore = _propertyUserStores.get(_filename);
-        if (propertyUserStore == null)
-            throw new IllegalStateException("PropertyUserStore should never be null here!");
-
-        LOG.debug("Checking PropertyUserStore " + _filename + " for " + userName);
-        UserIdentity userIdentity = propertyUserStore.getUserIdentity(userName);
+        LOG.debug("Checking PropertyUserStore {} for {}", _store.getConfig(), userName);
+        UserIdentity userIdentity = _store.getUserIdentity(userName);
         if (userIdentity == null)
             return null;
 
@@ -124,7 +139,6 @@ public class PropertyFileLoginModule extends AbstractLoginModule
             .collect(Collectors.toList());
 
         Credential credential = (Credential)userIdentity.getSubject().getPrivateCredentials().iterator().next();
-        LOG.debug("Found: " + userName + " in PropertyUserStore " + _filename);
         return new UserInfo(userName, credential, roles);
     }
 }
