@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -49,7 +49,6 @@ import org.eclipse.jetty.server.ShutdownMonitor;
 import org.eclipse.jetty.server.handler.ContextHandler;
 import org.eclipse.jetty.server.handler.ContextHandlerCollection;
 import org.eclipse.jetty.server.handler.HandlerCollection;
-import org.eclipse.jetty.util.PathWatcher;
 import org.eclipse.jetty.util.Scanner;
 import org.eclipse.jetty.util.StringUtil;
 import org.eclipse.jetty.util.resource.Resource;
@@ -474,7 +473,7 @@ public abstract class AbstractJettyMojo extends AbstractMojo
                         }
                         catch (Exception e)
                         {
-                            getLog().error("Error reconfiguring/restarting webapp after change in watched files",e);
+                            getLog().error("Error reconfiguring/restarting webapp after change in watched files", e);
                         }
                     }
                 });
@@ -559,7 +558,12 @@ public abstract class AbstractJettyMojo extends AbstractMojo
             File target = new File(project.getBuild().getDirectory());
             File tmp = new File(target, "tmp");
             if (!tmp.exists())
-                tmp.mkdirs();
+            {
+                if (!tmp.mkdirs())
+                {
+                    throw new MojoFailureException("Unable to create temp directory: " + tmp);
+                }
+            }
             webApp.setTempDirectory(tmp);
         }
 
