@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2019 Mort Bay Consulting Pty. Ltd.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -24,28 +24,28 @@ import java.util.List;
 /**
  * ScanPattern
  *
- * A pattern of includes and excludes.
+ * Ant-style pattern of includes and excludes.
  */
 public class ScanPattern
 {
     private List<String> _includes = Collections.emptyList();
     private List<String> _excludes = Collections.emptyList();
-    
-    public void setIncludes (List<String> includes)
+
+    public void setIncludes(List<String> includes)
     {
-        _includes= includes;
+        _includes = includes;
     }
-    
+
     public void setExcludes(List<String> excludes)
     {
         _excludes = excludes;
     }
-    
+
     public List<String> getIncludes()
     {
         return _includes;
     }
-    
+
     public List<String> getExcludes()
     {
         return _excludes;
