@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2019 Mort Bay Consulting Pty. Ltd.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -46,23 +46,20 @@ import org.osgi.util.tracker.ServiceTracker;
  * Jetty Provider that knows how to deploy a WebApp that has been registered as an OSGi service.
  */
 public class ServiceWebAppProvider extends AbstractWebAppProvider implements ServiceProvider
-{   
+{
     private static final Logger LOG = Log.getLogger(AbstractWebAppProvider.class);
-    
+
     /**
      * Map of ServiceRef to App. Used when it is an osgi service that is a WebAppContext.
      */
     private Map<ServiceReference, App> _serviceMap = new HashMap<>();
-    
+
     private ServiceRegistration _serviceRegForServices;
-    
+
     private ServiceTracker webappTracker;
-    
 
     /**
      * WebAppTracker
-     *
-     *
      */
     public class WebAppTracker extends ServiceTracker
     {
@@ -70,33 +67,33 @@ public class ServiceWebAppProvider extends AbstractWebAppProvider implements Ser
          * @param bundleContext the osgi context
          * @param filter the osgi filter for the tracker
          */
-        public WebAppTracker (BundleContext bundleContext, Filter filter)
+        public WebAppTracker(BundleContext bundleContext, Filter filter)
         {
             super(bundleContext, filter, null);
         }
 
-        /** 
+        /**
          * @see org.osgi.util.tracker.ServiceTracker#addingService(org.osgi.framework.ServiceReference)
          */
         @Override
         public Object addingService(ServiceReference reference)
         {
             WebAppContext wac = (WebAppContext)context.getService(reference);
-            serviceAdded (reference, wac);
+            serviceAdded(reference, wac);
             return wac;
         }
 
-        /** 
+        /**
          * @see org.osgi.util.tracker.ServiceTracker#modifiedService(org.osgi.framework.ServiceReference, java.lang.Object)
          */
         @Override
         public void modifiedService(ServiceReference reference, Object service)
         {
-            removedService(reference,service);
+            removedService(reference, service);
             addingService(reference);
         }
 
-        /** 
+        /**
          * @see org.osgi.util.tracker.ServiceTracker#removedService(org.osgi.framework.ServiceReference, java.lang.Object)
          */
         @Override
@@ -106,17 +103,14 @@ public class ServiceWebAppProvider extends AbstractWebAppProvider implements Ser
             context.ungetService(reference);
         }
     }
-    
-    
+
     /**
      * ServiceApp
-     *
-     *
      */
     public class ServiceApp extends OSGiApp
     {
 
-        public ServiceApp(DeploymentManager manager, AppProvider provider, Bundle bundle, Dictionary<String,String> properties, String originId)
+        public ServiceApp(DeploymentManager manager, AppProvider provider, Bundle bundle, Dictionary<String, String> properties, String originId)
         {
             super(manager, provider, bundle, properties, originId);
         }
@@ -138,52 +132,46 @@ public class ServiceWebAppProvider extends AbstractWebAppProvider implements Ser
             //not applicable for apps that are already services
         }
     }
-    
-    
-    
-    /* ------------------------------------------------------------ */
-    public ServiceWebAppProvider (ServerInstanceWrapper wrapper)
+
+    public ServiceWebAppProvider(ServerInstanceWrapper wrapper)
     {
         super(wrapper);
     }
-    
-    
-    /* ------------------------------------------------------------ */
+
     /**
      * A webapp that was deployed as an osgi service has been added,
      * and we want to deploy it.
-     * 
+     *
      * @param context the webapp
      */
     @Override
-    public boolean serviceAdded (ServiceReference serviceRef, ContextHandler context)
-    {   
+    public boolean serviceAdded(ServiceReference serviceRef, ContextHandler context)
+    {
         if (context == null || !(context instanceof WebAppContext))
             return false;
-        
+
         String watermark = (String)serviceRef.getProperty(OSGiWebappConstants.WATERMARK);
         if (watermark != null && !"".equals(watermark))
             return false;  //this service represents a webapp that has already been registered as a service by another of our deployers
-        
-        
+
         WebAppContext webApp = (WebAppContext)context;
-        Dictionary<String,String> properties = new Hashtable<>();
-        
+        Dictionary<String, String> properties = new Hashtable<>();
+
         String contextPath = (String)serviceRef.getProperty(OSGiWebappConstants.RFC66_WEB_CONTEXTPATH);
         if (contextPath == null)
             contextPath = (String)serviceRef.getProperty(OSGiWebappConstants.SERVICE_PROP_CONTEXT_PATH);
         if (contextPath == null)
             return false; //No context path
-     
+
         String base = (String)serviceRef.getProperty(OSGiWebappConstants.JETTY_WAR_FOLDER_PATH);
         if (base == null)
             base = (String)serviceRef.getProperty(OSGiWebappConstants.JETTY_WAR_RESOURCE_PATH);
         if (base == null)
             base = (String)serviceRef.getProperty(OSGiWebappConstants.SERVICE_PROP_WAR);
-        
-       if (base == null)
-           return false; //No webapp base
-        
+
+        if (base == null)
+            return false; //No webapp base
+
         String webdefaultXml = (String)serviceRef.getProperty(OSGiWebappConstants.JETTY_DEFAULT_WEB_XML_PATH);
         if (webdefaultXml == null)
             webdefaultXml = (String)serviceRef.getProperty(OSGiWebappConstants.SERVICE_PROP_DEFAULT_WEB_XML_PATH);
@@ -208,7 +196,7 @@ public class ServiceWebAppProvider extends AbstractWebAppProvider implements Ser
         if (bundleInstallOverride != null)
             properties.put(OSGiWebappConstants.JETTY_BUNDLE_INSTALL_LOCATION_OVERRIDE, bundleInstallOverride);
 
-        String  requiredTlds = (String)serviceRef.getProperty(OSGiWebappConstants.REQUIRE_TLD_BUNDLE);
+        String requiredTlds = (String)serviceRef.getProperty(OSGiWebappConstants.REQUIRE_TLD_BUNDLE);
         if (requiredTlds == null)
             requiredTlds = (String)serviceRef.getProperty(OSGiWebappConstants.SERVICE_PROP_REQUIRE_TLD_BUNDLE);
         if (requiredTlds != null)
@@ -229,26 +217,23 @@ public class ServiceWebAppProvider extends AbstractWebAppProvider implements Ser
         }
         finally
         {
-            Thread.currentThread().setContextClassLoader(cl); 
+            Thread.currentThread().setContextClassLoader(cl);
         }
     }
-    
-    
-    
-    /* ------------------------------------------------------------ */
+
     /**
      * @param context the webapp
      */
     @Override
-    public boolean serviceRemoved (ServiceReference serviceRef, ContextHandler context)
+    public boolean serviceRemoved(ServiceReference serviceRef, ContextHandler context)
     {
         if (context == null || !(context instanceof WebAppContext))
             return false;
-        
+
         String watermark = (String)serviceRef.getProperty(OSGiWebappConstants.WATERMARK);
         if (watermark != null && !"".equals(watermark))
             return false;  //this service represents a contexthandler that will be deregistered as a service by another of our deployers
-        
+
         App app = _serviceMap.remove(serviceRef);
         if (app != null)
         {
@@ -257,10 +242,8 @@ public class ServiceWebAppProvider extends AbstractWebAppProvider implements Ser
         }
         return false;
     }
-    
-    
-    /* ------------------------------------------------------------ */
-    /** 
+
+    /**
      * @see org.eclipse.jetty.util.component.AbstractLifeCycle#doStart()
      */
     @Override
@@ -269,28 +252,27 @@ public class ServiceWebAppProvider extends AbstractWebAppProvider implements Ser
         BundleContext bundleContext = FrameworkUtil.getBundle(this.getClass()).getBundleContext();
 
         //Start a tracker to find webapps that are osgi services that are targeted to my server name
-        webappTracker = new WebAppTracker (bundleContext, 
-                                            Util.createFilter(bundleContext, WebAppContext.class.getName(), getServerInstanceWrapper().getManagedServerName()));
+        webappTracker = new WebAppTracker(bundleContext,
+            Util.createFilter(bundleContext, WebAppContext.class.getName(), getServerInstanceWrapper().getManagedServerName()));
         webappTracker.open();
-        
+
         //register as an osgi service for deploying bundles, advertising the name of the jetty Server instance we are related to
-        Dictionary<String,String> properties = new Hashtable<>();
+        Dictionary<String, String> properties = new Hashtable<>();
         properties.put(OSGiServerConstants.MANAGED_JETTY_SERVER_NAME, getServerInstanceWrapper().getManagedServerName());
-       
+
         //register as an osgi service for deploying contexts (discovered as osgi services), advertising the name of the jetty Server instance we are related to
         _serviceRegForServices = FrameworkUtil.getBundle(this.getClass()).getBundleContext().registerService(ServiceProvider.class.getName(), this, properties);
         super.doStart();
     }
 
-    /* ------------------------------------------------------------ */
-    /** 
+    /**
      * @see org.eclipse.jetty.util.component.AbstractLifeCycle#doStop()
      */
     @Override
     protected void doStop() throws Exception
     {
         webappTracker.close();
-        
+
         //unregister ourselves
         if (_serviceRegForServices != null)
         {
@@ -305,5 +287,4 @@ public class ServiceWebAppProvider extends AbstractWebAppProvider implements Ser
         }
         super.doStop();
     }
-
 }
