@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -32,10 +32,9 @@ import java.util.Set;
 
 /**
  * LibExtClassLoaderHelper
- * 
- * 
+ * <p>
  * Helper to create a URL class-loader with the jars inside
- * ${jetty.home}/lib/ext and ${jetty.home}/resources. In an ideal world, every
+ * <code>${jetty.home}/lib/ext</code> and <code>${jetty.home}/resources</code>. In an ideal world, every
  * library is an OSGi bundle that does loads nicely. To support standard jars or
  * bundles that cannot be loaded in the current OSGi environment, we support
  * inserting the jars in the usual jetty/lib/ext folders in the proper classpath
@@ -43,7 +42,6 @@ import java.util.Set;
  * <p>
  * The drawback is that those jars will not be available in the OSGi
  * classloader.
- * </p>
  * <p>
  * Alternatives to placing jars in lib/ext:
  * <ol>
@@ -54,14 +52,13 @@ import java.util.Set;
  * <li>Use equinox Buddy-Policy: register a buddy of the jetty bootstrapper
  * bundle. (Note: it will work only on equinox)</li>
  * </ol>
- * </p>
  */
 public class LibExtClassLoaderHelper
 {
-    /* ------------------------------------------------------------ */
+
     /**
      * IFilesInJettyHomeResourcesProcessor
-     * 
+     *
      * Interface for callback impls
      */
     public interface IFilesInJettyHomeResourcesProcessor
@@ -69,28 +66,28 @@ public class LibExtClassLoaderHelper
         void processFilesInResourcesFolder(File jettyHome, Map<String, File> filesInResourcesFolder);
     }
 
-    
-    
-    public static final Set<IFilesInJettyHomeResourcesProcessor> registeredFilesInJettyHomeResourcesProcessors = new HashSet<IFilesInJettyHomeResourcesProcessor>();
+    public static final Set<IFilesInJettyHomeResourcesProcessor> registeredFilesInJettyHomeResourcesProcessors = new HashSet<>();
 
-    
-    /* ------------------------------------------------------------ */
     /**
-     * @param server
+     * @param jettyHome the jetty home
+     * @param parentClassLoader the parent classloader
      * @return a url classloader with the jars of resources, lib/ext and the
-     *         jars passed in the other argument. The parent classloader usually
-     *         is the JettyBootStrapper (an osgi classloader.
-     * @throws MalformedURLException
+     * jars passed in the other argument. The parent classloader usually
+     * is the JettyBootStrapper (an osgi classloader.
+     * @throws MalformedURLException if the jetty home reference is invalid
      */
     public static ClassLoader createLibEtcClassLoader(File jettyHome, ClassLoader parentClassLoader) throws MalformedURLException
     {
-        if (jettyHome == null) { return parentClassLoader; }
-        ArrayList<URL> urls = new ArrayList<URL>();
+        if (jettyHome == null)
+        {
+            return parentClassLoader;
+        }
+        ArrayList<URL> urls = new ArrayList<>();
         File jettyResources = new File(jettyHome, "resources");
         if (jettyResources.exists())
         {
             // make sure it contains something else than README:
-            Map<String, File> jettyResFiles = new HashMap<String, File>();
+            Map<String, File> jettyResFiles = new HashMap<>();
             for (File f : jettyResources.listFiles())
             {
                 jettyResFiles.put(f.getName(), f);
@@ -118,7 +115,8 @@ public class LibExtClassLoaderHelper
                     // cheap to tolerate folders so let's do it.
                     URL url = f.toURI().toURL();
                     if (f.isFile())
-                    {// is this necessary anyways?
+                    {
+                        // is this necessary anyways?
                         url = new URL("jar:" + url.toString() + "!/");
                     }
                     urls.add(url);
@@ -129,21 +127,24 @@ public class LibExtClassLoaderHelper
         return new URLClassLoader(urls.toArray(new URL[urls.size()]), parentClassLoader);
     }
 
-    
-    /* ------------------------------------------------------------ */
     /**
-     * @param server
+     * @param jarsContainerOrJars the jars via file references
+     * @param otherJarsOrFolder more jars via url references
+     * @param parentClassLoader the parent classloader
      * @return a url classloader with the jars of resources, lib/ext and the
-     *         jars passed in the other argument. The parent classloader usually
-     *         is the JettyBootStrapper (an osgi classloader). If there was no
-     *         extra jars to insert, then just return the parentClassLoader.
-     * @throws MalformedURLException
+     * jars passed in the other argument. The parent classloader usually
+     * is the JettyBootStrapper (an osgi classloader). If there was no
+     * extra jars to insert, then just return the parentClassLoader.
+     * @throws MalformedURLException if there is a bad jar file reference
      */
-    public static ClassLoader createLibExtClassLoader(List<File> jarsContainerOrJars, List<URL> otherJarsOrFolder, ClassLoader parentClassLoader) 
-    throws MalformedURLException
+    public static ClassLoader createLibExtClassLoader(List<File> jarsContainerOrJars, List<URL> otherJarsOrFolder, ClassLoader parentClassLoader)
+        throws MalformedURLException
     {
-        if (jarsContainerOrJars == null && otherJarsOrFolder == null) { return parentClassLoader; }
-        List<URL> urls = new ArrayList<URL>();
+        if (jarsContainerOrJars == null && otherJarsOrFolder == null)
+        {
+            return parentClassLoader;
+        }
+        List<URL> urls = new ArrayList<>();
         if (otherJarsOrFolder != null)
         {
             urls.addAll(otherJarsOrFolder);
@@ -174,20 +175,21 @@ public class LibExtClassLoaderHelper
         return new URLClassLoader(urls.toArray(new URL[urls.size()]), parentClassLoader);
     }
 
-    /* ------------------------------------------------------------ */
     /**
      * When we find files typically used for central logging configuration we do
      * what it takes in this method to do what the user expects. Without
      * depending too much directly on a particular logging framework.
      * <p>
      * We can afford to do some implementation specific code for a logging
-     * framework only in a fragment. <br/>
+     * framework only in a fragment.
+     * <p>
      * Trying to configure log4j and logback in here.
-     * </p>
      * <p>
      * We recommend that slf4j jars are all placed in the osgi framework. And a
      * single implementation if possible packaged as an osgi bundle is there.
-     * </p>
+     *
+     * @param jettyHome the jetty home reference
+     * @param childrenFiles the map of child files
      */
     protected static void processFilesInResourcesFolder(File jettyHome, Map<String, File> childrenFiles)
     {
@@ -196,5 +198,4 @@ public class LibExtClassLoaderHelper
             processor.processFilesInResourcesFolder(jettyHome, childrenFiles);
         }
     }
-
 }
