@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -129,9 +129,11 @@ public class OSGiWebappClassLoader extends WebAppClassLoader implements BundleRe
     public Enumeration<URL> getResources(String name) throws IOException
     {
         Enumeration<URL> osgiUrls = _osgiBundleClassLoader.getResources(name);
+        if (osgiUrls != null && osgiUrls.hasMoreElements())
+            return osgiUrls;
+        
         Enumeration<URL> urls = super.getResources(name);
-        List<URL> resources = toList(osgiUrls, urls);
-        return Collections.enumeration(resources);
+        return urls;
     }
 
     @Override
