@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -58,6 +58,7 @@ import javax.servlet.ServletResponse;
 import javax.servlet.http.Cookie;
 import javax.servlet.http.HttpServlet;
 import javax.servlet.http.HttpServletRequest;
+import javax.servlet.http.HttpServletRequestWrapper;
 import javax.servlet.http.HttpServletResponse;
 
 import org.eclipse.jetty.client.DuplexConnectionPool;
@@ -75,27 +76,34 @@ import org.eclipse.jetty.client.util.InputStreamResponseListener;
 import org.eclipse.jetty.http.HttpHeader;
 import org.eclipse.jetty.http.HttpHeaderValue;
 import org.eclipse.jetty.http.HttpMethod;
+import org.eclipse.jetty.http.HttpScheme;
 import org.eclipse.jetty.http.HttpStatus;
+import org.eclipse.jetty.http.HttpVersion;
 import org.eclipse.jetty.server.HttpConfiguration;
 import org.eclipse.jetty.server.HttpConnectionFactory;
 import org.eclipse.jetty.server.Server;
 import org.eclipse.jetty.server.ServerConnector;
+import org.eclipse.jetty.server.SslConnectionFactory;
 import org.eclipse.jetty.servlet.FilterHolder;
 import org.eclipse.jetty.servlet.ServletContextHandler;
 import org.eclipse.jetty.servlet.ServletHolder;
 import org.eclipse.jetty.toolchain.test.MavenTestingUtils;
 import org.eclipse.jetty.util.IO;
 import org.eclipse.jetty.util.StringUtil;
+import org.eclipse.jetty.util.ssl.SslContextFactory;
 import org.eclipse.jetty.util.thread.QueuedThreadPool;
-import org.hamcrest.Matchers;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.params.ParameterizedTest;
 import org.junit.jupiter.params.provider.Arguments;
 import org.junit.jupiter.params.provider.MethodSource;
+import org.junit.jupiter.params.provider.ValueSource;
 
 import static org.eclipse.jetty.http.HttpFieldsMatchers.containsHeader;
 import static org.hamcrest.MatcherAssert.assertThat;
+import static org.hamcrest.Matchers.containsString;
+import static org.hamcrest.Matchers.equalTo;
+import static org.hamcrest.Matchers.greaterThanOrEqualTo;
 import static org.hamcrest.Matchers.instanceOf;
 import static org.junit.jupiter.api.Assertions.assertArrayEquals;
 import static org.junit.jupiter.api.Assertions.assertEquals;
@@ -123,6 +131,7 @@ public class ProxyServletTest
     private AbstractProxyServlet proxyServlet;
     private Server server;
     private ServerConnector serverConnector;
+    private ServerConnector tlsServerConnector;
 
     private void startServer(HttpServlet servlet) throws Exception
     {
@@ -132,6 +141,16 @@ public class ProxyServletTest
         serverConnector = new ServerConnector(server);
         server.addConnector(serverConnector);
 
+        SslContextFactory.Server sslContextFactory = new SslContextFactory.Server();
+        String keyStorePath = MavenTestingUtils.getTestResourceFile("server_keystore.p12").getAbsolutePath();
+        sslContextFactory.setKeyStorePath(keyStorePath);
+        sslContextFactory.setKeyStorePassword("storepwd");
+        tlsServerConnector = new ServerConnector(server, new SslConnectionFactory(
+            sslContextFactory,
+            HttpVersion.HTTP_1_1.asString()),
+            new HttpConnectionFactory());
+        server.addConnector(tlsServerConnector);
+
         ServletContextHandler appCtx = new ServletContextHandler(server, "/", true, false);
         ServletHolder appServletHolder = new ServletHolder(servlet);
         appCtx.addServlet(appServletHolder, "/*");
@@ -145,6 +164,11 @@ public class ProxyServletTest
     }
 
     private void startProxy(Class<? extends ProxyServlet> proxyServletClass, Map<String, String> initParams) throws Exception
+    {
+        startProxy(proxyServletClass.getConstructor().newInstance(), initParams);
+    }
+
+    private void startProxy(AbstractProxyServlet proxyServlet, Map<String, String> initParams) throws Exception
     {
         QueuedThreadPool proxyPool = new QueuedThreadPool();
         proxyPool.setName("proxy");
@@ -159,9 +183,8 @@ public class ProxyServletTest
         proxyConnector = new ServerConnector(proxy, new HttpConnectionFactory(configuration));
         proxy.addConnector(proxyConnector);
 
-        proxyServlet = proxyServletClass.getDeclaredConstructor().newInstance();
-
         proxyContext = new ServletContextHandler(proxy, "/", true, false);
+        this.proxyServlet = proxyServlet;
         ServletHolder proxyServletHolder = new ServletHolder(proxyServlet);
         proxyServletHolder.setInitParameters(initParams);
         proxyContext.addServlet(proxyServletHolder, "/*");
@@ -546,7 +569,98 @@ public class ProxyServletTest
         ContentResponse response = client.GET("http://localhost:" + serverConnector.getLocalPort());
         assertThat("Response expected to contain content of X-Forwarded-Host Header from the request",
             response.getContentAsString(),
-            Matchers.equalTo("localhost:" + serverConnector.getLocalPort()));
+            equalTo("localhost:" + serverConnector.getLocalPort()));
+    }
+
+    @ParameterizedTest
+    @MethodSource("impls")
+    public void testProxyViaHeaderIsAdded(Class<? extends ProxyServlet> proxyServletClass) throws Exception
+    {
+        startServer(new EmptyHttpServlet()
+        {
+            @Override
+            protected void service(HttpServletRequest request, HttpServletResponse response) throws IOException
+            {
+                PrintWriter writer = response.getWriter();
+                List<String> viaValues = Collections.list(request.getHeaders("Via"));
+                writer.write(String.join(", ", viaValues));
+            }
+        });
+        String viaHost = "my-good-via-host.example.org";
+        startProxy(proxyServletClass, Collections.singletonMap("viaHost", viaHost));
+        startClient();
+
+        ContentResponse response = client.GET("http://localhost:" + serverConnector.getLocalPort());
+        assertThat(response.getContentAsString(), equalTo("1.1 " + viaHost));
+    }
+
+    @ParameterizedTest
+    @MethodSource("impls")
+    public void testProxyViaHeaderValueIsAppended(Class<? extends ProxyServlet> proxyServletClass) throws Exception
+    {
+        startServer(new EmptyHttpServlet()
+        {
+            @Override
+            protected void service(HttpServletRequest request, HttpServletResponse response) throws IOException
+            {
+                // Make sure the proxy coalesced the Via headers into just one.
+                org.eclipse.jetty.server.Request jettyRequest = (org.eclipse.jetty.server.Request)request;
+                assertEquals(1, jettyRequest.getHttpFields().getFields(HttpHeader.VIA).size());
+                PrintWriter writer = response.getWriter();
+                List<String> viaValues = Collections.list(request.getHeaders("Via"));
+                writer.write(String.join(", ", viaValues));
+            }
+        });
+        String viaHost = "beatrix";
+        startProxy(proxyServletClass, Collections.singletonMap("viaHost", viaHost));
+        startClient();
+
+        String existingViaHeader = "1.0 charon";
+        ContentResponse response = client.newRequest("http://localhost:" + serverConnector.getLocalPort())
+            .header(HttpHeader.VIA, existingViaHeader)
+            .send();
+        String expected = String.join(", ", existingViaHeader, "1.1 " + viaHost);
+        assertThat(response.getContentAsString(), equalTo(expected));
+    }
+
+    @ParameterizedTest
+    @ValueSource(strings = {"HTTP/2.0", "FCGI/1.0"})
+    public void testViaHeaderProtocols(String protocol) throws Exception
+    {
+        startServer(new EmptyHttpServlet()
+        {
+            @Override
+            protected void service(HttpServletRequest request, HttpServletResponse response) throws IOException
+            {
+                PrintWriter writer = response.getWriter();
+                List<String> viaValues = Collections.list(request.getHeaders("Via"));
+                writer.write(String.join(", ", viaValues));
+            }
+        });
+        String viaHost = "proxy";
+        startProxy(new ProxyServlet()
+        {
+            @Override
+            protected void addViaHeader(HttpServletRequest clientRequest, Request proxyRequest)
+            {
+                HttpServletRequest wrapped = new HttpServletRequestWrapper(clientRequest)
+                {
+                    @Override
+                    public String getProtocol()
+                    {
+                        return protocol;
+                    }
+                };
+                super.addViaHeader(wrapped, proxyRequest);
+            }
+        }, Collections.singletonMap("viaHost", viaHost));
+        startClient();
+
+        ContentResponse response = client.GET("http://localhost:" + serverConnector.getLocalPort());
+
+        String expectedProtocol = protocol.startsWith("HTTP/") ? protocol.substring("HTTP/".length()) : protocol;
+        String expected = expectedProtocol + " " + viaHost;
+        assertThat(response.getContentAsString(), equalTo(expected));
     }
 
     @ParameterizedTest
@@ -631,27 +745,80 @@ public class ProxyServletTest
     public static Stream<Arguments> transparentImpls()
     {
         return Stream.of(
-            ProxyServlet.Transparent.class,
-            AsyncProxyServlet.Transparent.class,
-            AsyncMiddleManServlet.Transparent.class
+            new ProxyServlet.Transparent()
+            {
+                @Override
+                protected HttpClient newHttpClient()
+                {
+                    return newTrustAllClient(super.newHttpClient());
+                }
+
+                @Override
+                public String toString()
+                {
+                    return ProxyServlet.Transparent.class.getName();
+                }
+            },
+            new AsyncProxyServlet.Transparent()
+            {
+                @Override
+                protected HttpClient newHttpClient()
+                {
+                    return newTrustAllClient(super.newHttpClient());
+                }
+
+                @Override
+                public String toString()
+                {
+                    return AsyncProxyServlet.Transparent.class.getName();
+                }
+            },
+            new AsyncMiddleManServlet.Transparent()
+            {
+                @Override
+                protected HttpClient newHttpClient()
+                {
+                    return newTrustAllClient(super.newHttpClient());
+                }
+
+                @Override
+                public String toString()
+                {
+                    return AsyncMiddleManServlet.Transparent.class.getName();
+                }
+            }
         ).map(Arguments::of);
     }
 
-    @ParameterizedTest
-    @MethodSource("transparentImpls")
-    public void testTransparentProxy(Class<? extends ProxyServlet> proxyServletClass) throws Exception
+    private static HttpClient newTrustAllClient(HttpClient client)
     {
-        testTransparentProxyWithPrefix(proxyServletClass, "/proxy");
+        SslContextFactory sslContextFactory = client.getSslContextFactory();
+        sslContextFactory.setTrustAll(true);
+        return client;
     }
 
     @ParameterizedTest
     @MethodSource("transparentImpls")
-    public void testTransparentProxyWithRootContext(Class<? extends ProxyServlet> proxyServletClass) throws Exception
+    public void testTransparentProxy(AbstractProxyServlet proxyServletClass) throws Exception
     {
-        testTransparentProxyWithPrefix(proxyServletClass, "/");
+        testTransparentProxyWithPrefix(proxyServletClass, "http", "/proxy");
     }
 
-    private void testTransparentProxyWithPrefix(Class<? extends ProxyServlet> proxyServletClass, String prefix) throws Exception
+    @ParameterizedTest
+    @MethodSource("transparentImpls")
+    public void testTransparentProxyTls(AbstractProxyServlet proxyServletClass) throws Exception
+    {
+        testTransparentProxyWithPrefix(proxyServletClass, "https", "/proxy");
+    }
+
+    @ParameterizedTest
+    @MethodSource("transparentImpls")
+    public void testTransparentProxyWithRootContext(AbstractProxyServlet proxyServletClass) throws Exception
+    {
+        testTransparentProxyWithPrefix(proxyServletClass, "http", "/");
+    }
+
+    private void testTransparentProxyWithPrefix(AbstractProxyServlet proxyServletClass, String scheme, String prefix) throws Exception
     {
         final String target = "/test";
         startServer(new HttpServlet()
@@ -664,7 +831,10 @@ public class ProxyServletTest
                 resp.setStatus(target.equals(req.getRequestURI()) ? 200 : 404);
             }
         });
-        String proxyTo = "http://localhost:" + serverConnector.getLocalPort();
+        int serverPort = serverConnector.getLocalPort();
+        if (HttpScheme.HTTPS.is(scheme))
+            serverPort = tlsServerConnector.getLocalPort();
+        String proxyTo = scheme + "://localhost:" + serverPort;
         Map<String, String> params = new HashMap<>();
         params.put("proxyTo", proxyTo);
         params.put("prefix", prefix);
@@ -682,33 +852,33 @@ public class ProxyServletTest
 
     @ParameterizedTest
     @MethodSource("transparentImpls")
-    public void testTransparentProxyWithQuery(Class<? extends ProxyServlet> proxyServletClass) throws Exception
+    public void testTransparentProxyWithQuery(AbstractProxyServlet proxyServletClass) throws Exception
     {
         testTransparentProxyWithQuery(proxyServletClass, "/foo", "/proxy", "/test");
     }
 
     @ParameterizedTest
     @MethodSource("transparentImpls")
-    public void testTransparentProxyEmptyContextWithQuery(Class<? extends ProxyServlet> proxyServletClass) throws Exception
+    public void testTransparentProxyEmptyContextWithQuery(AbstractProxyServlet proxyServletClass) throws Exception
     {
         testTransparentProxyWithQuery(proxyServletClass, "", "/proxy", "/test");
     }
 
     @ParameterizedTest
     @MethodSource("transparentImpls")
-    public void testTransparentProxyEmptyTargetWithQuery(Class<? extends ProxyServlet> proxyServletClass) throws Exception
+    public void testTransparentProxyEmptyTargetWithQuery(AbstractProxyServlet proxyServletClass) throws Exception
     {
         testTransparentProxyWithQuery(proxyServletClass, "/bar", "/proxy", "");
     }
 
     @ParameterizedTest
     @MethodSource("transparentImpls")
-    public void testTransparentProxyEmptyContextEmptyTargetWithQuery(Class<? extends ProxyServlet> proxyServletClass) throws Exception
+    public void testTransparentProxyEmptyContextEmptyTargetWithQuery(AbstractProxyServlet proxyServletClass) throws Exception
     {
         testTransparentProxyWithQuery(proxyServletClass, "", "/proxy", "");
     }
 
-    private void testTransparentProxyWithQuery(Class<? extends ProxyServlet> proxyServletClass, String proxyToContext, String prefix, String target) throws Exception
+    private void testTransparentProxyWithQuery(AbstractProxyServlet proxyServletClass, String proxyToContext, String prefix, String target) throws Exception
     {
         final String query = "a=1&b=2";
         startServer(new HttpServlet()
@@ -752,7 +922,7 @@ public class ProxyServletTest
 
     @ParameterizedTest
     @MethodSource("transparentImpls")
-    public void testTransparentProxyWithQueryWithSpaces(Class<? extends ProxyServlet> proxyServletClass) throws Exception
+    public void testTransparentProxyWithQueryWithSpaces(AbstractProxyServlet proxyServletClass) throws Exception
     {
         final String target = "/test";
         final String query = "a=1&b=2&c=1234%205678&d=hello+world";
@@ -794,7 +964,7 @@ public class ProxyServletTest
 
     @ParameterizedTest
     @MethodSource("transparentImpls")
-    public void testTransparentProxyWithoutPrefix(Class<? extends ProxyServlet> proxyServletClass) throws Exception
+    public void testTransparentProxyWithoutPrefix(AbstractProxyServlet proxyServletClass) throws Exception
     {
         final String target = "/test";
         startServer(new HttpServlet()
@@ -940,7 +1110,7 @@ public class ProxyServletTest
             ContentResponse response = client.newRequest("localhost", serverConnector.getLocalPort())
                 .timeout(5, TimeUnit.SECONDS)
                 .send();
-            assertThat(response.getStatus(), Matchers.greaterThanOrEqualTo(500));
+            assertThat(response.getStatus(), greaterThanOrEqualTo(500));
         }
         catch (ExecutionException e)
         {
@@ -1073,7 +1243,7 @@ public class ProxyServletTest
         // Make sure there is error page content, as the proxy-to-client response has been reset.
         InputStream input = listener.getInputStream();
         String body = IO.toString(input);
-        assertThat(body, Matchers.containsString("HTTP ERROR 504"));
+        assertThat(body, containsString("HTTP ERROR 504"));
         chunk1Latch.countDown();
 
         // Result succeeds because a 504 is a valid HTTP response.
