@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -120,7 +120,29 @@ public class QuickStartWebApp extends WebAppContext
     {
         _generateOrigin = generateOrigin;
     }
-
+    
+    /**
+     * Never call any listeners unless we are fully
+     * starting the webapp.
+     */
+    @Override
+    public void contextInitialized() throws Exception
+    {
+        if (_startWebapp)
+            super.contextInitialized();
+    }
+    
+    /**
+     * Never call any listeners unless we are fully
+     * starting the webapp.
+     */
+    @Override
+    public void contextDestroyed() throws Exception
+    {
+        if (_startWebapp)
+            super.contextDestroyed();
+    }
+    
     @Override
     protected void startWebapp() throws Exception
     {
