@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -25,6 +25,7 @@ import org.eclipse.jetty.servlet.ListenerHolder;
 import org.eclipse.jetty.servlet.ServletHolder;
 import org.eclipse.jetty.toolchain.test.FS;
 import org.eclipse.jetty.toolchain.test.MavenTestingUtils;
+import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 
@@ -69,7 +70,7 @@ public class TestQuickStart
         fooHolder.setName("foo");
         quickstart.getServletHandler().addServlet(fooHolder);
         ListenerHolder lholder = new ListenerHolder();
-        lholder.setListener(new FooContextListener());
+        lholder.setClassName("org.eclipse.jetty.quickstart.FooContextListener");
         quickstart.getServletHandler().addListener(lholder);
         server.setHandler(quickstart);
         server.start();
@@ -92,4 +93,50 @@ public class TestQuickStart
         assertEquals("foo", sh.getName());
         server.stop();
     }
+    
+    @Test
+    public void testListenersNotCalledInPreConfigure() throws Exception
+    {
+        File quickstartXml = new File(webInf, "quickstart-web.xml");
+        assertFalse(quickstartXml.exists());
+        
+        Server server = new Server();
+        
+        QuickStartWebApp quickstart = new QuickStartWebApp();
+
+        //add a listener directly to the ContextHandler so it is there when we start -
+        //if you add them to the ServletHandler (like StandardDescriptorProcessor does)
+        //then they are not added to the ContextHandler in a pre-generate.
+        quickstart.addEventListener(new FooContextListener());
+        quickstart.setResourceBase(testDir.getAbsolutePath());
+        quickstart.setPreconfigure(true);
+        quickstart.setGenerateOrigin(true);
+        server.setHandler(quickstart);
+        server.start();
+        server.stop();
+        assertTrue(quickstartXml.exists());
+        assertEquals(0, FooContextListener.___initialized);
+    }
+    
+    @Test
+    public void testListenersCalledIfGenerateWithStart() throws Exception
+    {
+        File quickstartXml = new File(webInf, "quickstart-web.xml");
+        assertFalse(quickstartXml.exists());
+        
+        Server server = new Server();
+        
+        QuickStartWebApp quickstart = new QuickStartWebApp();
+        quickstart.setAutoPreconfigure(true); //generate AND start the webapp
+
+        //add a listener directly to the ContextHandler so it is there when we start
+        quickstart.addEventListener(new FooContextListener());
+        quickstart.setResourceBase(testDir.getAbsolutePath());
+        quickstart.setGenerateOrigin(true);
+        server.setHandler(quickstart);
+        server.start();
+        server.stop();
+        assertTrue(quickstartXml.exists());
+        assertEquals(1, FooContextListener.___initialized);
+    }
 }
