@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -29,7 +29,7 @@ import static org.hamcrest.Matchers.is;
 public class RewritePatternRuleTest extends AbstractRuleTestCase
 {
     // TODO: Parameterize
-    private String[][] _tests =
+    private final String[][] _tests =
         {
             {"/foo/bar", "/", "/replace"},
             {"/foo/bar", "/*", "/replace/foo/bar"},
@@ -98,8 +98,8 @@ public class RewritePatternRuleTest extends AbstractRuleTestCase
         assertThat("result matches expected", result, is(replacement));
 
         rewritePatternRule.applyURI(_request, null, result);
-        assertThat("queryString matches expected", _request.getQueryString(), is(queryString));
         assertThat("request URI matches expected", _request.getRequestURI(), is(replacement));
+        assertThat("queryString matches expected", _request.getQueryString(), is(queryString));
     }
 
     @Test
