@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -29,7 +29,6 @@ import org.eclipse.jetty.security.authentication.SpnegoAuthenticator;
 import org.eclipse.jetty.server.Server;
 import org.eclipse.jetty.util.security.Constraint;
 
-/* ------------------------------------------------------------ */
 /**
  * The Default Authenticator Factory.
  * Uses the {@link AuthConfiguration#getAuthMethod()} to select an {@link Authenticator} from: <ul>
@@ -38,44 +37,43 @@ import org.eclipse.jetty.util.security.Constraint;
  * <li>{@link org.eclipse.jetty.security.authentication.FormAuthenticator}</li>
  * <li>{@link org.eclipse.jetty.security.authentication.ClientCertAuthenticator}</li>
  * </ul>
- * All authenticators derived from {@link org.eclipse.jetty.security.authentication.LoginAuthenticator} are 
+ * All authenticators derived from {@link org.eclipse.jetty.security.authentication.LoginAuthenticator} are
  * wrapped with a {@link org.eclipse.jetty.security.authentication.DeferredAuthentication}
  * instance, which is used if authentication is not mandatory.
- * 
- * The Authentications from the {@link org.eclipse.jetty.security.authentication.FormAuthenticator} are always wrapped in a 
+ *
+ * The Authentications from the {@link org.eclipse.jetty.security.authentication.FormAuthenticator} are always wrapped in a
  * {@link org.eclipse.jetty.security.authentication.SessionAuthentication}
  * <p>
  * If a {@link LoginService} has not been set on this factory, then
  * the service is selected by searching the {@link Server#getBeans(Class)} results for
  * a service that matches the realm name, else the first LoginService found is used.
- *
  */
 public class DefaultAuthenticatorFactory implements Authenticator.Factory
 {
     LoginService _loginService;
-    
+
+    @Override
     public Authenticator getAuthenticator(Server server, ServletContext context, AuthConfiguration configuration, IdentityService identityService, LoginService loginService)
     {
-        String auth=configuration.getAuthMethod();
-        Authenticator authenticator=null;
-        
-        if (auth==null || Constraint.__BASIC_AUTH.equalsIgnoreCase(auth))
-            authenticator=new BasicAuthenticator();
+        String auth = configuration.getAuthMethod();
+        Authenticator authenticator = null;
+
+        if (auth == null || Constraint.__BASIC_AUTH.equalsIgnoreCase(auth))
+            authenticator = new BasicAuthenticator();
         else if (Constraint.__DIGEST_AUTH.equalsIgnoreCase(auth))
-            authenticator=new DigestAuthenticator();
+            authenticator = new DigestAuthenticator();
         else if (Constraint.__FORM_AUTH.equalsIgnoreCase(auth))
-            authenticator=new FormAuthenticator();
-        else if ( Constraint.__SPNEGO_AUTH.equalsIgnoreCase(auth) )
+            authenticator = new FormAuthenticator();
+        else if (Constraint.__SPNEGO_AUTH.equalsIgnoreCase(auth))
             authenticator = new SpnegoAuthenticator();
-        else if ( Constraint.__NEGOTIATE_AUTH.equalsIgnoreCase(auth) ) // see Bug #377076
+        else if (Constraint.__NEGOTIATE_AUTH.equalsIgnoreCase(auth)) // see Bug #377076
             authenticator = new SpnegoAuthenticator(Constraint.__NEGOTIATE_AUTH);
-        if (Constraint.__CERT_AUTH.equalsIgnoreCase(auth)||Constraint.__CERT_AUTH2.equalsIgnoreCase(auth))
-            authenticator=new ClientCertAuthenticator();
-        
+        if (Constraint.__CERT_AUTH.equalsIgnoreCase(auth) || Constraint.__CERT_AUTH2.equalsIgnoreCase(auth))
+            authenticator = new ClientCertAuthenticator();
+
         return authenticator;
     }
-   
-    /* ------------------------------------------------------------ */
+
     /**
      * @return the loginService
      */
@@ -84,7 +82,6 @@ public class DefaultAuthenticatorFactory implements Authenticator.Factory
         return _loginService;
     }
 
-    /* ------------------------------------------------------------ */
     /**
      * @param loginService the loginService to set
      */
@@ -92,5 +89,4 @@ public class DefaultAuthenticatorFactory implements Authenticator.Factory
     {
         _loginService = loginService;
     }
-
 }
