@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -19,38 +19,43 @@
 package org.eclipse.jetty.security;
 
 import java.security.Principal;
-import java.util.List;
 import javax.security.auth.Subject;
 
 import org.eclipse.jetty.server.UserIdentity;
 
 public class SpnegoUserIdentity implements UserIdentity
 {
-    private Subject _subject;
-    private Principal _principal;
-    private List<String> _roles;
+    private final Subject _subject;
+    private final Principal _principal;
+    private final UserIdentity _roleDelegate;
 
-    public SpnegoUserIdentity( Subject subject, Principal principal, List<String> roles )
+    public SpnegoUserIdentity(Subject subject, Principal principal, UserIdentity roleDelegate)
     {
         _subject = subject;
         _principal = principal;
-        _roles = roles;
+        _roleDelegate = roleDelegate;
     }
 
-
+    @Override
     public Subject getSubject()
     {
         return _subject;
     }
 
+    @Override
     public Principal getUserPrincipal()
     {
         return _principal;
     }
 
+    @Override
     public boolean isUserInRole(String role, Scope scope)
     {
-        return _roles.contains(role);
+        return _roleDelegate != null && _roleDelegate.isUserInRole(role, scope);
     }
 
+    public boolean isEstablished()
+    {
+        return _roleDelegate != null;
+    }
 }
