@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -23,6 +23,7 @@ import java.security.KeyStore;
 import java.security.Principal;
 import java.security.cert.CRL;
 import java.security.cert.X509Certificate;
+import java.util.Base64;
 import java.util.Collection;
 import javax.servlet.ServletRequest;
 import javax.servlet.ServletResponse;
@@ -34,40 +35,59 @@ import org.eclipse.jetty.security.UserAuthentication;
 import org.eclipse.jetty.server.Authentication;
 import org.eclipse.jetty.server.Authentication.User;
 import org.eclipse.jetty.server.UserIdentity;
-import org.eclipse.jetty.util.B64Code;
+import org.eclipse.jetty.util.resource.Resource;
 import org.eclipse.jetty.util.security.CertificateUtils;
 import org.eclipse.jetty.util.security.CertificateValidator;
 import org.eclipse.jetty.util.security.Constraint;
 import org.eclipse.jetty.util.security.Password;
 
-/**
- * @version $Rev: 4793 $ $Date: 2009-03-19 00:00:01 +0100 (Thu, 19 Mar 2009) $
- */
 public class ClientCertAuthenticator extends LoginAuthenticator
 {
-    /** String name of keystore password property. */
+    /**
+     * String name of keystore password property.
+     */
     private static final String PASSWORD_PROPERTY = "org.eclipse.jetty.ssl.password";
 
-    /** Truststore path */
+    /**
+     * Truststore path
+     */
     private String _trustStorePath;
-    /** Truststore provider name */
+    /**
+     * Truststore provider name
+     */
     private String _trustStoreProvider;
-    /** Truststore type */
+    /**
+     * Truststore type
+     */
     private String _trustStoreType = "JKS";
-    /** Truststore password */
+    /**
+     * Truststore password
+     */
     private transient Password _trustStorePassword;
 
-    /** Set to true if SSL certificate validation is required */
+    /**
+     * Set to true if SSL certificate validation is required
+     */
     private boolean _validateCerts;
-    /** Path to file that contains Certificate Revocation List */
+    /**
+     * Path to file that contains Certificate Revocation List
+     */
     private String _crlPath;
-    /** Maximum certification path length (n - number of intermediate certs, -1 for unlimited) */
+    /**
+     * Maximum certification path length (n - number of intermediate certs, -1 for unlimited)
+     */
     private int _maxCertPathLength = -1;
-    /** CRL Distribution Points (CRLDP) support */
+    /**
+     * CRL Distribution Points (CRLDP) support
+     */
     private boolean _enableCRLDP = false;
-    /** On-Line Certificate Status Protocol (OCSP) support */
+    /**
+     * On-Line Certificate Status Protocol (OCSP) support
+     */
     private boolean _enableOCSP = false;
-    /** Location of OCSP Responder */
+    /**
+     * Location of OCSP Responder
+     */
     private String _ocspResponderURL;
 
     public ClientCertAuthenticator()
@@ -81,12 +101,6 @@ public class ClientCertAuthenticator extends LoginAuthenticator
         return Constraint.__CERT_AUTH;
     }
 
-    
-
-    /**
-     * @return Authentication for request
-     * @throws ServerAuthException
-     */
     @Override
     public Authentication validateRequest(ServletRequest req, ServletResponse res, boolean mandatory) throws ServerAuthException
     {
@@ -95,7 +109,7 @@ public class ClientCertAuthenticator extends LoginAuthenticator
 
         HttpServletRequest request = (HttpServletRequest)req;
         HttpServletResponse response = (HttpServletResponse)res;
-        X509Certificate[] certs = (X509Certificate[]) request.getAttribute("javax.servlet.request.X509Certificate");
+        X509Certificate[] certs = (X509Certificate[])request.getAttribute("javax.servlet.request.X509Certificate");
 
         try
         {
@@ -105,29 +119,31 @@ public class ClientCertAuthenticator extends LoginAuthenticator
 
                 if (_validateCerts)
                 {
-                    KeyStore trustStore = getKeyStore(null,
-                            _trustStorePath, _trustStoreType, _trustStoreProvider,
-                            _trustStorePassword == null ? null :_trustStorePassword.toString());
+                    KeyStore trustStore = getKeyStore(
+                        _trustStorePath, _trustStoreType, _trustStoreProvider,
+                        _trustStorePassword == null ? null : _trustStorePassword.toString());
                     Collection<? extends CRL> crls = loadCRL(_crlPath);
                     CertificateValidator validator = new CertificateValidator(trustStore, crls);
                     validator.validate(certs);
                 }
 
-                for (X509Certificate cert: certs)
+                for (X509Certificate cert : certs)
                 {
-                    if (cert==null)
+                    if (cert == null)
                         continue;
 
                     Principal principal = cert.getSubjectDN();
-                    if (principal == null) principal = cert.getIssuerDN();
+                    if (principal == null)
+                        principal = cert.getIssuerDN();
                     final String username = principal == null ? "clientcert" : principal.getName();
 
-                    final char[] credential = B64Code.encode(cert.getSignature());
+                    // TODO: investigate if using a raw byte[] is better vs older char[]
+                    final char[] credential = Base64.getEncoder().encodeToString(cert.getSignature()).toCharArray();
 
                     UserIdentity user = login(username, credential, req);
-                    if (user!=null)
+                    if (user != null)
                     {
-                        return new UserAuthentication(getAuthMethod(),user);
+                        return new UserAuthentication(getAuthMethod(), user);
                     }
                 }
             }
@@ -146,7 +162,12 @@ public class ClientCertAuthenticator extends LoginAuthenticator
         }
     }
 
-    /* ------------------------------------------------------------ */
+    @Deprecated
+    protected KeyStore getKeyStore(InputStream storeStream, String storePath, String storeType, String storeProvider, String storePassword) throws Exception
+    {
+        return getKeyStore(storePath, storeType, storeProvider, storePassword);
+    }
+
     /**
      * Loads keystore using an input stream or a file path in the same
      * order of precedence.
@@ -154,20 +175,18 @@ public class ClientCertAuthenticator extends LoginAuthenticator
      * Required for integrations to be able to override the mechanism
      * used to load a keystore in order to provide their own implementation.
      *
-     * @param storeStream keystore input stream
      * @param storePath path of keystore file
      * @param storeType keystore type
      * @param storeProvider keystore provider
      * @param storePassword keystore password
      * @return created keystore
-     * @throws Exception
+     * @throws Exception if unable to get keystore
      */
-    protected KeyStore getKeyStore(InputStream storeStream, String storePath, String storeType, String storeProvider, String storePassword) throws Exception
+    protected KeyStore getKeyStore(String storePath, String storeType, String storeProvider, String storePassword) throws Exception
     {
-        return CertificateUtils.getKeyStore(storeStream, storePath, storeType, storeProvider, storePassword);
+        return CertificateUtils.getKeyStore(Resource.newResource(storePath), storeType, storeProvider, storePassword);
     }
 
-    /* ------------------------------------------------------------ */
     /**
      * Loads certificate revocation list (CRL) from a file.
      *
@@ -176,8 +195,8 @@ public class ClientCertAuthenticator extends LoginAuthenticator
      *
      * @param crlPath path of certificate revocation list file
      * @return a (possibly empty) collection view of java.security.cert.CRL objects initialized with the data from the
-     *         input stream.
-     * @throws Exception
+     * input stream.
+     * @throws Exception if unable to load CRL
      */
     protected Collection<? extends CRL> loadCRL(String crlPath) throws Exception
     {
@@ -190,7 +209,6 @@ public class ClientCertAuthenticator extends LoginAuthenticator
         return true;
     }
 
-    /* ------------------------------------------------------------ */
     /**
      * @return true if SSL certificate has to be validated
      */
@@ -199,17 +217,14 @@ public class ClientCertAuthenticator extends LoginAuthenticator
         return _validateCerts;
     }
 
-    /* ------------------------------------------------------------ */
     /**
-     * @param validateCerts
-     *            true if SSL certificates have to be validated
+     * @param validateCerts true if SSL certificates have to be validated
      */
     public void setValidateCerts(boolean validateCerts)
     {
         _validateCerts = validateCerts;
     }
 
-    /* ------------------------------------------------------------ */
     /**
      * @return The file name or URL of the trust store location
      */
@@ -218,17 +233,14 @@ public class ClientCertAuthenticator extends LoginAuthenticator
         return _trustStorePath;
     }
 
-    /* ------------------------------------------------------------ */
     /**
-     * @param trustStorePath
-     *            The file name or URL of the trust store location
+     * @param trustStorePath The file name or URL of the trust store location
      */
     public void setTrustStore(String trustStorePath)
     {
         _trustStorePath = trustStorePath;
     }
 
-    /* ------------------------------------------------------------ */
     /**
      * @return The provider of the trust store
      */
@@ -237,17 +249,14 @@ public class ClientCertAuthenticator extends LoginAuthenticator
         return _trustStoreProvider;
     }
 
-    /* ------------------------------------------------------------ */
     /**
-     * @param trustStoreProvider
-     *            The provider of the trust store
+     * @param trustStoreProvider The provider of the trust store
      */
     public void setTrustStoreProvider(String trustStoreProvider)
     {
         _trustStoreProvider = trustStoreProvider;
     }
 
-    /* ------------------------------------------------------------ */
     /**
      * @return The type of the trust store (default "JKS")
      */
@@ -256,28 +265,25 @@ public class ClientCertAuthenticator extends LoginAuthenticator
         return _trustStoreType;
     }
 
-    /* ------------------------------------------------------------ */
     /**
-     * @param trustStoreType
-     *            The type of the trust store (default "JKS")
+     * @param trustStoreType The type of the trust store (default "JKS")
      */
     public void setTrustStoreType(String trustStoreType)
     {
         _trustStoreType = trustStoreType;
     }
 
-    /* ------------------------------------------------------------ */
     /**
-     * @param password
-     *            The password for the trust store
+     * @param password The password for the trust store
      */
     public void setTrustStorePassword(String password)
     {
-        _trustStorePassword = Password.getPassword(PASSWORD_PROPERTY,password,null);
+        _trustStorePassword = Password.getPassword(PASSWORD_PROPERTY, password, null);
     }
 
-    /* ------------------------------------------------------------ */
-    /** Get the crlPath.
+    /**
+     * Get the crlPath.
+     *
      * @return the crlPath
      */
     public String getCrlPath()
@@ -285,8 +291,9 @@ public class ClientCertAuthenticator extends LoginAuthenticator
         return _crlPath;
     }
 
-    /* ------------------------------------------------------------ */
-    /** Set the crlPath.
+    /**
+     * Set the crlPath.
+     *
      * @param crlPath the crlPath to set
      */
     public void setCrlPath(String crlPath)
@@ -303,18 +310,15 @@ public class ClientCertAuthenticator extends LoginAuthenticator
         return _maxCertPathLength;
     }
 
-    /* ------------------------------------------------------------ */
     /**
-     * @param maxCertPathLength
-     *            maximum number of intermediate certificates in
-     *            the certification path (-1 for unlimited)
+     * @param maxCertPathLength maximum number of intermediate certificates in
+     * the certification path (-1 for unlimited)
      */
     public void setMaxCertPathLength(int maxCertPathLength)
     {
         _maxCertPathLength = maxCertPathLength;
     }
 
-    /* ------------------------------------------------------------ */
     /**
      * @return true if CRL Distribution Points support is enabled
      */
@@ -323,8 +327,9 @@ public class ClientCertAuthenticator extends LoginAuthenticator
         return _enableCRLDP;
     }
 
-    /* ------------------------------------------------------------ */
-    /** Enables CRL Distribution Points Support
+    /**
+     * Enables CRL Distribution Points Support
+     *
      * @param enableCRLDP true - turn on, false - turns off
      */
     public void setEnableCRLDP(boolean enableCRLDP)
@@ -332,7 +337,6 @@ public class ClientCertAuthenticator extends LoginAuthenticator
         _enableCRLDP = enableCRLDP;
     }
 
-    /* ------------------------------------------------------------ */
     /**
      * @return true if On-Line Certificate Status Protocol support is enabled
      */
@@ -341,8 +345,9 @@ public class ClientCertAuthenticator extends LoginAuthenticator
         return _enableOCSP;
     }
 
-    /* ------------------------------------------------------------ */
-    /** Enables On-Line Certificate Status Protocol support
+    /**
+     * Enables On-Line Certificate Status Protocol support
+     *
      * @param enableOCSP true - turn on, false - turn off
      */
     public void setEnableOCSP(boolean enableOCSP)
@@ -350,7 +355,6 @@ public class ClientCertAuthenticator extends LoginAuthenticator
         _enableOCSP = enableOCSP;
     }
 
-    /* ------------------------------------------------------------ */
     /**
      * @return Location of the OCSP Responder
      */
@@ -359,8 +363,9 @@ public class ClientCertAuthenticator extends LoginAuthenticator
         return _ocspResponderURL;
     }
 
-    /* ------------------------------------------------------------ */
-    /** Set the location of the OCSP Responder.
+    /**
+     * Set the location of the OCSP Responder.
+     *
      * @param ocspResponderURL location of the OCSP Responder
      */
     public void setOcspResponderURL(String ocspResponderURL)
