@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -19,40 +19,40 @@
 package org.eclipse.jetty.security;
 
 import java.util.ArrayList;
-import java.util.Collection;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
+import java.util.stream.Stream;
 
 import org.eclipse.jetty.http.HttpStatus;
 import org.eclipse.jetty.server.Connector;
+import org.eclipse.jetty.server.Handler;
 import org.eclipse.jetty.server.LocalConnector;
 import org.eclipse.jetty.server.Server;
 import org.eclipse.jetty.server.handler.ContextHandler;
+import org.eclipse.jetty.server.handler.DefaultHandler;
+import org.eclipse.jetty.server.handler.HandlerList;
 import org.eclipse.jetty.server.handler.ResourceHandler;
 import org.eclipse.jetty.server.session.SessionHandler;
 import org.eclipse.jetty.toolchain.test.MavenTestingUtils;
 import org.eclipse.jetty.util.security.Constraint;
 import org.eclipse.jetty.util.security.Password;
-import org.junit.AfterClass;
-import org.junit.BeforeClass;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
-import org.junit.runners.Parameterized.Parameter;
-import org.junit.runners.Parameterized.Parameters;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.Arguments;
+import org.junit.jupiter.params.provider.MethodSource;
 
+import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.containsString;
 import static org.hamcrest.Matchers.startsWith;
-import static org.junit.Assert.assertThat;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.fail;
 
 /**
  * Some requests for static data that is served by ResourceHandler, but some is secured.
  * <p>
  * This is mainly here to test security bypass techniques using aliased names that should be caught.
  */
-@RunWith(Parameterized.class)
 public class AliasedConstraintTest
 {
     private static final String TEST_REALM = "TestRealm";
@@ -60,26 +60,30 @@ public class AliasedConstraintTest
     private static LocalConnector connector;
     private static ConstraintSecurityHandler security;
 
-    @BeforeClass
+    @BeforeAll
     public static void startServer() throws Exception
     {
         server = new Server();
         connector = new LocalConnector(server);
-        server.setConnectors(new Connector[] { connector });
+        server.setConnectors(new Connector[]{connector});
 
         ContextHandler context = new ContextHandler();
         SessionHandler session = new SessionHandler();
 
-        HashLoginService loginService = new HashLoginService(TEST_REALM);
-        loginService.putUser("user0",new Password("password"),new String[] {});
-        loginService.putUser("user",new Password("password"),new String[] { "user" });
-        loginService.putUser("user2",new Password("password"),new String[] { "user" });
-        loginService.putUser("admin",new Password("password"),new String[] { "user", "administrator" });
-        loginService.putUser("user3",new Password("password"),new String[] { "foo" });
+        TestLoginService loginService = new TestLoginService(TEST_REALM);
+
+        loginService.putUser("user0", new Password("password"), new String[]{});
+        loginService.putUser("user", new Password("password"), new String[]{"user"});
+        loginService.putUser("user2", new Password("password"), new String[]{"user"});
+        loginService.putUser("admin", new Password("password"), new String[]{"user", "administrator"});
+        loginService.putUser("user3", new Password("password"), new String[]{"foo"});
 
         context.setContextPath("/ctx");
         context.setResourceBase(MavenTestingUtils.getTestResourceDir("docroot").getAbsolutePath());
-        server.setHandler(context);
+
+        HandlerList handlers = new HandlerList();
+        handlers.setHandlers(new Handler[]{context, new DefaultHandler()});
+        server.setHandler(handlers);
         context.setHandler(session);
         // context.addAliasCheck(new AllowSymLinkAliasChecker());
 
@@ -104,45 +108,36 @@ public class AliasedConstraintTest
         knownRoles.add("user");
         knownRoles.add("administrator");
 
-        security.setConstraintMappings(constraints,knownRoles);
+        security.setConstraintMappings(constraints, knownRoles);
         server.start();
     }
 
-    @AfterClass
+    @AfterAll
     public static void stopServer() throws Exception
     {
         server.stop();
     }
 
-    @Parameters(name = "{0}: {1}")
-    public static Collection<Object[]> data()
+    public static Stream<Arguments> data()
     {
         List<Object[]> data = new ArrayList<>();
 
         final String OPENCONTENT = "this is open content";
 
-        data.add(new Object[] { "/ctx/all/index.txt", HttpStatus.OK_200, OPENCONTENT });
-        data.add(new Object[] { "/ctx/ALL/index.txt", HttpStatus.NOT_FOUND_404, null });
-        data.add(new Object[] { "/ctx/ALL/Fred/../index.txt", HttpStatus.NOT_FOUND_404, null });
-        data.add(new Object[] { "/ctx/../bar/../ctx/all/index.txt", HttpStatus.OK_200, OPENCONTENT });
-        data.add(new Object[] { "/ctx/forbid/index.txt", HttpStatus.FORBIDDEN_403, null });
-        data.add(new Object[] { "/ctx/all/../forbid/index.txt", HttpStatus.FORBIDDEN_403, null });
-        data.add(new Object[] { "/ctx/FoRbId/index.txt", HttpStatus.NOT_FOUND_404, null });
+        data.add(new Object[]{"/ctx/all/index.txt", HttpStatus.OK_200, OPENCONTENT});
+        data.add(new Object[]{"/ctx/ALL/index.txt", HttpStatus.NOT_FOUND_404, null});
+        data.add(new Object[]{"/ctx/ALL/Fred/../index.txt", HttpStatus.NOT_FOUND_404, null});
+        data.add(new Object[]{"/ctx/../bar/../ctx/all/index.txt", HttpStatus.OK_200, OPENCONTENT});
+        data.add(new Object[]{"/ctx/forbid/index.txt", HttpStatus.FORBIDDEN_403, null});
+        data.add(new Object[]{"/ctx/all/../forbid/index.txt", HttpStatus.FORBIDDEN_403, null});
+        data.add(new Object[]{"/ctx/FoRbId/index.txt", HttpStatus.NOT_FOUND_404, null});
 
-        return data;
+        return data.stream().map(Arguments::of);
     }
 
-    @Parameter(value = 0)
-    public String uri;
-
-    @Parameter(value = 1)
-    public int expectedStatusCode;
-
-    @Parameter(value = 2)
-    public String expectedContent;
-
-    @Test
-    public void testAccess() throws Exception
+    @ParameterizedTest
+    @MethodSource("data")
+    public void testAccess(String uri, int expectedStatusCode, String expectedContent) throws Exception
     {
         StringBuilder request = new StringBuilder();
         request.append("GET ").append(uri).append(" HTTP/1.1\r\n");
@@ -150,18 +145,18 @@ public class AliasedConstraintTest
         request.append("Connection: close\r\n");
         request.append("\r\n");
 
-        String response = connector.getResponses(request.toString());
+        String response = connector.getResponse(request.toString());
 
         switch (expectedStatusCode)
         {
             case 200:
-                assertThat(response,startsWith("HTTP/1.1 200 OK"));
+                assertThat(response, startsWith("HTTP/1.1 200 OK"));
                 break;
             case 403:
-                assertThat(response,startsWith("HTTP/1.1 403 Forbidden"));
+                assertThat(response, startsWith("HTTP/1.1 403 Forbidden"));
                 break;
             case 404:
-                assertThat(response,startsWith("HTTP/1.1 404 Not Found"));
+                assertThat(response, startsWith("HTTP/1.1 404 Not Found"));
                 break;
             default:
                 fail("Write a handler for response status code: " + expectedStatusCode);
@@ -170,7 +165,7 @@ public class AliasedConstraintTest
 
         if (expectedContent != null)
         {
-            assertThat(response,containsString("this is open content"));
+            assertThat(response, containsString("this is open content"));
         }
     }
 }
