@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -31,6 +31,7 @@ import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.TimeUnit;
 import java.util.function.Consumer;
+import java.util.logging.Logger;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import java.util.stream.Stream;
@@ -64,6 +65,7 @@ import org.eclipse.jetty.util.StringUtil;
 import org.eclipse.jetty.util.TypeUtil;
 import org.eclipse.jetty.util.security.Constraint;
 import org.eclipse.jetty.util.security.Password;
+import org.hamcrest.Matchers;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
@@ -73,10 +75,12 @@ import org.junit.jupiter.params.provider.MethodSource;
 
 import static java.nio.charset.StandardCharsets.ISO_8859_1;
 import static org.hamcrest.MatcherAssert.assertThat;
+import static org.hamcrest.Matchers.contains;
 import static org.hamcrest.Matchers.containsString;
 import static org.hamcrest.Matchers.in;
 import static org.hamcrest.Matchers.is;
 import static org.hamcrest.Matchers.not;
+import static org.hamcrest.Matchers.nullValue;
 import static org.hamcrest.Matchers.startsWith;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
@@ -90,9 +94,17 @@ public class ConstraintTest
     private LocalConnector _connector;
     private ConstraintSecurityHandler _security;
     private HttpConfiguration _config;
+    private Constraint _forbidConstraint;
+    private Constraint _authAnyRoleConstraint;
+    private Constraint _authAdminConstraint;
+    private Constraint _relaxConstraint;
+    private Constraint _loginPageConstraint;
+    private Constraint _noAuthConstraint;
+    private Constraint _confidentialDataConstraint;
+    private Constraint _anyUserAuthConstraint;
 
     @BeforeEach
-    public void startServer()
+    public void setupServer()
     {
         _server = new Server();
         _connector = new LocalConnector(_server);
@@ -141,100 +153,154 @@ public class ConstraintTest
 
     private List<ConstraintMapping> getConstraintMappings()
     {
-        Constraint constraint0 = new Constraint();
-        constraint0.setAuthenticate(true);
-        constraint0.setName("forbid");
+        _forbidConstraint = new Constraint();
+        _forbidConstraint.setAuthenticate(true);
+        _forbidConstraint.setName("forbid");
         ConstraintMapping mapping0 = new ConstraintMapping();
         mapping0.setPathSpec("/forbid/*");
-        mapping0.setConstraint(constraint0);
+        mapping0.setConstraint(_forbidConstraint);
 
-        Constraint constraint1 = new Constraint();
-        constraint1.setAuthenticate(true);
-        constraint1.setName("auth");
-        constraint1.setRoles(new String[]{Constraint.ANY_ROLE});
+        _authAnyRoleConstraint = new Constraint();
+        _authAnyRoleConstraint.setAuthenticate(true);
+        _authAnyRoleConstraint.setName("auth");
+        _authAnyRoleConstraint.setRoles(new String[]{Constraint.ANY_ROLE});
         ConstraintMapping mapping1 = new ConstraintMapping();
         mapping1.setPathSpec("/auth/*");
-        mapping1.setConstraint(constraint1);
+        mapping1.setConstraint(_authAnyRoleConstraint);
 
-        Constraint constraint2 = new Constraint();
-        constraint2.setAuthenticate(true);
-        constraint2.setName("admin");
-        constraint2.setRoles(new String[]{"administrator"});
+        _authAdminConstraint = new Constraint();
+        _authAdminConstraint.setAuthenticate(true);
+        _authAdminConstraint.setName("admin");
+        _authAdminConstraint.setRoles(new String[]{"administrator"});
         ConstraintMapping mapping2 = new ConstraintMapping();
         mapping2.setPathSpec("/admin/*");
-        mapping2.setConstraint(constraint2);
+        mapping2.setConstraint(_authAdminConstraint);
         mapping2.setMethod("GET");
+        ConstraintMapping mapping2o = new ConstraintMapping();
+        mapping2o.setPathSpec("/admin/*");
+        mapping2o.setConstraint(_forbidConstraint);
+        mapping2o.setMethodOmissions(new String[]{"GET"});
 
-        Constraint constraint3 = new Constraint();
-        constraint3.setAuthenticate(false);
-        constraint3.setName("relax");
+        _relaxConstraint = new Constraint();
+        _relaxConstraint.setAuthenticate(false);
+        _relaxConstraint.setName("relax");
         ConstraintMapping mapping3 = new ConstraintMapping();
         mapping3.setPathSpec("/admin/relax/*");
-        mapping3.setConstraint(constraint3);
+        mapping3.setConstraint(_relaxConstraint);
 
-        Constraint constraint4 = new Constraint();
-        constraint4.setAuthenticate(true);
-        constraint4.setName("loginpage");
-        constraint4.setRoles(new String[]{"administrator"});
+        _loginPageConstraint = new Constraint();
+        _loginPageConstraint.setAuthenticate(true);
+        _loginPageConstraint.setName("loginpage");
+        _loginPageConstraint.setRoles(new String[]{"administrator"});
         ConstraintMapping mapping4 = new ConstraintMapping();
         mapping4.setPathSpec("/testLoginPage");
-        mapping4.setConstraint(constraint4);
+        mapping4.setConstraint(_loginPageConstraint);
 
-        Constraint constraint5 = new Constraint();
-        constraint5.setAuthenticate(false);
-        constraint5.setName("allow forbidden POST");
+        _noAuthConstraint = new Constraint();
+        _noAuthConstraint.setAuthenticate(false);
+        _noAuthConstraint.setName("allow forbidden");
         ConstraintMapping mapping5 = new ConstraintMapping();
         mapping5.setPathSpec("/forbid/post");
-        mapping5.setConstraint(constraint5);
+        mapping5.setConstraint(_noAuthConstraint);
         mapping5.setMethod("POST");
+        ConstraintMapping mapping5o = new ConstraintMapping();
+        mapping5o.setPathSpec("/forbid/post");
+        mapping5o.setConstraint(_forbidConstraint);
+        mapping5o.setMethodOmissions(new String[]{"POST"});
 
-        Constraint constraint6 = new Constraint();
-        constraint6.setAuthenticate(false);
-        constraint6.setName("data constraint");
-        constraint6.setDataConstraint(2);
+        _confidentialDataConstraint = new Constraint();
+        _confidentialDataConstraint.setAuthenticate(false);
+        _confidentialDataConstraint.setName("data constraint");
+        _confidentialDataConstraint.setDataConstraint(Constraint.DC_CONFIDENTIAL);
         ConstraintMapping mapping6 = new ConstraintMapping();
         mapping6.setPathSpec("/data/*");
-        mapping6.setConstraint(constraint6);
+        mapping6.setConstraint(_confidentialDataConstraint);
 
-        Constraint constraint7 = new Constraint();
-        constraint7.setAuthenticate(true);
-        constraint7.setName("** constraint");
-        constraint7.setRoles(new String[]{
+        _anyUserAuthConstraint = new Constraint();
+        _anyUserAuthConstraint.setAuthenticate(true);
+        _anyUserAuthConstraint.setName("** constraint");
+        _anyUserAuthConstraint.setRoles(new String[]{
             Constraint.ANY_AUTH, "user"
         }); //the "user" role is superfluous once ** has been defined
         ConstraintMapping mapping7 = new ConstraintMapping();
         mapping7.setPathSpec("/starstar/*");
-        mapping7.setConstraint(constraint7);
+        mapping7.setConstraint(_anyUserAuthConstraint);
 
-        return Arrays.asList(mapping0, mapping1, mapping2, mapping3, mapping4, mapping5, mapping6, mapping7);
+        return Arrays.asList(mapping0, mapping1, mapping2, mapping2o, mapping3, mapping4, mapping5, mapping5o, mapping6, mapping7);
     }
 
+    /**
+     * Test that constraint mappings added before the context starts are
+     * retained, but those that are added after the context starts are not.
+     * 
+     * @throws Exception
+     */
     @Test
-    public void testConstraints() throws Exception
+    public void testDurableConstraints() throws Exception
     {
-        List<ConstraintMapping> mappings = new ArrayList<>(_security.getConstraintMappings());
-
-        assertTrue(mappings.get(0).getConstraint().isForbidden());
-        assertFalse(mappings.get(1).getConstraint().isForbidden());
-        assertFalse(mappings.get(2).getConstraint().isForbidden());
-        assertFalse(mappings.get(3).getConstraint().isForbidden());
-
-        assertFalse(mappings.get(0).getConstraint().isAnyRole());
-        assertTrue(mappings.get(1).getConstraint().isAnyRole());
-        assertFalse(mappings.get(2).getConstraint().isAnyRole());
-        assertFalse(mappings.get(3).getConstraint().isAnyRole());
-
-        assertFalse(mappings.get(0).getConstraint().hasRole("administrator"));
-        assertTrue(mappings.get(1).getConstraint().hasRole("administrator"));
-        assertTrue(mappings.get(2).getConstraint().hasRole("administrator"));
-        assertFalse(mappings.get(3).getConstraint().hasRole("administrator"));
-
-        assertTrue(mappings.get(0).getConstraint().getAuthenticate());
-        assertTrue(mappings.get(1).getConstraint().getAuthenticate());
-        assertTrue(mappings.get(2).getConstraint().getAuthenticate());
-        assertFalse(mappings.get(3).getConstraint().getAuthenticate());
+        List<ConstraintMapping> mappings =  _security.getConstraintMappings();
+        assertThat("before start", getConstraintMappings().size(), Matchers.equalTo(mappings.size()));
+        
+        _server.start();
+        
+        mappings =  _security.getConstraintMappings();
+        assertThat("after start", getConstraintMappings().size(), Matchers.equalTo(mappings.size()));
+        
+        _server.stop();
+        
+        //After a stop, just the durable mappings are left
+        mappings = _security.getConstraintMappings();
+        assertThat("after stop", getConstraintMappings().size(), Matchers.equalTo(mappings.size()));
+        
+        _server.start();
+        
+        //Verify the constraints are just the durables
+        mappings = _security.getConstraintMappings();
+        assertThat("after restart", getConstraintMappings().size(), Matchers.equalTo(mappings.size()));
+        
+        //Add a non-durable constraint
+        ConstraintMapping mapping = new ConstraintMapping();
+        mapping.setPathSpec("/xxxx/*");
+        Constraint constraint = new Constraint();
+        constraint.setAuthenticate(false);
+        constraint.setName("transient");
+        mapping.setConstraint(constraint);
+        
+        _security.addConstraintMapping(mapping);
+        
+        mappings = _security.getConstraintMappings();
+        assertThat("after addition", getConstraintMappings().size() + 1, Matchers.equalTo(mappings.size()));
+        
+        _server.stop();
+        _server.start();
+        
+        //After a stop, only the durable mappings remain
+        mappings = _security.getConstraintMappings();
+        assertThat("after addition", getConstraintMappings().size(), Matchers.equalTo(mappings.size()));
+        
+        //test that setConstraintMappings replaces all existing mappings whether durable or not
+        
+        //test setConstraintMappings in durable state
+        _server.stop();
+        _security.setConstraintMappings(Collections.singletonList(mapping));
+        mappings = _security.getConstraintMappings();
+        assertThat("after set during stop", 1, Matchers.equalTo(mappings.size()));
+        _server.start();
+        mappings = _security.getConstraintMappings();
+        assertThat("after set after start", 1, Matchers.equalTo(mappings.size()));
+       
+        //test setConstraintMappings not in durable state
+        _server.stop();
+        _server.start();
+        assertThat("no change after start", 1, Matchers.equalTo(mappings.size()));
+        _security.setConstraintMappings(getConstraintMappings());
+        mappings = _security.getConstraintMappings();
+        assertThat("durables lost", getConstraintMappings().size(), Matchers.equalTo(mappings.size()));
+        _server.stop();
+        mappings = _security.getConstraintMappings();
+        assertThat("no mappings", 0, Matchers.equalTo(mappings.size()));
     }
-
+    
     /**
      * Equivalent of Servlet Spec 3.1 pg 132, sec 13.4.1.1, Example 13-1
      * &#064;ServletSecurity
@@ -468,9 +534,6 @@ public class ConstraintTest
             )
         ));
 
-//        rawResponse = _connector.getResponse("GET /ctx/noauth/info HTTP/1.0\r\n\r\n");
-//        assertThat(rawResponse, startsWith("HTTP/1.1 200 OK"));
-
         scenarios.add(Arguments.of(
             new Scenario(
                 "GET /ctx/forbid/info HTTP/1.0\r\n\r\n",
@@ -478,9 +541,6 @@ public class ConstraintTest
             )
         ));
 
-//        rawResponse = _connector.getResponse("GET /ctx/forbid/info HTTP/1.0\r\n\r\n");
-//        assertThat(rawResponse, startsWith("HTTP/1.1 403 Forbidden"));
-
         scenarios.add(Arguments.of(
             new Scenario(
                 "GET /ctx/auth/info HTTP/1.0\r\n\r\n",
@@ -493,9 +553,39 @@ public class ConstraintTest
             )
         ));
 
-//        rawResponse = _connector.getResponse("GET /ctx/auth/info HTTP/1.0\r\n\r\n");
-//        assertThat(rawResponse, startsWith("HTTP/1.1 401 Unauthorized"));
-//        assertThat(rawResponse, containsString("WWW-Authenticate: basic realm=\"TestRealm\""));
+        scenarios.add(Arguments.of(
+            new Scenario(
+                "POST /ctx/auth/info HTTP/1.1\r\n" +
+                    "Host: test\r\n" +
+                    "Content-Length: 10\r\n" +
+                    "\r\n" +
+                    "0123456789",
+                HttpStatus.UNAUTHORIZED_401,
+                (response) ->
+                {
+                    String authHeader = response.get(HttpHeader.WWW_AUTHENTICATE);
+                    assertThat(response.toString(), authHeader, containsString("basic realm=\"TestRealm\""));
+                    assertThat(response.get(HttpHeader.CONNECTION), nullValue());
+                }
+            )
+        ));
+
+        scenarios.add(Arguments.of(
+            new Scenario(
+                "POST /ctx/auth/info HTTP/1.1\r\n" +
+                    "Host: test\r\n" +
+                    "Content-Length: 10\r\n" +
+                    "\r\n" +
+                    "012345",
+                HttpStatus.UNAUTHORIZED_401,
+                (response) ->
+                {
+                    String authHeader = response.get(HttpHeader.WWW_AUTHENTICATE);
+                    assertThat(response.toString(), authHeader, containsString("basic realm=\"TestRealm\""));
+                    assertThat(response.get(HttpHeader.CONNECTION), is("close"));
+                }
+            )
+        ));
 
         scenarios.add(Arguments.of(
             new Scenario(
@@ -511,12 +601,6 @@ public class ConstraintTest
             )
         ));
 
-//        rawResponse = _connector.getResponse("GET /ctx/auth/info HTTP/1.0\r\n" +
-//                "Authorization: Basic " + authBase64("user:wrong") + "\r\n" +
-//                "\r\n");
-//        assertThat(rawResponse, startsWith("HTTP/1.1 401 Unauthorized"));
-//        assertThat(rawResponse, containsString("WWW-Authenticate: basic realm=\"TestRealm\""));
-
         scenarios.add(Arguments.of(
             new Scenario(
                 "GET /ctx/auth/info HTTP/1.0\r\n" +
@@ -526,10 +610,16 @@ public class ConstraintTest
             )
         ));
 
-//        rawResponse = _connector.getResponse("GET /ctx/auth/info HTTP/1.0\r\n" +
-//                "Authorization: Basic " + authBase64("user:password") + "\r\n" +
-//                "\r\n");
-//        assertThat(rawResponse, startsWith("HTTP/1.1 200 OK"));
+        scenarios.add(Arguments.of(
+            new Scenario(
+                "POST /ctx/auth/info HTTP/1.0\r\n" +
+                    "Content-Length: 10\r\n" +
+                    "Authorization: Basic " + authBase64("user:password") + "\r\n" +
+                    "\r\n" +
+                    "0123456789",
+                HttpStatus.OK_200
+            )
+        ));
 
         // == test admin
         scenarios.add(Arguments.of(
@@ -544,10 +634,6 @@ public class ConstraintTest
             )
         ));
 
-//        rawResponse = _connector.getResponse("GET /ctx/admin/info HTTP/1.0\r\n\r\n");
-//        assertThat(rawResponse, startsWith("HTTP/1.1 401 Unauthorized"));
-//        assertThat(rawResponse, containsString("WWW-Authenticate: basic realm=\"TestRealm\""));
-
         scenarios.add(Arguments.of(
             new Scenario(
                 "GET /ctx/admin/info HTTP/1.0\r\n" +
@@ -634,7 +720,7 @@ public class ConstraintTest
     @MethodSource("basicScenarios")
     public void testBasic(Scenario scenario) throws Exception
     {
-        List<ConstraintMapping> list = new ArrayList<>(_security.getConstraintMappings());
+        List<ConstraintMapping> list = new ArrayList<>(getConstraintMappings());
 
         Constraint constraint6 = new Constraint();
         constraint6.setAuthenticate(true);
@@ -664,7 +750,7 @@ public class ConstraintTest
         constraint8.setRoles(new String[]{"foo"});
         ConstraintMapping mapping8 = new ConstraintMapping();
         mapping8.setPathSpec("/omit/*");
-        mapping8.setConstraint(constraint8);//requests for all methods must be in role "foo"
+        mapping8.setConstraint(constraint8); //requests for all methods must be in role "foo"
         list.add(mapping8);
 
         Set<String> knownRoles = new HashSet<>();
@@ -1007,6 +1093,63 @@ public class ConstraintTest
         assertThat(response, containsString("!role"));
     }
 
+    @Test
+    public void testNonFormPostRedirectHttp10() throws Exception
+    {
+        _security.setAuthenticator(new FormAuthenticator("/testLoginPage", "/testErrorPage", false));
+        _server.start();
+
+        String response = _connector.getResponse("POST /ctx/auth/info HTTP/1.0\r\n" +
+            "Content-Type: text/plain\r\n" +
+            "Connection: keep-alive\r\n" +
+            "Content-Length: 10\r\n" +
+            "\r\n" +
+            "0123456789\r\n");
+        assertThat(response, containsString(" 302 Found"));
+        assertThat(response, containsString("/ctx/testLoginPage"));
+        assertThat(response, not(containsString("Connection: close")));
+        assertThat(response, containsString("Connection: keep-alive"));
+
+        response = _connector.getResponse("POST /ctx/auth/info HTTP/1.0\r\n" +
+            "Host: localhost\r\n" +
+            "Content-Type: text/plain\r\n" +
+            "Connection: keep-alive\r\n" +
+            "Content-Length: 10\r\n" +
+            "\r\n" +
+            "012345\r\n");
+        assertThat(response, containsString(" 302 Found"));
+        assertThat(response, containsString("/ctx/testLoginPage"));
+        assertThat(response, not(containsString("Connection: keep-alive")));
+    }
+
+    @Test
+    public void testNonFormPostRedirectHttp11() throws Exception
+    {
+        _security.setAuthenticator(new FormAuthenticator("/testLoginPage", "/testErrorPage", false));
+        _server.start();
+
+        String response = _connector.getResponse("POST /ctx/auth/info HTTP/1.1\r\n" +
+            "Host: test\r\n" +
+            "Content-Type: text/plain\r\n" +
+            "Content-Length: 10\r\n" +
+            "\r\n" +
+            "0123456789\r\n");
+        assertThat(response, containsString(" 303 See Other"));
+        assertThat(response, containsString("/ctx/testLoginPage"));
+        assertThat(response, not(containsString("Connection: close")));
+
+        response = _connector.getResponse("POST /ctx/auth/info HTTP/1.1\r\n" +
+            "Host: test\r\n" +
+            "Host: localhost\r\n" +
+            "Content-Type: text/plain\r\n" +
+            "Content-Length: 10\r\n" +
+            "\r\n" +
+            "012345\r\n");
+        assertThat(response, containsString(" 303 See Other"));
+        assertThat(response, containsString("/ctx/testLoginPage"));
+        assertThat(response, containsString("Connection: close"));
+    }
+
     @Test
     public void testFormNoCookies() throws Exception
     {
@@ -1647,7 +1790,78 @@ public class ConstraintTest
         assertThat(response, startsWith("HTTP/1.1 200 "));
 
         response = _connector.getResponse("GET /ctx/forbid/post HTTP/1.0\r\n\r\n");
-        assertThat(response, startsWith("HTTP/1.1 200 "));  // This is so stupid, but it is the S P E C
+        assertThat(response, startsWith("HTTP/1.1 403 "));
+    }
+
+    @Test
+    public void testUncoveredMethod() throws Exception
+    {
+        ConstraintMapping specificMethod = new ConstraintMapping();
+        specificMethod.setMethod("GET");
+        specificMethod.setPathSpec("/specific/method");
+        specificMethod.setConstraint(_forbidConstraint);
+        _security.addConstraintMapping(specificMethod);
+        _security.setAuthenticator(new BasicAuthenticator());
+        Logger.getAnonymousLogger().info("Uncovered method for /specific/method is expected");
+        _server.start();
+
+        assertThat(_security.getPathsWithUncoveredHttpMethods(), contains("/specific/method"));
+
+        String response;
+        response = _connector.getResponse("GET /ctx/specific/method HTTP/1.0\r\n\r\n");
+        assertThat(response, startsWith("HTTP/1.1 403 "));
+
+        response = _connector.getResponse("POST /ctx/specific/method HTTP/1.0\r\n\r\n");
+        assertThat(response, startsWith("HTTP/1.1 200 ")); // This is so stupid, but it is the S P E C
+    }
+
+    @Test
+    public void testForbidTraceAndOptions() throws Exception
+    {
+        ConstraintMapping forbidTrace = new ConstraintMapping();
+        forbidTrace.setMethod("TRACE");
+        forbidTrace.setPathSpec("/");
+        forbidTrace.setConstraint(_forbidConstraint);
+        ConstraintMapping allowOmitTrace = new ConstraintMapping();
+        allowOmitTrace.setMethodOmissions(new String[] {"TRACE"});
+        allowOmitTrace.setPathSpec("/");
+        allowOmitTrace.setConstraint(_relaxConstraint);
+
+        ConstraintMapping forbidOptions = new ConstraintMapping();
+        forbidOptions.setMethod("OPTIONS");
+        forbidOptions.setPathSpec("/");
+        forbidOptions.setConstraint(_forbidConstraint);
+        ConstraintMapping allowOmitOptions = new ConstraintMapping();
+        allowOmitOptions.setMethodOmissions(new String[] {"OPTIONS"});
+        allowOmitOptions.setPathSpec("/");
+        allowOmitOptions.setConstraint(_relaxConstraint);
+
+        ConstraintMapping someConstraint = new ConstraintMapping();
+        someConstraint.setPathSpec("/some/constaint/*");
+        someConstraint.setConstraint(_noAuthConstraint);
+
+        _security.setConstraintMappings(new ConstraintMapping[] {forbidTrace, allowOmitTrace, forbidOptions, allowOmitOptions, someConstraint});
+
+        _security.setAuthenticator(new BasicAuthenticator());
+        _server.start();
+
+        assertThat(_security.getPathsWithUncoveredHttpMethods(), Matchers.empty());
+
+        String response;
+        response = _connector.getResponse("TRACE /ctx/some/path HTTP/1.0\r\n\r\n");
+        assertThat(response, startsWith("HTTP/1.1 403 "));
+
+        response = _connector.getResponse("OPTIONS /ctx/some/path HTTP/1.0\r\n\r\n");
+        assertThat(response, startsWith("HTTP/1.1 403 "));
+
+        response = _connector.getResponse("GET /ctx/some/path HTTP/1.0\r\n\r\n");
+        assertThat(response, startsWith("HTTP/1.1 200 "));
+
+        response = _connector.getResponse("GET /ctx/some/constraint/info HTTP/1.0\r\n\r\n");
+        assertThat(response, startsWith("HTTP/1.1 200 "));
+
+        response = _connector.getResponse("OPTIONS /ctx/some/constraint/info HTTP/1.0\r\n\r\n");
+        assertThat(response, startsWith("HTTP/1.1 403 "));
     }
 
     private static String authBase64(String authorization)
