@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -20,6 +20,7 @@ package org.eclipse.jetty.server;
 
 import java.util.Arrays;
 import java.util.Collections;
+import java.util.Iterator;
 import java.util.List;
 
 import org.eclipse.jetty.io.AbstractConnection;
@@ -87,6 +88,26 @@ public abstract class AbstractConnectionFactory extends ContainerLifeCycle imple
         _inputbufferSize = size;
     }
 
+    protected String findNextProtocol(Connector connector)
+    {
+        return findNextProtocol(connector, getProtocol());
+    }
+
+    protected static String findNextProtocol(Connector connector, String currentProtocol)
+    {
+        String nextProtocol = null;
+        for (Iterator<String> it = connector.getProtocols().iterator(); it.hasNext(); )
+        {
+            String protocol = it.next();
+            if (currentProtocol.equalsIgnoreCase(protocol))
+            {
+                nextProtocol = it.hasNext() ? it.next() : null;
+                break;
+            }
+        }
+        return nextProtocol;
+    }
+
     protected AbstractConnection configure(AbstractConnection connection, Connector connector, EndPoint endPoint)
     {
         connection.setInputBufferSize(getInputBufferSize());
