@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -18,6 +18,7 @@
 
 package org.eclipse.jetty.server;
 
+import java.nio.ByteBuffer;
 import java.util.List;
 
 import org.eclipse.jetty.http.BadMessageException;
@@ -85,4 +86,43 @@ public interface ConnectionFactory
          */
         Connection upgradeConnection(Connector connector, EndPoint endPoint, MetaData.Request upgradeRequest, HttpFields responseFields) throws BadMessageException;
     }
+
+    /**
+     * <p>Connections created by this factory MUST implement {@link Connection.UpgradeTo}.</p>
+     */
+    interface Detecting extends ConnectionFactory
+    {
+        /**
+         * The possible outcomes of the {@link #detect(ByteBuffer)} method.
+         */
+        enum Detection
+        {
+            /**
+             * A {@link Detecting} can work with the given bytes.
+             */
+            RECOGNIZED,
+            /**
+             * A {@link Detecting} cannot work with the given bytes.
+             */
+            NOT_RECOGNIZED,
+            /**
+             * A {@link Detecting} requires more bytes to make a decision.
+             */
+            NEED_MORE_BYTES
+        }
+
+        /**
+         * <p>Check the bytes in the given {@code buffer} to figure out if this {@link Detecting} instance
+         * can work with them or not.</p>
+         * <p>The {@code buffer} MUST be left untouched by this method: bytes MUST NOT be consumed and MUST NOT be modified.</p>
+         * @param buffer the buffer.
+         * @return One of:
+         * <ul>
+         * <li>{@link Detection#RECOGNIZED} if this {@link Detecting} instance can work with the bytes in the buffer</li>
+         * <li>{@link Detection#NOT_RECOGNIZED} if this {@link Detecting} instance cannot work with the bytes in the buffer</li>
+         * <li>{@link Detection#NEED_MORE_BYTES} if this {@link Detecting} instance requires more bytes to make a decision</li>
+         * </ul>
+         */
+        Detection detect(ByteBuffer buffer);
+    }
 }
