@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -34,6 +34,11 @@ public abstract class NegotiatingServerConnection extends AbstractConnection
 {
     private static final Logger LOG = Log.getLogger(NegotiatingServerConnection.class);
 
+    public interface CipherDiscriminator
+    {
+        boolean isAcceptable(String protocol, String tlsProtocol, String tlsCipher);
+    }
+
     private final Connector connector;
     private final SSLEngine engine;
     private final List<String> protocols;
@@ -49,22 +54,27 @@ public abstract class NegotiatingServerConnection extends AbstractConnection
         this.engine = engine;
     }
 
-    protected List<String> getProtocols()
+    public List<String> getProtocols()
     {
         return protocols;
     }
 
-    protected String getDefaultProtocol()
+    public String getDefaultProtocol()
     {
         return defaultProtocol;
     }
 
-    protected SSLEngine getSSLEngine()
+    public Connector getConnector()
+    {
+        return connector;
+    }
+
+    public SSLEngine getSSLEngine()
     {
         return engine;
     }
 
-    protected String getProtocol()
+    public String getProtocol()
     {
         return protocol;
     }
@@ -109,9 +119,8 @@ public abstract class NegotiatingServerConnection extends AbstractConnection
                 ConnectionFactory connectionFactory = connector.getConnectionFactory(protocol);
                 if (connectionFactory == null)
                 {
-                    if (LOG.isDebugEnabled())
-                        LOG.debug("{} application selected protocol '{}', but no correspondent {} has been configured",
-                            this, protocol, ConnectionFactory.class.getName());
+                    LOG.info("{} application selected protocol '{}', but no correspondent {} has been configured",
+                        this, protocol, ConnectionFactory.class.getName());
                     close();
                 }
                 else
@@ -126,7 +135,7 @@ public abstract class NegotiatingServerConnection extends AbstractConnection
         {
             // Something went bad, we need to close.
             if (LOG.isDebugEnabled())
-                LOG.debug("{} closing on client close", this);
+                LOG.debug("{} detected close on client side", this);
             close();
         }
         else
