@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -141,7 +141,7 @@ public class ResourceService
     public void setPrecompressedFormats(CompressedContentFormat[] precompressedFormats)
     {
         _precompressedFormats = precompressedFormats;
-        _preferredEncodingOrder = stream(_precompressedFormats).map(f -> f._encoding).toArray(String[]::new);
+        _preferredEncodingOrder = stream(_precompressedFormats).map(f -> f.getEncoding()).toArray(String[]::new);
     }
 
     public void setEncodingCacheSize(int encodingCacheSize)
@@ -181,7 +181,13 @@ public class ResourceService
 
     public void setCacheControl(HttpField cacheControl)
     {
-        _cacheControl = cacheControl;
+        if (cacheControl == null)
+            _cacheControl = null;
+        if (cacheControl.getHeader() != HttpHeader.CACHE_CONTROL)
+            throw new IllegalArgumentException("!Cache-Control");
+        _cacheControl = cacheControl instanceof PreEncodedHttpField
+            ? cacheControl
+            : new PreEncodedHttpField(cacheControl.getHeader(), cacheControl.getValue());
     }
 
     public List<String> getGzipEquivalentFileExtensions()
@@ -282,7 +288,7 @@ public class ResourceService
                     if (LOG.isDebugEnabled())
                         LOG.debug("precompressed={}", precompressedContent);
                     content = precompressedContent;
-                    response.setHeader(HttpHeader.CONTENT_ENCODING.asString(), precompressedContentEncoding._encoding);
+                    response.setHeader(HttpHeader.CONTENT_ENCODING.asString(), precompressedContentEncoding.getEncoding());
                 }
             }
 
@@ -355,7 +361,7 @@ public class ResourceService
         {
             for (CompressedContentFormat format : availableFormats)
             {
-                if (format._encoding.equals(encoding))
+                if (format.getEncoding().equals(encoding))
                     return format;
             }
 
@@ -399,8 +405,11 @@ public class ResourceService
 
         if (welcome != null)
         {
+            String servletPath = included ? (String)request.getAttribute(RequestDispatcher.INCLUDE_SERVLET_PATH)
+                    : request.getServletPath();
+
             if (_pathInfoOnly)
-                welcome = URIUtil.addPaths(request.getServletPath(), welcome);
+                welcome = URIUtil.addPaths(servletPath, welcome);
 
             if (LOG.isDebugEnabled())
                 LOG.debug("welcome={}", welcome);
@@ -528,9 +537,9 @@ public class ResourceService
                     if (etag != null)
                     {
                         QuotedCSV quoted = new QuotedCSV(true, ifm);
-                        for (String tag : quoted)
+                        for (String etagWithSuffix : quoted)
                         {
-                            if (CompressedContentFormat.tagEquals(etag, tag))
+                            if (CompressedContentFormat.tagEquals(etag, etagWithSuffix))
                             {
                                 match = true;
                                 break;
@@ -575,7 +584,7 @@ public class ResourceService
             {
                 //Get jetty's Response impl
                 String mdlm = content.getLastModifiedValue();
-                if (mdlm != null && ifms.equals(mdlm))
+                if (ifms.equals(mdlm))
                 {
                     sendStatus(response, HttpServletResponse.SC_NOT_MODIFIED, content::getETagValue);
                     return false;
@@ -671,10 +680,10 @@ public class ResourceService
                 content.getResource().writeTo(out, 0, content_length);
             }
             // else if we can't do a bypass write because of wrapping
-            else if (written || !(out instanceof HttpOutput))
+            else if (written)
             {
                 // write normally
-                putHeaders(response, content, written ? -1 : 0);
+                putHeaders(response, content, Response.NO_CONTENT_LENGTH);
                 ByteBuffer buffer = content.getIndirectBuffer();
                 if (buffer != null)
                     BufferUtil.writeTo(buffer, out);
@@ -685,10 +694,10 @@ public class ResourceService
             else
             {
                 // write the headers
-                putHeaders(response, content, 0);
+                putHeaders(response, content, Response.USE_KNOWN_CONTENT_LENGTH);
 
                 // write the content asynchronously if supported
-                if (request.isAsyncSupported() && content.getContentLengthValue() > response.getBufferSize())
+                if (request.isAsyncSupported())
                 {
                     final AsyncContext context = request.startAsync();
                     context.setTimeout(0);
@@ -733,7 +742,7 @@ public class ResourceService
             //  if there are no satisfiable ranges, send 416 response
             if (ranges == null || ranges.size() == 0)
             {
-                putHeaders(response, content, 0);
+                putHeaders(response, content, Response.USE_KNOWN_CONTENT_LENGTH);
                 response.setHeader(HttpHeader.CONTENT_RANGE.asString(),
                     InclusiveByteRange.to416HeaderRangeString(content_length));
                 sendStatus(response, HttpServletResponse.SC_REQUESTED_RANGE_NOT_SATISFIABLE, null);
@@ -760,8 +769,8 @@ public class ResourceService
             //  216 response which does not require an overall
             //  content-length header
             //
-            putHeaders(response, content, -1);
-            String mimetype = (content == null ? null : content.getContentTypeValue());
+            putHeaders(response, content, Response.NO_CONTENT_LENGTH);
+            String mimetype = content.getContentTypeValue();
             if (mimetype == null)
                 LOG.warn("Unknown mimetype for " + request.getRequestURI());
             MultiPartOutputStream multi = new MultiPartOutputStream(out);
@@ -783,19 +792,24 @@ public class ResourceService
             int length = 0;
             String[] header = new String[ranges.size()];
             int i = 0;
+            final int CRLF = "\r\n".length();
+            final int DASHDASH = "--".length();
+            final int BOUNDARY = multi.getBoundary().length();
+            final int FIELD_SEP = ": ".length();
             for (InclusiveByteRange ibr : ranges)
             {
                 header[i] = ibr.toHeaderRangeString(content_length);
-                length +=
-                    ((i > 0) ? 2 : 0) +
-                        2 + multi.getBoundary().length() + 2 +
-                        (mimetype == null ? 0 : HttpHeader.CONTENT_TYPE.asString().length() + 2 + mimetype.length()) + 2 +
-                        HttpHeader.CONTENT_RANGE.asString().length() + 2 + header[i].length() + 2 +
-                        2 +
-                        (ibr.getLast() - ibr.getFirst()) + 1;
+                if (i > 0) // in-part
+                    length += CRLF;
+                length += DASHDASH + BOUNDARY + CRLF;
+                if (mimetype != null)
+                    length += HttpHeader.CONTENT_TYPE.asString().length() + FIELD_SEP + mimetype.length() + CRLF;
+                length += HttpHeader.CONTENT_RANGE.asString().length() + FIELD_SEP + header[i].length() + CRLF;
+                length += CRLF;
+                length += ibr.getSize();
                 i++;
             }
-            length += 2 + 2 + multi.getBoundary().length() + 2 + 2;
+            length += CRLF + DASHDASH + BOUNDARY + DASHDASH + CRLF;
             response.setContentLength(length);
 
             try (RangeWriter rangeWriter = HttpContentRangeWriter.newRangeWriter(content))
@@ -820,20 +834,20 @@ public class ResourceService
         {
             Response r = (Response)response;
             r.putHeaders(content, contentLength, _etags);
-            HttpFields f = r.getHttpFields();
-            if (_acceptRanges)
-                f.put(ACCEPT_RANGES);
+            HttpFields fields = r.getHttpFields();
+            if (_acceptRanges && !fields.contains(HttpHeader.ACCEPT_RANGES))
+                fields.add(ACCEPT_RANGES);
 
-            if (_cacheControl != null)
-                f.put(_cacheControl);
+            if (_cacheControl != null && !fields.contains(HttpHeader.CACHE_CONTROL))
+                fields.add(_cacheControl);
         }
         else
         {
             Response.putHeaders(response, content, contentLength, _etags);
-            if (_acceptRanges)
+            if (_acceptRanges && !response.containsHeader(HttpHeader.ACCEPT_RANGES.asString()))
                 response.setHeader(ACCEPT_RANGES.getName(), ACCEPT_RANGES.getValue());
 
-            if (_cacheControl != null)
+            if (_cacheControl != null && !response.containsHeader(HttpHeader.CACHE_CONTROL.asString()))
                 response.setHeader(_cacheControl.getName(), _cacheControl.getValue());
         }
     }
