@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2019 Mort Bay Consulting Pty. Ltd.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -32,26 +32,24 @@ public class AbstractHandlerMBean extends ObjectMBean
 {
     private static final Logger LOG = Log.getLogger(AbstractHandlerMBean.class);
 
-    /* ------------------------------------------------------------ */
     public AbstractHandlerMBean(Object managedObject)
     {
         super(managedObject);
     }
 
-    /* ------------------------------------------------------------ */
     @Override
     public String getObjectContextBasis()
     {
-        if (_managed != null )
+        if (_managed != null)
         {
             String basis = null;
             if (_managed instanceof ContextHandler)
             {
                 ContextHandler handler = (ContextHandler)_managed;
                 String context = getContextName(handler);
-                if (context==null)
-                    context=handler.getDisplayName();
-                if (context!=null)
+                if (context == null)
+                    context = handler.getDisplayName();
+                if (context != null)
                     return context;
             }
             else if (_managed instanceof AbstractHandler)
@@ -60,10 +58,8 @@ public class AbstractHandlerMBean extends ObjectMBean
                 Server server = handler.getServer();
                 if (server != null)
                 {
-                    ContextHandler context = 
-                        AbstractHandlerContainer.findContainerOf(server,
-                                ContextHandler.class, handler);
-                    
+                    ContextHandler context = AbstractHandlerContainer.findContainerOf(server, ContextHandler.class, handler);
+
                     if (context != null)
                         basis = getContextName(context);
                 }
@@ -74,36 +70,35 @@ public class AbstractHandlerMBean extends ObjectMBean
         return super.getObjectContextBasis();
     }
 
-    /* ------------------------------------------------------------ */
     protected String getContextName(ContextHandler context)
     {
         String name = null;
-        
-        if (context.getContextPath()!=null && context.getContextPath().length()>0)
+
+        if (context.getContextPath() != null && context.getContextPath().length() > 0)
         {
             int idx = context.getContextPath().lastIndexOf('/');
             name = idx < 0 ? context.getContextPath() : context.getContextPath().substring(++idx);
-            if (name==null || name.length()==0)
-                name= "ROOT";
+            if (name == null || name.length() == 0)
+                name = "ROOT";
         }
-        
-        if (name==null && context.getBaseResource()!=null)
+
+        if (name == null && context.getBaseResource() != null)
         {
             try
             {
-                if (context.getBaseResource().getFile()!=null)
+                if (context.getBaseResource().getFile() != null)
                     name = context.getBaseResource().getFile().getName();
             }
-            catch(IOException e)
+            catch (IOException e)
             {
                 LOG.ignore(e);
-                name=context.getBaseResource().getName();
+                name = context.getBaseResource().getName();
             }
         }
-        
-        if (context.getVirtualHosts()!=null && context.getVirtualHosts().length>0)
-            name='"'+name+"@"+context.getVirtualHosts()[0]+'"';
-        
+
+        if (context.getVirtualHosts() != null && context.getVirtualHosts().length > 0)
+            name = '"' + name + "@" + context.getVirtualHosts()[0] + '"';
+
         return name;
     }
 }
