@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -18,9 +18,7 @@
 
 package org.eclipse.jetty.server;
 
-import java.io.BufferedReader;
 import java.io.IOException;
-import java.io.InputStreamReader;
 import java.io.OutputStream;
 import java.net.Socket;
 import java.nio.charset.StandardCharsets;
@@ -28,19 +26,16 @@ import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
+import org.eclipse.jetty.http.HttpTester;
 import org.eclipse.jetty.server.handler.AbstractHandler;
-import org.eclipse.jetty.toolchain.test.TestTracker;
-import org.eclipse.jetty.toolchain.test.http.SimpleHttpParser;
-import org.eclipse.jetty.toolchain.test.http.SimpleHttpResponse;
-import org.junit.Assert;
-import org.junit.Rule;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
+
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 public class HostHeaderCustomizerTest
 {
-    @Rule
-    public TestTracker tracker = new TestTracker();
-
     @Test
     public void testHostHeaderCustomizer() throws Exception
     {
@@ -58,8 +53,8 @@ public class HostHeaderCustomizerTest
             public void handle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException
             {
                 baseRequest.setHandled(true);
-                Assert.assertEquals(serverName, request.getServerName());
-                Assert.assertEquals(serverPort, request.getServerPort());
+                assertEquals(serverName, request.getServerName());
+                assertEquals(serverPort, request.getServerPort());
                 response.sendRedirect(redirectPath);
             }
         });
@@ -68,24 +63,25 @@ public class HostHeaderCustomizerTest
         {
             try (Socket socket = new Socket("localhost", connector.getLocalPort()))
             {
-                OutputStream output = socket.getOutputStream();
-                String request = "" +
+                try (OutputStream output = socket.getOutputStream())
+                {
+                    String request =
                         "GET / HTTP/1.0\r\n" +
-                        "\r\n";
-                output.write(request.getBytes(StandardCharsets.UTF_8));
-                output.flush();
+                            "\r\n";
+                    output.write(request.getBytes(StandardCharsets.UTF_8));
+                    output.flush();
 
-                BufferedReader input = new BufferedReader(new InputStreamReader(socket.getInputStream(), StandardCharsets.UTF_8));
-                SimpleHttpParser parser = new SimpleHttpParser();
-                SimpleHttpResponse response = parser.readResponse(input);
+                    HttpTester.Input input = HttpTester.from(socket.getInputStream());
+                    HttpTester.Response response = HttpTester.parseResponse(input);
 
-                String location = response.getHeaders().get("location");
-                Assert.assertNotNull(location);
-                String schemePrefix = "http://";
-                Assert.assertTrue(location.startsWith(schemePrefix));
-                Assert.assertTrue(location.endsWith(redirectPath));
-                String hostPort = location.substring(schemePrefix.length(), location.length() - redirectPath.length());
-                Assert.assertEquals(serverName + ":" + serverPort, hostPort);
+                    String location = response.get("location");
+                    assertNotNull(location);
+                    String schemePrefix = "http://";
+                    assertTrue(location.startsWith(schemePrefix));
+                    assertTrue(location.endsWith(redirectPath));
+                    String hostPort = location.substring(schemePrefix.length(), location.length() - redirectPath.length());
+                    assertEquals(serverName + ":" + serverPort, hostPort);
+                }
             }
         }
         finally
