@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -30,6 +30,7 @@ import java.io.IOException;
 import java.io.OutputStream;
 import java.io.PrintWriter;
 import java.io.StringReader;
+import java.nio.charset.StandardCharsets;
 import java.util.Arrays;
 import java.util.HashSet;
 import java.util.List;
@@ -157,12 +158,12 @@ public class HttpConnectionTest
         connector.getConnectionFactory(HttpConnectionFactory.class).setHttpCompliance(HttpCompliance.RFC2616);
         String request = "GET / HTTP/0.9\r\n\r\n";
         String response = connector.getResponse(request);
-        assertThat(response, containsString("400 Bad Version"));
+        assertThat(response, containsString("505 Unsupported Version"));
 
         connector.getConnectionFactory(HttpConnectionFactory.class).setHttpCompliance(HttpCompliance.RFC7230);
         request = "GET / HTTP/0.9\r\n\r\n";
         response = connector.getResponse(request);
-        assertThat(response, containsString("400 Bad Version"));
+        assertThat(response, containsString("505 Unsupported Version"));
     }
 
     /**
@@ -499,43 +500,28 @@ public class HttpConnectionTest
     public void testBadPathDotDotPath() throws Exception
     {
         String response = connector.getResponse("GET /ooops/../../path HTTP/1.0\r\nHost: localhost:80\r\n\n");
-        checkContains(response, 0, "HTTP/1.1 400 Bad URI");
-    }
-
-    @Test
-    public void testOKPathEncodedDotDotPath() throws Exception
-    {
-        String response = connector.getResponse("GET /ooops/%2e%2e/path HTTP/1.0\r\nHost: localhost:80\r\n\n");
-        checkContains(response, 0, "HTTP/1.1 200 OK");
-        checkContains(response, 0, "pathInfo=/path");
-    }
-
-    @Test
-    public void testBadPathEncodedDotDotPath() throws Exception
-    {
-        String response = connector.getResponse("GET /ooops/%2e%2e/%2e%2e/path HTTP/1.0\r\nHost: localhost:80\r\n\n");
-        checkContains(response, 0, "HTTP/1.1 400 Bad URI");
+        checkContains(response, 0, "HTTP/1.1 400 ");
     }
 
     @Test
     public void testBadDotDotPath() throws Exception
     {
         String response = connector.getResponse("GET ../path HTTP/1.0\r\nHost: localhost:80\r\n\n");
-        checkContains(response, 0, "HTTP/1.1 400 Bad URI");
+        checkContains(response, 0, "HTTP/1.1 400 ");
     }
 
     @Test
     public void testBadSlashDotDotPath() throws Exception
     {
         String response = connector.getResponse("GET /../path HTTP/1.0\r\nHost: localhost:80\r\n\n");
-        checkContains(response, 0, "HTTP/1.1 400 Bad URI");
+        checkContains(response, 0, "HTTP/1.1 400 ");
     }
 
     @Test
     public void testEncodedBadDotDotPath() throws Exception
     {
         String response = connector.getResponse("GET %2e%2e/path HTTP/1.0\r\nHost: localhost:80\r\n\n");
-        checkContains(response, 0, "HTTP/1.1 400 Bad URI");
+        checkContains(response, 0, "HTTP/1.1 400 ");
     }
 
     @Test
@@ -1258,6 +1244,48 @@ public class HttpConnectionTest
         }
     }
 
+    @Test
+    public void testAllowedLargeResponse() throws Exception
+    {
+        connector.getBean(HttpConnectionFactory.class).getHttpConfiguration().setResponseHeaderSize(16 * 1024);
+        connector.getBean(HttpConnectionFactory.class).getHttpConfiguration().setOutputBufferSize(8 * 1024);
+
+        byte[] bytes = new byte[12 * 1024];
+        Arrays.fill(bytes, (byte)'X');
+        final String longstr = "thisisastringthatshouldreachover12kbytes-" + new String(bytes, StandardCharsets.ISO_8859_1) + "_Z_";
+        final CountDownLatch checkError = new CountDownLatch(1);
+        server.stop();
+        server.setHandler(new AbstractHandler()
+        {
+            @SuppressWarnings("unused")
+            @Override
+            public void handle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException
+            {
+                baseRequest.setHandled(true);
+                response.setHeader(HttpHeader.CONTENT_TYPE.toString(), MimeTypes.Type.TEXT_HTML.toString());
+                response.setHeader("LongStr", longstr);
+                PrintWriter writer = response.getWriter();
+                writer.write("<html><h1>FOO</h1></html>");
+                writer.flush();
+                if (writer.checkError())
+                    checkError.countDown();
+                response.flushBuffer();
+            }
+        });
+        server.start();
+
+        String response = null;
+        response = connector.getResponse("GET / HTTP/1.1\r\n" +
+            "Host: localhost\r\n" +
+            "\r\n"
+        );
+
+        checkContains(response, 0, "HTTP/1.1 200");
+        checkContains(response, 0, "LongStr: thisisastringthatshouldreachover12kbytes");
+        checkContains(response, 0, "XXX_Z_");
+        assertThat(checkError.getCount(), is(1L));
+    }
+
     @Test
     public void testAsterisk() throws Exception
     {
