@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -27,6 +27,8 @@ import java.io.InputStream;
 import java.io.Reader;
 import java.io.UnsupportedEncodingException;
 import java.nio.charset.StandardCharsets;
+import java.nio.file.Files;
+import java.nio.file.Path;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Enumeration;
@@ -34,6 +36,7 @@ import java.util.List;
 import java.util.Locale;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicInteger;
+import java.util.stream.Stream;
 import javax.servlet.DispatcherType;
 import javax.servlet.MultipartConfigElement;
 import javax.servlet.ServletException;
@@ -46,6 +49,7 @@ import javax.servlet.http.Part;
 
 import org.eclipse.jetty.http.BadMessageException;
 import org.eclipse.jetty.http.HttpCompliance;
+import org.eclipse.jetty.http.HttpComplianceSection;
 import org.eclipse.jetty.http.HttpTester;
 import org.eclipse.jetty.http.MimeTypes;
 import org.eclipse.jetty.server.LocalConnector.LocalEndPoint;
@@ -54,6 +58,8 @@ import org.eclipse.jetty.server.handler.ContextHandler;
 import org.eclipse.jetty.server.handler.ErrorHandler;
 import org.eclipse.jetty.toolchain.test.FS;
 import org.eclipse.jetty.toolchain.test.MavenTestingUtils;
+import org.eclipse.jetty.toolchain.test.jupiter.WorkDir;
+import org.eclipse.jetty.toolchain.test.jupiter.WorkDirExtension;
 import org.eclipse.jetty.util.BufferUtil;
 import org.eclipse.jetty.util.IO;
 import org.eclipse.jetty.util.log.Log;
@@ -64,6 +70,7 @@ import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Disabled;
 import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.ExtendWith;
 
 import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.containsString;
@@ -81,9 +88,11 @@ import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.junit.jupiter.api.Assertions.fail;
 
 // @checkstyle-disable-check : AvoidEscapedUnicodeCharactersCheck
+@ExtendWith(WorkDirExtension.class)
 public class RequestTest
 {
     private static final Logger LOG = Log.getLogger(RequestTest.class);
+    public WorkDir workDir;
     private Server _server;
     private LocalConnector _connector;
     private RequestHandler _handler;
@@ -335,20 +344,14 @@ public class RequestTest
     @Test
     public void testMultiPart() throws Exception
     {
-        final File testTmpDir = File.createTempFile("reqtest", null);
-        if (testTmpDir.exists())
-            testTmpDir.delete();
-        testTmpDir.mkdir();
-        testTmpDir.deleteOnExit();
-        assertTrue(testTmpDir.list().length == 0);
+        Path testTmpDir = workDir.getEmptyPathDir();
 
         ContextHandler contextHandler = new ContextHandler();
         contextHandler.setContextPath("/foo");
         contextHandler.setResourceBase(".");
-        contextHandler.setHandler(new MultiPartRequestHandler(testTmpDir));
+        contextHandler.setHandler(new MultiPartRequestHandler(testTmpDir.toFile()));
         contextHandler.addEventListener(new MultiPartCleanerListener()
         {
-
             @Override
             public void requestDestroyed(ServletRequestEvent sre)
             {
@@ -356,12 +359,11 @@ public class RequestTest
                 assertNotNull(m);
                 ContextHandler.Context c = m.getContext();
                 assertNotNull(c);
-                assertTrue(c == sre.getServletContext());
-                assertTrue(!m.isEmpty());
-                assertTrue(testTmpDir.list().length == 2);
+                assertSame(c, sre.getServletContext());
+                assertFalse(m.isEmpty());
+                assertThat("File count in temp dir", getFileCount(testTmpDir), is(2L));
                 super.requestDestroyed(sre);
-                String[] files = testTmpDir.list();
-                assertTrue(files.length == 0);
+                assertThat("File count in temp dir", getFileCount(testTmpDir), is(0L));
             }
         });
         _server.stop();
@@ -395,20 +397,14 @@ public class RequestTest
     @Test
     public void testUtilMultiPart() throws Exception
     {
-        final File testTmpDir = File.createTempFile("reqtest", null);
-        if (testTmpDir.exists())
-            testTmpDir.delete();
-        testTmpDir.mkdir();
-        testTmpDir.deleteOnExit();
-        assertTrue(testTmpDir.list().length == 0);
+        Path testTmpDir = workDir.getEmptyPathDir();
 
         ContextHandler contextHandler = new ContextHandler();
         contextHandler.setContextPath("/foo");
         contextHandler.setResourceBase(".");
-        contextHandler.setHandler(new MultiPartRequestHandler(testTmpDir));
+        contextHandler.setHandler(new MultiPartRequestHandler(testTmpDir.toFile()));
         contextHandler.addEventListener(new MultiPartCleanerListener()
         {
-
             @Override
             public void requestDestroyed(ServletRequestEvent sre)
             {
@@ -416,12 +412,11 @@ public class RequestTest
                 assertNotNull(m);
                 ContextHandler.Context c = m.getContext();
                 assertNotNull(c);
-                assertTrue(c == sre.getServletContext());
-                assertTrue(!m.isEmpty());
-                assertTrue(testTmpDir.list().length == 2);
+                assertSame(c, sre.getServletContext());
+                assertFalse(m.isEmpty());
+                assertThat("File count in temp dir", getFileCount(testTmpDir), is(2L));
                 super.requestDestroyed(sre);
-                String[] files = testTmpDir.list();
-                assertTrue(files.length == 0);
+                assertThat("File count in temp dir", getFileCount(testTmpDir), is(0L));
             }
         });
         _server.stop();
@@ -458,17 +453,12 @@ public class RequestTest
     @Test
     public void testHttpMultiPart() throws Exception
     {
-        final File testTmpDir = File.createTempFile("reqtest", null);
-        if (testTmpDir.exists())
-            testTmpDir.delete();
-        testTmpDir.mkdir();
-        testTmpDir.deleteOnExit();
-        assertTrue(testTmpDir.list().length == 0);
+        Path testTmpDir = workDir.getEmptyPathDir();
 
         ContextHandler contextHandler = new ContextHandler();
         contextHandler.setContextPath("/foo");
         contextHandler.setResourceBase(".");
-        contextHandler.setHandler(new MultiPartRequestHandler(testTmpDir));
+        contextHandler.setHandler(new MultiPartRequestHandler(testTmpDir.toFile()));
 
         _server.stop();
         _server.setHandler(contextHandler);
@@ -503,17 +493,12 @@ public class RequestTest
     public void testBadMultiPart() throws Exception
     {
         //a bad multipart where one of the fields has no name
-        final File testTmpDir = File.createTempFile("badmptest", null);
-        if (testTmpDir.exists())
-            testTmpDir.delete();
-        testTmpDir.mkdir();
-        testTmpDir.deleteOnExit();
-        assertTrue(testTmpDir.list().length == 0);
+        Path testTmpDir = workDir.getEmptyPathDir();
 
         ContextHandler contextHandler = new ContextHandler();
         contextHandler.setContextPath("/foo");
         contextHandler.setResourceBase(".");
-        contextHandler.setHandler(new BadMultiPartRequestHandler(testTmpDir));
+        contextHandler.setHandler(new BadMultiPartRequestHandler(testTmpDir.toFile()));
         contextHandler.addEventListener(new MultiPartCleanerListener()
         {
 
@@ -524,10 +509,9 @@ public class RequestTest
                 assertNotNull(m);
                 ContextHandler.Context c = m.getContext();
                 assertNotNull(c);
-                assertTrue(c == sre.getServletContext());
+                assertSame(c, sre.getServletContext());
                 super.requestDestroyed(sre);
-                String[] files = testTmpDir.list();
-                assertTrue(files.length == 0);
+                assertThat("File count in temp dir", getFileCount(testTmpDir), is(0L));
             }
         });
         _server.stop();
@@ -613,7 +597,7 @@ public class RequestTest
                 }
                 catch (BadMessageException e)
                 {
-                    return e.getCode() == 501;
+                    return e.getCode() == 415;
                 }
             }
         };
@@ -653,7 +637,7 @@ public class RequestTest
         System.out.println(request);
 
         String responses = _connector.getResponse(request);
-        assertThat(responses,startsWith("HTTP/1.1 200"));
+        assertThat(responses, startsWith("HTTP/1.1 200"));
     }
 
     /**
@@ -1853,6 +1837,76 @@ public class RequestTest
         assertEquals(0, request.getParameterMap().size());
     }
 
+    @Test
+    public void testAmbiguousParameters() throws Exception
+    {
+        _handler._checker = (request, response) -> true;
+
+        String request = "GET /ambiguous/..;/path HTTP/1.0\r\n" +
+            "Host: whatever\r\n" +
+            "\r\n";
+
+        _connector.getBean(HttpConnectionFactory.class).setHttpCompliance(HttpCompliance.RFC7230);
+        assertThat(_connector.getResponse(request), startsWith("HTTP/1.1 400"));
+
+        HttpCompliance.CUSTOM0.sections().clear();
+        HttpCompliance.CUSTOM0.sections().addAll(HttpCompliance.RFC7230.sections());
+        HttpCompliance.CUSTOM0.sections().remove(HttpComplianceSection.NO_AMBIGUOUS_PATH_PARAMETERS);
+
+        _connector.getBean(HttpConnectionFactory.class).setHttpCompliance(HttpCompliance.CUSTOM0);
+        assertThat(_connector.getResponse(request), startsWith("HTTP/1.1 200"));
+    }
+
+    @Test
+    public void testAmbiguousSegments() throws Exception
+    {
+        _handler._checker = (request, response) -> true;
+
+        String request = "GET /ambiguous/%2e%2e/path HTTP/1.0\r\n" +
+            "Host: whatever\r\n" +
+            "\r\n";
+
+        _connector.getBean(HttpConnectionFactory.class).setHttpCompliance(HttpCompliance.RFC7230_NO_AMBIGUOUS_URIS);
+        assertThat(_connector.getResponse(request), startsWith("HTTP/1.1 400"));
+
+        _connector.getBean(HttpConnectionFactory.class).setHttpCompliance(HttpCompliance.RFC7230);
+        assertThat(_connector.getResponse(request), startsWith("HTTP/1.1 200"));
+
+        _connector.getBean(HttpConnectionFactory.class).setHttpCompliance(HttpCompliance.RFC2616);
+        assertThat(_connector.getResponse(request), startsWith("HTTP/1.1 200"));
+    }
+
+    @Test
+    public void testAmbiguousSeparators() throws Exception
+    {
+        _handler._checker = (request, response) -> true;
+
+        String request = "GET /ambiguous/%2f/path HTTP/1.0\r\n" +
+            "Host: whatever\r\n" +
+            "\r\n";
+
+        _connector.getBean(HttpConnectionFactory.class).setHttpCompliance(HttpCompliance.RFC7230_NO_AMBIGUOUS_URIS);
+        assertThat(_connector.getResponse(request), startsWith("HTTP/1.1 400"));
+
+        _connector.getBean(HttpConnectionFactory.class).setHttpCompliance(HttpCompliance.RFC7230);
+        assertThat(_connector.getResponse(request), startsWith("HTTP/1.1 200"));
+
+        _connector.getBean(HttpConnectionFactory.class).setHttpCompliance(HttpCompliance.RFC2616);
+        assertThat(_connector.getResponse(request), startsWith("HTTP/1.1 200"));
+    }
+
+    private static long getFileCount(Path path)
+    {
+        try (Stream<Path> s = Files.list(path))
+        {
+            return s.count();
+        }
+        catch (IOException e)
+        {
+            throw new RuntimeException("Unable to get file list count: " + path, e);
+        }
+    }
+
     interface RequestTester
     {
         boolean check(HttpServletRequest request, HttpServletResponse response) throws IOException;
@@ -1944,7 +1998,6 @@ public class RequestTest
             ((Request)request).setHandled(true);
             try
             {
-
                 MultipartConfigElement mpce = new MultipartConfigElement(tmpDir.getAbsolutePath(), -1, -1, 2);
                 request.setAttribute(Request.MULTIPART_CONFIG_ELEMENT, mpce);
 
