@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -27,7 +27,6 @@ import java.nio.file.Path;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
-
 import javax.servlet.ServletContextEvent;
 import javax.servlet.ServletContextListener;
 import javax.servlet.http.HttpServletRequest;
@@ -39,9 +38,12 @@ import org.eclipse.jetty.server.Request;
 import org.eclipse.jetty.server.Server;
 import org.eclipse.jetty.toolchain.test.FS;
 import org.eclipse.jetty.toolchain.test.MavenTestingUtils;
+import org.eclipse.jetty.toolchain.test.jupiter.WorkDir;
+import org.eclipse.jetty.toolchain.test.jupiter.WorkDirExtension;
 import org.eclipse.jetty.util.resource.Resource;
 import org.hamcrest.Matchers;
 import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.ExtendWith;
 
 import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.containsString;
@@ -51,8 +53,11 @@ import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
+@ExtendWith(WorkDirExtension.class)
 public class ContextHandlerTest
 {
+    public WorkDir workDir;
+
     @Test
     public void testGetResourcePathsWhenSuppliedPathEndsInSlash() throws Exception
     {
@@ -418,6 +423,18 @@ public class ContextHandlerTest
         assertThat(connector.getResponse("GET /foo/xxx HTTP/1.0\n\n"), Matchers.containsString("ctx='/foo'"));
         assertThat(connector.getResponse("GET /foo/bar/xxx HTTP/1.0\n\n"), Matchers.containsString("ctx='/foo/bar'"));
 
+        // If we make foobar unavailable, then requests will be handled by 503
+        foobar.setAvailable(false);
+        assertThat(connector.getResponse("GET / HTTP/1.0\n\n"), Matchers.containsString("ctx=''"));
+        assertThat(connector.getResponse("GET /foo/xxx HTTP/1.0\n\n"), Matchers.containsString("ctx='/foo'"));
+        assertThat(connector.getResponse("GET /foo/bar/xxx HTTP/1.0\n\n"), Matchers.containsString(" 503 "));
+
+        // If we make foobar available, then requests will be handled normally
+        foobar.setAvailable(true);
+        assertThat(connector.getResponse("GET / HTTP/1.0\n\n"), Matchers.containsString("ctx=''"));
+        assertThat(connector.getResponse("GET /foo/xxx HTTP/1.0\n\n"), Matchers.containsString("ctx='/foo'"));
+        assertThat(connector.getResponse("GET /foo/bar/xxx HTTP/1.0\n\n"), Matchers.containsString("ctx='/foo/bar'"));
+
         // If we stop foobar, then requests will be handled by foo
         foobar.stop();
         assertThat(connector.getResponse("GET / HTTP/1.0\n\n"), Matchers.containsString("ctx=''"));
@@ -448,7 +465,7 @@ public class ContextHandlerTest
         assertThat(connector.getResponse("GET /foo/xxx HTTP/1.0\n\n"), Matchers.containsString("ctx='/foo'"));
         assertThat(connector.getResponse("GET /foo/bar/xxx HTTP/1.0\n\n"), Matchers.containsString("ctx='/foo/bar'"));
     }
-    
+
     @Test
     public void testContextInitializationDestruction() throws Exception
     {
@@ -785,24 +802,14 @@ public class ContextHandlerTest
 
     private File setupTestDirectory() throws IOException
     {
-        File tmpDir = new File(System.getProperty("basedir", ".") + "/target/tmp/ContextHandlerTest");
-        tmpDir = tmpDir.getCanonicalFile();
-        if (!tmpDir.exists())
-            assertTrue(tmpDir.mkdirs());
-        File tmp = File.createTempFile("cht", null, tmpDir);
-        assertTrue(tmp.delete());
-        assertTrue(tmp.mkdir());
-        tmp.deleteOnExit();
-        File root = new File(tmp, getClass().getName());
-        assertTrue(root.mkdir());
+        Path root = workDir.getEmptyPathDir();
 
-        File webInf = new File(root, "WEB-INF");
-        assertTrue(webInf.mkdir());
+        Path webInfDir = root.resolve("WEB-INF");
+        FS.ensureDirExists(webInfDir);
+        FS.ensureDirExists(webInfDir.resolve("jsp"));
+        FS.touch(webInfDir.resolve("web.xml"));
 
-        assertTrue(new File(webInf, "jsp").mkdir());
-        assertTrue(new File(webInf, "web.xml").createNewFile());
-
-        return root;
+        return root.toFile();
     }
 
     private void checkWildcardHost(boolean succeed, Server server, String[] contextHosts, String[] requestHosts) throws Exception
@@ -859,12 +866,12 @@ public class ContextHandlerTest
             writer.println("ctx='" + request.getContextPath() + "'");
         }
     }
-    
+
     private static class TestServletContextListener implements ServletContextListener
     {
         public int initialized = 0;
         public int destroyed = 0;
-        
+
         @Override
         public void contextInitialized(ServletContextEvent sce)
         {
