@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2019 Mort Bay Consulting Pty. Ltd.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -27,7 +27,6 @@ import java.util.List;
 import java.util.concurrent.BlockingQueue;
 import java.util.concurrent.TimeUnit;
 import java.util.stream.Stream;
-
 import javax.servlet.AsyncContext;
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
@@ -38,6 +37,7 @@ import org.eclipse.jetty.server.AbstractNCSARequestLog;
 import org.eclipse.jetty.server.CustomRequestLog;
 import org.eclipse.jetty.server.Handler;
 import org.eclipse.jetty.server.HttpChannel;
+import org.eclipse.jetty.server.HttpChannelState;
 import org.eclipse.jetty.server.LocalConnector;
 import org.eclipse.jetty.server.Request;
 import org.eclipse.jetty.server.RequestLog;
@@ -45,6 +45,7 @@ import org.eclipse.jetty.server.Response;
 import org.eclipse.jetty.server.Server;
 import org.eclipse.jetty.util.BlockingArrayQueue;
 import org.eclipse.jetty.util.component.AbstractLifeCycle;
+import org.eclipse.jetty.util.log.Log;
 import org.eclipse.jetty.util.log.StacklessLogging;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.Assertions;
@@ -90,14 +91,14 @@ public class NcsaRequestLogTest
         _connector = new LocalConnector(_server);
         _server.addConnector(_connector);
     }
-    
+
     void testHandlerServerStart() throws Exception
     {
         _server.setRequestLog(_log);
         _server.setHandler(new TestHandler());
         _server.start();
     }
-    
+
     private void startServer() throws Exception
     {
         _server.start();
@@ -105,11 +106,9 @@ public class NcsaRequestLogTest
 
     private void makeRequest(String requestPath) throws Exception
     {
-        _connector.getResponse("GET "+requestPath+" HTTP/1.0\r\n\r\n");
+        _connector.getResponse("GET " + requestPath + " HTTP/1.0\r\n\r\n");
     }
 
-
-
     @BeforeEach
     public void before() throws Exception
     {
@@ -122,18 +121,17 @@ public class NcsaRequestLogTest
         _server.stop();
         stacklessLogging.close();
     }
-    
-    
+
     @ParameterizedTest()
     @ValueSource(strings = {"customNCSA", "NCSA"})
     public void testNotHandled(String logType) throws Exception
     {
         setup(logType);
         testHandlerServerStart();
-        
+
         _connector.getResponse("GET /foo HTTP/1.0\n\n");
-        String log = _entries.poll(5,TimeUnit.SECONDS);
-        assertThat(log,containsString("GET /foo HTTP/1.0\" 404 "));
+        String log = _entries.poll(5, TimeUnit.SECONDS);
+        assertThat(log, containsString("GET /foo HTTP/1.0\" 404 "));
     }
 
     @ParameterizedTest()
@@ -142,20 +140,20 @@ public class NcsaRequestLogTest
     {
         setup(logType);
         testHandlerServerStart();
-        
+
         _connector.getResponse("GET /foo?data=1 HTTP/1.0\nhost: host:80\n\n");
-        String log = _entries.poll(5,TimeUnit.SECONDS);
-        assertThat(log,containsString("GET /foo?data=1 HTTP/1.0\" 200 "));
-        
+        String log = _entries.poll(5, TimeUnit.SECONDS);
+        assertThat(log, containsString("GET /foo?data=1 HTTP/1.0\" 200 "));
+
         _connector.getResponse("GET //bad/foo?data=1 HTTP/1.0\n\n");
-        log = _entries.poll(5,TimeUnit.SECONDS);
-        assertThat(log,containsString("GET //bad/foo?data=1 HTTP/1.0\" 200 "));
-                
+        log = _entries.poll(5, TimeUnit.SECONDS);
+        assertThat(log, containsString("GET //bad/foo?data=1 HTTP/1.0\" 200 "));
+
         _connector.getResponse("GET http://host:80/foo?data=1 HTTP/1.0\n\n");
-        log = _entries.poll(5,TimeUnit.SECONDS);
-        assertThat(log,containsString("GET http://host:80/foo?data=1 HTTP/1.0\" 200 "));   
+        log = _entries.poll(5, TimeUnit.SECONDS);
+        assertThat(log, containsString("GET http://host:80/foo?data=1 HTTP/1.0\" 200 "));
     }
-    
+
     @ParameterizedTest()
     @ValueSource(strings = {"customNCSA", "NCSA"})
     public void testHTTP10Host(String logType) throws Exception
@@ -164,14 +162,14 @@ public class NcsaRequestLogTest
         testHandlerServerStart();
 
         _connector.getResponse(
-            "GET /foo?name=value HTTP/1.0\n"+
-            "Host: servername\n"+
-            "\n");
-        String log = _entries.poll(5,TimeUnit.SECONDS);
-        assertThat(log,containsString("GET /foo?name=value"));
-        assertThat(log,containsString(" 200 "));
+            "GET /foo?name=value HTTP/1.0\n" +
+                "Host: servername\n" +
+                "\n");
+        String log = _entries.poll(5, TimeUnit.SECONDS);
+        assertThat(log, containsString("GET /foo?name=value"));
+        assertThat(log, containsString(" 200 "));
     }
-    
+
     @ParameterizedTest()
     @ValueSource(strings = {"customNCSA", "NCSA"})
     public void testHTTP11(String logType) throws Exception
@@ -180,14 +178,14 @@ public class NcsaRequestLogTest
         testHandlerServerStart();
 
         _connector.getResponse(
-            "GET /foo?name=value HTTP/1.1\n"+
-            "Host: servername\n"+
-            "\n");
-        String log = _entries.poll(5,TimeUnit.SECONDS);
-        assertThat(log,containsString("GET /foo?name=value"));
-        assertThat(log,containsString(" 200 "));
+            "GET /foo?name=value HTTP/1.1\n" +
+                "Host: servername\n" +
+                "\n");
+        String log = _entries.poll(5, TimeUnit.SECONDS);
+        assertThat(log, containsString("GET /foo?name=value"));
+        assertThat(log, containsString(" 200 "));
     }
-    
+
     @ParameterizedTest()
     @ValueSource(strings = {"customNCSA", "NCSA"})
     public void testAbsolute(String logType) throws Exception
@@ -196,14 +194,14 @@ public class NcsaRequestLogTest
         testHandlerServerStart();
 
         _connector.getResponse(
-            "GET http://hostname:8888/foo?name=value HTTP/1.1\n"+
-            "Host: servername\n"+
-            "\n");
-        String log = _entries.poll(5,TimeUnit.SECONDS);
-        assertThat(log,containsString("GET http://hostname:8888/foo?name=value"));
-        assertThat(log,containsString(" 200 "));
+            "GET http://hostname:8888/foo?name=value HTTP/1.1\n" +
+                "Host: servername\n" +
+                "\n");
+        String log = _entries.poll(5, TimeUnit.SECONDS);
+        assertThat(log, containsString("GET http://hostname:8888/foo?name=value"));
+        assertThat(log, containsString(" 200 "));
     }
-    
+
     @ParameterizedTest()
     @ValueSource(strings = {"customNCSA", "NCSA"})
     public void testQuery(String logType) throws Exception
@@ -212,11 +210,11 @@ public class NcsaRequestLogTest
         testHandlerServerStart();
 
         _connector.getResponse("GET /foo?name=value HTTP/1.0\n\n");
-        String log = _entries.poll(5,TimeUnit.SECONDS);
-        assertThat(log,containsString("GET /foo?name=value"));
-        assertThat(log,containsString(" 200 "));
+        String log = _entries.poll(5, TimeUnit.SECONDS);
+        assertThat(log, containsString("GET /foo?name=value"));
+        assertThat(log, containsString(" 200 "));
     }
-    
+
     @ParameterizedTest()
     @ValueSource(strings = {"customNCSA", "NCSA"})
     public void testSmallData(String logType) throws Exception
@@ -225,11 +223,11 @@ public class NcsaRequestLogTest
         testHandlerServerStart();
 
         _connector.getResponse("GET /foo?data=42 HTTP/1.0\n\n");
-        String log = _entries.poll(5,TimeUnit.SECONDS);
-        assertThat(log,containsString("GET /foo?"));
-        assertThat(log,containsString(" 200 42 "));
+        String log = _entries.poll(5, TimeUnit.SECONDS);
+        assertThat(log, containsString("GET /foo?"));
+        assertThat(log, containsString(" 200 42 "));
     }
-    
+
     @ParameterizedTest()
     @ValueSource(strings = {"customNCSA", "NCSA"})
     public void testBigData(String logType) throws Exception
@@ -238,11 +236,11 @@ public class NcsaRequestLogTest
         testHandlerServerStart();
 
         _connector.getResponse("GET /foo?data=102400 HTTP/1.0\n\n");
-        String log = _entries.poll(5,TimeUnit.SECONDS);
-        assertThat(log,containsString("GET /foo?"));
-        assertThat(log,containsString(" 200 102400 "));
+        String log = _entries.poll(5, TimeUnit.SECONDS);
+        assertThat(log, containsString("GET /foo?"));
+        assertThat(log, containsString(" 200 102400 "));
     }
-    
+
     @ParameterizedTest()
     @ValueSource(strings = {"customNCSA", "NCSA"})
     public void testStatus(String logType) throws Exception
@@ -251,11 +249,11 @@ public class NcsaRequestLogTest
         testHandlerServerStart();
 
         _connector.getResponse("GET /foo?status=206 HTTP/1.0\n\n");
-        String log = _entries.poll(5,TimeUnit.SECONDS);
-        assertThat(log,containsString("GET /foo?"));
-        assertThat(log,containsString(" 206 0 "));
+        String log = _entries.poll(5, TimeUnit.SECONDS);
+        assertThat(log, containsString("GET /foo?"));
+        assertThat(log, containsString(" 206 0 "));
     }
-    
+
     @ParameterizedTest()
     @ValueSource(strings = {"customNCSA", "NCSA"})
     public void testStatusData(String logType) throws Exception
@@ -264,11 +262,11 @@ public class NcsaRequestLogTest
         testHandlerServerStart();
 
         _connector.getResponse("GET /foo?status=206&data=42 HTTP/1.0\n\n");
-        String log = _entries.poll(5,TimeUnit.SECONDS);
-        assertThat(log,containsString("GET /foo?"));
-        assertThat(log,containsString(" 206 42 "));
+        String log = _entries.poll(5, TimeUnit.SECONDS);
+        assertThat(log, containsString("GET /foo?"));
+        assertThat(log, containsString(" 206 42 "));
     }
-    
+
     @ParameterizedTest()
     @ValueSource(strings = {"customNCSA", "NCSA"})
     public void testBadRequest(String logType) throws Exception
@@ -277,11 +275,11 @@ public class NcsaRequestLogTest
         testHandlerServerStart();
 
         _connector.getResponse("XXXXXXXXXXXX\n\n");
-        String log = _entries.poll(5,TimeUnit.SECONDS);
-        assertThat(log,containsString("\"- - -\""));
-        assertThat(log,containsString(" 400 "));
+        String log = _entries.poll(5, TimeUnit.SECONDS);
+        assertThat(log, containsString("\"- - -\""));
+        assertThat(log, containsString(" 400 "));
     }
-    
+
     @ParameterizedTest()
     @ValueSource(strings = {"customNCSA", "NCSA"})
     public void testBadCharacter(String logType) throws Exception
@@ -290,11 +288,11 @@ public class NcsaRequestLogTest
         testHandlerServerStart();
 
         _connector.getResponse("METHOD /f\00o HTTP/1.0\n\n");
-        String log = _entries.poll(5,TimeUnit.SECONDS);
-        assertThat(log,containsString("\"- - -\""));
-        assertThat(log,containsString(" 400 "));
+        String log = _entries.poll(5, TimeUnit.SECONDS);
+        assertThat(log, containsString("\"- - -\""));
+        assertThat(log, containsString(" 400 "));
     }
-    
+
     @ParameterizedTest()
     @ValueSource(strings = {"customNCSA", "NCSA"})
     public void testBadVersion(String logType) throws Exception
@@ -303,11 +301,11 @@ public class NcsaRequestLogTest
         testHandlerServerStart();
 
         _connector.getResponse("METHOD /foo HTTP/9\n\n");
-        String log = _entries.poll(5,TimeUnit.SECONDS);
-        assertThat(log,containsString("\"- - -\""));
-        assertThat(log,containsString(" 400 "));
+        String log = _entries.poll(5, TimeUnit.SECONDS);
+        assertThat(log, containsString("\"- - -\""));
+        assertThat(log, containsString(" 505 "));
     }
-    
+
     @ParameterizedTest()
     @ValueSource(strings = {"customNCSA", "NCSA"})
     public void testLongURI(String logType) throws Exception
@@ -316,14 +314,14 @@ public class NcsaRequestLogTest
         testHandlerServerStart();
 
         char[] chars = new char[10000];
-        Arrays.fill(chars,'o');
+        Arrays.fill(chars, 'o');
         String ooo = new String(chars);
-        _connector.getResponse("METHOD /f"+ooo+" HTTP/1.0\n\n");
-        String log = _entries.poll(5,TimeUnit.SECONDS);
-        assertThat(log,containsString("\"- - -\""));
-        assertThat(log,containsString(" 414 "));
+        _connector.getResponse("METHOD /f" + ooo + " HTTP/1.0\n\n");
+        String log = _entries.poll(5, TimeUnit.SECONDS);
+        assertThat(log, containsString("\"- - -\""));
+        assertThat(log, containsString(" 414 "));
     }
-    
+
     @ParameterizedTest()
     @ValueSource(strings = {"customNCSA", "NCSA"})
     public void testLongHeader(String logType) throws Exception
@@ -332,14 +330,14 @@ public class NcsaRequestLogTest
         testHandlerServerStart();
 
         char[] chars = new char[10000];
-        Arrays.fill(chars,'o');
+        Arrays.fill(chars, 'o');
         String ooo = new String(chars);
-        _connector.getResponse("METHOD /foo HTTP/1.0\name: f+"+ooo+"\n\n");
-        String log = _entries.poll(5,TimeUnit.SECONDS);
-        assertThat(log,containsString("\"METHOD /foo HTTP/1.0\""));
-        assertThat(log,containsString(" 431 "));
+        _connector.getResponse("METHOD /foo HTTP/1.0\name: f+" + ooo + "\n\n");
+        String log = _entries.poll(5, TimeUnit.SECONDS);
+        assertThat(log, containsString("\"METHOD /foo HTTP/1.0\""));
+        assertThat(log, containsString(" 431 "));
     }
-    
+
     @ParameterizedTest()
     @ValueSource(strings = {"customNCSA", "NCSA"})
     public void testBadRequestNoHost(String logType) throws Exception
@@ -348,9 +346,9 @@ public class NcsaRequestLogTest
         testHandlerServerStart();
 
         _connector.getResponse("GET /foo HTTP/1.1\n\n");
-        String log = _entries.poll(5,TimeUnit.SECONDS);
-        assertThat(log,containsString("GET /foo "));
-        assertThat(log,containsString(" 400 "));
+        String log = _entries.poll(5, TimeUnit.SECONDS);
+        assertThat(log, containsString("GET /foo "));
+        assertThat(log, containsString(" 400 "));
     }
 
     @ParameterizedTest()
@@ -361,9 +359,9 @@ public class NcsaRequestLogTest
         testHandlerServerStart();
 
         _connector.getResponse("GET http://[:1]/foo HTTP/1.1\nReferer: http://other.site\n\n");
-        String log = _entries.poll(5,TimeUnit.SECONDS);
-        assertThat(log,containsString("GET http://[:1]/foo "));
-        assertThat(log,containsString(" 400 50 \"http://other.site\" \"-\""));
+        String log = _entries.poll(5, TimeUnit.SECONDS);
+        assertThat(log, containsString("GET http://[:1]/foo "));
+        assertThat(log, containsString(" 400 50 \"http://other.site\" \"-\""));
     }
 
     @ParameterizedTest()
@@ -374,18 +372,17 @@ public class NcsaRequestLogTest
         testHandlerServerStart();
 
         _connector.getResponse("GET http://[:1]/foo HTTP/1.1\nReferer: http://other.site\nUser-Agent: Mozilla/5.0 (test)\n\n");
-        String log = _entries.poll(5,TimeUnit.SECONDS);
-        assertThat(log,containsString("GET http://[:1]/foo "));
-        assertThat(log,containsString(" 400 50 \"http://other.site\" \"Mozilla/5.0 (test)\""));
+        String log = _entries.poll(5, TimeUnit.SECONDS);
+        assertThat(log, containsString("GET http://[:1]/foo "));
+        assertThat(log, containsString(" 400 50 \"http://other.site\" \"Mozilla/5.0 (test)\""));
     }
-    
 
     // Tests from here use these parameters
     public static Stream<Arguments> data()
     {
         List<Object[]> data = new ArrayList<>();
 
-        for(String logType : Arrays.asList("customNCSA","NCSA"))
+        for (String logType : Arrays.asList("customNCSA", "NCSA"))
         {
             data.add(new Object[]{logType, new NoopHandler(), "/noop", "\"GET /noop HTTP/1.0\" 404"});
             data.add(new Object[]{logType, new HelloHandler(), "/hello", "\"GET /hello HTTP/1.0\" 200"});
@@ -395,7 +392,7 @@ public class NcsaRequestLogTest
             data.add(new Object[]{logType, new IOExceptionPartialHandler(), "/ioex", "\"GET /ioex HTTP/1.0\" 200"});
             data.add(new Object[]{logType, new RuntimeExceptionHandler(), "/rtex", "\"GET /rtex HTTP/1.0\" 500"});
             data.add(new Object[]{logType, new BadMessageHandler(), "/bad", "\"GET /bad HTTP/1.0\" 499"});
-            data.add(new Object[]{logType, new AbortHandler(), "/bad", "\"GET /bad HTTP/1.0\" 488"});
+            data.add(new Object[]{logType, new AbortHandler(), "/bad", "\"GET /bad HTTP/1.0\" 500"});
             data.add(new Object[]{logType, new AbortPartialHandler(), "/bad", "\"GET /bad HTTP/1.0\" 200"});
         }
 
@@ -436,14 +433,13 @@ public class NcsaRequestLogTest
         RequestLogHandler handler = new RequestLogHandler();
         handler.setRequestLog(_log);
         HandlerCollection handlers = new HandlerCollection();
-        handlers.setHandlers(new Handler[] { handler, testHandler });
+        handlers.setHandlers(new Handler[]{handler, testHandler});
         _server.setHandler(handlers);
         startServer();
         makeRequest(requestPath);
         assertRequestLog(expectedLogEntry, _log);
     }
 
-
     @ParameterizedTest
     @MethodSource("data")
     public void testLogHandlerCollectionLast(String logType, Handler testHandler, String requestPath, String expectedLogEntry) throws Exception
@@ -459,27 +455,26 @@ public class NcsaRequestLogTest
         );
 
         HandlerCollection handlers = new HandlerCollection();
-        handlers.setHandlers(new Handler[] { testHandler, handler });
+        handlers.setHandlers(new Handler[]{testHandler, handler});
         _server.setHandler(handlers);
         startServer();
         makeRequest(requestPath);
         assertRequestLog(expectedLogEntry, _log);
     }
 
-
     @ParameterizedTest
     @MethodSource("data")
     public void testErrorHandler(String logType, Handler testHandler, String requestPath, String expectedLogEntry) throws Exception
     {
         setup(logType);
         _server.setRequestLog(_log);
-        AbstractHandler.ErrorDispatchHandler wrapper = new AbstractHandler.ErrorDispatchHandler()
+        AbstractHandler wrapper = new AbstractHandler()
         {
             @Override
-            protected void doNonErrorHandle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response)
+            public void handle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response)
                 throws IOException, ServletException
             {
-                testHandler.handle(target,baseRequest,request,response);
+                testHandler.handle(target, baseRequest, request, response);
             }
         };
 
@@ -489,10 +484,11 @@ public class NcsaRequestLogTest
         ErrorHandler errorHandler = new ErrorHandler()
         {
             @Override
-            public void doError(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response) throws IOException
+            public void handle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response)
+                throws IOException, ServletException
             {
                 errors.add(baseRequest.getRequestURI());
-                super.doError(target, baseRequest, request, response);
+                super.handle(target, baseRequest, request, response);
             }
         };
         _server.addBean(errorHandler);
@@ -501,20 +497,19 @@ public class NcsaRequestLogTest
         assertRequestLog(expectedLogEntry, _log);
     }
 
-
     @ParameterizedTest
     @MethodSource("data")
     public void testOKErrorHandler(String logType, Handler testHandler, String requestPath, String expectedLogEntry) throws Exception
     {
         setup(logType);
         _server.setRequestLog(_log);
-        AbstractHandler.ErrorDispatchHandler wrapper = new AbstractHandler.ErrorDispatchHandler()
+        AbstractHandler wrapper = new AbstractHandler()
         {
             @Override
-            protected void doNonErrorHandle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response)
+            public void handle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response)
                 throws IOException, ServletException
             {
-                testHandler.handle(target,baseRequest,request,response);
+                testHandler.handle(target, baseRequest, request, response);
             }
         };
 
@@ -525,11 +520,12 @@ public class NcsaRequestLogTest
         startServer();
         makeRequest(requestPath);
 
-        expectedLogEntry = "\"GET " + requestPath + " HTTP/1.0\" 200";
+        // If we abort, we can't write a 200 error page
+        if (!(testHandler instanceof AbortHandler))
+            expectedLogEntry = expectedLogEntry.replaceFirst(" [1-9][0-9][0-9]", " 200");
         assertRequestLog(expectedLogEntry, _log);
     }
 
-
     @ParameterizedTest
     @MethodSource("data")
     public void testAsyncDispatch(String logType, Handler testHandler, String requestPath, String expectedLogEntry) throws Exception
@@ -543,10 +539,10 @@ public class NcsaRequestLogTest
                 throws IOException, ServletException
             {
                 if (Boolean.TRUE.equals(request.getAttribute("ASYNC")))
-                    testHandler.handle(target,baseRequest,request,response);
+                    testHandler.handle(target, baseRequest, request, response);
                 else
                 {
-                    request.setAttribute("ASYNC",Boolean.TRUE);
+                    request.setAttribute("ASYNC", Boolean.TRUE);
                     AsyncContext ac = request.startAsync();
                     ac.setTimeout(1000);
                     ac.dispatch();
@@ -560,7 +556,6 @@ public class NcsaRequestLogTest
         assertRequestLog(expectedLogEntry, _log);
     }
 
-
     @ParameterizedTest
     @MethodSource("data")
     public void testAsyncComplete(String logType, Handler testHandler, String requestPath, String expectedLogEntry) throws Exception
@@ -574,19 +569,23 @@ public class NcsaRequestLogTest
                 throws IOException, ServletException
             {
                 if (Boolean.TRUE.equals(request.getAttribute("ASYNC")))
-                    testHandler.handle(target,baseRequest,request,response);
+                    testHandler.handle(target, baseRequest, request, response);
                 else
                 {
-                    request.setAttribute("ASYNC",Boolean.TRUE);
+                    request.setAttribute("ASYNC", Boolean.TRUE);
                     AsyncContext ac = request.startAsync();
                     ac.setTimeout(1000);
                     baseRequest.setHandled(true);
-                    _server.getThreadPool().execute(()->
+                    _server.getThreadPool().execute(() ->
                     {
                         try
                         {
                             try
                             {
+                                while (baseRequest.getHttpChannel().getState().getState() != HttpChannelState.State.WAITING)
+                                {
+                                    Thread.sleep(10);
+                                }
                                 baseRequest.setHandled(false);
                                 testHandler.handle(target, baseRequest, request, response);
                                 if (!baseRequest.isHandled())
@@ -594,18 +593,21 @@ public class NcsaRequestLogTest
                             }
                             catch (BadMessageException bad)
                             {
-                                response.sendError(bad.getCode());
+                                response.sendError(bad.getCode(), bad.getReason());
                             }
                             catch (Exception e)
                             {
-                                response.sendError(500);
+                                response.sendError(500, e.toString());
                             }
                         }
-                        catch(Throwable th)
+                        catch (IOException | IllegalStateException th)
                         {
-                            throw new RuntimeException(th);
+                            Log.getLog().ignore(th);
+                        }
+                        finally
+                        {
+                            ac.complete();
                         }
-                        ac.complete();
                     });
                 }
             }
@@ -615,12 +617,11 @@ public class NcsaRequestLogTest
         assertRequestLog(expectedLogEntry, _log);
     }
 
-
     private void assertRequestLog(final String expectedLogEntry, RequestLog log) throws Exception
     {
         String line = _entries.poll(5, TimeUnit.SECONDS);
         Assertions.assertNotNull(line);
-        assertThat(line,containsString(expectedLogEntry));
+        assertThat(line, containsString(expectedLogEntry));
         Assertions.assertTrue(_entries.isEmpty());
     }
 
@@ -632,11 +633,11 @@ public class NcsaRequestLogTest
         public void log(Request request, Response response)
         {
             int status = response.getCommittedMetaData().getStatus();
-            log.add(String.format("%s %s %s %03d",request.getMethod(),request.getRequestURI(),request.getProtocol(),status));
+            log.add(String.format("%s %s %s %03d", request.getMethod(), request.getRequestURI(), request.getProtocol(), status));
         }
     }
 
-    private static abstract class AbstractTestHandler extends AbstractHandler
+    private abstract static class AbstractTestHandler extends AbstractHandler
     {
         @Override
         public String toString()
@@ -660,7 +661,7 @@ public class NcsaRequestLogTest
         {
             response.setContentType("text/plain");
             response.getWriter().print("Hello World");
-            if (baseRequest!=null)
+            if (baseRequest != null)
                 baseRequest.setHandled(true);
         }
     }
@@ -670,8 +671,8 @@ public class NcsaRequestLogTest
         @Override
         public void handle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException
         {
-            response.sendError(599,"expected");
-            if (baseRequest!=null)
+            response.sendError(599, "expected");
+            if (baseRequest != null)
                 baseRequest.setHandled(true);
         }
     }
@@ -762,14 +763,14 @@ public class NcsaRequestLogTest
             }
 
             // collect error details
-            String reason = (response instanceof Response)?((Response)response).getReason():null;
+            String reason = (response instanceof Response) ? ((Response)response).getReason() : null;
             int status = response.getStatus();
 
             // intentionally set response status to OK (this is a test to see what is actually logged)
             response.setStatus(200);
             response.setContentType("text/plain");
             PrintWriter out = response.getWriter();
-            out.printf("Error %d: %s%n",status,reason);
+            out.printf("Error %d: %s%n", status, reason);
             baseRequest.setHandled(true);
         }
     }
@@ -783,7 +784,7 @@ public class NcsaRequestLogTest
             {
                 _entries.add(requestEntry);
             }
-            catch(Exception e)
+            catch (Exception e)
             {
                 e.printStackTrace();
             }
@@ -796,16 +797,16 @@ public class NcsaRequestLogTest
         public void handle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException
         {
             String q = request.getQueryString();
-            if (q==null)
+            if (q == null)
                 return;
 
             baseRequest.setHandled(true);
             for (String action : q.split("\\&"))
             {
                 String[] param = action.split("=");
-                String name=param[0];
-                String value=param.length>1?param[1]:null;
-                switch(name)
+                String name = param[0];
+                String value = param.length > 1 ? param[1] : null;
+                switch (name)
                 {
                     case "status":
                     {
@@ -818,12 +819,12 @@ public class NcsaRequestLogTest
                         int data = Integer.parseInt(value);
                         PrintWriter out = response.getWriter();
 
-                        int w=0;
-                        while (w<data)
+                        int w = 0;
+                        while (w < data)
                         {
-                            if ((data-w)>17)
+                            if ((data - w) > 17)
                             {
-                                w+=17;
+                                w += 17;
                                 out.print("0123456789ABCDEF\n");
                             }
                             else
@@ -841,11 +842,11 @@ public class NcsaRequestLogTest
                         {
                             throw (Throwable)(Class.forName(value).getDeclaredConstructor().newInstance());
                         }
-                        catch(ServletException | IOException | Error | RuntimeException e)
+                        catch (ServletException | IOException | Error | RuntimeException e)
                         {
                             throw e;
                         }
-                        catch(Throwable e)
+                        catch (Throwable e)
                         {
                             throw new ServletException(e);
                         }
@@ -859,7 +860,10 @@ public class NcsaRequestLogTest
                     case "read":
                     {
                         InputStream in = request.getInputStream();
-                        while (in.read()>=0);
+                        while (in.read() >= 0)
+                        {
+                            ;
+                        }
                         break;
                     }
                 }
