@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -18,7 +18,9 @@
 
 package org.eclipse.jetty.servlet;
 
+import java.io.ByteArrayOutputStream;
 import java.io.IOException;
+import java.io.OutputStream;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.EnumSet;
@@ -32,10 +34,12 @@ import javax.servlet.RequestDispatcher;
 import javax.servlet.Servlet;
 import javax.servlet.ServletContext;
 import javax.servlet.ServletException;
+import javax.servlet.ServletOutputStream;
 import javax.servlet.ServletRequest;
 import javax.servlet.ServletRequestWrapper;
 import javax.servlet.ServletResponse;
 import javax.servlet.ServletResponseWrapper;
+import javax.servlet.WriteListener;
 import javax.servlet.http.HttpServlet;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletRequestWrapper;
@@ -114,8 +118,9 @@ public class DispatcherTest
         String expected =
             "HTTP/1.1 200 OK\r\n" +
                 "Content-Type: text/html\r\n" +
-                "Content-Length: 0\r\n" +
-                "\r\n";
+                "Content-Length: 7\r\n" +
+                "\r\n" +
+                "FORWARD";
 
         String responses = _connector.getResponse("GET /context/ForwardServlet?do=assertforward&do=more&test=1 HTTP/1.0\n\n");
 
@@ -131,8 +136,9 @@ public class DispatcherTest
         String expected =
             "HTTP/1.1 200 OK\r\n" +
                 "Content-Type: text/html\r\n" +
-                "Content-Length: 0\r\n" +
-                "\r\n";
+                "Content-Length: 7\r\n" +
+                "\r\n" +
+                "FORWARD";
         String responses = _connector.getResponse("GET /context/ForwardServlet?do=assertforward&foreign=%d2%e5%ec%ef%e5%f0%e0%f2%f3%f0%e0&test=1 HTTP/1.0\n\n");
 
         assertEquals(expected, responses);
@@ -201,7 +207,9 @@ public class DispatcherTest
 
         String expected =
             "HTTP/1.1 200 OK\r\n" +
-                "\r\n";
+                "Content-Length: 7\r\n" +
+                "\r\n" +
+                "INCLUDE";
 
         String responses = _connector.getResponse("GET /context/IncludeServlet?do=assertinclude&do=more&test=1 HTTP/1.0\n\n");
 
@@ -217,7 +225,9 @@ public class DispatcherTest
 
         String expected =
             "HTTP/1.1 200 OK\r\n" +
-                "\r\n";
+                "Content-Length: 7\r\n" +
+                "\r\n" +
+                "INCLUDE";
 
         String responses = _connector.getResponse("GET /context/ForwardServlet/forwardpath?do=include HTTP/1.0\n\n");
 
@@ -233,7 +243,9 @@ public class DispatcherTest
 
         String expected =
             "HTTP/1.1 200 OK\r\n" +
-                "\r\n";
+                "Content-Length: 7\r\n" +
+                "\r\n" +
+                "FORWARD";
 
         String responses = _connector.getResponse("GET /context/IncludeServlet/includepath?do=forward HTTP/1.0\n\n");
 
@@ -373,6 +385,88 @@ public class DispatcherTest
         assertThat(rechoResponse, containsString("txeTohce"));
     }
 
+    @Test
+    public void testWrappedForwardCloseIntercepted() throws Exception
+    {
+        // Add filter that wraps response, intercepts close and writes after doChain
+        _contextHandler.addFilter(WrappingFilter.class, "/*", EnumSet.of(DispatcherType.REQUEST));
+        testForward();
+    }
+
+    public static class WrappingFilter implements Filter
+    {
+        @Override
+        public void init(FilterConfig filterConfig) throws ServletException
+        {
+        }
+
+        @Override
+        public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain) throws IOException, ServletException
+        {
+            ResponseWrapper wrapper = new ResponseWrapper((HttpServletResponse)response);
+            chain.doFilter(request, wrapper);
+            wrapper.sendResponse(response.getOutputStream());
+        }
+
+        @Override
+        public void destroy()
+        {
+        }
+    }
+
+    public static class ResponseWrapper extends HttpServletResponseWrapper
+    {
+        ByteArrayOutputStream buffer = new ByteArrayOutputStream();
+
+        public ResponseWrapper(HttpServletResponse response)
+        {
+            super(response);
+        }
+
+        @Override
+        public ServletOutputStream getOutputStream() throws IOException
+        {
+            return new ServletOutputStream()
+            {
+                @Override
+                public boolean isReady()
+                {
+                    return true;
+                }
+
+                @Override
+                public void setWriteListener(WriteListener writeListener)
+                {
+                    throw new UnsupportedOperationException();
+                }
+
+                @Override
+                public void write(int b) throws IOException
+                {
+                    buffer.write(b);
+                }
+
+                @Override
+                public void write(byte[] b, int off, int len) throws IOException
+                {
+                    buffer.write(b, off, len);
+                }
+
+                @Override
+                public void close() throws IOException
+                {
+                    buffer.close();
+                }
+            };
+        }
+
+        public void sendResponse(OutputStream out) throws IOException
+        {
+            out.write(buffer.toByteArray());
+            out.close();
+        }
+    }
+
     public static class ForwardServlet extends HttpServlet implements Servlet
     {
         @Override
@@ -648,6 +742,7 @@ public class DispatcherTest
 
             response.setContentType("text/html");
             response.setStatus(HttpServletResponse.SC_OK);
+            response.getOutputStream().print(request.getDispatcherType().toString());
         }
     }
 
@@ -696,6 +791,7 @@ public class DispatcherTest
 
             response.setContentType("text/html");
             response.setStatus(HttpServletResponse.SC_OK);
+            response.getOutputStream().print(request.getDispatcherType().toString());
         }
     }
 
@@ -724,6 +820,7 @@ public class DispatcherTest
 
             response.setContentType("text/html");
             response.setStatus(HttpServletResponse.SC_OK);
+            response.getOutputStream().print(request.getDispatcherType().toString());
         }
     }
 
@@ -761,6 +858,7 @@ public class DispatcherTest
 
             response.setContentType("text/html");
             response.setStatus(HttpServletResponse.SC_OK);
+            response.getOutputStream().print(request.getDispatcherType().toString());
         }
     }
 
@@ -796,6 +894,7 @@ public class DispatcherTest
 
             response.setContentType("text/html");
             response.setStatus(HttpServletResponse.SC_OK);
+            response.getOutputStream().print(request.getDispatcherType().toString());
         }
     }
 }
