@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -157,6 +157,11 @@ public class ServletTester extends ContainerLifeCycle
         return _context.getBaseResource();
     }
 
+    public void setBaseResource(Resource resource)
+    {
+        _context.setBaseResource(resource);
+    }
+
     public String getResourceBase()
     {
         return _context.getResourceBase();
