@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -22,7 +22,7 @@ import java.net.URL;
 
 import org.junit.jupiter.api.Disabled;
 
-@Disabled
+@Disabled("Not a test case")
 public class TestConfiguration
 {
     public static int VALUE = 77;
