@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -57,6 +57,14 @@ import org.eclipse.jetty.util.ManifestUtils;
 public class StartArgs
 {
     public static final String VERSION;
+    public static final Set<String> ALL_PARTS = Collections.unmodifiableSet(new HashSet<>(Arrays.asList(
+        "java",
+        "opts",
+        "path",
+        "main",
+        "args")));
+    public static final Set<String> ARG_PARTS = Collections.unmodifiableSet(new HashSet<>(Arrays.asList(
+        "args")));
 
     static
     {
@@ -219,6 +227,7 @@ public class StartArgs
     private boolean listConfig = false;
     private boolean version = false;
     private boolean dryRun = false;
+    private final Set<String> dryRunParts = new HashSet<>();
     private boolean jpms = false;
     private boolean createStartd = false;
     private boolean updateIni = false;
@@ -236,9 +245,9 @@ public class StartArgs
 
     private void addFile(Module module, String uriLocation)
     {
-        if (module.isSkipFilesValidation())
+        if (module != null && module.isSkipFilesValidation())
         {
-            StartLog.debug("Not validating %s [files] for %s", module, uriLocation);
+            StartLog.debug("Not validating module %s [files] for %s", module, uriLocation);
             return;
         }
 
@@ -675,8 +684,11 @@ public class StartArgs
         return jvmArgs;
     }
 
-    public CommandLineBuilder getMainArgs(boolean addJavaInit) throws IOException
+    public CommandLineBuilder getMainArgs(Set<String> parts) throws IOException
     {
+        if (parts.isEmpty())
+            parts = ALL_PARTS;
+
         CommandLineBuilder cmd = new CommandLineBuilder();
 
         // Special Stop/Shutdown properties
@@ -684,10 +696,11 @@ public class StartArgs
         ensureSystemPropertySet("STOP.KEY");
         ensureSystemPropertySet("STOP.WAIT");
 
-        if (addJavaInit)
-        {
+        if (parts.contains("java"))
             cmd.addRawArg(CommandLineBuilder.findJavaBin());
 
+        if (parts.contains("opts"))
+        {
             cmd.addRawArg("-Djava.io.tmpdir=" + System.getProperty("java.io.tmpdir"));
             cmd.addRawArg("-Djetty.home=" + baseHome.getHome());
             cmd.addRawArg("-Djetty.base=" + baseHome.getBase());
@@ -702,6 +715,7 @@ public class StartArgs
 
                     Prop p = processSystemProperty(key, value, null);
                     cmd.addRawArg("-D" + p.key + "=" + getProperties().expand(p.value));
+
                 }
                 else
                 {
@@ -715,7 +729,10 @@ public class StartArgs
                 String value = System.getProperty(propKey);
                 cmd.addEqualsArg("-D" + propKey, value);
             }
+        }
 
+        if (parts.contains("path"))
+        {
             if (isJPMS())
             {
                 Map<Boolean, List<File>> dirsAndFiles = StreamSupport.stream(classpath.spliterator(), false)
@@ -764,52 +781,58 @@ public class StartArgs
                     cmd.addRawArg("--add-reads");
                     cmd.addRawArg(entry.getKey() + "=" + String.join(",", entry.getValue()));
                 }
-
-                cmd.addRawArg("--module");
-                cmd.addRawArg(getMainClassname());
             }
             else
             {
                 cmd.addRawArg("-cp");
                 cmd.addRawArg(classpath.toString());
-                cmd.addRawArg(getMainClassname());
             }
         }
 
+        if (parts.contains("main"))
+        {
+            if (isJPMS())
+                cmd.addRawArg("--module");
+            cmd.addRawArg(getMainClassname());
+        }
+
         // pass properties as args or as a file
-        if (dryRun && execProperties == null)
+        if (parts.contains("args"))
         {
-            for (Prop p : properties)
+            if (dryRun && execProperties == null)
             {
-                cmd.addRawArg(CommandLineBuilder.quote(p.key) + "=" + CommandLineBuilder.quote(p.value));
+                for (Prop p : properties)
+                {
+                    cmd.addRawArg(CommandLineBuilder.quote(p.key) + "=" + CommandLineBuilder.quote(p.value));
+                }
             }
-        }
-        else if (properties.size() > 0)
-        {
-            Path propPath;
-            if (execProperties == null)
+            else if (properties.size() > 0)
             {
-                propPath = Files.createTempFile("start_", ".properties");
-                propPath.toFile().deleteOnExit();
-            }
-            else
-                propPath = new File(execProperties).toPath();
+                Path propPath;
+                if (execProperties == null)
+                {
+                    propPath = Files.createTempFile("start_", ".properties");
+                    propPath.toFile().deleteOnExit();
+                }
+                else
+                    propPath = new File(execProperties).toPath();
 
-            try (OutputStream out = Files.newOutputStream(propPath))
+                try (OutputStream out = Files.newOutputStream(propPath))
+                {
+                    properties.store(out, "start.jar properties");
+                }
+                cmd.addRawArg(propPath.toAbsolutePath().toString());
+            }
+
+            for (Path xml : xmls)
             {
-                properties.store(out, "start.jar properties");
+                cmd.addRawArg(xml.toAbsolutePath().toString());
             }
-            cmd.addRawArg(propPath.toAbsolutePath().toString());
-        }
 
-        for (Path xml : xmls)
-        {
-            cmd.addRawArg(xml.toAbsolutePath().toString());
-        }
-
-        for (Path propertyFile : propertyFiles)
-        {
-            cmd.addRawArg(propertyFile.toAbsolutePath().toString());
+            for (Path propertyFile : propertyFiles)
+            {
+                cmd.addRawArg(propertyFile.toAbsolutePath().toString());
+            }
         }
 
         return cmd;
@@ -935,6 +958,11 @@ public class StartArgs
         return dryRun;
     }
 
+    public Set<String> getDryRunParts()
+    {
+        return dryRunParts;
+    }
+
     public boolean isExec()
     {
         return exec;
@@ -1152,6 +1180,21 @@ public class StartArgs
             return;
         }
 
+        if (arg.startsWith("--dry-run="))
+        {
+            int colon = arg.indexOf('=');
+            for (String part : arg.substring(colon + 1).split(","))
+            {
+                if (!ALL_PARTS.contains(part))
+                    throw new UsageException(UsageException.ERR_BAD_ARG, "Unrecognized --dry-run=\"%s\" in %s", part, source);
+
+                dryRunParts.add(part);
+            }
+            dryRun = true;
+            run = false;
+            return;
+        }
+
         // Enable forked execution of Jetty server
         if ("--exec".equals(arg))
         {
@@ -1462,10 +1505,14 @@ public class StartArgs
             {
                 JavaVersion ver = JavaVersion.parse(value);
                 properties.setProperty("java.version.platform", Integer.toString(ver.getPlatform()), source);
+
                 // @deprecated - below will be removed in Jetty 10.x
                 properties.setProperty("java.version.major", Integer.toString(ver.getMajor()), "Deprecated");
                 properties.setProperty("java.version.minor", Integer.toString(ver.getMinor()), "Deprecated");
                 properties.setProperty("java.version.micro", Integer.toString(ver.getMicro()), "Deprecated");
+
+                // ALPN feature exists
+                properties.setProperty("runtime.feature.alpn", Boolean.toString(isMethodAvailable(javax.net.ssl.SSLParameters.class, "getApplicationProtocols", null)), source);
             }
             catch (Throwable x)
             {
@@ -1482,6 +1529,19 @@ public class StartArgs
         }
     }
 
+    private boolean isMethodAvailable(Class<?> clazz, String methodName, Class<?>[] params)
+    {
+        try
+        {
+            clazz.getMethod(methodName, params);
+            return true;
+        }
+        catch (NoSuchMethodException e)
+        {
+            return false;
+        }
+    }
+
     public void setRun(boolean run)
     {
         this.run = run;
