@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2019 Mort Bay Consulting Pty. Ltd.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -18,12 +18,6 @@
 
 package org.eclipse.jetty.start;
 
-import static org.hamcrest.MatcherAssert.assertThat;
-import static org.hamcrest.Matchers.containsString;
-import static org.hamcrest.Matchers.is;
-import static org.hamcrest.Matchers.notNullValue;
-import static org.junit.jupiter.api.Assertions.assertThrows;
-
 import java.io.File;
 import java.nio.file.Path;
 import java.util.ArrayList;
@@ -39,6 +33,12 @@ import org.eclipse.jetty.toolchain.test.jupiter.WorkDirExtension;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.extension.ExtendWith;
 
+import static org.hamcrest.MatcherAssert.assertThat;
+import static org.hamcrest.Matchers.containsString;
+import static org.hamcrest.Matchers.is;
+import static org.hamcrest.Matchers.notNullValue;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+
 @ExtendWith(WorkDirExtension.class)
 public class IncludeJettyDirTest
 {
@@ -58,15 +58,15 @@ public class IncludeJettyDirTest
                     actualOrder.add(source.getId());
                 }
             }
-            ConfigurationAssert.assertOrdered("Search Order",expectedSearchOrder,actualOrder);
+            ConfigurationAssert.assertOrdered("Search Order", expectedSearchOrder, actualOrder);
         }
 
         public void assertProperty(String key, String expectedValue)
         {
             Prop prop = args.getProperties().getProp(key);
             String prefix = "Prop[" + key + "]";
-            assertThat(prefix + " should have a value",prop,notNullValue());
-            assertThat(prefix + " value",prop.value,is(expectedValue));
+            assertThat(prefix + " should have a value", prop, notNullValue());
+            assertThat(prefix + " value", prop.value, is(expectedValue));
         }
     }
 
@@ -94,48 +94,48 @@ public class IncludeJettyDirTest
         // Create home
         Path home = testdir.getPathFile("home");
         FS.ensureEmpty(home);
-        TestEnv.copyTestDir("dist-home",home);
+        TestEnv.copyTestDir("dist-home", home);
 
         // Create base
         Path base = testdir.getPathFile("base");
         FS.ensureEmpty(base);
-        TestEnv.makeFile(base,"start.ini", //
-                "jetty.http.host=127.0.0.1");
+        TestEnv.makeFile(base, "start.ini",
+            "jetty.http.host=127.0.0.1");
 
         // Simple command line - no reference to include-jetty-dirs
-        MainResult result = runMain(base,home);
+        MainResult result = runMain(base, home);
 
         List<String> expectedSearchOrder = new ArrayList<>();
         expectedSearchOrder.add("${jetty.base}");
         expectedSearchOrder.add("${jetty.home}");
         result.assertSearchOrder(expectedSearchOrder);
 
-        result.assertProperty("jetty.http.host","127.0.0.1");
+        result.assertProperty("jetty.http.host", "127.0.0.1");
     }
 
     @Test
-    public void testCommandLine_1Extra() throws Exception
+    public void testCommandLine1Extra() throws Exception
     {
         // Create home
         Path home = testdir.getPathFile("home");
         FS.ensureEmpty(home);
-        TestEnv.copyTestDir("dist-home",home);
+        TestEnv.copyTestDir("dist-home", home);
 
         // Create common
         Path common = testdir.getPathFile("common");
         FS.ensureEmpty(common);
-        TestEnv.makeFile(common,"start.ini","jetty.http.port=8080");
+        TestEnv.makeFile(common, "start.ini", "jetty.http.port=8080");
 
         // Create base
         Path base = testdir.getPathFile("base");
         FS.ensureEmpty(base);
-        TestEnv.makeFile(base,"start.ini", //
-                "jetty.http.host=127.0.0.1");
+        TestEnv.makeFile(base, "start.ini",
+            "jetty.http.host=127.0.0.1");
 
         // Simple command line reference to include-jetty-dir
-        MainResult result = runMain(base,home,
-        // direct reference via path
-                "--include-jetty-dir=" + common.toString());
+        MainResult result = runMain(base, home,
+            // direct reference via path
+            "--include-jetty-dir=" + common.toString());
 
         List<String> expectedSearchOrder = new ArrayList<>();
         expectedSearchOrder.add("${jetty.base}");
@@ -143,35 +143,35 @@ public class IncludeJettyDirTest
         expectedSearchOrder.add("${jetty.home}");
         result.assertSearchOrder(expectedSearchOrder);
 
-        result.assertProperty("jetty.http.host","127.0.0.1");
-        result.assertProperty("jetty.http.port","8080"); // from 'common'
+        result.assertProperty("jetty.http.host", "127.0.0.1");
+        result.assertProperty("jetty.http.port", "8080"); // from 'common'
     }
 
     @Test
-    public void testCommandLine_1Extra_FromSimpleProp() throws Exception
+    public void testCommandLine1ExtraFromSimpleProp() throws Exception
     {
         // Create home
         Path home = testdir.getPathFile("home");
         FS.ensureEmpty(home);
-        TestEnv.copyTestDir("dist-home",home);
+        TestEnv.copyTestDir("dist-home", home);
 
         // Create common
         Path common = testdir.getPathFile("common");
         FS.ensureEmpty(common);
-        TestEnv.makeFile(common,"start.ini","jetty.http.port=8080");
+        TestEnv.makeFile(common, "start.ini", "jetty.http.port=8080");
 
         // Create base
         Path base = testdir.getPathFile("base");
         FS.ensureEmpty(base);
-        TestEnv.makeFile(base,"start.ini", //
-                "jetty.http.host=127.0.0.1");
+        TestEnv.makeFile(base, "start.ini",
+            "jetty.http.host=127.0.0.1");
 
         // Simple command line reference to include-jetty-dir via property (also on command line)
-        MainResult result = runMain(base,home,
-        // property
-                "my.common=" + common.toString(),
-                // reference via property
-                "--include-jetty-dir=${my.common}");
+        MainResult result = runMain(base, home,
+            // property
+            "my.common=" + common.toString(),
+            // reference via property
+            "--include-jetty-dir=${my.common}");
 
         List<String> expectedSearchOrder = new ArrayList<>();
         expectedSearchOrder.add("${jetty.base}");
@@ -179,17 +179,17 @@ public class IncludeJettyDirTest
         expectedSearchOrder.add("${jetty.home}");
         result.assertSearchOrder(expectedSearchOrder);
 
-        result.assertProperty("jetty.http.host","127.0.0.1");
-        result.assertProperty("jetty.http.port","8080"); // from 'common'
+        result.assertProperty("jetty.http.host", "127.0.0.1");
+        result.assertProperty("jetty.http.port", "8080"); // from 'common'
     }
 
     @Test
-    public void testCommandLine_1Extra_FromPropPrefix() throws Exception
+    public void testCommandLine1ExtraFromPropPrefix() throws Exception
     {
         // Create home
         Path home = testdir.getPathFile("home");
         FS.ensureEmpty(home);
-        TestEnv.copyTestDir("dist-home",home);
+        TestEnv.copyTestDir("dist-home", home);
 
         // Create opt
         Path opt = testdir.getPathFile("opt");
@@ -198,22 +198,22 @@ public class IncludeJettyDirTest
         // Create common
         Path common = opt.resolve("common");
         FS.ensureEmpty(common);
-        TestEnv.makeFile(common,"start.ini","jetty.http.port=8080");
+        TestEnv.makeFile(common, "start.ini", "jetty.http.port=8080");
 
         // Create base
         Path base = testdir.getPathFile("base");
         FS.ensureEmpty(base);
-        TestEnv.makeFile(base,"start.ini", //
-                "jetty.http.host=127.0.0.1");
+        TestEnv.makeFile(base, "start.ini",
+            "jetty.http.host=127.0.0.1");
 
         String dirRef = "${my.opt}" + File.separator + "common";
 
         // Simple command line reference to include-jetty-dir via property (also on command line)
-        MainResult result = runMain(base,home,
-        // property to 'opt' dir
-                "my.opt=" + opt.toString(),
-                // reference via property prefix
-                "--include-jetty-dir=" + dirRef);
+        MainResult result = runMain(base, home,
+            // property to 'opt' dir
+            "my.opt=" + opt.toString(),
+            // reference via property prefix
+            "--include-jetty-dir=" + dirRef);
 
         List<String> expectedSearchOrder = new ArrayList<>();
         expectedSearchOrder.add("${jetty.base}");
@@ -221,17 +221,17 @@ public class IncludeJettyDirTest
         expectedSearchOrder.add("${jetty.home}");
         result.assertSearchOrder(expectedSearchOrder);
 
-        result.assertProperty("jetty.http.host","127.0.0.1");
-        result.assertProperty("jetty.http.port","8080"); // from 'common'
+        result.assertProperty("jetty.http.host", "127.0.0.1");
+        result.assertProperty("jetty.http.port", "8080"); // from 'common'
     }
 
     @Test
-    public void testCommandLine_1Extra_FromCompoundProp() throws Exception
+    public void testCommandLine1ExtraFromCompoundProp() throws Exception
     {
         // Create home
         Path home = testdir.getPathFile("home");
         FS.ensureEmpty(home);
-        TestEnv.copyTestDir("dist-home",home);
+        TestEnv.copyTestDir("dist-home", home);
 
         // Create opt
         Path opt = testdir.getPathFile("opt");
@@ -240,24 +240,24 @@ public class IncludeJettyDirTest
         // Create common
         Path common = opt.resolve("common");
         FS.ensureEmpty(common);
-        TestEnv.makeFile(common,"start.ini","jetty.http.port=8080");
+        TestEnv.makeFile(common, "start.ini", "jetty.http.port=8080");
 
         // Create base
         Path base = testdir.getPathFile("base");
         FS.ensureEmpty(base);
-        TestEnv.makeFile(base,"start.ini", //
-                "jetty.http.host=127.0.0.1");
+        TestEnv.makeFile(base, "start.ini",
+            "jetty.http.host=127.0.0.1");
 
         String dirRef = "${my.opt}" + File.separator + "${my.dir}";
 
         // Simple command line reference to include-jetty-dir via property (also on command line)
-        MainResult result = runMain(base,home,
-        // property to 'opt' dir
-                "my.opt=" + opt.toString(),
-                // property to commmon dir name
-                "my.dir=common",
-                // reference via property prefix
-                "--include-jetty-dir=" + dirRef);
+        MainResult result = runMain(base, home,
+            // property to 'opt' dir
+            "my.opt=" + opt.toString(),
+            // property to commmon dir name
+            "my.dir=common",
+            // reference via property prefix
+            "--include-jetty-dir=" + dirRef);
 
         List<String> expectedSearchOrder = new ArrayList<>();
         expectedSearchOrder.add("${jetty.base}");
@@ -265,8 +265,8 @@ public class IncludeJettyDirTest
         expectedSearchOrder.add("${jetty.home}");
         result.assertSearchOrder(expectedSearchOrder);
 
-        result.assertProperty("jetty.http.host","127.0.0.1");
-        result.assertProperty("jetty.http.port","8080"); // from 'common'
+        result.assertProperty("jetty.http.host", "127.0.0.1");
+        result.assertProperty("jetty.http.port", "8080"); // from 'common'
     }
 
     @Test
@@ -275,21 +275,21 @@ public class IncludeJettyDirTest
         // Create home
         Path home = testdir.getPathFile("home");
         FS.ensureEmpty(home);
-        TestEnv.copyTestDir("dist-home",home);
+        TestEnv.copyTestDir("dist-home", home);
 
         // Create common
         Path common = testdir.getPathFile("common");
         FS.ensureEmpty(common);
-        TestEnv.makeFile(common,"start.ini","jetty.http.port=8080");
+        TestEnv.makeFile(common, "start.ini", "jetty.http.port=8080");
 
         // Create base
         Path base = testdir.getPathFile("base");
         FS.ensureEmpty(base);
-        TestEnv.makeFile(base,"start.ini", //
-                "jetty.http.host=127.0.0.1",//
-                "--include-jetty-dir=" + common.toString());
+        TestEnv.makeFile(base, "start.ini",
+            "jetty.http.host=127.0.0.1",
+            "--include-jetty-dir=" + common.toString());
 
-        MainResult result = runMain(base,home);
+        MainResult result = runMain(base, home);
 
         List<String> expectedSearchOrder = new ArrayList<>();
         expectedSearchOrder.add("${jetty.base}");
@@ -297,8 +297,8 @@ public class IncludeJettyDirTest
         expectedSearchOrder.add("${jetty.home}");
         result.assertSearchOrder(expectedSearchOrder);
 
-        result.assertProperty("jetty.http.host","127.0.0.1");
-        result.assertProperty("jetty.http.port","8080"); // from 'common'
+        result.assertProperty("jetty.http.host", "127.0.0.1");
+        result.assertProperty("jetty.http.port", "8080"); // from 'common'
     }
 
     @Test
@@ -307,12 +307,12 @@ public class IncludeJettyDirTest
         // Create home
         Path home = testdir.getPathFile("home");
         FS.ensureEmpty(home);
-        TestEnv.copyTestDir("dist-home",home);
+        TestEnv.copyTestDir("dist-home", home);
 
         // Create common
         Path common = testdir.getPathFile("common");
         FS.ensureEmpty(common);
-        TestEnv.makeFile(common,"start.ini","jetty.http.port=8080");
+        TestEnv.makeFile(common, "start.ini", "jetty.http.port=8080");
 
         // Create corp
         Path corp = testdir.getPathFile("corp");
@@ -321,12 +321,12 @@ public class IncludeJettyDirTest
         // Create base
         Path base = testdir.getPathFile("base");
         FS.ensureEmpty(base);
-        TestEnv.makeFile(base,"start.ini", //
-                "jetty.http.host=127.0.0.1",//
-                "--include-jetty-dir=" + common.toString(), //
-                "--include-jetty-dir=" + corp.toString());
+        TestEnv.makeFile(base, "start.ini",
+            "jetty.http.host=127.0.0.1",
+            "--include-jetty-dir=" + common.toString(),
+            "--include-jetty-dir=" + corp.toString());
 
-        MainResult result = runMain(base,home);
+        MainResult result = runMain(base, home);
 
         List<String> expectedSearchOrder = new ArrayList<>();
         expectedSearchOrder.add("${jetty.base}");
@@ -335,8 +335,8 @@ public class IncludeJettyDirTest
         expectedSearchOrder.add("${jetty.home}");
         result.assertSearchOrder(expectedSearchOrder);
 
-        result.assertProperty("jetty.http.host","127.0.0.1");
-        result.assertProperty("jetty.http.port","8080"); // from 'common'
+        result.assertProperty("jetty.http.host", "127.0.0.1");
+        result.assertProperty("jetty.http.port", "8080"); // from 'common'
     }
 
     @Test
@@ -345,28 +345,28 @@ public class IncludeJettyDirTest
         // Create home
         Path home = testdir.getPathFile("home");
         FS.ensureEmpty(home);
-        TestEnv.copyTestDir("dist-home",home);
+        TestEnv.copyTestDir("dist-home", home);
 
         // Create corp
         Path corp = testdir.getPathFile("corp");
         FS.ensureEmpty(corp);
-        TestEnv.makeFile(corp,"start.ini","jetty.http.port=9090");
+        TestEnv.makeFile(corp, "start.ini", "jetty.http.port=9090");
 
         // Create common
         Path common = testdir.getPathFile("common");
         FS.ensureEmpty(common);
-        TestEnv.makeFile(common,"start.ini", //
-                "--include-jetty-dir=" + corp.toString(), //
-                "jetty.http.port=8080");
+        TestEnv.makeFile(common, "start.ini",
+            "--include-jetty-dir=" + corp.toString(),
+            "jetty.http.port=8080");
 
         // Create base
         Path base = testdir.getPathFile("base");
         FS.ensureEmpty(base);
-        TestEnv.makeFile(base,"start.ini", //
-                "jetty.http.host=127.0.0.1",//
-                "--include-jetty-dir=" + common.toString());
+        TestEnv.makeFile(base, "start.ini",
+            "jetty.http.host=127.0.0.1",
+            "--include-jetty-dir=" + common.toString());
 
-        MainResult result = runMain(base,home);
+        MainResult result = runMain(base, home);
 
         List<String> expectedSearchOrder = new ArrayList<>();
         expectedSearchOrder.add("${jetty.base}");
@@ -375,41 +375,41 @@ public class IncludeJettyDirTest
         expectedSearchOrder.add("${jetty.home}");
         result.assertSearchOrder(expectedSearchOrder);
 
-        result.assertProperty("jetty.http.host","127.0.0.1");
-        result.assertProperty("jetty.http.port","8080"); // from 'common'
+        result.assertProperty("jetty.http.host", "127.0.0.1");
+        result.assertProperty("jetty.http.port", "8080"); // from 'common'
     }
 
     @Test
-    public void testRefCommonRefCorp_FromSimpleProps() throws Exception
+    public void testRefCommonRefCorpFromSimpleProps() throws Exception
     {
         // Create home
         Path home = testdir.getPathFile("home");
         FS.ensureEmpty(home);
-        TestEnv.copyTestDir("dist-home",home);
+        TestEnv.copyTestDir("dist-home", home);
 
         // Create corp
         Path corp = testdir.getPathFile("corp");
         FS.ensureEmpty(corp);
-        TestEnv.makeFile(corp,"start.ini", //
-                "jetty.http.port=9090");
+        TestEnv.makeFile(corp, "start.ini",
+            "jetty.http.port=9090");
 
         // Create common
         Path common = testdir.getPathFile("common");
         FS.ensureEmpty(common);
-        TestEnv.makeFile(common,"start.ini", //
-                "my.corp=" + corp.toString(), //
-                "--include-jetty-dir=${my.corp}", //
-                "jetty.http.port=8080");
+        TestEnv.makeFile(common, "start.ini",
+            "my.corp=" + corp.toString(),
+            "--include-jetty-dir=${my.corp}",
+            "jetty.http.port=8080");
 
         // Create base
         Path base = testdir.getPathFile("base");
         FS.ensureEmpty(base);
-        TestEnv.makeFile(base,"start.ini", //
-                "jetty.http.host=127.0.0.1",//
-                "my.common=" + common.toString(), //
-                "--include-jetty-dir=${my.common}");
+        TestEnv.makeFile(base, "start.ini",
+            "jetty.http.host=127.0.0.1",
+            "my.common=" + common.toString(),
+            "--include-jetty-dir=${my.common}");
 
-        MainResult result = runMain(base,home);
+        MainResult result = runMain(base, home);
 
         List<String> expectedSearchOrder = new ArrayList<>();
         expectedSearchOrder.add("${jetty.base}");
@@ -418,48 +418,48 @@ public class IncludeJettyDirTest
         expectedSearchOrder.add("${jetty.home}");
         result.assertSearchOrder(expectedSearchOrder);
 
-        result.assertProperty("jetty.http.host","127.0.0.1");
-        result.assertProperty("jetty.http.port","8080"); // from 'common'
+        result.assertProperty("jetty.http.host", "127.0.0.1");
+        result.assertProperty("jetty.http.port", "8080"); // from 'common'
     }
 
     @Test
-    public void testRefCommonRefCorp_CmdLineRef() throws Exception
+    public void testRefCommonRefCorpCmdLineRef() throws Exception
     {
         // Create home
         Path home = testdir.getPathFile("home");
         FS.ensureEmpty(home);
-        TestEnv.copyTestDir("dist-home",home);
+        TestEnv.copyTestDir("dist-home", home);
 
         // Create devops
         Path devops = testdir.getPathFile("devops");
         FS.ensureEmpty(devops);
-        TestEnv.makeFile(devops,"start.ini", //
-                "--module=optional", //
-                "jetty.http.port=2222");
+        TestEnv.makeFile(devops, "start.ini",
+            "--module=optional",
+            "jetty.http.port=2222");
 
         // Create corp
         Path corp = testdir.getPathFile("corp");
         FS.ensureEmpty(corp);
-        TestEnv.makeFile(corp,"start.ini", //
-                "jetty.http.port=9090");
+        TestEnv.makeFile(corp, "start.ini",
+            "jetty.http.port=9090");
 
         // Create common
         Path common = testdir.getPathFile("common");
         FS.ensureEmpty(common);
-        TestEnv.makeFile(common,"start.ini", //
-                "--include-jetty-dir=" + corp.toString(), //
-                "jetty.http.port=8080");
+        TestEnv.makeFile(common, "start.ini",
+            "--include-jetty-dir=" + corp.toString(),
+            "jetty.http.port=8080");
 
         // Create base
         Path base = testdir.getPathFile("base");
         FS.ensureEmpty(base);
-        TestEnv.makeFile(base,"start.ini", //
-                "jetty.http.host=127.0.0.1",//
-                "--include-jetty-dir=" + common.toString());
+        TestEnv.makeFile(base, "start.ini",
+            "jetty.http.host=127.0.0.1",
+            "--include-jetty-dir=" + common.toString());
 
-        MainResult result = runMain(base,home,
-        // command line provided include-jetty-dir ref
-                "--include-jetty-dir=" + devops.toString());
+        MainResult result = runMain(base, home,
+            // command line provided include-jetty-dir ref
+            "--include-jetty-dir=" + devops.toString());
 
         List<String> expectedSearchOrder = new ArrayList<>();
         expectedSearchOrder.add("${jetty.base}");
@@ -469,41 +469,41 @@ public class IncludeJettyDirTest
         expectedSearchOrder.add("${jetty.home}");
         result.assertSearchOrder(expectedSearchOrder);
 
-        result.assertProperty("jetty.http.host","127.0.0.1");
-        result.assertProperty("jetty.http.port","2222"); // from 'devops'
+        result.assertProperty("jetty.http.host", "127.0.0.1");
+        result.assertProperty("jetty.http.port", "2222"); // from 'devops'
     }
 
     @Test
-    public void testRefCommonRefCorp_CmdLineProp() throws Exception
+    public void testRefCommonRefCorpCmdLineProp() throws Exception
     {
         // Create home
         Path home = testdir.getPathFile("home");
         FS.ensureEmpty(home);
-        TestEnv.copyTestDir("dist-home",home);
+        TestEnv.copyTestDir("dist-home", home);
 
         // Create corp
         Path corp = testdir.getPathFile("corp");
         FS.ensureEmpty(corp);
-        TestEnv.makeFile(corp,"start.ini", //
-                "jetty.http.port=9090");
+        TestEnv.makeFile(corp, "start.ini",
+            "jetty.http.port=9090");
 
         // Create common
         Path common = testdir.getPathFile("common");
         FS.ensureEmpty(common);
-        TestEnv.makeFile(common,"start.ini", //
-                "--include-jetty-dir=" + corp.toString(), //
-                "jetty.http.port=8080");
+        TestEnv.makeFile(common, "start.ini",
+            "--include-jetty-dir=" + corp.toString(),
+            "jetty.http.port=8080");
 
         // Create base
         Path base = testdir.getPathFile("base");
         FS.ensureEmpty(base);
-        TestEnv.makeFile(base,"start.ini", //
-                "jetty.http.host=127.0.0.1",//
-                "--include-jetty-dir=" + common.toString());
+        TestEnv.makeFile(base, "start.ini",
+            "jetty.http.host=127.0.0.1",
+            "--include-jetty-dir=" + common.toString());
 
-        MainResult result = runMain(base,home,
-        // command line property should override all others
-                "jetty.http.port=7070");
+        MainResult result = runMain(base, home,
+            // command line property should override all others
+            "jetty.http.port=7070");
 
         List<String> expectedSearchOrder = new ArrayList<>();
         expectedSearchOrder.add("${jetty.base}");
@@ -512,8 +512,8 @@ public class IncludeJettyDirTest
         expectedSearchOrder.add("${jetty.home}");
         result.assertSearchOrder(expectedSearchOrder);
 
-        result.assertProperty("jetty.http.host","127.0.0.1");
-        result.assertProperty("jetty.http.port","7070"); // from command line
+        result.assertProperty("jetty.http.host", "127.0.0.1");
+        result.assertProperty("jetty.http.port", "7070"); // from command line
     }
 
     @Test
@@ -522,7 +522,7 @@ public class IncludeJettyDirTest
         // Create home
         Path home = testdir.getPathFile("home");
         FS.ensureEmpty(home);
-        TestEnv.copyTestDir("dist-home",home);
+        TestEnv.copyTestDir("dist-home", home);
 
         // Create common
         Path common = testdir.getPathFile("common");
@@ -531,27 +531,27 @@ public class IncludeJettyDirTest
         // Create corp
         Path corp = testdir.getPathFile("corp");
         FS.ensureEmpty(corp);
-        TestEnv.makeFile(corp,"start.ini",
-        // standard property
-                "jetty.http.port=9090",
-                // INTENTIONAL BAD Reference (duplicate)
-                "--include-jetty-dir=" + common.toString());
+        TestEnv.makeFile(corp, "start.ini",
+            // standard property
+            "jetty.http.port=9090",
+            // INTENTIONAL BAD Reference (duplicate)
+            "--include-jetty-dir=" + common.toString());
 
         // Populate common
-        TestEnv.makeFile(common,"start.ini",
-        // standard property
-                "jetty.http.port=8080",
-                // reference to corp
-                "--include-jetty-dir=" + corp.toString());
+        TestEnv.makeFile(common, "start.ini",
+            // standard property
+            "jetty.http.port=8080",
+            // reference to corp
+            "--include-jetty-dir=" + corp.toString());
 
         // Create base
         Path base = testdir.getPathFile("base");
         FS.ensureEmpty(base);
-        TestEnv.makeFile(base,"start.ini", //
-                "jetty.http.host=127.0.0.1",//
-                "--include-jetty-dir=" + common.toString());
+        TestEnv.makeFile(base, "start.ini",
+            "jetty.http.host=127.0.0.1",
+            "--include-jetty-dir=" + common.toString());
 
-        UsageException e = assertThrows(UsageException.class, ()-> runMain(base,home));
-        assertThat("UsageException",e.getMessage(),containsString("Duplicate"));
+        UsageException e = assertThrows(UsageException.class, () -> runMain(base, home));
+        assertThat("UsageException", e.getMessage(), containsString("Duplicate"));
     }
 }
