@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -18,30 +18,32 @@
 
 package org.eclipse.jetty.start;
 
+import java.io.BufferedWriter;
 import java.io.File;
-import java.io.FileWriter;
 import java.io.IOException;
 import java.io.PrintWriter;
+import java.nio.file.Files;
+import java.nio.file.Path;
 
 import org.eclipse.jetty.toolchain.test.FS;
 import org.eclipse.jetty.toolchain.test.IO;
 import org.eclipse.jetty.toolchain.test.MavenTestingUtils;
-import org.eclipse.jetty.toolchain.test.OS;
 
 public class TestEnv
 {
-    public static void copyTestDir(String testResourceDir, File destDir) throws IOException
+    public static void copyTestDir(String testResourceDir, Path destDir) throws IOException
     {
         FS.ensureDirExists(destDir);
         File srcDir = MavenTestingUtils.getTestResourceDir(testResourceDir);
-        IO.copyDir(srcDir,destDir);
+        IO.copyDir(srcDir, destDir.toFile());
     }
 
-    public static void makeFile(File dir, String relFilePath, String... contents) throws IOException
+    public static void makeFile(Path dir, String relFilePath, String... contents) throws IOException
     {
-        File outputFile = new File(dir,OS.separators(relFilePath));
-        FS.ensureDirExists(outputFile.getParentFile());
-        try (FileWriter writer = new FileWriter(outputFile); PrintWriter out = new PrintWriter(writer))
+        Path outputFile = dir.resolve(FS.separators(relFilePath));
+        FS.ensureDirExists(outputFile.getParent());
+        try (BufferedWriter writer = Files.newBufferedWriter(outputFile);
+             PrintWriter out = new PrintWriter(writer))
         {
             for (String content : contents)
             {
