@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -93,7 +93,7 @@ public class ConfigSourcesTest
         // Create base
         Path base = testdir.getPathFile("base");
         FS.ensureEmpty(base);
-        TestEnv.makeFile(base, "start.ini", //
+        TestEnv.makeFile(base, "start.ini",
             "jetty.http.host=127.0.0.1");
 
         ConfigSources sources = new ConfigSources();
@@ -122,8 +122,8 @@ public class ConfigSourcesTest
         // Create base
         Path base = testdir.getPathFile("base");
         FS.ensureEmpty(base);
-        TestEnv.makeFile(base, "start.ini", //
-            "jetty.http.host=127.0.0.1",//
+        TestEnv.makeFile(base, "start.ini",
+            "jetty.http.host=127.0.0.1",
             "--include-jetty-dir=" + common.toString());
 
         ConfigSources sources = new ConfigSources();
@@ -152,7 +152,7 @@ public class ConfigSourcesTest
         // Create base
         Path base = testdir.getPathFile("base");
         FS.ensureEmpty(base);
-        TestEnv.makeFile(base, "start.ini", //
+        TestEnv.makeFile(base, "start.ini",
             "jetty.http.host=127.0.0.1");
 
         ConfigSources sources = new ConfigSources();
@@ -198,7 +198,7 @@ public class ConfigSourcesTest
         // Create base
         Path base = testdir.getPathFile("base");
         FS.ensureEmpty(base);
-        TestEnv.makeFile(base, "start.ini", //
+        TestEnv.makeFile(base, "start.ini",
             "jetty.http.host=127.0.0.1");
 
         String dirRef = "${my.opt}" + File.separator + "common";
@@ -245,7 +245,7 @@ public class ConfigSourcesTest
         // Create base
         Path base = testdir.getPathFile("base");
         FS.ensureEmpty(base);
-        TestEnv.makeFile(base, "start.ini", //
+        TestEnv.makeFile(base, "start.ini",
             "jetty.http.host=127.0.0.1");
 
         String dirRef = "${my.opt}" + File.separator + "${my.dir}";
@@ -291,8 +291,8 @@ public class ConfigSourcesTest
         // Create base
         Path base = testdir.getPathFile("base");
         FS.ensureEmpty(base);
-        TestEnv.makeFile(base, "start.ini", //
-            "jetty.http.host=127.0.0.1",//
+        TestEnv.makeFile(base, "start.ini",
+            "jetty.http.host=127.0.0.1",
             "--include-jetty-dir=" + common.toString());
 
         ConfigSources sources = new ConfigSources();
@@ -330,9 +330,9 @@ public class ConfigSourcesTest
         // Create base
         Path base = testdir.getPathFile("base");
         FS.ensureEmpty(base);
-        TestEnv.makeFile(base, "start.ini", //
-            "jetty.http.host=127.0.0.1",//
-            "--include-jetty-dir=" + common.toString(), //
+        TestEnv.makeFile(base, "start.ini",
+            "jetty.http.host=127.0.0.1",
+            "--include-jetty-dir=" + common.toString(),
             "--include-jetty-dir=" + corp.toString());
 
         ConfigSources sources = new ConfigSources();
@@ -364,21 +364,21 @@ public class ConfigSourcesTest
         // Create corp
         Path corp = testdir.getPathFile("corp");
         FS.ensureEmpty(corp);
-        TestEnv.makeFile(corp, "start.ini", //
+        TestEnv.makeFile(corp, "start.ini",
             "jetty.http.port=9090");
 
         // Create common
         Path common = testdir.getPathFile("common");
         FS.ensureEmpty(common);
-        TestEnv.makeFile(common, "start.ini", //
-            "--include-jetty-dir=" + corp.toString(), //
+        TestEnv.makeFile(common, "start.ini",
+            "--include-jetty-dir=" + corp.toString(),
             "jetty.http.port=8080");
 
         // Create base
         Path base = testdir.getPathFile("base");
         FS.ensureEmpty(base);
-        TestEnv.makeFile(base, "start.ini", //
-            "jetty.http.host=127.0.0.1",//
+        TestEnv.makeFile(base, "start.ini",
+            "jetty.http.host=127.0.0.1",
             "--include-jetty-dir=" + common.toString());
 
         ConfigSources sources = new ConfigSources();
@@ -410,23 +410,23 @@ public class ConfigSourcesTest
         // Create corp
         Path corp = testdir.getPathFile("corp");
         FS.ensureEmpty(corp);
-        TestEnv.makeFile(corp, "start.ini", //
+        TestEnv.makeFile(corp, "start.ini",
             "jetty.http.port=9090");
 
         // Create common
         Path common = testdir.getPathFile("common");
         FS.ensureEmpty(common);
-        TestEnv.makeFile(common, "start.ini", //
-            "my.corp=" + corp.toString(), //
-            "--include-jetty-dir=${my.corp}", //
+        TestEnv.makeFile(common, "start.ini",
+            "my.corp=" + corp.toString(),
+            "--include-jetty-dir=${my.corp}",
             "jetty.http.port=8080");
 
         // Create base
         Path base = testdir.getPathFile("base");
         FS.ensureEmpty(base);
-        TestEnv.makeFile(base, "start.ini", //
-            "jetty.http.host=127.0.0.1",//
-            "my.common=" + common.toString(), //
+        TestEnv.makeFile(base, "start.ini",
+            "jetty.http.host=127.0.0.1",
+            "my.common=" + common.toString(),
             "--include-jetty-dir=${my.common}");
 
         ConfigSources sources = new ConfigSources();
@@ -459,28 +459,28 @@ public class ConfigSourcesTest
         // Create devops
         Path devops = testdir.getPathFile("devops");
         FS.ensureEmpty(devops);
-        TestEnv.makeFile(devops, "start.ini", //
-            "--module=logging", //
+        TestEnv.makeFile(devops, "start.ini",
+            "--module=logging",
             "jetty.http.port=2222");
 
         // Create corp
         Path corp = testdir.getPathFile("corp");
         FS.ensureEmpty(corp);
-        TestEnv.makeFile(corp, "start.ini", //
+        TestEnv.makeFile(corp, "start.ini",
             "jetty.http.port=9090");
 
         // Create common
         Path common = testdir.getPathFile("common");
         FS.ensureEmpty(common);
-        TestEnv.makeFile(common, "start.ini", //
-            "--include-jetty-dir=" + corp.toString(), //
+        TestEnv.makeFile(common, "start.ini",
+            "--include-jetty-dir=" + corp.toString(),
             "jetty.http.port=8080");
 
         // Create base
         Path base = testdir.getPathFile("base");
         FS.ensureEmpty(base);
-        TestEnv.makeFile(base, "start.ini", //
-            "jetty.http.host=127.0.0.1",//
+        TestEnv.makeFile(base, "start.ini",
+            "jetty.http.host=127.0.0.1",
             "--include-jetty-dir=" + common.toString());
 
         ConfigSources sources = new ConfigSources();
@@ -517,21 +517,21 @@ public class ConfigSourcesTest
         // Create corp
         Path corp = testdir.getPathFile("corp");
         FS.ensureEmpty(corp);
-        TestEnv.makeFile(corp, "start.ini", //
+        TestEnv.makeFile(corp, "start.ini",
             "jetty.http.port=9090");
 
         // Create common
         Path common = testdir.getPathFile("common");
         FS.ensureEmpty(common);
-        TestEnv.makeFile(common, "start.ini", //
-            "--include-jetty-dir=" + corp.toString(), //
+        TestEnv.makeFile(common, "start.ini",
+            "--include-jetty-dir=" + corp.toString(),
             "jetty.http.port=8080");
 
         // Create base
         Path base = testdir.getPathFile("base");
         FS.ensureEmpty(base);
-        TestEnv.makeFile(base, "start.ini", //
-            "jetty.http.host=127.0.0.1",//
+        TestEnv.makeFile(base, "start.ini",
+            "jetty.http.host=127.0.0.1",
             "--include-jetty-dir=" + common.toString());
 
         ConfigSources sources = new ConfigSources();
@@ -586,8 +586,8 @@ public class ConfigSourcesTest
         // Create base
         Path base = testdir.getPathFile("base");
         FS.ensureEmpty(base);
-        TestEnv.makeFile(base, "start.ini", //
-            "jetty.http.host=127.0.0.1",//
+        TestEnv.makeFile(base, "start.ini",
+            "jetty.http.host=127.0.0.1",
             "--include-jetty-dir=" + common.toString());
 
         ConfigSources sources = new ConfigSources();
