@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -1501,12 +1501,12 @@ public class LazyListTest
         uris.add(URI.create("http://www.mortbay.org/"));
         uris.add(URI.create("http://jetty.codehaus.org/jetty/"));
         uris.add(URI.create("http://www.intalio.com/jetty/"));
-        uris.add(URI.create("http://www.eclipse.org/jetty/"));
+        uris.add(URI.create("https://www.eclipse.org/jetty/"));
 
         // Make sure that Generics pass through the 'get' routine safely.
         // We should be able to call this without casting the result to URI
         URI eclipseUri = LazyList.get(uris, 3);
-        assertEquals("http://www.eclipse.org/jetty/", eclipseUri.toASCIIString());
+        assertEquals("https://www.eclipse.org/jetty/", eclipseUri.toASCIIString());
     }
 
     /**
