@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2019 Mort Bay Consulting Pty. Ltd.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -18,6 +18,18 @@
 
 package org.eclipse.jetty.util.component;
 
+import java.io.BufferedReader;
+import java.io.IOException;
+import java.io.StringReader;
+import java.util.Queue;
+import java.util.concurrent.ConcurrentLinkedQueue;
+import java.util.concurrent.atomic.AtomicBoolean;
+import java.util.concurrent.atomic.AtomicInteger;
+
+import org.eclipse.jetty.util.TypeUtil;
+import org.hamcrest.Matchers;
+import org.junit.jupiter.api.Test;
+
 import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.containsInAnyOrder;
 import static org.junit.jupiter.api.Assertions.assertEquals;
@@ -25,17 +37,6 @@ import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
-import java.io.BufferedReader;
-import java.io.IOException;
-import java.io.StringReader;
-import java.util.Queue;
-import java.util.concurrent.ConcurrentLinkedQueue;
-import java.util.concurrent.atomic.AtomicInteger;
-
-import org.eclipse.jetty.util.TypeUtil;
-import org.hamcrest.Matchers;
-import org.junit.jupiter.api.Test;
-
 public class ContainerLifeCycleTest
 {
     @Test
@@ -129,9 +130,7 @@ public class ContainerLifeCycleTest
         container.stop();
         container.destroy();
 
-        assertThrows(IllegalStateException.class, ()-> {
-            container.start();
-        });
+        assertThrows(IllegalStateException.class, container::start);
     }
 
     @Test
@@ -209,13 +208,13 @@ public class ContainerLifeCycleTest
     {
         ContainerLifeCycle a0 = new ContainerLifeCycle();
         String dump = trim(a0.dump());
-        dump = check(dump, "ContainerLifeCycl");
+        check(dump, "ContainerLifeCycl");
 
         ContainerLifeCycle aa0 = new ContainerLifeCycle();
         a0.addBean(aa0);
         dump = trim(a0.dump());
         dump = check(dump, "ContainerLifeCycl");
-        dump = check(dump, "+? ContainerLife");
+        check(dump, "+? ContainerLife");
 
         ContainerLifeCycle aa1 = new ContainerLifeCycle();
         a0.addBean(aa1);
@@ -223,7 +222,7 @@ public class ContainerLifeCycleTest
         dump = check(dump, "ContainerLifeCycl");
         dump = check(dump, "+? ContainerLife");
         dump = check(dump, "+? ContainerLife");
-        dump = check(dump, "");
+        check(dump, "");
 
         ContainerLifeCycle aa2 = new ContainerLifeCycle();
         a0.addBean(aa2, false);
@@ -232,7 +231,7 @@ public class ContainerLifeCycleTest
         dump = check(dump, "+? ContainerLife");
         dump = check(dump, "+? ContainerLife");
         dump = check(dump, "+~ ContainerLife");
-        dump = check(dump, "");
+        check(dump, "");
 
         aa1.start();
         a0.start();
@@ -241,7 +240,7 @@ public class ContainerLifeCycleTest
         dump = check(dump, "+= ContainerLife");
         dump = check(dump, "+~ ContainerLife");
         dump = check(dump, "+~ ContainerLife");
-        dump = check(dump, "");
+        check(dump, "");
 
         a0.manage(aa1);
         a0.removeBean(aa2);
@@ -249,7 +248,7 @@ public class ContainerLifeCycleTest
         dump = check(dump, "ContainerLifeCycl");
         dump = check(dump, "+= ContainerLife");
         dump = check(dump, "+= ContainerLife");
-        dump = check(dump, "");
+        check(dump, "");
 
         ContainerLifeCycle aaa0 = new ContainerLifeCycle();
         aa0.addBean(aaa0);
@@ -258,7 +257,7 @@ public class ContainerLifeCycleTest
         dump = check(dump, "+= ContainerLife");
         dump = check(dump, "|  +~ Container");
         dump = check(dump, "+= ContainerLife");
-        dump = check(dump, "");
+        check(dump, "");
 
         ContainerLifeCycle aa10 = new ContainerLifeCycle();
         aa1.addBean(aa10, true);
@@ -268,7 +267,7 @@ public class ContainerLifeCycleTest
         dump = check(dump, "|  +~ Container");
         dump = check(dump, "+= ContainerLife");
         dump = check(dump, "   += Container");
-        dump = check(dump, "");
+        check(dump, "");
 
         final ContainerLifeCycle a1 = new ContainerLifeCycle();
         final ContainerLifeCycle a2 = new ContainerLifeCycle();
@@ -280,12 +279,13 @@ public class ContainerLifeCycleTest
             @Override
             public void dump(Appendable out, String indent) throws IOException
             {
-                Dumpable.dumpObjects(out, indent, this.toString(), TypeUtil.asList(new Object[]{a1, a2}), TypeUtil.asList(new Object[]{a3, a4}));
+                Dumpable.dumpObjects(out, indent, this.toString(), TypeUtil.asList(new Object[]{
+                    a1, a2
+                }), TypeUtil.asList(new Object[]{a3, a4}));
             }
         };
         a0.addBean(aa, true);
 
-
         dump = trim(a0.dump());
         dump = check(dump, "ContainerLifeCycl");
         dump = check(dump, "+= ContainerLife");
@@ -299,7 +299,7 @@ public class ContainerLifeCycleTest
         dump = check(dump, "   +> java.util.Arrays$ArrayList");
         dump = check(dump, "      +: ContainerLifeCycle");
         dump = check(dump, "      +: ContainerLifeCycle");
-        dump = check(dump, "");
+        check(dump, "");
 
         a2.addBean(aa0, true);
         dump = trim(a0.dump());
@@ -317,7 +317,7 @@ public class ContainerLifeCycleTest
         dump = check(dump, "   +> java.util.Arrays$ArrayList");
         dump = check(dump, "      +: ContainerLifeCycle");
         dump = check(dump, "      +: ContainerLifeCycle");
-        dump = check(dump, "");
+        check(dump, "");
 
         a2.unmanage(aa0);
         dump = trim(a0.dump());
@@ -334,7 +334,7 @@ public class ContainerLifeCycleTest
         dump = check(dump, "   +> java.util.Arrays$ArrayList");
         dump = check(dump, "      +: ContainerLifeCycle");
         dump = check(dump, "      +: ContainerLifeCycle");
-        dump = check(dump, "");
+        check(dump, "");
 
         a0.unmanage(aa);
         dump = trim(a0.dump());
@@ -344,7 +344,7 @@ public class ContainerLifeCycleTest
         dump = check(dump, "+= ContainerLife");
         dump = check(dump, "|  += Container");
         dump = check(dump, "+~ ContainerLife");
-        dump = check(dump, "");
+        check(dump, "");
     }
 
     @Test
@@ -375,9 +375,8 @@ public class ContainerLifeCycleTest
                 child.add(c);
             }
 
-            public
             @Override
-            String toString()
+            public String toString()
             {
                 return "listener";
             }
@@ -385,18 +384,16 @@ public class ContainerLifeCycleTest
 
         ContainerLifeCycle c0 = new ContainerLifeCycle()
         {
-            public
             @Override
-            String toString()
+            public String toString()
             {
                 return "c0";
             }
         };
         ContainerLifeCycle c00 = new ContainerLifeCycle()
         {
-            public
             @Override
-            String toString()
+            public String toString()
             {
                 return "c00";
             }
@@ -437,9 +434,8 @@ public class ContainerLifeCycleTest
                 child.add(c);
             }
 
-            public
             @Override
-            String toString()
+            public String toString()
             {
                 return "inherited";
             }
@@ -502,7 +498,7 @@ public class ContainerLifeCycleTest
         assertEquals(c00, child.poll());
     }
 
-    private final class InheritedListenerLifeCycle extends AbstractLifeCycle implements Container.InheritedListener
+    private static final class InheritedListenerLifeCycle extends AbstractLifeCycle implements Container.InheritedListener
     {
         @Override
         public void beanRemoved(Container p, Object c)
@@ -526,27 +522,24 @@ public class ContainerLifeCycleTest
     {
         ContainerLifeCycle c0 = new ContainerLifeCycle()
         {
-            public
             @Override
-            String toString()
+            public String toString()
             {
                 return "c0";
             }
         };
         ContainerLifeCycle c00 = new ContainerLifeCycle()
         {
-            public
             @Override
-            String toString()
+            public String toString()
             {
                 return "c00";
             }
         };
         ContainerLifeCycle c01 = new ContainerLifeCycle()
         {
-            public
             @Override
-            String toString()
+            public String toString()
             {
                 return "c01";
             }
@@ -591,8 +584,7 @@ public class ContainerLifeCycleTest
             s = s.substring(0, nl);
         }
 
-
-        assertThat( s, Matchers.startsWith( x));
+        assertThat(s, Matchers.startsWith(x));
 
         return r;
     }
@@ -625,9 +617,8 @@ public class ContainerLifeCycleTest
         }
     }
 
-
     @Test
-    public void testGetBeans() throws Exception
+    public void testGetBeans()
     {
         TestContainerLifeCycle root = new TestContainerLifeCycle();
         TestContainerLifeCycle left = new TestContainerLifeCycle();
@@ -637,19 +628,114 @@ public class ContainerLifeCycleTest
         TestContainerLifeCycle leaf = new TestContainerLifeCycle();
         right.addBean(leaf);
 
-        root.addBean(Integer.valueOf(0));
-        root.addBean(Integer.valueOf(1));
-        left.addBean(Integer.valueOf(2));
-        right.addBean(Integer.valueOf(3));
-        leaf.addBean(Integer.valueOf(4));
+        Integer zero = 0;
+        Integer one = 1;
+        Integer two = 2;
+        Integer three = 3;
+        Integer four = 4;
+        root.addBean(zero);
+        root.addBean(one);
+        left.addBean(two);
+        right.addBean(three);
+        leaf.addBean(four);
         leaf.addBean("leaf");
 
-        assertThat(root.getBeans(Container.class), containsInAnyOrder(left,right));
-        assertThat(root.getBeans(Integer.class), containsInAnyOrder(Integer.valueOf(0),Integer.valueOf(1)));
+        assertThat(root.getBeans(Container.class), containsInAnyOrder(left, right));
+        assertThat(root.getBeans(Integer.class), containsInAnyOrder(zero, one));
         assertThat(root.getBeans(String.class), containsInAnyOrder());
 
-        assertThat(root.getContainedBeans(Container.class), containsInAnyOrder(left,right,leaf));
-        assertThat(root.getContainedBeans(Integer.class), containsInAnyOrder(Integer.valueOf(0),Integer.valueOf(1),Integer.valueOf(2),Integer.valueOf(3),Integer.valueOf(4)));
+        assertThat(root.getContainedBeans(Container.class), containsInAnyOrder(left, right, leaf));
+        assertThat(root.getContainedBeans(Integer.class), containsInAnyOrder(zero, one, two, three, four));
         assertThat(root.getContainedBeans(String.class), containsInAnyOrder("leaf"));
     }
+
+    @Test
+    public void testBeanStoppingAddedToStartingBean() throws Exception
+    {
+        ContainerLifeCycle longLived = new ContainerLifeCycle()
+        {
+            @Override
+            protected void doStop() throws Exception
+            {
+                super.doStop();
+
+                ContainerLifeCycle shortLived = new ContainerLifeCycle();
+                shortLived.addBean(this);
+                shortLived.start();
+
+                assertTrue(shortLived.isStarted());
+                assertTrue(isStopping());
+                assertFalse(shortLived.isManaged(this));
+            }
+        };
+        longLived.start();
+        longLived.stop();
+    }
+
+    @Test
+    public void testFailedManagedBeanCanBeRestarted() throws Exception
+    {
+        AtomicBoolean fail = new AtomicBoolean();
+        ContainerLifeCycle container = new ContainerLifeCycle();
+        ContainerLifeCycle bean1 = new ContainerLifeCycle();
+        ContainerLifeCycle bean2 = new ContainerLifeCycle()
+        {
+            @Override
+            protected void doStart() throws Exception
+            {
+                super.doStart();
+                // Fail only the first time.
+                if (fail.compareAndSet(false, true))
+                    throw new RuntimeException();
+            }
+        };
+        ContainerLifeCycle bean3 = new ContainerLifeCycle();
+        container.addBean(bean1);
+        container.addBean(bean2);
+        container.addBean(bean3);
+
+        // Start the first time, it should fail.
+        assertThrows(RuntimeException.class, container::start);
+        assertTrue(container.isFailed());
+        assertTrue(bean1.isStopped());
+        assertTrue(bean2.isFailed());
+        assertTrue(bean3.isStopped());
+
+        // Re-start, it should succeed.
+        container.start();
+        assertTrue(container.isStarted());
+        assertTrue(bean1.isStarted());
+        assertTrue(bean2.isStarted());
+        assertTrue(bean3.isStarted());
+    }
+
+    @Test
+    public void testFailedAutoBeanIsNotRestarted() throws Exception
+    {
+        AtomicBoolean fail = new AtomicBoolean();
+        ContainerLifeCycle bean = new ContainerLifeCycle()
+        {
+            @Override
+            protected void doStart() throws Exception
+            {
+                super.doStart();
+                // Fail only the first time.
+                if (fail.compareAndSet(false, true))
+                    throw new RuntimeException();
+            }
+        };
+        // The bean is started externally and fails.
+        assertThrows(RuntimeException.class, bean::start);
+
+        // The same bean now becomes part of a container.
+        ContainerLifeCycle container = new ContainerLifeCycle();
+        container.addBean(bean);
+        assertTrue(container.isAuto(bean));
+
+        // Start the container, the bean must not be managed.
+        container.start();
+        assertTrue(container.isStarted());
+        assertTrue(bean.isFailed());
+        assertTrue(container.isUnmanaged(bean));
+    }
 }
