@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -22,6 +22,7 @@ import java.io.BufferedReader;
 import java.io.File;
 import java.io.InputStreamReader;
 import java.nio.file.Path;
+import java.util.Arrays;
 
 import org.eclipse.jetty.toolchain.test.FS;
 import org.eclipse.jetty.toolchain.test.MavenTestingUtils;
@@ -32,7 +33,9 @@ import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.extension.ExtendWith;
 
 import static org.hamcrest.MatcherAssert.assertThat;
+import static org.hamcrest.Matchers.contains;
 import static org.hamcrest.Matchers.is;
+import static org.hamcrest.Matchers.nullValue;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
@@ -175,7 +178,21 @@ public class ResourceCollectionTest
     }
 
     @Test
-    public void testMutlipleSources1() throws Exception
+    public void testList() throws Exception
+    {
+        ResourceCollection rc1 = new ResourceCollection(
+            Resource.newResource("src/test/resources/org/eclipse/jetty/util/resource/one/"),
+            Resource.newResource("src/test/resources/org/eclipse/jetty/util/resource/two/"),
+            Resource.newResource("src/test/resources/org/eclipse/jetty/util/resource/three/"));
+
+        assertThat(Arrays.asList(rc1.list()), contains("1.txt", "2.txt", "3.txt", "dir/"));
+        assertThat(Arrays.asList(rc1.addPath("dir").list()), contains("1.txt", "2.txt", "3.txt"));
+        assertThat(rc1.addPath("unknown").list(), nullValue());
+        // TODO for jetty-10 assertThat(rc1.addPath("unknown").list(), nullValue());
+    }
+
+    @Test
+    public void testMultipleSources1() throws Exception
     {
         ResourceCollection rc1 = new ResourceCollection(new String[]{
             "src/test/resources/org/eclipse/jetty/util/resource/one/",
