@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -18,20 +18,35 @@
 
 package org.eclipse.jetty.util.ssl;
 
+import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
+import java.io.OutputStream;
+import java.net.InetSocketAddress;
+import java.nio.charset.StandardCharsets;
 import java.security.KeyStore;
+import java.security.cert.Certificate;
+import java.security.cert.X509Certificate;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.List;
+import java.util.Optional;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
+import javax.net.ssl.SNIHostName;
 import javax.net.ssl.SSLContext;
 import javax.net.ssl.SSLEngine;
+import javax.net.ssl.SSLParameters;
+import javax.net.ssl.SSLServerSocket;
+import javax.net.ssl.SSLSocket;
+import javax.net.ssl.X509ExtendedKeyManager;
 
+import org.eclipse.jetty.util.IO;
 import org.eclipse.jetty.util.component.AbstractLifeCycle;
 import org.eclipse.jetty.util.log.StacklessLogging;
 import org.eclipse.jetty.util.resource.Resource;
-import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 
 import static org.hamcrest.MatcherAssert.assertThat;
@@ -40,9 +55,12 @@ import static org.hamcrest.Matchers.containsString;
 import static org.hamcrest.Matchers.equalTo;
 import static org.hamcrest.Matchers.greaterThan;
 import static org.hamcrest.Matchers.hasItem;
+import static org.hamcrest.Matchers.hasItemInArray;
 import static org.hamcrest.Matchers.is;
 import static org.hamcrest.Matchers.matchesRegex;
 import static org.hamcrest.Matchers.not;
+import static org.hamcrest.Matchers.startsWith;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
@@ -52,25 +70,10 @@ import static org.junit.jupiter.api.Assertions.assertTrue;
 
 public class SslContextFactoryTest
 {
-    private SslContextFactory cf;
-
-    @BeforeEach
-    public void setUp() throws Exception
-    {
-        cf = new SslContextFactory.Server();
-
-        java.security.cert.CertPathBuilder certPathBuilder = java.security.cert.CertPathBuilder.getInstance("PKIX");
-        java.security.cert.PKIXRevocationChecker revocationChecker = (java.security.cert.PKIXRevocationChecker)certPathBuilder.getRevocationChecker();
-        revocationChecker.setOptions(java.util.EnumSet.of(
-            java.security.cert.PKIXRevocationChecker.Option.valueOf("PREFER_CRLS"),
-            java.security.cert.PKIXRevocationChecker.Option.valueOf("SOFT_FAIL"),
-            java.security.cert.PKIXRevocationChecker.Option.valueOf("NO_FALLBACK")));
-        cf.setPkixCertPathChecker(revocationChecker);
-    }
-
     @Test
     public void testSLOTH() throws Exception
     {
+        SslContextFactory.Server cf = new SslContextFactory.Server();
         cf.setKeyStorePassword("storepwd");
         cf.setKeyManagerPassword("keypwd");
 
@@ -79,9 +82,13 @@ public class SslContextFactoryTest
         // cf.dump(System.out, "");
         List<SslSelectionDump> dumps = cf.selectionDump();
 
-        SslSelectionDump cipherDump = dumps.stream()
+        Optional<SslSelectionDump> cipherSuiteDumpOpt = dumps.stream()
             .filter((dump) -> dump.type.contains("Cipher Suite"))
-            .findFirst().get();
+            .findFirst();
+
+        assertTrue(cipherSuiteDumpOpt.isPresent(), "Cipher Suite dump section should exist");
+
+        SslSelectionDump cipherDump = cipherSuiteDumpOpt.get();
 
         for (String enabledCipher : cipherDump.enabled)
         {
@@ -89,9 +96,42 @@ public class SslContextFactoryTest
         }
     }
 
+    @Test
+    public void testDumpExcludedProtocols() throws Exception
+    {
+        SslContextFactory.Server cf = new SslContextFactory.Server();
+        cf.setExcludeProtocols("TLSv1\\.?[01]?");
+        cf.start();
+
+        // Confirm behavior in engine
+        assertThat(cf.newSSLEngine().getEnabledProtocols(), not(hasItemInArray("TLSv1.1")));
+        assertThat(cf.newSSLEngine().getEnabledProtocols(), not(hasItemInArray("TLSv1")));
+
+        // Confirm output in dump
+        List<SslSelectionDump> dumps = cf.selectionDump();
+
+        Optional<SslSelectionDump> protocolDumpOpt = dumps.stream()
+            .filter((dump) -> dump.type.contains("Protocol"))
+            .findFirst();
+
+        assertTrue(protocolDumpOpt.isPresent(), "Protocol dump section should exist");
+
+        SslSelectionDump protocolDump = protocolDumpOpt.get();
+
+        long countTls11Enabled = protocolDump.enabled.stream().filter((t) -> t.contains("TLSv1.1")).count();
+        long countTls11Disabled = protocolDump.disabled.stream().filter((t) -> t.contains("TLSv1.1")).count();
+
+        assertThat("Enabled Protocols TLSv1.1 count", countTls11Enabled, is(0L));
+        assertThat("Disabled Protocols TLSv1.1 count", countTls11Disabled, is(1L));
+
+        // Uncomment to show dump in console.
+        // cf.dump(System.out, "");
+    }
+
     @Test
     public void testDumpIncludeTlsRsa() throws Exception
     {
+        SslContextFactory.Server cf = new SslContextFactory.Server();
         cf.setKeyStorePassword("storepwd");
         cf.setKeyManagerPassword("keypwd");
         cf.setIncludeCipherSuites("TLS_RSA_.*");
@@ -109,9 +149,15 @@ public class SslContextFactoryTest
             .collect(Collectors.toList());
 
         List<String> selectedSuites = Arrays.asList(cf.getSelectedCipherSuites());
-        SslSelectionDump cipherDump = dumps.stream()
+
+        Optional<SslSelectionDump> cipherSuiteDumpOpt = dumps.stream()
             .filter((dump) -> dump.type.contains("Cipher Suite"))
-            .findFirst().get();
+            .findFirst();
+
+        assertTrue(cipherSuiteDumpOpt.isPresent(), "Cipher Suite dump section should exist");
+
+        SslSelectionDump cipherDump = cipherSuiteDumpOpt.get();
+
         assertThat("Dump Enabled List size is equal to selected list size", cipherDump.enabled.size(), is(selectedSuites.size()));
 
         for (String expectedCipherSuite : tlsRsaSuites)
@@ -124,17 +170,19 @@ public class SslContextFactoryTest
     @Test
     public void testNoTsFileKs() throws Exception
     {
+        SslContextFactory.Server cf = new SslContextFactory.Server();
         cf.setKeyStorePassword("storepwd");
         cf.setKeyManagerPassword("keypwd");
 
         cf.start();
 
-        assertTrue(cf.getSslContext() != null);
+        assertNotNull(cf.getSslContext());
     }
 
     @Test
     public void testNoTsSetKs() throws Exception
     {
+        SslContextFactory.Server cf = new SslContextFactory.Server();
         KeyStore ks = KeyStore.getInstance("JKS");
         try (InputStream keystoreInputStream = this.getClass().getResourceAsStream("keystore"))
         {
@@ -145,26 +193,21 @@ public class SslContextFactoryTest
 
         cf.start();
 
-        assertTrue(cf.getSslContext() != null);
+        assertNotNull(cf.getSslContext());
     }
 
     @Test
     public void testNoTsNoKs() throws Exception
     {
+        SslContextFactory.Server cf = new SslContextFactory.Server();
         cf.start();
-        assertTrue(cf.getSslContext() != null);
-    }
-
-    @Test
-    public void testTrustAll() throws Exception
-    {
-        cf.start();
-        assertTrue(cf.getSslContext() != null);
+        assertNotNull(cf.getSslContext());
     }
 
     @Test
     public void testNoTsResourceKs() throws Exception
     {
+        SslContextFactory.Server cf = new SslContextFactory.Server();
         Resource keystoreResource = Resource.newSystemResource("keystore");
 
         cf.setKeyStoreResource(keystoreResource);
@@ -175,12 +218,13 @@ public class SslContextFactoryTest
 
         cf.start();
 
-        assertTrue(cf.getSslContext() != null);
+        assertNotNull(cf.getSslContext());
     }
 
     @Test
     public void testResourceTsResourceKs() throws Exception
     {
+        SslContextFactory.Server cf = new SslContextFactory.Server();
         Resource keystoreResource = Resource.newSystemResource("keystore");
         Resource truststoreResource = Resource.newSystemResource("keystore");
 
@@ -192,12 +236,13 @@ public class SslContextFactoryTest
 
         cf.start();
 
-        assertTrue(cf.getSslContext() != null);
+        assertNotNull(cf.getSslContext());
     }
 
     @Test
     public void testResourceTsResourceKsWrongPW() throws Exception
     {
+        SslContextFactory.Server cf = new SslContextFactory.Server();
         Resource keystoreResource = Resource.newSystemResource("keystore");
         Resource truststoreResource = Resource.newSystemResource("keystore");
 
@@ -210,7 +255,7 @@ public class SslContextFactoryTest
         try (StacklessLogging ignore = new StacklessLogging(AbstractLifeCycle.class))
         {
             java.security.UnrecoverableKeyException x = assertThrows(
-                java.security.UnrecoverableKeyException.class, () -> cf.start());
+                java.security.UnrecoverableKeyException.class, cf::start);
             assertThat(x.getMessage(), containsString("Cannot recover key"));
         }
     }
@@ -218,6 +263,7 @@ public class SslContextFactoryTest
     @Test
     public void testResourceTsWrongPWResourceKs() throws Exception
     {
+        SslContextFactory.Server cf = new SslContextFactory.Server();
         Resource keystoreResource = Resource.newSystemResource("keystore");
         Resource truststoreResource = Resource.newSystemResource("keystore");
 
@@ -229,14 +275,15 @@ public class SslContextFactoryTest
 
         try (StacklessLogging ignore = new StacklessLogging(AbstractLifeCycle.class))
         {
-            IOException x = assertThrows(IOException.class, () -> cf.start());
+            IOException x = assertThrows(IOException.class, cf::start);
             assertThat(x.getMessage(), containsString("Keystore was tampered with, or password was incorrect"));
         }
     }
 
     @Test
-    public void testNoKeyConfig() throws Exception
+    public void testNoKeyConfig()
     {
+        SslContextFactory.Server cf = new SslContextFactory.Server();
         try (StacklessLogging ignore = new StacklessLogging(AbstractLifeCycle.class))
         {
             IllegalStateException x = assertThrows(IllegalStateException.class, () ->
@@ -244,13 +291,14 @@ public class SslContextFactoryTest
                 cf.setTrustStorePath("/foo");
                 cf.start();
             });
-            assertThat(x.getMessage(), containsString("no valid keystore"));
+            assertThat(x.getMessage(), containsString(File.separator + "foo is not a valid keystore"));
         }
     }
 
     @Test
     public void testSetExcludeCipherSuitesRegex() throws Exception
     {
+        SslContextFactory.Server cf = new SslContextFactory.Server();
         cf.setExcludeCipherSuites(".*RC4.*");
         cf.start();
         SSLEngine sslEngine = cf.newSSLEngine();
@@ -265,6 +313,7 @@ public class SslContextFactoryTest
     @Test
     public void testSetIncludeCipherSuitesRegex() throws Exception
     {
+        SslContextFactory.Server cf = new SslContextFactory.Server();
         cf.setIncludeCipherSuites(".*ECDHE.*", ".*WIBBLE.*");
 
         cf.start();
@@ -280,6 +329,7 @@ public class SslContextFactoryTest
     @Test
     public void testProtocolAndCipherSettingsAreNPESafe()
     {
+        SslContextFactory.Server cf = new SslContextFactory.Server();
         assertNotNull(cf.getExcludeProtocols());
         assertNotNull(cf.getIncludeProtocols());
         assertNotNull(cf.getExcludeCipherSuites());
@@ -289,6 +339,7 @@ public class SslContextFactoryTest
     @Test
     public void testSNICertificates() throws Exception
     {
+        SslContextFactory.Server cf = new SslContextFactory.Server();
         Resource keystoreResource = Resource.newSystemResource("snikeystore");
 
         cf.setKeyStoreResource(keystoreResource);
@@ -330,7 +381,7 @@ public class SslContextFactoryTest
     @Test
     public void testNonDefaultKeyStoreTypeUsedForTrustStore() throws Exception
     {
-        cf = new SslContextFactory.Server();
+        SslContextFactory.Server cf = new SslContextFactory.Server();
         cf.setKeyStoreResource(Resource.newSystemResource("keystore.p12"));
         cf.setKeyStoreType("pkcs12");
         cf.setKeyStorePassword("storepwd");
@@ -348,7 +399,7 @@ public class SslContextFactoryTest
     @Test
     public void testClientSslContextFactory() throws Exception
     {
-        cf = new SslContextFactory.Client();
+        SslContextFactory.Client cf = new SslContextFactory.Client();
         cf.start();
 
         assertEquals("HTTPS", cf.getEndpointIdentificationAlgorithm());
@@ -357,9 +408,86 @@ public class SslContextFactoryTest
     @Test
     public void testServerSslContextFactory() throws Exception
     {
-        cf = new SslContextFactory.Server();
+        SslContextFactory.Server cf = new SslContextFactory.Server();
         cf.start();
 
         assertNull(cf.getEndpointIdentificationAlgorithm());
     }
+
+    @Test
+    public void testSNIWithPKIX() throws Exception
+    {
+        SslContextFactory.Server serverTLS = new SslContextFactory.Server()
+        {
+            @Override
+            protected X509ExtendedKeyManager newSniX509ExtendedKeyManager(X509ExtendedKeyManager keyManager)
+            {
+                SniX509ExtendedKeyManager result = new SniX509ExtendedKeyManager(keyManager, this);
+                result.setAliasMapper(alias ->
+                {
+                    // Workaround for https://bugs.openjdk.java.net/browse/JDK-8246262.
+                    Matcher matcher = Pattern.compile(".*\\..*\\.(.*)").matcher(alias);
+                    if (matcher.matches())
+                        return matcher.group(1);
+                    return alias;
+                });
+                return result;
+            }
+        };
+        // This test requires a SNI keystore so that the X509ExtendedKeyManager is wrapped.
+        serverTLS.setKeyStoreResource(Resource.newSystemResource("keystore_sni.p12"));
+        serverTLS.setKeyStorePassword("storepwd");
+        serverTLS.setKeyManagerPassword("keypwd");
+        serverTLS.setKeyManagerFactoryAlgorithm("PKIX");
+        // Don't pick a default certificate if SNI does not match.
+        serverTLS.setSniRequired(true);
+        serverTLS.start();
+
+        SslContextFactory.Client clientTLS = new SslContextFactory.Client(true);
+        clientTLS.start();
+
+        try (SSLServerSocket serverSocket = serverTLS.newSslServerSocket(null, 0, 128);
+             SSLSocket clientSocket = clientTLS.newSslSocket())
+        {
+            SSLParameters sslParameters = clientSocket.getSSLParameters();
+            String hostName = "jetty.eclipse.org";
+            sslParameters.setServerNames(Collections.singletonList(new SNIHostName(hostName)));
+            clientSocket.setSSLParameters(sslParameters);
+            clientSocket.connect(new InetSocketAddress("localhost", serverSocket.getLocalPort()), 5000);
+            try (SSLSocket sslSocket = (SSLSocket)serverSocket.accept())
+            {
+                byte[] data = "HELLO".getBytes(StandardCharsets.UTF_8);
+                new Thread(() ->
+                {
+                    try
+                    {
+                        // Start the TLS handshake and verify that
+                        // the client got the right server certificate.
+                        clientSocket.startHandshake();
+                        Certificate[] certificates = clientSocket.getSession().getPeerCertificates();
+                        assertThat(certificates.length, greaterThan(0));
+                        X509Certificate certificate = (X509Certificate)certificates[0];
+                        assertThat(certificate.getSubjectX500Principal().getName(), startsWith("CN=" + hostName));
+                        // Send some data to verify communication is ok.
+                        OutputStream output = clientSocket.getOutputStream();
+                        output.write(data);
+                        output.flush();
+                        clientSocket.close();
+                    }
+                    catch (Throwable x)
+                    {
+                        x.printStackTrace();
+                    }
+                }).start();
+                // Verify that we received the data the client sent.
+                sslSocket.setSoTimeout(5000);
+                InputStream input = sslSocket.getInputStream();
+                byte[] bytes = IO.readBytes(input);
+                assertArrayEquals(data, bytes);
+            }
+        }
+
+        clientTLS.stop();
+        serverTLS.stop();
+    }
 }
