@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -18,7 +18,11 @@
 
 package org.eclipse.jetty.util.thread;
 
+import java.time.Duration;
+
 import org.eclipse.jetty.util.ProcessorUtils;
+import org.eclipse.jetty.util.component.ContainerLifeCycle;
+import org.eclipse.jetty.util.component.LifeCycle;
 import org.eclipse.jetty.util.thread.ThreadPool.SizedThreadPool;
 import org.hamcrest.Matchers;
 import org.junit.jupiter.api.AfterAll;
@@ -26,6 +30,8 @@ import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.Test;
 
 import static org.hamcrest.MatcherAssert.assertThat;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTimeoutPreemptively;
 import static org.junit.jupiter.api.Assertions.fail;
 
 public abstract class AbstractThreadPoolTest
@@ -87,4 +93,26 @@ public abstract class AbstractThreadPoolTest
 
         assertThat(pool.getMaxThreads(), Matchers.is(3));
     }
+
+    @Test
+    public void testJoinWithStopTimeout()
+    {
+        // ThreadPool must be an implement ContainerLifeCycle for this test to be valid.
+        SizedThreadPool threadPool = newPool(3);
+        if (!(threadPool instanceof ContainerLifeCycle))
+            return;
+
+        final long stopTimeout = 100;
+        ((ContainerLifeCycle)threadPool).setStopTimeout(100);
+        LifeCycle.start(threadPool);
+
+        // Verify that join does not timeout after waiting twice the stopTimeout.
+        assertThrows(Throwable.class, () ->
+            assertTimeoutPreemptively(Duration.ofMillis(stopTimeout * 2), threadPool::join)
+        );
+
+        // After stopping the ThreadPool join should unblock.
+        LifeCycle.stop(threadPool);
+        assertTimeoutPreemptively(Duration.ofMillis(stopTimeout), threadPool::join);
+    }
 }
