@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -19,6 +19,10 @@
 package org.eclipse.jetty.util.thread;
 
 import java.io.Closeable;
+import java.net.URL;
+import java.net.URLClassLoader;
+import java.util.ArrayList;
+import java.util.List;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicInteger;
@@ -27,6 +31,7 @@ import org.eclipse.jetty.util.log.Log;
 import org.eclipse.jetty.util.log.Logger;
 import org.eclipse.jetty.util.log.StacklessLogging;
 import org.eclipse.jetty.util.thread.ThreadPool.SizedThreadPool;
+import org.hamcrest.Matchers;
 import org.junit.jupiter.api.Test;
 
 import static org.hamcrest.MatcherAssert.assertThat;
@@ -191,7 +196,7 @@ public class QueuedThreadPoolTest extends AbstractThreadPoolTest
         waitForIdle(tp, 2);
 
         // Doesn't shrink to less than min threads
-        Thread.sleep(3 * tp.getIdleTimeout() / 2);
+        Thread.sleep(3L * tp.getIdleTimeout() / 2);
         assertThat(tp.getThreads(), is(2));
         assertThat(tp.getIdleThreads(), is(2));
 
@@ -293,7 +298,7 @@ public class QueuedThreadPoolTest extends AbstractThreadPoolTest
             waitForIdle(tp, 2);
 
             // Doesn't shrink to less than min threads
-            Thread.sleep(3 * tp.getIdleTimeout() / 2);
+            Thread.sleep(3L * tp.getIdleTimeout() / 2);
             waitForThreads(tp, 2);
             waitForIdle(tp, 2);
 
@@ -778,8 +783,8 @@ public class QueuedThreadPoolTest extends AbstractThreadPoolTest
         assertThat(count(dump, " - STARTED"), is(2));
         assertThat(dump, containsString(",3<=3<=4,i=3,r=2,q=0"));
         assertThat(dump, containsString("[ReservedThreadExecutor@"));
-        assertThat(count(dump, " IDLE "), is(3));
-        assertThat(count(dump, " RESERVED "), is(0));
+        assertThat(count(dump, " IDLE"), is(3));
+        assertThat(count(dump, " RESERVED"), is(0));
 
         CountDownLatch started = new CountDownLatch(1);
         CountDownLatch waiting = new CountDownLatch(1);
@@ -801,9 +806,9 @@ public class QueuedThreadPoolTest extends AbstractThreadPoolTest
         assertThat(count(dump, " - STARTED"), is(2));
         assertThat(dump, containsString(",3<=3<=4,i=2,r=2,q=0"));
         assertThat(dump, containsString("[ReservedThreadExecutor@"));
-        assertThat(count(dump, " IDLE "), is(2));
-        assertThat(count(dump, " WAITING "), is(1));
-        assertThat(count(dump, " RESERVED "), is(0));
+        assertThat(count(dump, " IDLE"), is(2));
+        assertThat(count(dump, " WAITING"), is(1));
+        assertThat(count(dump, " RESERVED"), is(0));
         assertThat(count(dump, "QueuedThreadPoolTest.lambda$testDump$"), is(0));
 
         pool.setDetailedDump(true);
@@ -812,9 +817,9 @@ public class QueuedThreadPoolTest extends AbstractThreadPoolTest
         assertThat(dump, containsString(",3<=3<=4,i=2,r=2,q=0"));
         assertThat(dump, containsString("s=0/2"));
         assertThat(dump, containsString("[ReservedThreadExecutor@"));
-        assertThat(count(dump, " IDLE "), is(2));
-        assertThat(count(dump, " WAITING "), is(1));
-        assertThat(count(dump, " RESERVED "), is(0));
+        assertThat(count(dump, " IDLE"), is(2));
+        assertThat(count(dump, " WAITING"), is(1));
+        assertThat(count(dump, " RESERVED"), is(0));
         assertThat(count(dump, "QueuedThreadPoolTest.lambda$testDump$"), is(1));
 
         assertFalse(pool.tryExecute(() ->
@@ -827,12 +832,105 @@ public class QueuedThreadPoolTest extends AbstractThreadPoolTest
         assertThat(dump, containsString(",3<=3<=4,i=1,r=2,q=0"));
         assertThat(dump, containsString("s=1/2"));
         assertThat(dump, containsString("[ReservedThreadExecutor@"));
-        assertThat(count(dump, " IDLE "), is(1));
-        assertThat(count(dump, " WAITING "), is(1));
-        assertThat(count(dump, " RESERVED "), is(1));
+        assertThat(count(dump, " IDLE"), is(1));
+        assertThat(count(dump, " WAITING"), is(1));
+        assertThat(count(dump, " RESERVED"), is(1));
         assertThat(count(dump, "QueuedThreadPoolTest.lambda$testDump$"), is(1));
     }
 
+    @Test
+    public void testContextClassLoader() throws Exception
+    {
+        QueuedThreadPool tp = new QueuedThreadPool();
+        try (StacklessLogging stackless = new StacklessLogging(QueuedThreadPool.class))
+        {
+            //change the current thread's classloader to something else
+            Thread.currentThread().setContextClassLoader(new URLClassLoader(new URL[] {}));
+            
+            //create a new thread
+            Thread t = tp.newThread(() ->
+            {
+                //the executing thread should be still set to the classloader of the QueuedThreadPool,
+                //not that of the thread that created this thread.
+                assertThat(Thread.currentThread().getContextClassLoader(), Matchers.equalTo(QueuedThreadPool.class.getClassLoader()));
+            });
+            
+            //new thread should be set to the classloader of the QueuedThreadPool
+            assertThat(t.getContextClassLoader(), Matchers.equalTo(QueuedThreadPool.class.getClassLoader()));
+        }
+    }
+
+    @Test
+    public void testThreadCounts() throws Exception
+    {
+        int maxThreads = 100;
+        QueuedThreadPool tp = new QueuedThreadPool(maxThreads, 0);
+        // Long timeout so it does not expire threads during the test.
+        tp.setIdleTimeout(60000);
+        int reservedThreads = 7;
+        tp.setReservedThreads(reservedThreads);
+        tp.start();
+        int leasedThreads = 5;
+        tp.getThreadPoolBudget().leaseTo(new Object(), leasedThreads);
+        List<RunningJob> leasedJobs = new ArrayList<>();
+        for (int i = 0; i < leasedThreads; ++i)
+        {
+            RunningJob job = new RunningJob("JOB" + i);
+            leasedJobs.add(job);
+            tp.execute(job);
+            assertTrue(job._run.await(5, TimeUnit.SECONDS));
+        }
+
+        // Run some job to spawn threads.
+        for (int i = 0; i < 3; ++i)
+        {
+            tp.tryExecute(() -> {});
+        }
+        int spawned = 13;
+        List<RunningJob> jobs = new ArrayList<>();
+        for (int i = 0; i < spawned; ++i)
+        {
+            RunningJob job = new RunningJob("JOB" + i);
+            jobs.add(job);
+            tp.execute(job);
+            assertTrue(job._run.await(5, TimeUnit.SECONDS));
+        }
+        for (RunningJob job : jobs)
+        {
+            job._stopping.countDown();
+        }
+
+        // Wait for the threads to become idle again.
+        Thread.sleep(1000);
+
+        // Submit less jobs to the queue so we have active and idle threads.
+        jobs.clear();
+        int transientJobs = spawned / 2;
+        for (int i = 0; i < transientJobs; ++i)
+        {
+            RunningJob job = new RunningJob("JOB" + i);
+            jobs.add(job);
+            tp.execute(job);
+            assertTrue(job._run.await(5, TimeUnit.SECONDS));
+        }
+
+        try
+        {
+            assertThat(tp.getMaxReservedThreads(), Matchers.equalTo(reservedThreads));
+            assertThat(tp.getLeasedThreads(), Matchers.equalTo(leasedThreads));
+            assertThat(tp.getReadyThreads(), Matchers.equalTo(tp.getIdleThreads() + tp.getAvailableReservedThreads()));
+            assertThat(tp.getUtilizedThreads(), Matchers.equalTo(transientJobs));
+            assertThat(tp.getThreads(), Matchers.equalTo(tp.getReadyThreads() + tp.getLeasedThreads() + tp.getUtilizedThreads()));
+            assertThat(tp.getBusyThreads(), Matchers.equalTo(tp.getUtilizedThreads() + tp.getLeasedThreads()));
+        }
+        finally
+        {
+            jobs.forEach(job -> job._stopping.countDown());
+            leasedJobs.forEach(job -> job._stopping.countDown());
+            tp.stop();
+        }
+    }
+    
     private int count(String s, String p)
     {
         int c = 0;
