@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -24,6 +24,8 @@ import java.net.URI;
 import java.net.URISyntaxException;
 import java.net.URL;
 import java.net.URLClassLoader;
+import java.nio.file.Files;
+import java.nio.file.Path;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
@@ -134,17 +136,17 @@ public class WebInfConfiguration extends AbstractConfiguration
     @Override
     public void preConfigure(final WebAppContext context) throws Exception
     {
-        //Make a temp directory for the webapp if one is not already set
+        // Make a temp directory for the webapp if one is not already set
         resolveTempDirectory(context);
 
-        //Extract webapp if necessary
+        // Extract webapp if necessary
         unpack(context);
 
         findAndFilterContainerPaths(context);
 
         findAndFilterWebAppPaths(context);
 
-        //No pattern to appy to classes, just add to metadata
+        // No pattern to apply to classes, just add to metadata
         context.getMetaData().setWebInfClassesDirs(findClassDirs(context));
     }
 
@@ -352,10 +354,12 @@ public class WebInfConfiguration extends AbstractConfiguration
     @Override
     public void deconfigure(WebAppContext context) throws Exception
     {
-        //if we're not persisting the temp dir contents delete it
-        if (!context.isPersistTempDirectory())
+        File tempDirectory = context.getTempDirectory();
+
+        // if we're not persisting the temp dir contents delete it
+        if (!context.isPersistTempDirectory() && !IO.isEmptyDir(tempDirectory))
         {
-            IO.delete(context.getTempDirectory());
+            IO.delete(tempDirectory);
         }
 
         //if it wasn't explicitly configured by the user, then unset it
@@ -375,14 +379,10 @@ public class WebInfConfiguration extends AbstractConfiguration
     @Override
     public void cloneConfigure(WebAppContext template, WebAppContext context) throws Exception
     {
-        File tmpDir = File.createTempFile(WebInfConfiguration.getCanonicalNameForWebAppTmpDir(context), "", template.getTempDirectory().getParentFile());
-        if (tmpDir.exists())
-        {
-            IO.delete(tmpDir);
-        }
-        tmpDir.mkdir();
-        tmpDir.deleteOnExit();
-        context.setTempDirectory(tmpDir);
+        Path tmpDir = Files.createTempDirectory(template.getTempDirectory().getParentFile().toPath(), WebInfConfiguration.getCanonicalNameForWebAppTmpDir(context));
+        File tmpDirAsFile = tmpDir.toFile();
+        tmpDirAsFile.deleteOnExit();
+        context.setTempDirectory(tmpDirAsFile);
     }
 
     /**
@@ -506,17 +506,15 @@ public class WebInfConfiguration extends AbstractConfiguration
             //if it is to be persisted, make sure it will be the same name
             //by not using File.createTempFile, which appends random digits
             tmpDir = new File(parent, temp);
+            configureTempDirectory(tmpDir, context);
         }
         else
         {
-            //ensure file will always be unique by appending random digits
-            tmpDir = File.createTempFile(temp, ".dir", parent);
-            //delete the file that was created
-            tmpDir.delete();
-            //and make a directory of the same name
-            tmpDir.mkdirs();
+            // ensure dir will always be unique by having classlib generate random path name
+            tmpDir = Files.createTempDirectory(parent.toPath(), temp).toFile();
+            tmpDir.deleteOnExit();
+            ensureTempDirUsable(tmpDir);
         }
-        configureTempDirectory(tmpDir, context);
 
         if (LOG.isDebugEnabled())
             LOG.debug("Set temp dir " + tmpDir);
@@ -528,21 +526,30 @@ public class WebInfConfiguration extends AbstractConfiguration
         if (dir == null)
             throw new IllegalArgumentException("Null temp dir");
 
-        //if dir exists and we don't want it persisted, delete it
-        if (dir.exists() && !context.isPersistTempDirectory())
+        // if dir exists and we don't want it persisted, delete it
+        if (!context.isPersistTempDirectory() && dir.exists() && !IO.delete(dir))
         {
-            if (!IO.delete(dir))
-                throw new IllegalStateException("Failed to delete temp dir " + dir);
+            throw new IllegalStateException("Failed to delete temp dir " + dir);
         }
 
-        //if it doesn't exist make it
+        // if it doesn't exist make it
         if (!dir.exists())
-            dir.mkdirs();
+        {
+            if (!dir.mkdirs())
+            {
+                throw new IllegalStateException("Unable to create temp dir " + dir);
+            }
+        }
 
         if (!context.isPersistTempDirectory())
             dir.deleteOnExit();
 
-        //is it useable
+        ensureTempDirUsable(dir);
+    }
+
+    private void ensureTempDirUsable(File dir)
+    {
+        // is it useable
         if (!dir.canWrite() || !dir.isDirectory())
             throw new IllegalStateException("Temp dir " + dir + " not useable: writeable=" + dir.canWrite() + ", dir=" + dir.isDirectory());
     }
@@ -947,13 +954,47 @@ public class WebInfConfiguration extends AbstractConfiguration
         StringTokenizer tokenizer = new StringTokenizer(context.getExtraClasspath(), ",;");
         while (tokenizer.hasMoreTokens())
         {
-            Resource resource = context.newResource(tokenizer.nextToken().trim());
-            String fnlc = resource.getName().toLowerCase(Locale.ENGLISH);
-            int dot = fnlc.lastIndexOf('.');
-            String extension = (dot < 0 ? null : fnlc.substring(dot));
-            if (extension != null && (extension.equals(".jar") || extension.equals(".zip")))
+            String token = tokenizer.nextToken().trim();
+
+            // Is this a Glob Reference?
+            if (isGlobReference(token))
             {
-                jarResources.add(resource);
+                String dir = token.substring(0, token.length() - 2);
+                // Use directory
+                Resource dirResource = context.newResource(dir);
+                if (dirResource.exists() && dirResource.isDirectory())
+                {
+                    // To obtain the list of files
+                    String[] entries = dirResource.list();
+                    if (entries != null)
+                    {
+                        Arrays.sort(entries);
+                        for (String entry : entries)
+                        {
+                            try
+                            {
+                                Resource fileResource = dirResource.addPath(entry);
+                                if (isFileSupported(fileResource))
+                                {
+                                    jarResources.add(fileResource);
+                                }
+                            }
+                            catch (Exception ex)
+                            {
+                                LOG.warn(Log.EXCEPTION, ex);
+                            }
+                        }
+                    }
+                }
+            }
+            else
+            {
+                // Simple reference, add as-is
+                Resource resource = context.newResource(token);
+                if (isFileSupported(resource))
+                {
+                    jarResources.add(resource);
+                }
             }
         }
 
@@ -1003,11 +1044,31 @@ public class WebInfConfiguration extends AbstractConfiguration
         StringTokenizer tokenizer = new StringTokenizer(context.getExtraClasspath(), ",;");
         while (tokenizer.hasMoreTokens())
         {
-            Resource resource = context.newResource(tokenizer.nextToken().trim());
-            if (resource.exists() && resource.isDirectory())
-                dirResources.add(resource);
+            String token = tokenizer.nextToken().trim();
+            // ignore glob references, they only refer to lists of jars/zips anyway
+            if (!isGlobReference(token))
+            {
+                Resource resource = context.newResource(token);
+                if (resource.exists() && resource.isDirectory())
+                {
+                    dirResources.add(resource);
+                }
+            }
         }
 
         return dirResources;
     }
+
+    private boolean isGlobReference(String token)
+    {
+        return token.endsWith("/*") || token.endsWith("\\*");
+    }
+
+    private boolean isFileSupported(Resource resource)
+    {
+        String filenameLowercase = resource.getName().toLowerCase(Locale.ENGLISH);
+        int dot = filenameLowercase.lastIndexOf('.');
+        String extension = (dot < 0 ? null : filenameLowercase.substring(dot));
+        return (extension != null && (extension.equals(".jar") || extension.equals(".zip")));
+    }
 }
