@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -51,7 +51,10 @@ public abstract class AbstractJsrRemote implements RemoteEndpoint
         {
             StringBuilder err = new StringBuilder();
             err.append("Unexpected implementation [");
-            err.append(session.getRemote().getClass().getName());
+            if (session.getRemote() == null)
+                err.append("<null>");
+            else
+                err.append(session.getRemote().getClass().getName());
             err.append("].  Expected an instanceof [");
             err.append(WebSocketRemoteEndpoint.class.getName());
             err.append("]");
@@ -98,7 +101,7 @@ public abstract class AbstractJsrRemote implements RemoteEndpoint
     }
 
     @SuppressWarnings(
-            {"rawtypes", "unchecked"})
+        {"rawtypes", "unchecked"})
     public Future<Void> sendObjectViaFuture(Object data)
     {
         assertMessageNotNull(data);
