@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2019 Mort Bay Consulting Pty. Ltd.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -25,5 +25,7 @@ import javax.websocket.EndpointConfig;
  */
 public interface Configurable
 {
-    public void init(EndpointConfig config);
+    void init(EndpointConfig config);
+
+    void destroy();
 }
