@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -69,6 +69,12 @@ public class DecoderFactory implements Configurable
         {
             this.decoder.init(config);
         }
+
+        @Override
+        public void destroy()
+        {
+            this.decoder.destroy();
+        }
     }
 
     private static final Logger LOG = Log.getLogger(DecoderFactory.class);
@@ -185,6 +191,17 @@ public class DecoderFactory implements Configurable
         }
     }
 
+    @Override
+    public void destroy()
+    {
+        for (Wrapper wrapper : activeWrappers.values())
+        {
+            wrapper.decoder.destroy();
+        }
+
+        activeWrappers.clear();
+    }
+
     public Wrapper newWrapper(DecoderMetadata metadata)
     {
         Class<? extends Decoder> decoderClass = metadata.getCoderClass();
