@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -87,17 +87,23 @@ public class JsrEndpointEventDriver extends AbstractJsrEventDriver
             }
             else if (wrapper.wantsStreams())
             {
-                final MessageInputStream stream = new MessageInputStream();
-                activeMessage = stream;
-                dispatch(new Runnable()
+                @SuppressWarnings("unchecked")
+                MessageHandler.Whole<InputStream> handler = (Whole<InputStream>)wrapper.getHandler();
+                MessageInputStream inputStream = new MessageInputStream(session);
+                activeMessage = inputStream;
+                dispatch(() ->
                 {
-                    @SuppressWarnings("unchecked")
-                    @Override
-                    public void run()
+                    try
                     {
-                        MessageHandler.Whole<InputStream> handler = (Whole<InputStream>)wrapper.getHandler();
-                        handler.onMessage(stream);
+                        handler.onMessage(inputStream);
                     }
+                    catch (Throwable t)
+                    {
+                        session.close(t);
+                        return;
+                    }
+
+                    inputStream.handlerComplete();
                 });
             }
             else
@@ -190,18 +196,23 @@ public class JsrEndpointEventDriver extends AbstractJsrEventDriver
             }
             else if (wrapper.wantsStreams())
             {
-                final MessageReader stream = new MessageReader(new MessageInputStream());
-                activeMessage = stream;
-
-                dispatch(new Runnable()
+                @SuppressWarnings("unchecked")
+                MessageHandler.Whole<Reader> handler = (Whole<Reader>)wrapper.getHandler();
+                MessageReader reader = new MessageReader(session);
+                activeMessage = reader;
+                dispatch(() ->
                 {
-                    @SuppressWarnings("unchecked")
-                    @Override
-                    public void run()
+                    try
                     {
-                        MessageHandler.Whole<Reader> handler = (Whole<Reader>)wrapper.getHandler();
-                        handler.onMessage(stream);
+                        handler.onMessage(reader);
                     }
+                    catch (Throwable t)
+                    {
+                        session.close(t);
+                        return;
+                    }
+
+                    reader.handlerComplete();
                 });
             }
             else
