@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -51,7 +51,7 @@ public class BinaryWholeMessage extends SimpleBinaryMessage
     {
         super.finished = true;
 
-        byte[] data = out.toByteArray();
+        byte[] data = (out == null) ? new byte[]{} : out.toByteArray();
 
         DecoderFactory.Wrapper decoder = msgWrapper.getDecoder();
         Decoder.Binary<Object> binaryDecoder = (Binary<Object>)decoder.getDecoder();
