@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -26,8 +26,8 @@ import javax.websocket.Session;
 
 import org.eclipse.jetty.util.log.Log;
 import org.eclipse.jetty.util.log.Logger;
-import org.junit.Assert;
 
+import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.notNullValue;
 
 /**
@@ -49,10 +49,11 @@ public class EndpointEchoClient extends Endpoint
     public void onOpen(Session session, EndpointConfig config)
     {
         if (LOG.isDebugEnabled())
-            LOG.debug("onOpen({}, {})",session,config);
+            LOG.debug("onOpen({}, {})", session, config);
         this.session = session;
-        Assert.assertThat("Session is required",session,notNullValue());
-        Assert.assertThat("EndpointConfig is required",config,notNullValue());
+        this.session.getUserProperties().put("endpoint", this);
+        assertThat("Session is required", session, notNullValue());
+        assertThat("EndpointConfig is required", config, notNullValue());
         this.session.addMessageHandler(textCapture);
     }
 
