@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -43,7 +43,7 @@ public class ValidDualEncoder implements Encoder.Text<Integer>, Encoder.BinarySt
     @Override
     public void encode(Long object, OutputStream os) throws EncodeException, IOException
     {
-        byte b[] = new byte[8];
+        byte[] b = new byte[8];
         long v = object;
         b[0] = (byte)(v >>> 56);
         b[1] = (byte)(v >>> 48);
@@ -53,7 +53,7 @@ public class ValidDualEncoder implements Encoder.Text<Integer>, Encoder.BinarySt
         b[5] = (byte)(v >>> 16);
         b[6] = (byte)(v >>> 8);
         b[7] = (byte)(v >>> 0);
-        os.write(b,0,8);
+        os.write(b, 0, 8);
     }
 
     @Override
