@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -129,7 +129,7 @@ public class AnnotatedServerEndpointConfig implements ServerEndpointConfig
         {
             try
             {
-                resolvedConfigurator = anno.configurator().getDeclaredConstructor().newInstance();
+                resolvedConfigurator = anno.configurator().getConstructor().newInstance();
             }
             catch (Exception e)
             {
