@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -18,6 +18,7 @@
 
 package org.eclipse.jetty.websocket.jsr356.server.samples;
 
+import javax.websocket.ClientEndpoint;
 import javax.websocket.CloseReason;
 import javax.websocket.OnClose;
 import javax.websocket.OnOpen;
@@ -26,6 +27,7 @@ import javax.websocket.server.ServerEndpoint;
 import org.eclipse.jetty.websocket.jsr356.server.TrackingSocket;
 
 @ServerEndpoint(value = "/basic")
+@ClientEndpoint
 public class BasicOpenCloseSocket extends TrackingSocket
 {
     @OnOpen
