@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2019 Mort Bay Consulting Pty. Ltd.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -28,7 +28,7 @@ public class FastFailEndpoint extends AbstractCloseEndpoint
     @Override
     public void onWebSocketConnect(Session sess)
     {
-        LOG.debug("onWebSocketConnect({})",sess);
+        log.debug("onWebSocketConnect({})", sess);
         // Test failure due to unhandled exception
         // this should trigger a fast-fail closure during open/connect
         throw new RuntimeException("Intentional FastFail");
