@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -30,9 +30,11 @@ import java.util.Objects;
 import java.util.Set;
 import java.util.concurrent.Executor;
 import java.util.concurrent.Future;
+import java.util.concurrent.TimeUnit;
 import java.util.function.Supplier;
 
 import org.eclipse.jetty.client.HttpClient;
+import org.eclipse.jetty.client.api.Request;
 import org.eclipse.jetty.io.ByteBufferPool;
 import org.eclipse.jetty.util.DecoratedObjectFactory;
 import org.eclipse.jetty.util.StringUtil;
@@ -342,7 +344,7 @@ public class WebSocketClient extends ContainerLifeCycle implements WebSocketCont
         }
 
         String scheme = toUri.getScheme().toLowerCase(Locale.ENGLISH);
-        if (("ws".equals(scheme) == false) && ("wss".equals(scheme) == false))
+        if ((!"ws".equals(scheme)) && (!"wss".equals(scheme)))
         {
             throw new IllegalArgumentException("WebSocket URI scheme only supports [ws] and [wss], not [" + scheme + "]");
         }
@@ -374,8 +376,13 @@ public class WebSocketClient extends ContainerLifeCycle implements WebSocketCont
         init();
 
         WebSocketUpgradeRequest wsReq = new WebSocketUpgradeRequest(this, httpClient, request);
-
+        wsReq.timeout(request.getTimeout(), TimeUnit.MILLISECONDS);
         wsReq.setUpgradeListener(upgradeListener);
+        for (Request.Listener l : getBeans(Request.Listener.class))
+        {
+            wsReq.listener(l);
+        }
+
         return wsReq.sendAsync();
     }
 
@@ -427,6 +434,7 @@ public class WebSocketClient extends ContainerLifeCycle implements WebSocketCont
      *
      * @return number of milliseconds for timeout of an attempted write operation
      */
+    @Deprecated
     public long getAsyncWriteTimeout()
     {
         return getPolicy().getAsyncWriteTimeout();
