@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -19,9 +19,9 @@
 package org.eclipse.jetty.websocket.client;
 
 import java.util.concurrent.CountDownLatch;
+import java.util.concurrent.LinkedBlockingQueue;
 import java.util.concurrent.TimeUnit;
 
-import org.eclipse.jetty.toolchain.test.EventQueue;
 import org.eclipse.jetty.util.log.Log;
 import org.eclipse.jetty.util.log.Logger;
 import org.eclipse.jetty.websocket.api.Session;
@@ -30,11 +30,12 @@ import org.eclipse.jetty.websocket.api.annotations.OnWebSocketConnect;
 import org.eclipse.jetty.websocket.api.annotations.OnWebSocketError;
 import org.eclipse.jetty.websocket.api.annotations.OnWebSocketMessage;
 import org.eclipse.jetty.websocket.api.annotations.WebSocket;
-import org.junit.Assert;
 
+import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.is;
+import static org.junit.jupiter.api.Assertions.assertEquals;
 
-@WebSocket(maxTextMessageSize = 100*1024)
+@WebSocket(maxTextMessageSize = 100 * 1024)
 public class MaxMessageSocket
 {
     private static final Logger LOG = Log.getLogger(MaxMessageSocket.class);
@@ -42,8 +43,8 @@ public class MaxMessageSocket
     public CountDownLatch openLatch = new CountDownLatch(1);
     public CountDownLatch closeLatch = new CountDownLatch(1);
     public CountDownLatch dataLatch = new CountDownLatch(1);
-    public EventQueue<String> messageQueue = new EventQueue<>();
-    public EventQueue<Throwable> errorQueue = new EventQueue<>();
+    public LinkedBlockingQueue<String> messageQueue = new LinkedBlockingQueue<>();
+    public LinkedBlockingQueue<Throwable> errorQueue = new LinkedBlockingQueue<>();
     public int closeCode = -1;
     public StringBuilder closeMessage = new StringBuilder();
 
@@ -53,11 +54,11 @@ public class MaxMessageSocket
         this.session = session;
         openLatch.countDown();
     }
-    
+
     @OnWebSocketClose
     public void onClose(int statusCode, String reason)
     {
-        LOG.debug("onWebSocketClose({},{})",statusCode,reason);
+        LOG.debug("onWebSocketClose({},{})", statusCode, reason);
         closeCode = statusCode;
         closeMessage.append(reason);
         closeLatch.countDown();
@@ -66,16 +67,16 @@ public class MaxMessageSocket
     @OnWebSocketMessage
     public void onMessage(String message)
     {
-        LOG.debug("onWebSocketText({})",message);
+        LOG.debug("onWebSocketText({})", message);
         messageQueue.offer(message);
         dataLatch.countDown();
     }
-    
+
     @OnWebSocketError
     public void onError(Throwable cause)
     {
-        LOG.debug("onWebSocketError",cause);
-        Assert.assertThat("Error capture",errorQueue.offer(cause),is(true));
+        LOG.debug("onWebSocketError", cause);
+        assertThat("Error capture", errorQueue.offer(cause), is(true));
     }
 
     public Session getSession()
@@ -85,18 +86,18 @@ public class MaxMessageSocket
 
     public void awaitConnect(int duration, TimeUnit unit) throws InterruptedException
     {
-        Assert.assertThat("Client Socket connected",openLatch.await(duration,unit),is(true));
+        assertThat("Client Socket connected", openLatch.await(duration, unit), is(true));
     }
-    
+
     public void waitForMessage(int timeoutDuration, TimeUnit timeoutUnit) throws InterruptedException
     {
         LOG.debug("Waiting for message");
-        Assert.assertThat("Message Received",dataLatch.await(timeoutDuration,timeoutUnit),is(true));
+        assertThat("Message Received", dataLatch.await(timeoutDuration, timeoutUnit), is(true));
     }
-    
+
     public void assertMessage(String expected)
     {
         String actual = messageQueue.poll();
-        Assert.assertEquals("Message",expected,actual);
+        assertEquals(expected, actual, "Message");
     }
 }
