@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2019 Mort Bay Consulting Pty. Ltd.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -20,6 +20,7 @@ package org.eclipse.jetty.websocket.common;
 
 import java.nio.ByteBuffer;
 import java.util.List;
+import java.util.concurrent.atomic.LongAdder;
 
 import org.eclipse.jetty.io.ByteBufferPool;
 import org.eclipse.jetty.util.BufferUtil;
@@ -62,6 +63,9 @@ public class Parser
     private final WebSocketPolicy policy;
     private final ByteBufferPool bufferPool;
 
+    // Stats (where a message is defined as a WebSocket frame)
+    private final LongAdder messagesIn = new LongAdder();
+
     // State specific
     private State state = State.START;
     private int cursor = 0;
@@ -73,18 +77,18 @@ public class Parser
     private int payloadLength;
     private PayloadProcessor maskProcessor = new DeMaskProcessor();
 
-    /** 
+    /**
      * Is there an extension using RSV flag?
      * <p>
-     * 
+     *
      * <pre>
      *   0100_0000 (0x40) = rsv1
      *   0010_0000 (0x20) = rsv2
      *   0001_0000 (0x10) = rsv3
      * </pre>
      */
-    private byte flagsInUse=0x00;
-    
+    private byte flagsInUse = 0x00;
+
     private IncomingFrames incomingFramesHandler;
 
     public Parser(WebSocketPolicy wspolicy, ByteBufferPool bufferPool)
@@ -95,8 +99,9 @@ public class Parser
 
     private void assertSanePayloadLength(long len)
     {
-        if (LOG.isDebugEnabled()) {
-            LOG.debug("{} Payload Length: {} - {}",policy.getBehavior(),len,this);
+        if (LOG.isDebugEnabled())
+        {
+            LOG.debug("{} Payload Length: {} - {}", policy.getBehavior(), len, this);
         }
 
         // Since we use ByteBuffer so often, having lengths over Integer.MAX_VALUE is really impossible.
@@ -113,13 +118,12 @@ public class Parser
                 {
                     throw new ProtocolException("Invalid close frame payload length, [" + payloadLength + "]");
                 }
-                // fall thru
+                // fallthru
             case OpCode.PING:
             case OpCode.PONG:
                 if (len > ControlFrame.MAX_CONTROL_PAYLOAD)
                 {
-                    throw new ProtocolException("Invalid control frame payload length, [" + payloadLength + "] cannot exceed ["
-                            + ControlFrame.MAX_CONTROL_PAYLOAD + "]");
+                    throw new ProtocolException("Invalid control frame payload length, [" + payloadLength + "] cannot exceed [" + ControlFrame.MAX_CONTROL_PAYLOAD + "]");
                 }
                 break;
             case OpCode.TEXT:
@@ -132,7 +136,7 @@ public class Parser
     }
 
     public void configureFromExtensions(List<? extends Extension> exts)
-    {        
+    {
         // default
         flagsInUse = 0x00;
 
@@ -182,17 +186,17 @@ public class Parser
     protected void notifyFrame(final Frame f) throws WebSocketException
     {
         if (LOG.isDebugEnabled())
-            LOG.debug("{} Notify {}",policy.getBehavior(),getIncomingFramesHandler());
+            LOG.debug("{} Notify {}", policy.getBehavior(), getIncomingFramesHandler());
 
         if (policy.getBehavior() == WebSocketBehavior.SERVER)
         {
             /* Parsing on server.
-             * 
+             *
              * Then you MUST make sure all incoming frames are masked!
-             * 
+             *
              * Technically, this test is in violation of RFC-6455, Section 5.1
              * http://tools.ietf.org/html/rfc6455#section-5.1
-             * 
+             *
              * But we can't trust the client at this point, so Jetty opts to close
              * the connection as a Protocol error.
              */
@@ -201,7 +205,7 @@ public class Parser
                 throw new ProtocolException("Client MUST mask all frames (RFC-6455: Section 5.1)");
             }
         }
-        else if(policy.getBehavior() == WebSocketBehavior.CLIENT)
+        else if (policy.getBehavior() == WebSocketBehavior.CLIENT)
         {
             // Required by RFC-6455 / Section 5.1
             if (f.isMasked())
@@ -212,7 +216,7 @@ public class Parser
 
         if (incomingFramesHandler == null)
         {
-            if(LOG.isDebugEnabled())
+            if (LOG.isDebugEnabled())
                 LOG.debug("No IncomingFrames Handler to notify");
             return;
         }
@@ -232,17 +236,26 @@ public class Parser
 
     public void parse(ByteBuffer buffer) throws WebSocketException
     {
-        if (buffer.remaining() <= 0)
+        while (buffer.hasRemaining())
         {
-            return;
+            parseSingleFrame(buffer);
         }
+    }
+
+    public void parseSingleFrame(ByteBuffer buffer) throws WebSocketException
+    {
+        if (buffer.remaining() <= 0)
+            return;
+
         try
         {
-            // parse through all the frames in the buffer
-            while (parseFrame(buffer))
+            // attempt to parse a frame from the buffer
+            if (parseFrame(buffer))
             {
                 if (LOG.isDebugEnabled())
-                    LOG.debug("{} Parsed Frame: {}",policy.getBehavior(),frame);
+                    LOG.debug("{} Parsed Frame: {}", policy.getBehavior(), frame);
+
+                messagesIn.increment();
                 notifyFrame(frame);
                 if (frame.isDataFrame())
                 {
@@ -251,19 +264,15 @@ public class Parser
                 reset();
             }
         }
-        catch (WebSocketException e)
-        {
-            buffer.position(buffer.limit()); // consume remaining
-            reset();
-            // need to throw for proper close behavior in connection
-            throw e;
-        }
         catch (Throwable t)
         {
             buffer.position(buffer.limit()); // consume remaining
             reset();
             // need to throw for proper close behavior in connection
-            throw new WebSocketException(t);
+            if (t instanceof WebSocketException)
+                throw t;
+            else
+                throw new WebSocketException(t);
         }
     }
 
@@ -282,16 +291,15 @@ public class Parser
      * Note the first byte (fin,rsv1,rsv2,rsv3,opcode) are parsed by the {@link Parser#parse(ByteBuffer)} method
      * <p>
      * Not overridable
-     * 
-     * @param buffer
-     *            the buffer to parse from.
+     *
+     * @param buffer the buffer to parse from.
      * @return true if done parsing base framing protocol and ready for parsing of the payload. false if incomplete parsing of base framing protocol.
      */
     private boolean parseFrame(ByteBuffer buffer)
     {
         if (LOG.isDebugEnabled())
         {
-            LOG.debug("{} Parsing {} bytes",policy.getBehavior(),buffer.remaining());
+            LOG.debug("{} Parsing {} bytes", policy.getBehavior(), buffer.remaining());
         }
         while (buffer.hasRemaining())
         {
@@ -302,25 +310,25 @@ public class Parser
                     // peek at byte
                     byte b = buffer.get();
                     boolean fin = ((b & 0x80) != 0);
-                    
+
                     byte opcode = (byte)(b & 0x0F);
 
                     if (!OpCode.isKnown(opcode))
                     {
                         throw new ProtocolException("Unknown opcode: " + opcode);
                     }
-                    
+
                     if (LOG.isDebugEnabled())
                         LOG.debug("{} OpCode {}, fin={} rsv={}{}{}",
-                                policy.getBehavior(),
-                                OpCode.name(opcode),
-                                fin,
-                                (((b & 0x40) != 0)?'1':'.'),
-                                (((b & 0x20) != 0)?'1':'.'),
-                                (((b & 0x10) != 0)?'1':'.'));
+                            policy.getBehavior(),
+                            OpCode.name(opcode),
+                            fin,
+                            (((b & 0x40) != 0) ? '1' : '.'),
+                            (((b & 0x20) != 0) ? '1' : '.'),
+                            (((b & 0x10) != 0) ? '1' : '.'));
 
                     // base framing flags
-                    switch(opcode)
+                    switch (opcode)
                     {
                         case OpCode.TEXT:
                             frame = new TextFrame();
@@ -372,7 +380,7 @@ public class Parser
                             }
                             break;
                     }
-                    
+
                     frame.setFin(fin);
 
                     // Are any flags set?
@@ -380,7 +388,7 @@ public class Parser
                     {
                         /*
                          * RFC 6455 Section 5.2
-                         * 
+                         *
                          * MUST be 0 unless an extension is negotiated that defines meanings for non-zero values. If a nonzero value is received and none of the
                          * negotiated extensions defines the meaning of such a nonzero value, the receiving endpoint MUST _Fail the WebSocket Connection_.
                          */
@@ -391,7 +399,7 @@ public class Parser
                             else
                             {
                                 String err = "RSV1 not allowed to be set";
-                                if(LOG.isDebugEnabled())
+                                if (LOG.isDebugEnabled())
                                 {
                                     LOG.debug(err + ": Remaining buffer: {}", BufferUtil.toDetailString(buffer));
                                 }
@@ -405,7 +413,7 @@ public class Parser
                             else
                             {
                                 String err = "RSV2 not allowed to be set";
-                                if(LOG.isDebugEnabled())
+                                if (LOG.isDebugEnabled())
                                 {
                                     LOG.debug(err + ": Remaining buffer: {}", BufferUtil.toDetailString(buffer));
                                 }
@@ -419,7 +427,7 @@ public class Parser
                             else
                             {
                                 String err = "RSV3 not allowed to be set";
-                                if(LOG.isDebugEnabled())
+                                if (LOG.isDebugEnabled())
                                 {
                                     LOG.debug(err + ": Remaining buffer: {}", BufferUtil.toDetailString(buffer));
                                 }
@@ -427,11 +435,11 @@ public class Parser
                             }
                         }
                     }
-                    
+
                     state = State.PAYLOAD_LEN;
                     break;
                 }
-                
+
                 case PAYLOAD_LEN:
                 {
                     byte b = buffer.get();
@@ -475,7 +483,7 @@ public class Parser
 
                     break;
                 }
-                
+
                 case PAYLOAD_LEN_BYTES:
                 {
                     byte b = buffer.get();
@@ -503,14 +511,14 @@ public class Parser
                     }
                     break;
                 }
-                
+
                 case MASK:
                 {
-                    byte m[] = new byte[4];
+                    byte[] m = new byte[4];
                     frame.setMask(m);
                     if (buffer.remaining() >= 4)
                     {
-                        buffer.get(m,0,4);
+                        buffer.get(m, 0, 4);
                         // special case for empty payloads (no more bytes left in buffer)
                         if (payloadLength == 0)
                         {
@@ -528,7 +536,7 @@ public class Parser
                     }
                     break;
                 }
-                
+
                 case MASK_BYTES:
                 {
                     byte b = buffer.get();
@@ -548,7 +556,7 @@ public class Parser
                     }
                     break;
                 }
-                
+
                 case PAYLOAD:
                 {
                     frame.assertValid();
@@ -574,13 +582,12 @@ public class Parser
 
     /**
      * Implementation specific parsing of a payload
-     * 
-     * @param buffer
-     *            the payload buffer
+     *
+     * @param buffer the payload buffer
      * @return true if payload is done reading, false if incomplete
      */
     private boolean parsePayload(ByteBuffer buffer)
-    {        
+    {
         if (payloadLength == 0)
         {
             return true;
@@ -601,8 +608,9 @@ public class Parser
             buffer.limit(limit);
             buffer.position(buffer.position() + window.remaining());
 
-            if (LOG.isDebugEnabled()) {
-                LOG.debug("{} Window: {}",policy.getBehavior(),BufferUtil.toDetailString(window));
+            if (LOG.isDebugEnabled())
+            {
+                LOG.debug("{} Window: {}", policy.getBehavior(), BufferUtil.toDetailString(window));
             }
 
             maskProcessor.process(window);
@@ -617,7 +625,7 @@ public class Parser
             {
                 if (payload == null)
                 {
-                    payload = bufferPool.acquire(payloadLength,false);
+                    payload = bufferPool.acquire(payloadLength, false);
                     BufferUtil.clearToFill(payload);
                 }
                 // Copy the payload.
@@ -639,6 +647,11 @@ public class Parser
         this.incomingFramesHandler = incoming;
     }
 
+    public long getMessagesIn()
+    {
+        return messagesIn.longValue();
+    }
+
     @Override
     public String toString()
     {
