@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -34,6 +34,8 @@ public class TextFrame extends DataFrame
     @Override
     public Type getType()
     {
+        if (getOpCode() == OpCode.CONTINUATION)
+            return Type.CONTINUATION;
         return Type.TEXT;
     }
 
@@ -42,7 +44,8 @@ public class TextFrame extends DataFrame
         setPayload(ByteBuffer.wrap(StringUtil.getUtf8Bytes(str)));
         return this;
     }
-    
+
+    @Override
     public String getPayloadAsUTF8()
     {
         if (data == null)
