@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -36,9 +36,9 @@ import org.eclipse.jetty.websocket.common.test.IncomingFramesCapture;
 import org.eclipse.jetty.websocket.common.test.UnitGenerator;
 import org.eclipse.jetty.websocket.common.test.UnitParser;
 import org.eclipse.jetty.websocket.common.util.Hex;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
+import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.is;
 
 public class GeneratorTest
@@ -76,11 +76,11 @@ public class GeneratorTest
             for (Frame f : frames)
             {
                 ByteBuffer header = generator.generateHeaderBytes(f);
-                totalBytes += BufferUtil.put(header,completeBuf);
+                totalBytes += BufferUtil.put(header, completeBuf);
 
                 if (f.hasPayload())
                 {
-                    ByteBuffer payload=f.getPayload();
+                    ByteBuffer payload = f.getPayload();
                     totalBytes += payload.remaining();
                     totalParts++;
                     completeBuf.put(payload.slice());
@@ -88,18 +88,18 @@ public class GeneratorTest
             }
 
             // Return results
-            BufferUtil.flipToFlush(completeBuf,0);
+            BufferUtil.flipToFlush(completeBuf, 0);
             return completeBuf;
         }
 
         public void assertTotalParts(int expectedParts)
         {
-            Assert.assertThat("Generated Parts",totalParts,is(expectedParts));
+            assertThat("Generated Parts", totalParts, is(expectedParts));
         }
 
         public void assertTotalBytes(int expectedBytes)
         {
-            Assert.assertThat("Generated Bytes",totalBytes,is(expectedBytes));
+            assertThat("Generated Bytes", totalBytes, is(expectedBytes));
         }
     }
 
@@ -110,13 +110,13 @@ public class GeneratorTest
         // Get hex String form of all frames bytebuffer.
         String actual = Hex.asHex(allframes);
         // Validate
-        Assert.assertThat("Buffer",actual,is(expectedBytes.toString()));
+        assertThat("Buffer", actual, is(expectedBytes.toString()));
     }
 
     private String asMaskedHex(String str, byte[] maskingKey)
     {
-        byte utf[] = StringUtil.getUtf8Bytes(str);
-        mask(utf,maskingKey);
+        byte[] utf = StringUtil.getUtf8Bytes(str);
+        mask(utf, maskingKey);
         return Hex.asHex(utf);
     }
 
@@ -130,54 +130,54 @@ public class GeneratorTest
     }
 
     @Test
-    public void testClose_Empty()
+    public void testCloseEmpty()
     {
         // 0 byte payload (no status code)
-        assertGeneratedBytes("8800",new CloseFrame());
+        assertGeneratedBytes("8800", new CloseFrame());
     }
 
     @Test
-    public void testClose_CodeNoReason()
+    public void testCloseCodeNoReason()
     {
         CloseInfo close = new CloseInfo(StatusCode.NORMAL);
         // 2 byte payload (2 bytes for status code)
-        assertGeneratedBytes("880203E8",close.asFrame());
+        assertGeneratedBytes("880203E8", close.asFrame());
     }
 
     @Test
-    public void testClose_CodeOkReason()
+    public void testCloseCodeOkReason()
     {
-        CloseInfo close = new CloseInfo(StatusCode.NORMAL,"OK");
+        CloseInfo close = new CloseInfo(StatusCode.NORMAL, "OK");
         // 4 byte payload (2 bytes for status code, 2 more for "OK")
-        assertGeneratedBytes("880403E84F4B",close.asFrame());
+        assertGeneratedBytes("880403E84F4B", close.asFrame());
     }
 
     @Test
-    public void testText_Hello()
+    public void testTextHello()
     {
         WebSocketFrame frame = new TextFrame().setPayload("Hello");
-        byte utf[] = StringUtil.getUtf8Bytes("Hello");
-        assertGeneratedBytes("8105" + Hex.asHex(utf),frame);
+        byte[] utf = StringUtil.getUtf8Bytes("Hello");
+        assertGeneratedBytes("8105" + Hex.asHex(utf), frame);
     }
 
     @Test
-    public void testText_Masked()
+    public void testTextMasked()
     {
         WebSocketFrame frame = new TextFrame().setPayload("Hello");
-        byte maskingKey[] = Hex.asByteArray("11223344");
+        byte[] maskingKey = Hex.asByteArray("11223344");
         frame.setMask(maskingKey);
 
         // what is expected
         StringBuilder expected = new StringBuilder();
         expected.append("8185").append("11223344");
-        expected.append(asMaskedHex("Hello",maskingKey));
+        expected.append(asMaskedHex("Hello", maskingKey));
 
         // validate
-        assertGeneratedBytes(expected,frame);
+        assertGeneratedBytes(expected, frame);
     }
 
     @Test
-    public void testText_Masked_OffsetSourceByteBuffer()
+    public void testTextMaskedOffsetSourceByteBuffer()
     {
         ByteBuffer payload = ByteBuffer.allocate(100);
         payload.position(5);
@@ -188,18 +188,18 @@ public class GeneratorTest
         // but only a few bytes in the middle are made available for the payload.
         // we are testing that masking works as intended, even if the provided
         // payload does not start at position 0.
-        LOG.debug("Payload = {}",BufferUtil.toDetailString(payload));
+        LOG.debug("Payload = {}", BufferUtil.toDetailString(payload));
         WebSocketFrame frame = new TextFrame().setPayload(payload);
-        byte maskingKey[] = Hex.asByteArray("11223344");
+        byte[] maskingKey = Hex.asByteArray("11223344");
         frame.setMask(maskingKey);
 
         // what is expected
         StringBuilder expected = new StringBuilder();
         expected.append("8185").append("11223344");
-        expected.append(asMaskedHex("Hello",maskingKey));
+        expected.append(asMaskedHex("Hello", maskingKey));
 
         // validate
-        assertGeneratedBytes(expected,frame);
+        assertGeneratedBytes(expected, frame);
     }
 
     /**
@@ -214,12 +214,12 @@ public class GeneratorTest
         WebSocketFrame[] frames = new WebSocketFrame[pingCount + 1];
         for (int i = 0; i < pingCount; i++)
         {
-            frames[i] = new PingFrame().setPayload(String.format("ping-%d",i));
+            frames[i] = new PingFrame().setPayload(String.format("ping-%d", i));
         }
         frames[pingCount] = new CloseInfo(StatusCode.NORMAL).asFrame();
 
         // Mask All Frames
-        byte maskingKey[] = Hex.asByteArray("11223344");
+        byte[] maskingKey = Hex.asByteArray("11223344");
         for (WebSocketFrame f : frames)
         {
             f.setMask(maskingKey);
@@ -228,15 +228,15 @@ public class GeneratorTest
         // Validate result of generation
         StringBuilder expected = new StringBuilder();
         expected.append("8986").append("11223344");
-        expected.append(asMaskedHex("ping-0",maskingKey)); // ping 0
+        expected.append(asMaskedHex("ping-0", maskingKey)); // ping 0
         expected.append("8986").append("11223344");
-        expected.append(asMaskedHex("ping-1",maskingKey)); // ping 1
+        expected.append(asMaskedHex("ping-1", maskingKey)); // ping 1
         expected.append("8882").append("11223344");
-        byte closure[] = Hex.asByteArray("03E8");
-        mask(closure,maskingKey);
+        byte[] closure = Hex.asByteArray("03E8");
+        mask(closure, maskingKey);
         expected.append(Hex.asHex(closure)); // normal closure
 
-        assertGeneratedBytes(expected,frames);
+        assertGeneratedBytes(expected, frames);
     }
 
     /**
@@ -246,8 +246,8 @@ public class GeneratorTest
     public void testWindowedGenerate()
     {
         // A decent sized frame, no masking
-        byte payload[] = new byte[10240];
-        Arrays.fill(payload,(byte)0x44);
+        byte[] payload = new byte[10240];
+        Arrays.fill(payload, (byte)0x44);
 
         WebSocketFrame frame = new BinaryFrame().setPayload(payload);
 
@@ -264,18 +264,18 @@ public class GeneratorTest
         helper.assertTotalParts(expectedParts);
         helper.assertTotalBytes(payload.length + expectedHeaderSize);
 
-        Assert.assertThat("Generated Buffer",completeBuffer.remaining(),is(expectedSize));
+        assertThat("Generated Buffer", completeBuffer.remaining(), is(expectedSize));
     }
 
     @Test
     public void testWindowedGenerateWithMasking()
     {
         // A decent sized frame, with masking
-        byte payload[] = new byte[10240];
-        Arrays.fill(payload,(byte)0x55);
+        byte[] payload = new byte[10240];
+        Arrays.fill(payload, (byte)0x55);
 
-        byte mask[] = new byte[]
-        { 0x2A, (byte)0xF0, 0x0F, 0x00 };
+        byte[] mask = new byte[]
+            {0x2A, (byte)0xF0, 0x0F, 0x00};
 
         WebSocketFrame frame = new BinaryFrame().setPayload(payload);
         frame.setMask(mask); // masking!
@@ -293,7 +293,7 @@ public class GeneratorTest
         helper.assertTotalParts(expectedParts);
         helper.assertTotalBytes(payload.length + expectedHeaderSize);
 
-        Assert.assertThat("Generated Buffer",completeBuffer.remaining(),is(expectedSize));
+        assertThat("Generated Buffer", completeBuffer.remaining(), is(expectedSize));
 
         // Parse complete buffer.
         WebSocketPolicy policy = WebSocketPolicy.newServerPolicy();
@@ -305,15 +305,15 @@ public class GeneratorTest
 
         // Assert validity of frame
         WebSocketFrame actual = capture.getFrames().poll();
-        Assert.assertThat("Frame.opcode",actual.getOpCode(),is(OpCode.BINARY));
-        Assert.assertThat("Frame.payloadLength",actual.getPayloadLength(),is(payload.length));
+        assertThat("Frame.opcode", actual.getOpCode(), is(OpCode.BINARY));
+        assertThat("Frame.payloadLength", actual.getPayloadLength(), is(payload.length));
 
         // Validate payload contents for proper masking
         ByteBuffer actualData = actual.getPayload().slice();
-        Assert.assertThat("Frame.payload.remaining",actualData.remaining(),is(payload.length));
+        assertThat("Frame.payload.remaining", actualData.remaining(), is(payload.length));
         while (actualData.remaining() > 0)
         {
-            Assert.assertThat("Actual.payload[" + actualData.position() + "]",actualData.get(),is((byte)0x55));
+            assertThat("Actual.payload[" + actualData.position() + "]", actualData.get(), is((byte)0x55));
         }
     }
 }
