@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -21,9 +21,9 @@ package org.eclipse.jetty.websocket.common.message;
 import java.io.IOException;
 import java.io.InputStream;
 import java.util.concurrent.CountDownLatch;
+import java.util.concurrent.LinkedBlockingQueue;
 import java.util.concurrent.TimeUnit;
 
-import org.eclipse.jetty.toolchain.test.EventQueue;
 import org.eclipse.jetty.util.IO;
 import org.eclipse.jetty.util.log.Log;
 import org.eclipse.jetty.util.log.Logger;
@@ -31,8 +31,8 @@ import org.eclipse.jetty.websocket.api.annotations.OnWebSocketClose;
 import org.eclipse.jetty.websocket.api.annotations.OnWebSocketError;
 import org.eclipse.jetty.websocket.api.annotations.OnWebSocketMessage;
 import org.eclipse.jetty.websocket.api.annotations.WebSocket;
-import org.junit.Assert;
 
+import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.is;
 
 @WebSocket
@@ -43,8 +43,8 @@ public class TrackingInputStreamSocket
     public int closeCode = -1;
     public StringBuilder closeMessage = new StringBuilder();
     public CountDownLatch closeLatch = new CountDownLatch(1);
-    public EventQueue<String> messageQueue = new EventQueue<>();
-    public EventQueue<Throwable> errorQueue = new EventQueue<>();
+    public LinkedBlockingQueue<String> messageQueue = new LinkedBlockingQueue<>();
+    public LinkedBlockingQueue<Throwable> errorQueue = new LinkedBlockingQueue<>();
 
     public TrackingInputStreamSocket()
     {
@@ -64,20 +64,20 @@ public class TrackingInputStreamSocket
 
     public void assertCloseCode(int expectedCode) throws InterruptedException
     {
-        Assert.assertThat("Was Closed",closeLatch.await(50,TimeUnit.MILLISECONDS),is(true));
-        Assert.assertThat("Close Code",closeCode,is(expectedCode));
+        assertThat("Was Closed", closeLatch.await(50, TimeUnit.MILLISECONDS), is(true));
+        assertThat("Close Code", closeCode, is(expectedCode));
     }
 
     private void assertCloseReason(String expectedReason)
     {
-        Assert.assertThat("Close Reason",closeMessage.toString(),is(expectedReason));
+        assertThat("Close Reason", closeMessage.toString(), is(expectedReason));
     }
 
     @OnWebSocketClose
     public void onClose(int statusCode, String reason)
     {
         if (LOG.isDebugEnabled())
-            LOG.debug("{} onClose({},{})",id,statusCode,reason);
+            LOG.debug("{} onClose({},{})", id, statusCode, reason);
         closeCode = statusCode;
         closeMessage.append(reason);
         closeLatch.countDown();
@@ -93,7 +93,7 @@ public class TrackingInputStreamSocket
     public void onInputStream(InputStream stream)
     {
         if (LOG.isDebugEnabled())
-            LOG.debug("{} onInputStream({})",id,stream);
+            LOG.debug("{} onInputStream({})", id, stream);
         try
         {
             String msg = IO.toString(stream);
@@ -107,6 +107,6 @@ public class TrackingInputStreamSocket
 
     public void waitForClose(int timeoutDuration, TimeUnit timeoutUnit) throws InterruptedException
     {
-        Assert.assertThat("Client Socket Closed",closeLatch.await(timeoutDuration,timeoutUnit),is(true));
+        assertThat("Client Socket Closed", closeLatch.await(timeoutDuration, timeoutUnit), is(true));
     }
 }
