@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -24,10 +24,12 @@ import java.io.StringReader;
 import java.lang.annotation.Annotation;
 import java.lang.reflect.Array;
 import java.lang.reflect.Constructor;
+import java.lang.reflect.Executable;
 import java.lang.reflect.Field;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.lang.reflect.Modifier;
+import java.lang.reflect.Parameter;
 import java.net.InetAddress;
 import java.net.MalformedURLException;
 import java.net.URL;
@@ -37,11 +39,12 @@ import java.nio.file.Paths;
 import java.security.AccessController;
 import java.security.PrivilegedExceptionAction;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.Comparator;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.LinkedList;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
@@ -51,10 +54,10 @@ import java.util.Queue;
 import java.util.ServiceLoader;
 import java.util.Set;
 
-import org.eclipse.jetty.util.ArrayUtil;
 import org.eclipse.jetty.util.LazyList;
 import org.eclipse.jetty.util.Loader;
 import org.eclipse.jetty.util.MultiException;
+import org.eclipse.jetty.util.Pool;
 import org.eclipse.jetty.util.StringUtil;
 import org.eclipse.jetty.util.TypeUtil;
 import org.eclipse.jetty.util.annotation.Name;
@@ -97,32 +100,51 @@ public class XmlConfiguration
             ArrayList.class, HashSet.class, Queue.class, List.class, Set.class, Collection.class
         };
     private static final Iterable<ConfigurationProcessorFactory> __factoryLoader = ServiceLoader.load(ConfigurationProcessorFactory.class);
-    private static final XmlParser __parser = initParser();
-
-    private static XmlParser initParser()
+    private static final Pool<ConfigurationParser> __parsers =
+        new Pool<>(Pool.StrategyType.THREAD_ID, Math.min(8, Runtime.getRuntime().availableProcessors()));
+    public static final Comparator<Executable> EXECUTABLE_COMPARATOR = (e1, e2) ->
     {
-        ClassLoader loader = XmlConfiguration.class.getClassLoader();
-        XmlParser parser = new XmlParser();
-        URL config60 = loader.getResource("org/eclipse/jetty/xml/configure_6_0.dtd");
-        URL config76 = loader.getResource("org/eclipse/jetty/xml/configure_7_6.dtd");
-        URL config90 = loader.getResource("org/eclipse/jetty/xml/configure_9_0.dtd");
-        URL config93 = loader.getResource("org/eclipse/jetty/xml/configure_9_3.dtd");
-        parser.redirectEntity("configure.dtd", config90);
-        parser.redirectEntity("configure_1_0.dtd", config60);
-        parser.redirectEntity("configure_1_1.dtd", config60);
-        parser.redirectEntity("configure_1_2.dtd", config60);
-        parser.redirectEntity("configure_1_3.dtd", config60);
-        parser.redirectEntity("configure_6_0.dtd", config60);
-        parser.redirectEntity("configure_7_6.dtd", config76);
-        parser.redirectEntity("configure_9_0.dtd", config90);
-        parser.redirectEntity("configure_9_3.dtd", config93);
-        parser.redirectEntity("http://jetty.mortbay.org/configure.dtd", config93);
-        parser.redirectEntity("http://jetty.eclipse.org/configure.dtd", config93);
-        parser.redirectEntity("http://www.eclipse.org/jetty/configure.dtd", config93);
-        parser.redirectEntity("-//Mort Bay Consulting//DTD Configure//EN", config93);
-        parser.redirectEntity("-//Jetty//Configure//EN", config93);
-        return parser;
-    }
+        // Favour methods with less parameters
+        int count = e1.getParameterCount();
+        int compare = Integer.compare(count, e2.getParameterCount());
+        if (compare == 0 && count > 0)
+        {
+            Parameter[] p1 = e1.getParameters();
+            Parameter[] p2 = e2.getParameters();
+
+            // Favour methods without varargs
+            compare = Boolean.compare(p1[count - 1].isVarArgs(), p2[count - 1].isVarArgs());
+            if (compare == 0)
+            {
+                // Rank by differences in the parameters
+                for (int i = 0; i < count; i++)
+                {
+                    Class<?> t1 = p1[i].getType();
+                    Class<?> t2 = p2[i].getType();
+                    if (t1 != t2)
+                    {
+                        // Favour derived type over base type
+                        compare = Boolean.compare(t1.isAssignableFrom(t2), t2.isAssignableFrom(t1));
+                        if (compare == 0)
+                        {
+                            // favour primitive type over reference
+                            compare = Boolean.compare(!t1.isPrimitive(), !t2.isPrimitive());
+                            if (compare == 0)
+                                // Use name to avoid non determinant sorting
+                                compare = t1.getName().compareTo(t2.getName());
+                        }
+
+                        // break on the first different parameter (should always be true)
+                        if (compare != 0)
+                            break;
+                    }
+                }
+            }
+            compare = Math.min(1, Math.max(compare, -1));
+        }
+
+        return compare;
+    };
 
     /**
      * Set the standard IDs and properties expected in a jetty XML file:
@@ -181,6 +203,14 @@ public class XmlConfiguration
     private final String _dtd;
     private ConfigurationProcessor _processor;
 
+    ConfigurationParser getParser()
+    {
+        Pool<ConfigurationParser>.Entry entry = __parsers.acquire(ConfigurationParser::new);
+        if (entry == null)
+            return new ConfigurationParser(null);
+        return entry.getPooled();
+    }
+
     /**
      * Reads and parses the XML configuration file.
      *
@@ -190,14 +220,11 @@ public class XmlConfiguration
      */
     public XmlConfiguration(Resource resource) throws SAXException, IOException
     {
-        synchronized (__parser)
+        try (ConfigurationParser parser = getParser(); InputStream inputStream = resource.getInputStream())
         {
             _location = resource;
-            try (InputStream inputStream = resource.getInputStream())
-            {
-                setConfig(__parser.parse(inputStream));
-            }
-            _dtd = __parser.getDTD();
+            setConfig(parser.parse(inputStream));
+            _dtd = parser.getDTD();
         }
     }
 
@@ -230,15 +257,12 @@ public class XmlConfiguration
         configuration = "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n" +
             "<!DOCTYPE Configure PUBLIC \"-//Jetty//Configure//EN\" \"http://www.eclipse.org/jetty/configure_9_3.dtd\">" +
             configuration;
-        try (StringReader reader = new StringReader(configuration))
+        try (ConfigurationParser parser = getParser(); StringReader reader = new StringReader(configuration))
         {
             InputSource source = new InputSource(reader);
-            synchronized (__parser)
-            {
-                _location = null;
-                setConfig(__parser.parse(source));
-                _dtd = __parser.getDTD();
-            }
+            _location = null;
+            setConfig(parser.parse(source));
+            _dtd = parser.getDTD();
         }
     }
 
@@ -254,11 +278,11 @@ public class XmlConfiguration
     public XmlConfiguration(InputStream configuration) throws SAXException, IOException
     {
         InputSource source = new InputSource(configuration);
-        synchronized (__parser)
+        try (ConfigurationParser parser = getParser())
         {
             _location = null;
-            setConfig(__parser.parse(source));
-            _dtd = __parser.getDTD();
+            setConfig(parser.parse(source));
+            _dtd = parser.getDTD();
         }
     }
 
@@ -351,6 +375,8 @@ public class XmlConfiguration
      */
     public Object configure() throws Exception
     {
+        if (LOG.isDebugEnabled())
+            LOG.debug("Configure {}", _location);
         return _processor.configure();
     }
 
@@ -397,7 +423,12 @@ public class XmlConfiguration
             String id = _root.getAttribute("id");
             if (id != null)
                 _configuration.getIdMap().put(id, obj);
-            configure(obj, _root, 0);
+
+            AttrOrElementNode aoeNode = new AttrOrElementNode(obj, _root, "Arg");
+            // The Object already existed, if it has <Arg> nodes, warn about them not being used.
+            aoeNode.getNodes("Arg")
+                .forEach((node) -> LOG.warn("Ignored arg {} in {}", node, this._configuration._location));
+            configure(obj, _root, aoeNode.getNext());
             return obj;
         }
 
@@ -409,49 +440,32 @@ public class XmlConfiguration
             String id = _root.getAttribute("id");
             Object obj = id == null ? null : _configuration.getIdMap().get(id);
 
-            int index = 0;
+            AttrOrElementNode aoeNode;
+
             if (obj == null && oClass != null)
             {
-                index = _root.size();
-                Map<String, Object> namedArgMap = new HashMap<>();
-
-                List<Object> arguments = new LinkedList<>();
-                for (int i = 0; i < _root.size(); i++)
-                {
-                    Object o = _root.get(i);
-                    if (o instanceof String)
-                        continue;
-
-                    XmlParser.Node node = (XmlParser.Node)o;
-                    if (node.getTag().equals("Arg"))
-                    {
-                        String namedAttribute = node.getAttribute("name");
-                        Object value = value(null, (XmlParser.Node)o);
-                        if (namedAttribute != null)
-                            namedArgMap.put(namedAttribute, value);
-                        arguments.add(value);
-                    }
-                    else
-                    {
-                        index = i;
-                        break;
-                    }
-                }
-
+                aoeNode = new AttrOrElementNode(_root, "Arg");
                 try
                 {
-                    obj = construct(oClass, arguments.toArray(), namedArgMap);
+                    obj = construct(oClass, new Args(null, oClass, aoeNode.getNodes("Arg")));
                 }
                 catch (NoSuchMethodException x)
                 {
-                    throw new IllegalStateException(String.format("No constructor %s(%s,%s) in %s", oClass, arguments, namedArgMap, _configuration));
+                    throw new IllegalStateException(String.format("No matching constructor %s in %s", oClass, _configuration));
                 }
             }
+            else
+            {
+                aoeNode = new AttrOrElementNode(obj, _root, "Arg");
+                // The Object already existed, if it has <Arg> nodes, warn about them not being used.
+                aoeNode.getNodes("Arg")
+                    .forEach((node) -> LOG.warn("Ignored arg {} in {}", node, this._configuration._location));
+            }
             if (id != null)
                 _configuration.getIdMap().put(id, obj);
 
             _configuration.initializeDefaults(obj);
-            configure(obj, _root, index);
+            configure(obj, _root, aoeNode.getNext());
             return obj;
         }
 
@@ -474,21 +488,6 @@ public class XmlConfiguration
          */
         public void configure(Object obj, XmlParser.Node cfg, int i) throws Exception
         {
-            // Object already constructed so skip any arguments
-            for (; i < cfg.size(); i++)
-            {
-                Object o = cfg.get(i);
-                if (o instanceof String)
-                    continue;
-                XmlParser.Node node = (XmlParser.Node)o;
-                if ("Arg".equals(node.getTag()))
-                {
-                    LOG.warn("Ignored arg: " + node);
-                    continue;
-                }
-                break;
-            }
-
             // Process real arguments
             for (; i < cfg.size(); i++)
             {
@@ -502,6 +501,10 @@ public class XmlConfiguration
                     String tag = node.getTag();
                     switch (tag)
                     {
+                        case "Arg":
+                        case "Class":
+                        case "Id":
+                            throw new IllegalStateException("Element '" + tag + "' not skipped");
                         case "Set":
                             set(obj, node);
                             break;
@@ -916,7 +919,6 @@ public class XmlConfiguration
             String id = aoeNode.getString("Id");
             String name = aoeNode.getString("Name");
             String clazz = aoeNode.getString("Class");
-            List<Object> args = aoeNode.getList("Arg");
 
             Class<?> oClass;
             if (clazz != null)
@@ -937,7 +939,7 @@ public class XmlConfiguration
 
             try
             {
-                Object nobj = call(oClass, name, obj, args.toArray(new Object[0]));
+                Object nobj = call(oClass, name, obj, new Args(obj, oClass, aoeNode.getNodes("Arg")));
                 if (id != null)
                     _configuration.getIdMap().put(id, nobj);
                 configure(nobj, node, aoeNode.getNext());
@@ -949,7 +951,7 @@ public class XmlConfiguration
             }
         }
 
-        private Object call(Class<?> oClass, String methodName, Object obj, Object[] arg) throws InvocationTargetException, NoSuchMethodException
+        private Object call(Class<?> oClass, String methodName, Object obj, Args args) throws InvocationTargetException, NoSuchMethodException
         {
             Objects.requireNonNull(oClass, "Class cannot be null");
             Objects.requireNonNull(methodName, "Method name cannot be null");
@@ -957,11 +959,15 @@ public class XmlConfiguration
                 throw new IllegalArgumentException("Method name cannot be blank");
 
             // Lets just try all methods for now
-            for (Method method : oClass.getMethods())
+
+            Method[] methods = oClass.getMethods();
+            Arrays.sort(methods, EXECUTABLE_COMPARATOR);
+            for (Method method : methods)
             {
                 if (!method.getName().equals(methodName))
                     continue;
-                if (method.getParameterCount() != arg.length)
+                Object[] arguments = args.applyTo(method);
+                if (arguments == null)
                     continue;
                 if (Modifier.isStatic(method.getModifiers()) != (obj == null))
                     continue;
@@ -970,34 +976,7 @@ public class XmlConfiguration
 
                 try
                 {
-                    return invokeMethod(method, obj, arg);
-                }
-                catch (IllegalAccessException | IllegalArgumentException e)
-                {
-                    LOG.ignore(e);
-                }
-            }
-
-            // Lets look for a method with varargs arguments
-            Object[] argsWithVarargs = null;
-            for (Method method : oClass.getMethods())
-            {
-                if (!method.getName().equals(methodName))
-                    continue;
-                if (method.getParameterCount() != arg.length + 1)
-                    continue;
-                if (!method.getParameterTypes()[arg.length].isArray())
-                    continue;
-                if (Modifier.isStatic(method.getModifiers()) != (obj == null))
-                    continue;
-                if ((obj == null) && method.getDeclaringClass() != oClass)
-                    continue;
-
-                if (argsWithVarargs == null)
-                    argsWithVarargs = ArrayUtil.addToArray(arg, new Object[0], Object.class);
-                try
-                {
-                    return invokeMethod(method, obj, argsWithVarargs);
+                    return invokeMethod(method, obj, arguments);
                 }
                 catch (IllegalAccessException | IllegalArgumentException e)
                 {
@@ -1020,33 +999,16 @@ public class XmlConfiguration
             AttrOrElementNode aoeNode = new AttrOrElementNode(obj, node, "Id", "Class", "Arg");
             String id = aoeNode.getString("Id");
             String clazz = aoeNode.getString("Class");
-            List<XmlParser.Node> argNodes = aoeNode.getNodes("Arg");
 
             if (LOG.isDebugEnabled())
                 LOG.debug("XML new " + clazz);
 
             Class<?> oClass = Loader.loadClass(clazz);
 
-            // Find the <Arg> elements
-            Map<String, Object> namedArgMap = new HashMap<>();
-            List<Object> arguments = new LinkedList<>();
-            for (XmlParser.Node child : argNodes)
-            {
-                String namedAttribute = child.getAttribute("name");
-                Object value = value(obj, child);
-                if (namedAttribute != null)
-                {
-                    // named arguments
-                    namedArgMap.put(namedAttribute, value);
-                }
-                // raw arguments
-                arguments.add(value);
-            }
-
             Object nobj;
             try
             {
-                nobj = construct(oClass, arguments.toArray(), namedArgMap);
+                nobj = construct(oClass, new Args(obj, oClass, aoeNode.getNodes("Arg")));
             }
             catch (NoSuchMethodException e)
             {
@@ -1061,80 +1023,20 @@ public class XmlConfiguration
             return nobj;
         }
 
-        private Object construct(Class<?> klass, Object[] arguments, Map<String, Object> namedArgMap) throws InvocationTargetException, NoSuchMethodException
+        private Object construct(Class<?> klass, Args args) throws InvocationTargetException, NoSuchMethodException
         {
             Objects.requireNonNull(klass, "Class cannot be null");
-            Objects.requireNonNull(namedArgMap, "Named Argument Map cannot be null");
+            Objects.requireNonNull(args, "Named list cannot be null");
 
-            for (Constructor<?> constructor : klass.getConstructors())
+            Constructor<?>[] constructors = klass.getConstructors();
+            Arrays.sort(constructors, EXECUTABLE_COMPARATOR);
+            for (Constructor<?> constructor : constructors)
             {
-                if (arguments == null)
-                {
-                    // null arguments in .newInstance() is allowed
-                    if (constructor.getParameterCount() != 0)
-                        continue;
-                }
-                else if (constructor.getParameterCount() != arguments.length)
-                {
-                    continue;
-                }
-
                 try
                 {
-                    if (arguments == null || arguments.length == 0)
-                    {
-                        if (LOG.isDebugEnabled())
-                            LOG.debug("Invoking constructor, no arguments");
-                        return invokeConstructor(constructor);
-                    }
-
-                    if (namedArgMap.isEmpty())
-                    {
-                        if (LOG.isDebugEnabled())
-                            LOG.debug("Invoking constructor, no XML parameter mapping");
+                    Object[] arguments = args.applyTo(constructor);
+                    if (arguments != null)
                         return invokeConstructor(constructor, arguments);
-                    }
-
-                    Annotation[][] parameterAnnotations = constructor.getParameterAnnotations();
-                    if (parameterAnnotations == null || parameterAnnotations.length == 0)
-                    {
-                        if (LOG.isDebugEnabled())
-                            LOG.debug("Invoking constructor, no parameter annotations");
-                        return invokeConstructor(constructor, arguments);
-                    }
-
-                    int count = 0;
-                    Object[] swizzled = new Object[arguments.length];
-                    for (Annotation[] annotations : parameterAnnotations)
-                    {
-                        for (Annotation annotation : annotations)
-                        {
-                            if (annotation instanceof Name)
-                            {
-                                Name param = (Name)annotation;
-                                if (namedArgMap.containsKey(param.value()))
-                                {
-                                    if (LOG.isDebugEnabled())
-                                        LOG.debug("Mapping named parameter {} in position {}", param.value(), count);
-                                    swizzled[count] = namedArgMap.get(param.value());
-                                }
-                                else
-                                {
-                                    if (LOG.isDebugEnabled())
-                                        LOG.debug("Mapping argument {} in position {}", arguments[count], count);
-                                    swizzled[count] = arguments[count];
-                                }
-                                ++count;
-                            }
-                            else
-                            {
-                                if (LOG.isDebugEnabled())
-                                    LOG.debug("Skipping parameter annotated with {}", annotation);
-                            }
-                        }
-                    }
-
-                    return invokeConstructor(constructor, swizzled);
                 }
                 catch (InstantiationException | IllegalAccessException | IllegalArgumentException e)
                 {
@@ -1777,40 +1679,158 @@ public class XmlConfiguration
 
             public List<XmlParser.Node> getNodes(String elementName)
             {
-                String attrName = StringUtil.asciiToLowerCase(elementName);
-                final List<XmlParser.Node> values = new ArrayList<>();
-
-                String attr = _node.getAttribute(attrName);
-                if (attr != null)
-                {
-                    for (String a : StringUtil.csvSplit(null, attr, 0, attr.length()))
-                    {
-                        // create a fake node
-                        XmlParser.Node n = new XmlParser.Node(null, elementName, null);
-                        n.add(a);
-                        values.add(n);
-                    }
-                }
-
-                for (int i = 0; i < _next; i++)
-                {
-                    Object o = _node.get(i);
-                    if (!(o instanceof XmlParser.Node))
-                        continue;
-                    XmlParser.Node n = (XmlParser.Node)o;
-
-                    if (elementName.equals(n.getTag()))
-                    {
-                        if (attr != null)
-                            throw new IllegalStateException("Cannot have attr '" + attrName + "' and element '" + elementName + "'");
-
-                        values.add(n);
-                    }
-                }
-
-                return values;
+                return XmlConfiguration.getNodes(_node, elementName);
             }
         }
+
+        private class Args
+        {
+            private final Class<?> _class;
+            private final List<Object> _arguments;
+            private final List<String> _names;
+
+            private Args(Object obj, Class<?> oClass, List<XmlParser.Node> args) throws Exception
+            {
+                _class = oClass;
+                _arguments = new ArrayList<>();
+                _names = new ArrayList<>();
+                for (XmlParser.Node child : args)
+                {
+                    _arguments.add(value(obj, child));
+                    _names.add(child.getAttribute("name"));
+                }
+            }
+
+            private Args(List<Object> arguments, List<String> names)
+            {
+                _class = null;
+                _arguments = arguments;
+                _names = names;
+            }
+
+            Object[] applyTo(Executable executable)
+            {
+                Object[] args = matchArgsToParameters(executable);
+                if (args == null && _class != null)
+                {
+                    // Could this be an empty varargs match?
+                    int count = executable.getParameterCount();
+                    if (count > 0 && executable.getParameters()[count - 1].isVarArgs())
+                    {
+                        // There is not a no varArgs alternative so let's try a an empty varArgs match
+                        args = asEmptyVarArgs(executable.getParameterTypes()[count - 1]).matchArgsToParameters(executable);
+                    }
+                }
+                return args;
+            }
+
+            Args asEmptyVarArgs(Class<?> varArgType)
+            {
+                List<Object> arguments = new ArrayList<>(_arguments);
+                arguments.add(Array.newInstance(varArgType.getComponentType(), 0));
+                List<String> names = new ArrayList<>(_names);
+                names.add(null);
+                return new Args(arguments, names);
+            }
+
+            Object[] matchArgsToParameters(Executable executable)
+            {
+                int count = executable.getParameterCount();
+
+                // No match of wrong number of parameters
+                if (count != _arguments.size())
+                    return null;
+
+                // Handle no parameter case
+                if (count == 0)
+                    return new Object[0];
+
+                // If no arg names are specified, keep the arg order
+                Object[] args;
+                if (_names.stream().noneMatch(Objects::nonNull))
+                {
+                    args = _arguments.toArray(new Object[0]);
+                }
+                else
+                {
+                    // If we don't have any parameters with names, then no match
+                    Annotation[][] parameterAnnotations = executable.getParameterAnnotations();
+                    if (parameterAnnotations == null || parameterAnnotations.length == 0)
+                        return null;
+
+                    // Find the position of all named parameters from the executable
+                    Map<String, Integer> position = new HashMap<>();
+                    int p = 0;
+                    for (Annotation[] paramAnnotation : parameterAnnotations)
+                    {
+                        Integer pos = p++;
+                        Arrays.stream(paramAnnotation)
+                            .filter(Name.class::isInstance)
+                            .map(Name.class::cast)
+                            .findFirst().ifPresent(n -> position.put(n.value(), pos));
+                    }
+
+                    List<Object> arguments = new ArrayList<>(_arguments);
+                    List<String> names = new ArrayList<>(_names);
+                    // Map the actual arguments to the names
+                    for (p = 0; p < count; p++)
+                    {
+                        String name = names.get(p);
+                        if (name != null)
+                        {
+                            Integer pos = position.get(name);
+                            if (pos == null)
+                                return null;
+                            if (pos != p)
+                            {
+                                // adjust position of parameter
+                                arguments.add(pos, arguments.remove(p));
+                                names.add(pos, names.remove(p));
+                                p = Math.min(p, pos);
+                            }
+                        }
+                    }
+                    args = arguments.toArray(new Object[0]);
+                }
+
+                return args;
+            }
+        }
+    }
+
+    private static List<XmlParser.Node> getNodes(XmlParser.Node node, String elementName)
+    {
+        String attrName = StringUtil.asciiToLowerCase(elementName);
+        final List<XmlParser.Node> values = new ArrayList<>();
+
+        String attr = node.getAttribute(attrName);
+        if (attr != null)
+        {
+            for (String a : StringUtil.csvSplit(null, attr, 0, attr.length()))
+            {
+                // create a fake node
+                XmlParser.Node n = new XmlParser.Node(null, elementName, null);
+                n.add(a);
+                values.add(n);
+            }
+        }
+
+        for (Object o : node)
+        {
+            if (!(o instanceof XmlParser.Node))
+                continue;
+            XmlParser.Node n = (XmlParser.Node)o;
+
+            if (elementName.equals(n.getTag()))
+            {
+                if (attr != null)
+                    throw new IllegalStateException("Cannot have attr '" + attrName + "' and element '" + elementName + "'");
+
+                values.add(n);
+            }
+        }
+
+        return values;
     }
 
     /**
@@ -1858,16 +1878,15 @@ public class XmlConfiguration
                 {
                     if (!arg.toLowerCase(Locale.ENGLISH).endsWith(".properties") && (arg.indexOf('=') < 0))
                     {
-                        XmlConfiguration configuration = new XmlConfiguration(Resource.newResource(arg).getURI().toURL());
+                        XmlConfiguration configuration = new XmlConfiguration(Resource.newResource(arg));
                         if (last != null)
                             configuration.getIdMap().putAll(last.getIdMap());
                         if (properties.size() > 0)
                         {
                             Map<String, String> props = new HashMap<>();
-                            for (Object key : properties.keySet())
-                            {
-                                props.put(key.toString(), String.valueOf(properties.get(key)));
-                            }
+                            properties.entrySet().stream()
+                                .forEach(objectObjectEntry -> props.put(objectObjectEntry.getKey().toString(),
+                                                                        String.valueOf(objectObjectEntry.getValue())));
                             configuration.getProperties().putAll(props);
                         }
 
@@ -1898,4 +1917,42 @@ public class XmlConfiguration
             throw e;
         }
     }
+
+    private static class ConfigurationParser extends XmlParser implements AutoCloseable
+    {
+        private final Pool<ConfigurationParser>.Entry _entry;
+
+        private ConfigurationParser(Pool<ConfigurationParser>.Entry entry)
+        {
+            _entry = entry;
+            ClassLoader loader = XmlConfiguration.class.getClassLoader();
+            URL config60 = loader.getResource("org/eclipse/jetty/xml/configure_6_0.dtd");
+            URL config76 = loader.getResource("org/eclipse/jetty/xml/configure_7_6.dtd");
+            URL config90 = loader.getResource("org/eclipse/jetty/xml/configure_9_0.dtd");
+            URL config93 = loader.getResource("org/eclipse/jetty/xml/configure_9_3.dtd");
+            redirectEntity("configure.dtd", config90);
+            redirectEntity("configure_1_0.dtd", config60);
+            redirectEntity("configure_1_1.dtd", config60);
+            redirectEntity("configure_1_2.dtd", config60);
+            redirectEntity("configure_1_3.dtd", config60);
+            redirectEntity("configure_6_0.dtd", config60);
+            redirectEntity("configure_7_6.dtd", config76);
+            redirectEntity("configure_9_0.dtd", config90);
+            redirectEntity("configure_9_3.dtd", config93);
+            redirectEntity("http://jetty.mortbay.org/configure.dtd", config93);
+            redirectEntity("http://jetty.eclipse.org/configure.dtd", config93);
+            redirectEntity("https://jetty.eclipse.org/configure.dtd", config93);
+            redirectEntity("http://www.eclipse.org/jetty/configure.dtd", config93);
+            redirectEntity("https://www.eclipse.org/jetty/configure.dtd", config93);
+            redirectEntity("-//Mort Bay Consulting//DTD Configure//EN", config93);
+            redirectEntity("-//Jetty//Configure//EN", config93);
+        }
+
+        @Override
+        public void close()
+        {
+            if (_entry != null)
+                __parsers.release(_entry);
+        }
+    }
 }
