@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -41,6 +41,18 @@ public class AnnotatedTestConfiguration
     {
     }
 
+    public AnnotatedTestConfiguration(Integer test)
+    {
+        // exists to make constructor matching harder
+        throw new UnsupportedOperationException("Should not be called");
+    }
+
+    public AnnotatedTestConfiguration(Integer one, Integer two, Integer three)
+    {
+        // exists to make constructor matching harder
+        throw new UnsupportedOperationException("Should not be called");
+    }
+
     public AnnotatedTestConfiguration(@Name("first") String first, @Name("second") String second, @Name("third") String third)
     {
         this.first = first;
@@ -48,6 +60,53 @@ public class AnnotatedTestConfiguration
         this.third = third;
     }
 
+    public AnnotatedTestConfiguration(Long one, Long two, Long three)
+    {
+        // exists to make constructor matching harder
+        throw new UnsupportedOperationException("Should not be called");
+    }
+
+    public void setAll(Integer one, Integer two, Integer three)
+    {
+        // exists to make method matching harder
+        throw new UnsupportedOperationException("Should not be called");
+    }
+
+    public void setAll(@Name("first") String first, @Name("second") String second, @Name("third") String third)
+    {
+        this.first = first;
+        this.second = second;
+        this.third = third;
+    }
+
+    public void setAll(long one, long two, long three)
+    {
+        // exists to make method matching harder
+        throw new UnsupportedOperationException("Should not be called");
+    }
+
+    public void setVarArgs(String first, String... theRest)
+    {
+        this.first = first;
+        this.second = theRest.length > 0 ? theRest[0] : null;
+        this.third = theRest.length > 1 ? theRest[1] : null;
+    }
+
+    public void call(Integer value)
+    {
+        this.first = String.valueOf(value);
+    }
+
+    public void call(String value)
+    {
+        this.second = value;
+    }
+
+    public <E> void call(E value)
+    {
+        this.third = String.valueOf(value);
+    }
+
     public String getFirst()
     {
         return first;
