@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -29,7 +29,7 @@ import java.util.Set;
 import org.eclipse.jetty.util.annotation.Name;
 import org.junit.jupiter.api.Disabled;
 
-@Disabled
+@Disabled("Not a test case")
 public class TestConfiguration extends HashMap<String, Object>
 {
     public static int VALUE = 77;
@@ -54,6 +54,7 @@ public class TestConfiguration extends HashMap<String, Object>
     private Set set;
     private ConstructorArgTestClass constructorArgTestClass;
     public Map map;
+    public Double number;
 
     public TestConfiguration()
     {
@@ -65,6 +66,16 @@ public class TestConfiguration extends HashMap<String, Object>
         name = n;
     }
 
+    public void setNumber(Object value)
+    {
+        testObject = value;
+    }
+
+    public void setNumber(double value)
+    {
+        number = value;
+    }
+
     public void setTest(Object value)
     {
         testObject = value;
