@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -57,6 +57,7 @@ import org.eclipse.jetty.util.ssl.SslContextFactory;
 import org.junit.jupiter.api.Assumptions;
 import org.junit.jupiter.params.ParameterizedTest;
 import org.junit.jupiter.params.provider.ArgumentsSource;
+import org.opentest4j.TestAbortedException;
 
 import static org.eclipse.jetty.http.client.Transport.UNIX_SOCKET;
 import static org.junit.jupiter.api.Assertions.assertArrayEquals;
@@ -509,7 +510,7 @@ public class HttpClientTimeoutTest extends AbstractTest<TransportScenario>
             // connect to them will hang the connection attempt, which is
             // what we want to simulate in this test.
             socket.connect(new InetSocketAddress(host, port), connectTimeout);
-            // Abort the test if we can connect.
+            // Fail the test if we can connect.
             fail("Error: Should not have been able to connect to " + host + ":" + port);
         }
         catch (SocketTimeoutException x)
@@ -520,7 +521,7 @@ public class HttpClientTimeoutTest extends AbstractTest<TransportScenario>
         catch (Throwable x)
         {
             // Abort if any other exception happens.
-            fail(x);
+            throw new TestAbortedException("Not able to validate connect timeout conditions", x);
         }
     }
 
