@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2019 Mort Bay Consulting Pty. Ltd.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -18,18 +18,6 @@
 
 package org.eclipse.jetty.http.client;
 
-import static org.eclipse.jetty.http.client.Transport.FCGI;
-import static org.eclipse.jetty.http.client.Transport.UNIX_SOCKET;
-import static org.hamcrest.Matchers.containsString;
-import static org.hamcrest.Matchers.instanceOf;
-import static org.hamcrest.Matchers.is;
-import static org.junit.Assert.assertThat;
-import static org.junit.jupiter.api.Assertions.assertArrayEquals;
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-
 import java.io.IOException;
 import java.io.InterruptedIOException;
 import java.nio.ByteBuffer;
@@ -39,7 +27,6 @@ import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.LinkedBlockingQueue;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.TimeoutException;
-
 import javax.servlet.AsyncContext;
 import javax.servlet.ReadListener;
 import javax.servlet.ServletException;
@@ -69,6 +56,17 @@ import org.junit.jupiter.api.Assumptions;
 import org.junit.jupiter.params.ParameterizedTest;
 import org.junit.jupiter.params.provider.ArgumentsSource;
 
+import static org.eclipse.jetty.http.client.Transport.FCGI;
+import static org.hamcrest.MatcherAssert.assertThat;
+import static org.hamcrest.Matchers.containsString;
+import static org.hamcrest.Matchers.instanceOf;
+import static org.hamcrest.Matchers.is;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
 {
     @Override
@@ -155,7 +153,6 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
                         asyncContext.complete();
                     }
                 });
-
             }
         }, delayDispatch);
     }
@@ -185,14 +182,14 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
         CountDownLatch resultLatch = new CountDownLatch(2);
         DeferredContentProvider content = new DeferredContentProvider();
         scenario.client.POST(scenario.newURI())
-                .content(content)
-                .onResponseSuccess(response ->
-                {
-                    if (response.getStatus() == HttpStatus.INTERNAL_SERVER_ERROR_500)
-                        resultLatch.countDown();
-                    content.close();
-                })
-                .send(result -> resultLatch.countDown());
+            .content(content)
+            .onResponseSuccess(response ->
+            {
+                if (response.getStatus() == HttpStatus.INTERNAL_SERVER_ERROR_500)
+                    resultLatch.countDown();
+                content.close();
+            })
+            .send(result -> resultLatch.countDown());
 
         // The client did not send the content, the request was
         // dispatched, the server should have idle timed it out.
@@ -216,12 +213,12 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
             DeferredContentProvider contentProvider = new DeferredContentProvider(ByteBuffer.allocate(1));
             CountDownLatch resultLatch = new CountDownLatch(1);
             scenario.client.POST(scenario.newURI())
-                    .content(contentProvider)
-                    .send(result ->
-                    {
-                        if (result.getResponse().getStatus() == HttpStatus.INTERNAL_SERVER_ERROR_500)
-                            resultLatch.countDown();
-                    });
+                .content(contentProvider)
+                .send(result ->
+                {
+                    if (result.getResponse().getStatus() == HttpStatus.INTERNAL_SERVER_ERROR_500)
+                        resultLatch.countDown();
+                });
 
             // Blocking read should timeout.
             assertTrue(handlerLatch.await(2 * idleTimeout, TimeUnit.MILLISECONDS));
@@ -248,12 +245,12 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
             DeferredContentProvider contentProvider = new DeferredContentProvider(ByteBuffer.allocate(1));
             CountDownLatch resultLatch = new CountDownLatch(1);
             scenario.client.POST(scenario.newURI())
-                    .content(contentProvider)
-                    .send(result ->
-                    {
-                        if (result.getResponse().getStatus() == HttpStatus.INTERNAL_SERVER_ERROR_500)
-                            resultLatch.countDown();
-                    });
+                .content(contentProvider)
+                .send(result ->
+                {
+                    if (result.getResponse().getStatus() == HttpStatus.INTERNAL_SERVER_ERROR_500)
+                        resultLatch.countDown();
+                });
 
             // Blocking read should timeout.
             assertTrue(handlerLatch.await(2 * blockingTimeout, TimeUnit.MILLISECONDS));
@@ -280,12 +277,12 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
             DeferredContentProvider contentProvider = new DeferredContentProvider(ByteBuffer.allocate(1));
             CountDownLatch resultLatch = new CountDownLatch(1);
             scenario.client.POST(scenario.newURI())
-                    .content(contentProvider)
-                    .send(result ->
-                    {
-                        if (result.getResponse().getStatus() == HttpStatus.INTERNAL_SERVER_ERROR_500)
-                            resultLatch.countDown();
-                    });
+                .content(contentProvider)
+                .send(result ->
+                {
+                    if (result.getResponse().getStatus() == HttpStatus.INTERNAL_SERVER_ERROR_500)
+                        resultLatch.countDown();
+                });
 
             // Blocking read should timeout.
             assertTrue(handlerLatch.await(2 * idleTimeout, TimeUnit.MILLISECONDS));
@@ -311,16 +308,16 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
             BlockingQueue<Callback> callbacks = new LinkedBlockingQueue<>();
             CountDownLatch resultLatch = new CountDownLatch(1);
             scenario.client.newRequest(scenario.newURI())
-                    .onResponseContentAsync((response, content, callback) ->
-                    {
-                        // Do not succeed the callback so the server will block writing.
-                        callbacks.offer(callback);
-                    })
-                    .send(result ->
-                    {
-                        if (result.isFailed())
-                            resultLatch.countDown();
-                    });
+                .onResponseContentAsync((response, content, callback) ->
+                {
+                    // Do not succeed the callback so the server will block writing.
+                    callbacks.offer(callback);
+                })
+                .send(result ->
+                {
+                    if (result.isFailed())
+                        resultLatch.countDown();
+                });
 
             // Blocking write should timeout.
             assertTrue(handlerLatch.await(2 * idleTimeout, TimeUnit.MILLISECONDS));
@@ -353,16 +350,16 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
             BlockingQueue<Callback> callbacks = new LinkedBlockingQueue<>();
             CountDownLatch resultLatch = new CountDownLatch(1);
             scenario.client.newRequest(scenario.newURI())
-                    .onResponseContentAsync((response, content, callback) ->
-                    {
-                        // Do not succeed the callback so the server will block writing.
-                        callbacks.offer(callback);
-                    })
-                    .send(result ->
-                    {
-                        if (result.isFailed())
-                            resultLatch.countDown();
-                    });
+                .onResponseContentAsync((response, content, callback) ->
+                {
+                    // Do not succeed the callback so the server will block writing.
+                    callbacks.offer(callback);
+                })
+                .send(result ->
+                {
+                    if (result.isFailed())
+                        resultLatch.countDown();
+                });
 
             // Blocking write should timeout.
             assertTrue(handlerLatch.await(2 * blockingTimeout, TimeUnit.MILLISECONDS));
@@ -395,16 +392,16 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
             BlockingQueue<Callback> callbacks = new LinkedBlockingQueue<>();
             CountDownLatch resultLatch = new CountDownLatch(1);
             scenario.client.newRequest(scenario.newURI())
-                    .onResponseContentAsync((response, content, callback) ->
-                    {
-                        // Do not succeed the callback so the server will block writing.
-                        callbacks.offer(callback);
-                    })
-                    .send(result ->
-                    {
-                        if (result.isFailed())
-                            resultLatch.countDown();
-                    });
+                .onResponseContentAsync((response, content, callback) ->
+                {
+                    // Do not succeed the callback so the server will block writing.
+                    callbacks.offer(callback);
+                })
+                .send(result ->
+                {
+                    if (result.isFailed())
+                        resultLatch.countDown();
+                });
 
             // Blocking read should timeout.
             assertTrue(handlerLatch.await(2 * idleTimeout, TimeUnit.MILLISECONDS));
@@ -429,10 +426,10 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
         long blockingTimeout = 2 * idleTimeout;
         scenario.httpConfig.setBlockingTimeout(blockingTimeout);
         CountDownLatch handlerLatch = new CountDownLatch(1);
-        scenario.start(new AbstractHandler.ErrorDispatchHandler()
+        scenario.start(new AbstractHandler()
         {
             @Override
-            protected void doNonErrorHandle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response) throws IOException
+            public void handle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response) throws IOException
             {
                 try
                 {
@@ -459,14 +456,14 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
             DeferredContentProvider contentProvider = new DeferredContentProvider();
             CountDownLatch resultLatch = new CountDownLatch(1);
             scenario.client.newRequest(scenario.newURI())
-                    .content(contentProvider)
-                    .send(result ->
-                    {
-                        // Result may fail to send the whole request body,
-                        // but the response has arrived successfully.
-                        if (result.getResponse().getStatus() == HttpStatus.INTERNAL_SERVER_ERROR_500)
-                            resultLatch.countDown();
-                    });
+                .content(contentProvider)
+                .send(result ->
+                {
+                    // Result may fail to send the whole request body,
+                    // but the response has arrived successfully.
+                    if (result.getResponse().getStatus() == HttpStatus.INTERNAL_SERVER_ERROR_500)
+                        resultLatch.countDown();
+                });
 
             // The writes should be slow but not trigger the idle timeout.
             long period = idleTimeout / 2;
@@ -490,10 +487,10 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
     {
         init(transport);
         CountDownLatch handlerLatch = new CountDownLatch(1);
-        scenario.start(new AbstractHandler.ErrorDispatchHandler()
+        scenario.start(new AbstractHandler()
         {
             @Override
-            protected void doNonErrorHandle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response) throws IOException
+            public void handle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response) throws IOException
             {
                 baseRequest.setHandled(true);
                 AsyncContext asyncContext = request.startAsync();
@@ -533,12 +530,12 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
         DeferredContentProvider contentProvider = new DeferredContentProvider(ByteBuffer.allocate(1));
         CountDownLatch resultLatch = new CountDownLatch(1);
         scenario.client.POST(scenario.newURI())
-                .content(contentProvider)
-                .send(result ->
-                {
-                    if (result.getResponse().getStatus() == HttpStatus.INTERNAL_SERVER_ERROR_500)
-                        resultLatch.countDown();
-                });
+            .content(contentProvider)
+            .send(result ->
+            {
+                if (result.getResponse().getStatus() == HttpStatus.INTERNAL_SERVER_ERROR_500)
+                    resultLatch.countDown();
+            });
 
         // Async read should timeout.
         assertTrue(handlerLatch.await(2 * idleTimeout, TimeUnit.MILLISECONDS));
@@ -552,14 +549,12 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
     public void testAsyncWriteIdleTimeoutFires(Transport transport) throws Exception
     {
         init(transport);
-        // TODO work out why this test fails for UNIX_SOCKET
-        Assumptions.assumeFalse(scenario.transport == UNIX_SOCKET);
 
         CountDownLatch handlerLatch = new CountDownLatch(1);
-        scenario.start(new AbstractHandler.ErrorDispatchHandler()
+        scenario.start(new AbstractHandler()
         {
             @Override
-            protected void doNonErrorHandle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response) throws IOException
+            public void handle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response) throws IOException
             {
                 baseRequest.setHandled(true);
                 AsyncContext asyncContext = request.startAsync();
@@ -591,16 +586,16 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
         BlockingQueue<Callback> callbacks = new LinkedBlockingQueue<>();
         CountDownLatch resultLatch = new CountDownLatch(1);
         scenario.client.newRequest(scenario.newURI())
-                .onResponseContentAsync((response, content, callback) ->
-                {
-                    // Do not succeed the callback so the server will block writing.
-                    callbacks.offer(callback);
-                })
-                .send(result ->
-                {
-                    if (result.isFailed())
-                        resultLatch.countDown();
-                });
+            .onResponseContentAsync((response, content, callback) ->
+            {
+                // Do not succeed the callback so the server will block writing.
+                callbacks.offer(callback);
+            })
+            .send(result ->
+            {
+                if (result.isFailed())
+                    resultLatch.countDown();
+            });
 
         // Async write should timeout.
         assertTrue(handlerLatch.await(2 * idleTimeout, TimeUnit.MILLISECONDS));
@@ -624,10 +619,10 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
         scenario.requestLog.clear();
         scenario.httpConfig.setMinRequestDataRate(bytesPerSecond);
         CountDownLatch handlerLatch = new CountDownLatch(1);
-        scenario.start(new AbstractHandler.ErrorDispatchHandler()
+        scenario.start(new AbstractHandler()
         {
             @Override
-            public void doNonErrorHandle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response) throws IOException
+            public void handle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response) throws IOException
             {
                 try
                 {
@@ -651,14 +646,14 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
         DeferredContentProvider contentProvider = new DeferredContentProvider();
         BlockingQueue<Object> results = new BlockingArrayQueue<>();
         scenario.client.newRequest(scenario.newURI())
-                .content(contentProvider)
-                .send(result ->
-                {
-                    if (result.isFailed())
-                        results.offer(result.getFailure());
-                    else
-                        results.offer(result.getResponse().getStatus());
-                });
+            .content(contentProvider)
+            .send(result ->
+            {
+                if (result.isFailed())
+                    results.offer(result.getFailure());
+                else
+                    results.offer(result.getResponse().getStatus());
+            });
 
         for (int i = 0; i < 3; ++i)
         {
@@ -667,7 +662,7 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
         }
         contentProvider.close();
 
-        assertThat(scenario.requestLog.poll(5,TimeUnit.SECONDS), containsString(" 408"));
+        assertThat(scenario.requestLog.poll(5, TimeUnit.SECONDS), containsString(" 408"));
 
         // Request should timeout.
         assertTrue(handlerLatch.await(5, TimeUnit.SECONDS));
@@ -675,9 +670,9 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
         Object result = results.poll(5, TimeUnit.SECONDS);
         assertNotNull(result);
         if (result instanceof Integer)
-            assertThat((Integer)result,is(408));
+            assertThat((Integer)result, is(408));
         else
-            assertThat(result,instanceOf(Throwable.class));
+            assertThat(result, instanceOf(Throwable.class));
     }
 
     @ParameterizedTest
@@ -688,10 +683,10 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
         int bytesPerSecond = 20;
         scenario.httpConfig.setMinRequestDataRate(bytesPerSecond);
         CountDownLatch handlerLatch = new CountDownLatch(1);
-        scenario.start(new AbstractHandler.ErrorDispatchHandler()
+        scenario.start(new AbstractHandler()
         {
             @Override
-            protected void doNonErrorHandle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response) throws IOException
+            public void handle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response) throws IOException
             {
                 baseRequest.setHandled(true);
                 ServletInputStream input = request.getInputStream();
@@ -708,12 +703,12 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
         DeferredContentProvider contentProvider = new DeferredContentProvider();
         CountDownLatch resultLatch = new CountDownLatch(1);
         scenario.client.newRequest(scenario.newURI())
-                .content(contentProvider)
-                .send(result ->
-                {
-                    if (result.getResponse().getStatus() == HttpStatus.OK_200)
-                        resultLatch.countDown();
-                });
+            .content(contentProvider)
+            .send(result ->
+            {
+                if (result.getResponse().getStatus() == HttpStatus.OK_200)
+                    resultLatch.countDown();
+            });
 
         for (int i = 0; i < 3; ++i)
         {
@@ -743,12 +738,12 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
             DeferredContentProvider contentProvider = new DeferredContentProvider(ByteBuffer.allocate(1));
             CountDownLatch resultLatch = new CountDownLatch(1);
             scenario.client.POST(scenario.newURI())
-                    .content(contentProvider)
-                    .send(result ->
-                    {
-                        if (result.getResponse().getStatus() == HttpStatus.INTERNAL_SERVER_ERROR_500)
-                            resultLatch.countDown();
-                    });
+                .content(contentProvider)
+                .send(result ->
+                {
+                    if (result.getResponse().getStatus() == HttpStatus.INTERNAL_SERVER_ERROR_500)
+                        resultLatch.countDown();
+                });
 
             // Blocking read should timeout.
             assertTrue(handlerLatch.await(2 * httpIdleTimeout, TimeUnit.MILLISECONDS));
@@ -767,10 +762,10 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
         long idleTimeout = 3 * httpIdleTimeout;
         scenario.httpConfig.setIdleTimeout(httpIdleTimeout);
         CountDownLatch handlerLatch = new CountDownLatch(1);
-        scenario.start(new AbstractHandler.ErrorDispatchHandler()
+        scenario.start(new AbstractHandler()
         {
             @Override
-            protected void doNonErrorHandle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response) throws IOException
+            public void handle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response) throws IOException
             {
                 baseRequest.setHandled(true);
                 AsyncContext asyncContext = request.startAsync();
@@ -809,12 +804,12 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
         DeferredContentProvider contentProvider = new DeferredContentProvider(ByteBuffer.allocate(1));
         CountDownLatch resultLatch = new CountDownLatch(1);
         scenario.client.POST(scenario.newURI())
-                .content(contentProvider)
-                .send(result ->
-                {
-                    if (result.getResponse().getStatus() == HttpStatus.INTERNAL_SERVER_ERROR_500)
-                        resultLatch.countDown();
-                });
+            .content(contentProvider)
+            .send(result ->
+            {
+                if (result.getResponse().getStatus() == HttpStatus.INTERNAL_SERVER_ERROR_500)
+                    resultLatch.countDown();
+            });
 
         // Async read should timeout.
         assertTrue(handlerLatch.await(2 * idleTimeout, TimeUnit.MILLISECONDS));
@@ -856,19 +851,19 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
         DeferredContentProvider content = new DeferredContentProvider(ByteBuffer.wrap(data1));
         CountDownLatch latch = new CountDownLatch(1);
         scenario.client.newRequest(scenario.newURI())
-                .path(scenario.servletPath)
-                .content(content)
-                .send(new BufferingResponseListener()
+            .path(scenario.servletPath)
+            .content(content)
+            .send(new BufferingResponseListener()
+            {
+                @Override
+                public void onComplete(Result result)
                 {
-                    @Override
-                    public void onComplete(Result result)
-                    {
-                        assertTrue(result.isSucceeded());
-                        assertEquals(HttpStatus.OK_200, result.getResponse().getStatus());
-                        assertArrayEquals(data, getContent());
-                        latch.countDown();
-                    }
-                });
+                    assertTrue(result.isSucceeded());
+                    assertEquals(HttpStatus.OK_200, result.getResponse().getStatus());
+                    assertArrayEquals(data, getContent());
+                    latch.countDown();
+                }
+            });
 
         // Wait for the server application to block reading.
         Thread.sleep(2 * idleTimeout);
@@ -922,18 +917,18 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
         BlockingQueue<Object> objects = new LinkedBlockingQueue<>();
         CountDownLatch clientLatch = new CountDownLatch(1);
         scenario.client.newRequest(scenario.newURI())
-                .onResponseContentAsync((response, content, callback) ->
-                {
-                    objects.offer(content.remaining());
-                    objects.offer(callback);
-                })
-                .send(result ->
-                {
-                    objects.offer(-1);
-                    objects.offer(Callback.NOOP);
-                    if (result.isFailed())
-                        clientLatch.countDown();
-                });
+            .onResponseContentAsync((response, content, callback) ->
+            {
+                objects.offer(content.remaining());
+                objects.offer(callback);
+            })
+            .send(result ->
+            {
+                objects.offer(-1);
+                objects.offer(Callback.NOOP);
+                if (result.isFailed())
+                    clientLatch.countDown();
+            });
 
         long readRate = bytesPerSecond / 2;
         while (true)
@@ -951,7 +946,7 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
         assertTrue(clientLatch.await(15, TimeUnit.SECONDS));
     }
 
-    private static class BlockingReadHandler extends AbstractHandler.ErrorDispatchHandler
+    private static class BlockingReadHandler extends AbstractHandler
     {
         private final CountDownLatch handlerLatch;
 
@@ -961,7 +956,7 @@ public class ServerTimeoutsTest extends AbstractTest<TransportScenario>
         }
 
         @Override
-        protected void doNonErrorHandle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response) throws IOException
+        public void handle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response) throws IOException
         {
             baseRequest.setHandled(true);
             ServletInputStream input = request.getInputStream();
