@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -19,30 +19,35 @@
 package org.eclipse.jetty.server.session;
 
 import org.eclipse.jetty.session.infinispan.InfinispanSessionDataStoreFactory;
-import org.junit.jupiter.api.AfterAll;
-import org.junit.jupiter.api.BeforeAll;
+import org.eclipse.jetty.toolchain.test.jupiter.WorkDir;
+import org.eclipse.jetty.toolchain.test.jupiter.WorkDirExtension;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.ExtendWith;
 
 /**
  * ClusteredSessionScavengingTest
  */
+@ExtendWith(WorkDirExtension.class)
 public class ClusteredSessionScavengingTest extends AbstractClusteredSessionScavengingTest
 {
-    public static InfinispanTestSupport __testSupport;
+    public WorkDir workDir;
+    public InfinispanTestSupport testSupport;
 
-    @BeforeAll
-    public static void setup() throws Exception
+    @BeforeEach
+    public void setup() throws Exception
     {
-        __testSupport = new InfinispanTestSupport();
-        __testSupport.setUseFileStore(true);
-        __testSupport.setup();
+        testSupport = new InfinispanTestSupport();
+        testSupport.setUseFileStore(true);
+        testSupport.setup(workDir.getEmptyPathDir());
     }
 
-    @AfterAll
-    public static void teardown() throws Exception
+    @AfterEach
+    public void teardown() throws Exception
     {
-        if (__testSupport != null)
-            __testSupport.teardown();
+        if (testSupport != null)
+            testSupport.teardown();
     }
 
     @Override
@@ -60,7 +65,7 @@ public class ClusteredSessionScavengingTest extends AbstractClusteredSessionScav
     public SessionDataStoreFactory createSessionDataStoreFactory()
     {
         InfinispanSessionDataStoreFactory factory = new InfinispanSessionDataStoreFactory();
-        factory.setCache(__testSupport.getCache());
+        factory.setCache(testSupport.getCache());
         return factory;
     }
 }
