@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -22,12 +22,15 @@ import org.eclipse.jetty.servlet.ServletContextHandler;
 import org.eclipse.jetty.session.infinispan.InfinispanSessionData;
 import org.eclipse.jetty.session.infinispan.InfinispanSessionDataStore;
 import org.eclipse.jetty.session.infinispan.InfinispanSessionDataStoreFactory;
+import org.eclipse.jetty.toolchain.test.jupiter.WorkDir;
+import org.eclipse.jetty.toolchain.test.jupiter.WorkDirExtension;
 import org.infinispan.query.Search;
 import org.infinispan.query.dsl.Query;
 import org.infinispan.query.dsl.QueryFactory;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.ExtendWith;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertThrows;
@@ -35,16 +38,19 @@ import static org.junit.jupiter.api.Assertions.assertThrows;
 /**
  * InfinispanSessionDataStoreTest
  */
+@ExtendWith(WorkDirExtension.class)
 public class InfinispanSessionDataStoreTest extends AbstractSessionDataStoreTest
 {
 
     public InfinispanTestSupport _testSupport;
 
+    public WorkDir workDir;
+
     @BeforeEach
     public void setup() throws Exception
     {
         _testSupport = new InfinispanTestSupport();
-        _testSupport.setup();
+        _testSupport.setup(workDir.getEmptyPathDir());
     }
 
     @AfterEach
