@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -31,31 +31,61 @@ import org.hibernate.search.cfg.Environment;
 import org.hibernate.search.cfg.SearchMapping;
 import org.infinispan.client.hotrod.RemoteCache;
 import org.infinispan.client.hotrod.RemoteCacheManager;
+import org.infinispan.client.hotrod.configuration.ClientIntelligence;
+import org.infinispan.client.hotrod.configuration.Configuration;
 import org.infinispan.client.hotrod.configuration.ConfigurationBuilder;
 import org.infinispan.client.hotrod.marshall.ProtoStreamMarshaller;
 import org.infinispan.protostream.FileDescriptorSource;
 import org.infinispan.protostream.SerializationContext;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import org.testcontainers.containers.GenericContainer;
+import org.testcontainers.containers.output.Slf4jLogConsumer;
+import org.testcontainers.containers.wait.strategy.LogMessageWaitStrategy;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
 
 /**
  * RemoteInfinispanTestSupport
  */
 public class RemoteInfinispanTestSupport
 {
+    private static final Logger LOG = LoggerFactory.getLogger(RemoteInfinispanTestSupport.class);
     public static final String DEFAULT_CACHE_NAME = "session_test_cache";
     public RemoteCache<String, SessionData> _cache;
     private String _name;
     public static RemoteCacheManager _manager;
+    private static final Logger INFINISPAN_LOG =
+        LoggerFactory.getLogger("org.eclipse.jetty.server.session.remote.infinispanLogs");
+
+    static GenericContainer infinispan;
 
     static
     {
         try
         {
-            String host = System.getProperty("hotrod.host", "127.0.0.1");
+            //Testcontainers.exposeHostPorts(11222);
+            long start = System.currentTimeMillis();
+            String infinispanVersion = System.getProperty("infinispan.docker.image.version", "9.4.8.Final");
+            infinispan =
+                new GenericContainer(System.getProperty("infinispan.docker.image.name", "jboss/infinispan-server") +
+                    ":" + infinispanVersion)
+                    .withEnv("APP_USER", "theuser")
+                    .withEnv("APP_PASS", "foobar")
+                    .withEnv("MGMT_USER", "admin")
+                    .withEnv("MGMT_PASS", "admin")
+                    .waitingFor(new LogMessageWaitStrategy()
+                        .withRegEx(".*Infinispan Server.*started in.*\\s"))
+                    .withExposedPorts(4712, 4713, 8088, 8089, 8443, 9990, 9993, 11211, 11222, 11223, 11224)
+                    .withLogConsumer(new Slf4jLogConsumer(INFINISPAN_LOG));
+            infinispan.start();
+            String host = infinispan.getContainerIpAddress();
+            System.setProperty("hotrod.host", host);
+            int port = infinispan.getMappedPort(11222);
 
+            LOG.info("Infinispan container started for {}:{} - {}ms", host, port,
+                     System.currentTimeMillis() - start);
             SearchMapping mapping = new SearchMapping();
             mapping.entity(SessionData.class).indexed().providedId()
                 .property("expiry", ElementType.METHOD).field();
@@ -63,10 +93,25 @@ public class RemoteInfinispanTestSupport
             Properties properties = new Properties();
             properties.put(Environment.MODEL_MAPPING, mapping);
 
-            ConfigurationBuilder clientBuilder = new ConfigurationBuilder();
-            clientBuilder.withProperties(properties).addServer().host(host).marshaller(new ProtoStreamMarshaller());
+            ConfigurationBuilder configurationBuilder = new ConfigurationBuilder().withProperties(properties)
+                .addServer().host(host).port(port)
+                // we just want to limit connectivity to list of host:port we knows at start
+                // as infinispan create new host:port dynamically but due to how docker expose host/port we cannot do that
+                .clientIntelligence(ClientIntelligence.BASIC)
+                .marshaller(new ProtoStreamMarshaller());
 
-            _manager = new RemoteCacheManager(clientBuilder.build());
+            if (infinispanVersion.startsWith("1"))
+            {
+                configurationBuilder.security().authentication()
+                    .realm("default")
+                    .serverName("infinispan")
+                    .saslMechanism("DIGEST-MD5")
+                    .username("theuser").password("foobar");
+            }
+
+            Configuration configuration = configurationBuilder.build();
+
+            _manager = new RemoteCacheManager(configuration);
 
             FileDescriptorSource fds = new FileDescriptorSource();
             fds.addProtoFiles("/session.proto");
@@ -86,11 +131,12 @@ public class RemoteInfinispanTestSupport
             }
 
             String content = baos.toString("UTF-8");
-            _manager.getCache("___protobuf_metadata").put("session.proto", content);
+            _manager.administration().getOrCreateCache("___protobuf_metadata", (String)null).put("session.proto", content);
         }
         catch (Exception e)
         {
-            fail(e);
+            LOG.error(e.getMessage(), e);
+            throw new RuntimeException(e);
         }
     }
 
@@ -114,7 +160,7 @@ public class RemoteInfinispanTestSupport
 
     public void setup() throws Exception
     {
-        _cache = _manager.getCache(_name);
+        _cache = _manager.administration().getOrCreateCache(_name, (String)null);
     }
 
     public void teardown() throws Exception
