@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -33,6 +33,7 @@ import org.eclipse.jetty.servlet.ServletContextHandler;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
+import org.testcontainers.junit.jupiter.Testcontainers;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
@@ -40,17 +41,19 @@ import static org.junit.jupiter.api.Assertions.assertNotNull;
 /**
  * MongoSessionDataStoreTest
  */
+@Testcontainers(disabledWithoutDocker = true)
 public class MongoSessionDataStoreTest extends AbstractSessionDataStoreTest
 {
+
     @BeforeEach
-    public void beforeClass() throws Exception
+    public void beforeEach() throws Exception
     {
         MongoTestHelper.dropCollection();
         MongoTestHelper.createCollection();
     }
 
     @AfterEach
-    public void afterClass() throws Exception
+    public void afterEach() throws Exception
     {
         MongoTestHelper.dropCollection();
     }
