@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -32,8 +32,11 @@ import com.mongodb.MongoException;
 import com.mongodb.WriteConcern;
 import org.eclipse.jetty.server.session.SessionData;
 import org.eclipse.jetty.util.ClassLoadingObjectInputStream;
-import org.eclipse.jetty.util.log.Log;
-import org.eclipse.jetty.util.log.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import org.testcontainers.containers.GenericContainer;
+import org.testcontainers.containers.output.Slf4jLogConsumer;
+import org.testcontainers.containers.wait.strategy.LogMessageWaitStrategy;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
@@ -44,46 +47,66 @@ import static org.junit.jupiter.api.Assertions.assertTrue;
  */
 public class MongoTestHelper
 {
-    private static final Logger LOG = Log.getLogger(MongoTestHelper.class);
-    static int __workers = 0;
+    private static final Logger LOG = LoggerFactory.getLogger(MongoTestHelper.class);
+    private static final Logger MONGO_LOG = LoggerFactory.getLogger("org.eclipse.jetty.nosql.mongodb.MongoLogs");
     public static final String DB_NAME = "HttpSessions";
     public static final String COLLECTION_NAME = "testsessions";
 
-    static MongoClient _mongoClient;
+    static GenericContainer mongo =
+        new GenericContainer("mongo:" + System.getProperty("mongo.docker.version", "2.2.7"))
+            .withLogConsumer(new Slf4jLogConsumer(MONGO_LOG))
+            .waitingFor(new LogMessageWaitStrategy()
+                            .withRegEx(".*waiting for connections.*"));
+
+    static MongoClient mongoClient;
+
+    static String mongoHost;
+    static int mongoPort;
 
     static
     {
         try
         {
-            _mongoClient =
-                new MongoClient(System.getProperty("embedmongo.host"), Integer.getInteger("embedmongoPort"));
+            long start = System.currentTimeMillis();
+            mongo.start();
+            mongoHost =  mongo.getHost();
+            mongoPort = mongo.getMappedPort(27017);
+            LOG.info("Mongo container started for {}:{} - {}ms", mongoHost, mongoPort,
+                     System.currentTimeMillis() - start);
+            mongoClient = new MongoClient(mongoHost, mongoPort);
         }
-        catch (UnknownHostException e)
+        catch (Exception e)
         {
-            e.printStackTrace();
+            LOG.error(e.getMessage(), e);
+            throw new RuntimeException(e);
         }
     }
 
-    public static void dropCollection() throws MongoException, UnknownHostException
+    public static MongoClient getMongoClient() throws UnknownHostException
     {
-        _mongoClient.getDB(DB_NAME).getCollection(COLLECTION_NAME).drop();
+        return mongoClient;
+    }
+
+    public static void dropCollection() throws Exception
+    {
+        getMongoClient().getDB(DB_NAME).getCollection(COLLECTION_NAME).drop();
     }
 
     public static void createCollection() throws UnknownHostException, MongoException
     {
-        _mongoClient.getDB(DB_NAME).createCollection(COLLECTION_NAME, null);
+        getMongoClient().getDB(DB_NAME).createCollection(COLLECTION_NAME, null);
     }
 
     public static DBCollection getCollection() throws UnknownHostException, MongoException
     {
-        return _mongoClient.getDB(DB_NAME).getCollection(COLLECTION_NAME);
+        return getMongoClient().getDB(DB_NAME).getCollection(COLLECTION_NAME);
     }
 
     public static MongoSessionDataStoreFactory newSessionDataStoreFactory()
     {
         MongoSessionDataStoreFactory storeFactory = new MongoSessionDataStoreFactory();
-        storeFactory.setHost(System.getProperty("embedmongoHost"));
-        storeFactory.setPort(Integer.getInteger("embedmongoPort"));
+        storeFactory.setHost(mongoHost);
+        storeFactory.setPort(mongoPort);
         storeFactory.setCollectionName(COLLECTION_NAME);
         storeFactory.setDbName(DB_NAME);
         return storeFactory;
@@ -92,7 +115,7 @@ public class MongoTestHelper
     public static boolean checkSessionExists(String id)
         throws Exception
     {
-        DBCollection collection = _mongoClient.getDB(DB_NAME).getCollection(COLLECTION_NAME);
+        DBCollection collection = getMongoClient().getDB(DB_NAME).getCollection(COLLECTION_NAME);
 
         DBObject fields = new BasicDBObject();
         fields.put(MongoSessionDataStore.EXPIRY, 1);
@@ -109,7 +132,7 @@ public class MongoTestHelper
     public static boolean checkSessionPersisted(SessionData data)
         throws Exception
     {
-        DBCollection collection = _mongoClient.getDB(DB_NAME).getCollection(COLLECTION_NAME);
+        DBCollection collection = getMongoClient().getDB(DB_NAME).getCollection(COLLECTION_NAME);
 
         DBObject fields = new BasicDBObject();
 
@@ -117,7 +140,7 @@ public class MongoTestHelper
         if (sessionDocument == null)
             return false; //doesn't exist
 
-        LOG.info("{}", sessionDocument);
+        LOG.debug("{}", sessionDocument);
 
         Boolean valid = (Boolean)sessionDocument.get(MongoSessionDataStore.VALID);
 
@@ -183,7 +206,7 @@ public class MongoTestHelper
                                                Map<String, Object> attributes)
         throws Exception
     {
-        DBCollection collection = _mongoClient.getDB(DB_NAME).getCollection(COLLECTION_NAME);
+        DBCollection collection = getMongoClient().getDB(DB_NAME).getCollection(COLLECTION_NAME);
 
         // Form query for upsert
         BasicDBObject key = new BasicDBObject(MongoSessionDataStore.ID, id);
@@ -193,7 +216,7 @@ public class MongoTestHelper
         boolean upsert = false;
         BasicDBObject sets = new BasicDBObject();
 
-        Object version = new Long(1);
+        Object version = 1L;
 
         // New session
 
@@ -232,7 +255,7 @@ public class MongoTestHelper
         throws Exception
     {
 
-        DBCollection collection = _mongoClient.getDB(DB_NAME).getCollection(COLLECTION_NAME);
+        DBCollection collection = getMongoClient().getDB(DB_NAME).getCollection(COLLECTION_NAME);
 
         // Form query for upsert
         BasicDBObject key = new BasicDBObject(MongoSessionDataStore.ID, id);
@@ -242,7 +265,7 @@ public class MongoTestHelper
         boolean upsert = false;
         BasicDBObject sets = new BasicDBObject();
 
-        Object version = new Long(1);
+        Object version = 1L;
 
         // New session
         upsert = true;
@@ -278,7 +301,7 @@ public class MongoTestHelper
         throws Exception
     {
         //make old-style session to test if we can retrieve it
-        DBCollection collection = _mongoClient.getDB(DB_NAME).getCollection(COLLECTION_NAME);
+        DBCollection collection = getMongoClient().getDB(DB_NAME).getCollection(COLLECTION_NAME);
 
         // Form query for upsert
         BasicDBObject key = new BasicDBObject(MongoSessionDataStore.ID, id);
@@ -288,7 +311,7 @@ public class MongoTestHelper
         boolean upsert = false;
         BasicDBObject sets = new BasicDBObject();
 
-        Object version = new Long(1);
+        Object version = 1L;
 
         // New session
         upsert = true;
