@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -115,7 +115,7 @@ public abstract class AbstractSessionDataStoreTest
             Class fooclazz = Class.forName("Foo", true, _contextClassLoader);
             //create a session
             long now = System.currentTimeMillis();
-            data = store.newSessionData("1234", 100, now, now - 1, -1);//never expires
+            data = store.newSessionData("1234", 100, now, now - 1, -1); //never expires
             data.setLastNode(sessionContext.getWorkerName());
 
             //Make an attribute that uses the class only known to the webapp classloader
@@ -175,7 +175,7 @@ public abstract class AbstractSessionDataStoreTest
 
         //create a session
         long now = System.currentTimeMillis();
-        SessionData data = store.newSessionData("1234", 100, 200, 199, -1);//never expires
+        SessionData data = store.newSessionData("1234", 100, 200, 199, -1); //never expires
         data.setAttribute("a", "b");
         data.setLastNode(sessionContext.getWorkerName());
         data.setLastSaved(400); //make it look like it was previously saved by the store
@@ -253,7 +253,7 @@ public abstract class AbstractSessionDataStoreTest
             Class factoryclazz = Class.forName("ProxyableFactory", true, _contextClassLoader);
             //create a session
             long now = System.currentTimeMillis();
-            data = store.newSessionData("1234", 100, now, now - 1, -1);//never expires
+            data = store.newSessionData("1234", 100, now, now - 1, -1); //never expires
             data.setLastNode(sessionContext.getWorkerName());
             Method m = factoryclazz.getMethod("newProxyable", ClassLoader.class);
             Object proxy = m.invoke(null, _contextClassLoader);
@@ -322,7 +322,7 @@ public abstract class AbstractSessionDataStoreTest
 
         //persist a session that is not expired
         long now = System.currentTimeMillis();
-        SessionData data = store.newSessionData("1234", 100, now, now - 1, -1);//never expires
+        SessionData data = store.newSessionData("1234", 100, now, now - 1, -1); //never expires
         data.setLastNode(sessionContext.getWorkerName());
         persistSession(data);
 
@@ -355,7 +355,7 @@ public abstract class AbstractSessionDataStoreTest
 
         //persist a session that is expired
         long now = System.currentTimeMillis();
-        SessionData data = store.newSessionData("678", 100, now - 20, now - 30, 10);//10 sec max idle
+        SessionData data = store.newSessionData("678", 100, now - 20, now - 30, 10); //10 sec max idle
         data.setLastNode(sessionContext.getWorkerName());
         data.setExpiry(RECENT_TIMESTAMP); //make it expired recently
         persistSession(data);
@@ -427,7 +427,72 @@ public abstract class AbstractSessionDataStoreTest
             //expected exception
         }
     }
+    
+    
+    /**
+     * Test that a session containing no attributes can be stored and re-read
+     * @throws Exception
+     */
+    @Test
+    public void testEmptyLoadSession() throws Exception
+    {
+        //create the SessionDataStore
+        ServletContextHandler context = new ServletContextHandler(ServletContextHandler.SESSIONS);
+        context.setContextPath("/test");
+        SessionDataStoreFactory factory = createSessionDataStoreFactory();
+        ((AbstractSessionDataStoreFactory)factory).setGracePeriodSec(GRACE_PERIOD_SEC);
+        SessionDataStore store = factory.getSessionDataStore(context.getSessionHandler());
+        SessionContext sessionContext = new SessionContext("foo", context.getServletContext());
+        store.initialize(sessionContext);
+        store.start();
+        
+        //persist a session that has no attributes
+        long now = System.currentTimeMillis();
+        SessionData data = store.newSessionData("222", 100, now, now - 1, -1);
+        data.setLastNode(sessionContext.getWorkerName());
+        //persistSession(data);
+        store.store("222", data);
 
+        //test that we can retrieve it
+        SessionData savedSession = store.load("222");
+        assertEquals(0, savedSession.getAllAttributes().size());
+    }
+    
+    //Test that a session that had attributes can be modified to contain no
+    //attributes, and still read
+    @Test
+    public void testModifyEmptyLoadSession() throws Exception
+    {
+        //create the SessionDataStore
+        ServletContextHandler context = new ServletContextHandler(ServletContextHandler.SESSIONS);
+        context.setContextPath("/test");
+        SessionDataStoreFactory factory = createSessionDataStoreFactory();
+        ((AbstractSessionDataStoreFactory)factory).setGracePeriodSec(GRACE_PERIOD_SEC);
+        SessionDataStore store = factory.getSessionDataStore(context.getSessionHandler());
+        SessionContext sessionContext = new SessionContext("foo", context.getServletContext());
+        store.initialize(sessionContext);
+        store.start();
+        
+        //persist a session that has attributes
+        long now = System.currentTimeMillis();
+        SessionData data = store.newSessionData("222", 100, now, now - 1, -1);
+        data.setAttribute("foo", "bar");
+        data.setLastNode(sessionContext.getWorkerName());
+        store.store("222", data);
+
+        //test that we can retrieve it
+        SessionData savedSession = store.load("222");
+        assertEquals("bar", savedSession.getAttribute("foo"));
+        
+        //now modify so there are no attributes
+        savedSession.setAttribute("foo", null);
+        store.store("222", savedSession);
+        
+        //check its still readable
+        savedSession = store.load("222");
+        assertEquals(0, savedSession.getAllAttributes().size());
+    }
+    
     /**
      * Test that we can delete a persisted session.
      */
