@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -21,18 +21,22 @@ package org.eclipse.jetty.server.session;
 import java.util.Collections;
 import java.util.Set;
 import java.util.concurrent.TimeUnit;
-
+import javax.servlet.http.HttpSession;
 import javax.servlet.http.HttpSessionActivationListener;
 import javax.servlet.http.HttpSessionEvent;
 
+import org.eclipse.jetty.server.Request;
 import org.eclipse.jetty.server.Server;
 import org.eclipse.jetty.servlet.ServletContextHandler;
+import org.eclipse.jetty.util.log.Log;
+import org.eclipse.jetty.util.log.StacklessLogging;
 import org.junit.jupiter.api.Test;
 
 import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.containsInAnyOrder;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertTrue;
@@ -43,6 +47,58 @@ import static org.junit.jupiter.api.Assertions.assertTrue;
  */
 public abstract class AbstractSessionCacheTest
 {
+    public static class UnreadableSessionDataStore extends AbstractSessionDataStore
+    {
+        int _count;
+        int _calls;
+        SessionData _data;
+
+        public UnreadableSessionDataStore(int count, SessionData data)
+        {
+            _count = count;
+            _data = data;
+        }
+
+        @Override
+        public boolean isPassivating()
+        {
+            return false;
+        }
+
+        @Override
+        public boolean exists(String id) throws Exception
+        {
+            return _data != null;
+        }
+
+        @Override
+        public boolean delete(String id) throws Exception
+        {
+            _data = null;
+            return true;
+        }
+
+        @Override
+        public void doStore(String id, SessionData data, long lastSaveTime) throws Exception
+        {
+        }
+
+        @Override
+        public SessionData doLoad(String id) throws Exception
+        {
+            ++_calls;
+            if (_calls <= _count)
+                throw new UnreadableSessionDataException(id, _context, new IllegalStateException("Throw for test"));
+            else
+                return _data;
+        }
+
+        @Override
+        public Set<String> doGetExpired(Set<String> candidates)
+        {
+            return null;
+        }
+    }
 
     public static class TestSessionActivationListener implements HttpSessionActivationListener
     {
@@ -61,11 +117,76 @@ public abstract class AbstractSessionCacheTest
             ++activateCalls;
         }
     }
-    
-    public abstract AbstractSessionCacheFactory newSessionCacheFactory(int evictionPolicy, boolean saveOnCreate, 
-                                                                       boolean saveOnInactiveEvict, boolean removeUnloadableSessions,
+
+    public abstract AbstractSessionCacheFactory newSessionCacheFactory(int evictionPolicy,
+                                                                       boolean saveOnCreate, 
+                                                                       boolean saveOnInactiveEvict,
+                                                                       boolean removeUnloadableSessions,
                                                                        boolean flushOnResponseCommit);
+
+    public abstract void checkSessionBeforeShutdown(String id,
+                                                    SessionDataStore store, 
+                                                    SessionCache cache, 
+                                                    TestSessionActivationListener activationListener,
+                                                    TestHttpSessionListener sessionListener) throws Exception;
     
+    public abstract void checkSessionAfterShutdown(String id,
+                                                   SessionDataStore store,
+                                                   SessionCache cache,
+                                                   TestSessionActivationListener activationListener,
+                                                   TestHttpSessionListener sessionListener) throws Exception;
+
+    /**
+     * Test that a session that exists in the datastore, but that cannot be
+     * read will be invalidated and deleted, and thus a request to re-use that
+     * same id will not succeed.
+     * 
+     * @throws Exception
+     */
+    @Test
+    public void testUnreadableSession() throws Exception
+    {
+        Server server = new Server();
+        server.setSessionIdManager(new DefaultSessionIdManager(server));
+
+        ServletContextHandler context = new ServletContextHandler(ServletContextHandler.SESSIONS);
+        context.setContextPath("/test");
+        context.setServer(server);
+        server.setHandler(context);
+
+        AbstractSessionCacheFactory cacheFactory = newSessionCacheFactory(SessionCache.NEVER_EVICT, false, false, false, false);
+        SessionCache cache = cacheFactory.getSessionCache(context.getSessionHandler());
+
+        //prefill the datastore with a session that will be treated as unreadable
+        UnreadableSessionDataStore store = new UnreadableSessionDataStore(1, new SessionData("1234", "/test", "0.0.0.0", System.currentTimeMillis(), 0, 0, -1));
+        cache.setSessionDataStore(store);
+        context.getSessionHandler().setSessionCache(cache);
+        server.start();
+
+        try (StacklessLogging ignored = new StacklessLogging(Log.getLogger("org.eclipse.jetty.server.session")))
+        {
+            //check that session 1234 cannot be read, ie returns null AND
+            //that it is deleted in the datastore
+            Session session = context.getSessionHandler().getSession("1234");
+            assertNull(session);
+            assertFalse(store.exists("1234"));
+
+            //now try to make a session with the same id as if from a request with
+            //a SESSION_ID cookie set - the id from the cookie should not be able to
+            //be re-used because we just deleted the session with that id. Ids cannot
+            //be re-used (unless another context is already using that same id (ie cross
+            //context dispatch), which is not the case in this test).
+            Request request = new Request(null, null);
+            request.setRequestedSessionId("1234");
+            HttpSession newSession = context.getSessionHandler().newHttpSession(request);
+            assertNotEquals("1234", newSession.getId());
+        }
+        finally
+        {
+            server.stop();
+        }
+    }
+
     /**
      * Test that a new Session object can be created from
      * previously persisted data (SessionData).
@@ -84,7 +205,7 @@ public abstract class AbstractSessionCacheTest
         cacheFactory.setEvictionPolicy(SessionCache.NEVER_EVICT);
         DefaultSessionCache cache = (DefaultSessionCache)cacheFactory.getSessionCache(context.getSessionHandler());
 
-        TestSessionDataStore store = new TestSessionDataStore(true);//fake passivation
+        TestSessionDataStore store = new TestSessionDataStore(true); //fake passivation
         cache.setSessionDataStore(store);
         context.getSessionHandler().setSessionCache(cache);
 
@@ -134,11 +255,14 @@ public abstract class AbstractSessionCacheTest
         assertEquals(now - 20, session.getCreationTime());
     }
     
+    /**
+     * Test state of session with call to commit
+     * 
+     * @throws Exception
+     */
     @Test
     public void testCommit() throws Exception
     {
-        //Test state of session with call to commit
-        
         Server server = new Server();
 
         ServletContextHandler context = new ServletContextHandler(ServletContextHandler.SESSIONS);
@@ -161,14 +285,14 @@ public abstract class AbstractSessionCacheTest
         store._numSaves.set(0); //clear save counter
         Session session = createUnExpiredSession(cache, store, "1234");
         cache.add("1234", session);
-        session.getSessionData().setLastSaved(100);//simulate previously saved
+        session.getSessionData().setLastSaved(100); //simulate previously saved
         commitAndCheckSaveState(cache, store, session, false, true, false, true, 0, 0);
         
         //call commit: session has changed, should be written
         store._numSaves.set(0); //clear save counter
         session = createUnExpiredSession(cache, store, "456");
         cache.add("456", session);
-        session.getSessionData().setLastSaved(100);//simulate previously saved
+        session.getSessionData().setLastSaved(100); //simulate previously saved
         session.setAttribute("foo", "bar");
         commitAndCheckSaveState(cache, store, session, true, true, false, false, 0, 1);
         
@@ -176,7 +300,7 @@ public abstract class AbstractSessionCacheTest
         store._numSaves.set(0); //clear save counter
         session = createUnExpiredSession(cache, store, "678");
         cache.add("678", session);
-        session.getSessionData().setLastSaved(100);//simulate previously saved
+        session.getSessionData().setLastSaved(100); //simulate previously saved
         session.getSessionData().calcAndSetExpiry(System.currentTimeMillis() + TimeUnit.DAYS.toMillis(1));
         commitAndCheckSaveState(cache, store, session, false, true, false, true, 0, 0);
 
@@ -190,14 +314,14 @@ public abstract class AbstractSessionCacheTest
         store._numSaves.set(0); //clear save counter
         session = createUnExpiredSession(cache, store, "890");
         cache.add("890", session);
-        session.getSessionData().setLastSaved(100);//simulate previously saved
+        session.getSessionData().setLastSaved(100); //simulate previously saved
         commitAndCheckSaveState(cache, store, session, false, true, false, true, 0, 0);
         
         //call commit: session has changed so session must be written
         store._numSaves.set(0); //clear save counter
         session = createUnExpiredSession(cache, store, "012");
         cache.add("012", session);
-        session.getSessionData().setLastSaved(100);//simulate previously saved
+        session.getSessionData().setLastSaved(100); //simulate previously saved
         session.setAttribute("foo", "bar");
         commitAndCheckSaveState(cache, store, session, true, true, false, false, 0, 1);
 
@@ -206,16 +330,19 @@ public abstract class AbstractSessionCacheTest
         session = createUnExpiredSession(cache, store, "234");
         session.getSessionData().setMetaDataDirty(true);
         cache.add("234", session);
-        session.getSessionData().setLastSaved(100);//simulate previously saved
+        session.getSessionData().setLastSaved(100); //simulate previously saved
         session.getSessionData().calcAndSetExpiry(System.currentTimeMillis() + TimeUnit.DAYS.toMillis(1));
         commitAndCheckSaveState(cache, store, session, false, true, false, true, 0, 0);
     }
     
+    /**
+     * Test what happens with various states of a session when commit
+     * is called before release
+     * @throws Exception
+     */
     @Test
     public void testCommitAndRelease() throws Exception
     {
-        //test what happens with various states of a session when commit
-        //is called before release
         Server server = new Server();
 
         ServletContextHandler context = new ServletContextHandler(ServletContextHandler.SESSIONS);
@@ -249,7 +376,7 @@ public abstract class AbstractSessionCacheTest
         session = createUnExpiredSession(cache, store, "456");
         cache.add("456", session);
         session.setAttribute("foo", "bar");
-        session.getSessionData().setLastSaved(100);//simulate not "new" session, ie has been previously saved
+        session.getSessionData().setLastSaved(100); //simulate not "new" session, ie has been previously saved
         commitAndCheckSaveState(cache, store, session, true, true, false, false, 0, 1);
         //call release: session not dirty but release changes metadata, so it will be saved
         cache.release("456", session);
@@ -290,7 +417,7 @@ public abstract class AbstractSessionCacheTest
         store._numSaves.set(0); //clear save counter
         session = createUnExpiredSession(cache, store, "012");
         cache.add("012", session);
-        session.getSessionData().setLastSaved(100);//simulate previously saved session
+        session.getSessionData().setLastSaved(100); //simulate previously saved session
         session.setAttribute("foo", "bar");
         session.getSessionData().setMetaDataDirty(false);
         commitAndCheckSaveState(cache, store, session, true, false, false, false, 0, 1);
@@ -304,7 +431,7 @@ public abstract class AbstractSessionCacheTest
         store._numSaves.set(0); //clear save counter
         session = createUnExpiredSession(cache, store, "234");
         session.getSessionData().calcAndSetExpiry(System.currentTimeMillis() + TimeUnit.DAYS.toMillis(1));
-        session.getSessionData().setLastSaved(System.currentTimeMillis());//simulate session last saved recently
+        session.getSessionData().setLastSaved(System.currentTimeMillis()); //simulate session last saved recently
         commitAndCheckSaveState(cache, store, session, false, true, false, true, 0, 0);
         //call release: not dirty, release sets metadirty true (recalc expiry) but not within saveperiod so skip write
         cache.release("1234", session);
@@ -312,7 +439,7 @@ public abstract class AbstractSessionCacheTest
         assertFalse(session.getSessionData().isDirty());
         assertTrue(session.getSessionData().isMetaDataDirty());
     }
-    
+
     /**
      * Test the exist method.
      */
@@ -384,7 +511,7 @@ public abstract class AbstractSessionCacheTest
         assertFalse(cache.contains("1234"));
 
         //test remove of session in both store and cache
-        session = cache.newSession(null, "1234",now - 20, TimeUnit.MINUTES.toMillis(10));//saveOnCreate ensures write to store
+        session = cache.newSession(null, "1234", now - 20, TimeUnit.MINUTES.toMillis(10)); //saveOnCreate ensures write to store
         cache.add("1234", session);
         assertTrue(store.exists("1234"));
         assertTrue(cache.contains("1234"));
@@ -487,6 +614,92 @@ public abstract class AbstractSessionCacheTest
         cache.newSession(null, "1234", now, TimeUnit.MINUTES.toMillis(10));
         assertFalse(store.exists("1234"));
     }
+    
+    /**
+     * Test shutting down the server with invalidateOnShutdown==false
+     * 
+     * @throws Exception
+     */
+    @Test
+    public void testNoInvalidateOnShutdown()
+        throws Exception
+    {
+        Server server = new Server();
+
+        ServletContextHandler context = new ServletContextHandler(ServletContextHandler.SESSIONS);
+        context.setContextPath("/test");
+        context.setServer(server);
+        server.setHandler(context);
+
+        AbstractSessionCacheFactory cacheFactory = newSessionCacheFactory(SessionCache.NEVER_EVICT, false, false, false, false);
+        SessionCache cache = cacheFactory.getSessionCache(context.getSessionHandler());
+
+        TestSessionDataStore store = new TestSessionDataStore(true); //fake passivation
+        cache.setSessionDataStore(store);
+        context.getSessionHandler().setSessionCache(cache);
+        TestHttpSessionListener sessionListener = new TestHttpSessionListener();
+        context.getSessionHandler().addEventListener(sessionListener);
+
+        server.start();
+
+        //put a session in the cache and store
+        long now = System.currentTimeMillis();
+        SessionData data = store.newSessionData("1234", now - 20, now - 10, now - 20, TimeUnit.MINUTES.toMillis(10));
+        Session session = cache.newSession(data);
+        TestSessionActivationListener activationListener = new TestSessionActivationListener();
+        cache.add("1234", session);
+        session.setAttribute("aaa", activationListener);
+        cache.release("1234", session);
+        checkSessionBeforeShutdown("1234", store, cache, activationListener, sessionListener);
+
+        server.stop(); //calls shutdown
+
+        checkSessionAfterShutdown("1234", store, cache, activationListener, sessionListener);
+    }
+    
+    /**
+     * Test shutdown of the server with invalidateOnShutdown==true
+     * @throws Exception
+     */
+    @Test
+    public void testInvalidateOnShutdown()
+        throws Exception
+    {
+        Server server = new Server();
+
+        ServletContextHandler context = new ServletContextHandler(ServletContextHandler.SESSIONS);
+        context.setContextPath("/test");
+        server.setHandler(context);
+
+        //flushOnResponseCommit is true
+        AbstractSessionCacheFactory cacheFactory = newSessionCacheFactory(SessionCache.NEVER_EVICT, false, false, false, true);
+        cacheFactory.setInvalidateOnShutdown(true);
+        SessionCache cache = cacheFactory.getSessionCache(context.getSessionHandler());
+
+
+        TestSessionDataStore store = new TestSessionDataStore(true); //fake a passivating store
+        cache.setSessionDataStore(store);
+        context.getSessionHandler().setSessionCache(cache);
+        TestHttpSessionListener sessionListener = new TestHttpSessionListener();
+        context.getSessionHandler().addEventListener(sessionListener);
+
+        server.start();
+
+        //Make a session in the store and cache and check that it is invalidated on shutdown
+        long now = System.currentTimeMillis();
+        SessionData data = store.newSessionData("8888", now - 20, now - 10, now - 20, TimeUnit.MINUTES.toMillis(10));
+        Session session = cache.newSession(data);
+        cache.add("8888", session);
+
+        TestSessionActivationListener activationListener = new TestSessionActivationListener();
+        session.setAttribute("aaa", activationListener);
+        cache.release("8888", session);
+        checkSessionBeforeShutdown("8888", store, cache, activationListener, sessionListener);
+
+        server.stop();
+
+        checkSessionAfterShutdown("8888", store, cache, activationListener, sessionListener);
+    }
 
     public void commitAndCheckSaveState(SessionCache cache, TestSessionDataStore store, Session session, 
                                         boolean expectedBeforeDirty, boolean expectedBeforeMetaDirty, 
@@ -502,7 +715,7 @@ public abstract class AbstractSessionCacheTest
         assertEquals(expectedAfterMetaDirty, session.getSessionData().isMetaDataDirty());
         assertEquals(expectedAfterNumSaves, store._numSaves.get());
     }
-    
+
     public Session createUnExpiredSession(SessionCache cache, SessionDataStore store, String id)
     {
         long now = System.currentTimeMillis();
