@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2019 Mort Bay Consulting Pty. Ltd.
+//  Copyright (c) 1995-2021 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -21,7 +21,6 @@ package com.acme;
 import java.io.IOException;
 import java.util.HashSet;
 import java.util.Set;
-
 import javax.servlet.Filter;
 import javax.servlet.FilterChain;
 import javax.servlet.FilterConfig;
@@ -32,18 +31,16 @@ import javax.servlet.ServletRequestWrapper;
 import javax.servlet.ServletResponse;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletRequestWrapper;
-import javax.servlet.http.HttpServletResponse;
 
 import org.eclipse.jetty.util.log.Log;
 import org.eclipse.jetty.util.log.Logger;
 
-/* ------------------------------------------------------------ */
-/** TestFilter.
+/**
+ * TestFilter.
  *
  * This filter checks for a none local request, and if the init parameter
  * "remote" is not set to true, then all non local requests are forwarded
  * to /remote.html
- *
  */
 public class TestFilter implements Filter
 {
@@ -53,70 +50,69 @@ public class TestFilter implements Filter
     private ServletContext _context;
     private final Set<String> _allowed = new HashSet<String>();
 
-    /* ------------------------------------------------------------ */
     /*
      * @see javax.servlet.Filter#init(javax.servlet.FilterConfig)
      */
     @Override
     public void init(FilterConfig filterConfig) throws ServletException
     {
-        _context= filterConfig.getServletContext();
-        _remote=Boolean.parseBoolean(filterConfig.getInitParameter("remote"));
+        _context = filterConfig.getServletContext();
+        _remote = Boolean.parseBoolean(filterConfig.getInitParameter("remote"));
         _allowed.add("/favicon.ico");
         _allowed.add("/jetty_banner.gif");
         _allowed.add("/remote.html");
 
-        LOG.debug("TestFilter#remote="+_remote);
+        LOG.debug("TestFilter#remote=" + _remote);
     }
 
-    /* ------------------------------------------------------------ */
     /*
      * @see javax.servlet.Filter#doFilter(javax.servlet.ServletRequest, javax.servlet.ServletResponse, javax.servlet.FilterChain)
      */
     @Override
     public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain)
-            throws IOException, ServletException
+        throws IOException, ServletException
     {
         String from = request.getRemoteAddr();
         String to = request.getLocalAddr();
-        String path=((HttpServletRequest)request).getServletPath();
-        
+        String path = ((HttpServletRequest)request).getServletPath();
+
         if (!_remote && !_allowed.contains(path) && !from.equals(to))
         {
-            _context.getRequestDispatcher("/remote.html").forward(request,response);
+            _context.getRequestDispatcher("/remote.html").forward(request, response);
             return;
         }
 
-        Integer old_value=null;
+        Integer oldValue = null;
         ServletRequest r = request;
         while (r instanceof ServletRequestWrapper)
-            r=((ServletRequestWrapper)r).getRequest();
+        {
+            r = ((ServletRequestWrapper)r).getRequest();
+        }
 
         try
         {
-            old_value=(Integer)request.getAttribute("testFilter");
+            oldValue = (Integer)request.getAttribute("testFilter");
 
-            Integer value=(old_value==null)?new Integer(1):new Integer(old_value.intValue()+1);
+            Integer value = (oldValue == null) ? new Integer(1) : new Integer(oldValue.intValue() + 1);
 
             request.setAttribute("testFilter", value);
 
             String qString = ((HttpServletRequest)request).getQueryString();
-            if (qString != null && qString.indexOf("wrap")>=0)
+            if (qString != null && qString.indexOf("wrap") >= 0)
             {
-                request=new HttpServletRequestWrapper((HttpServletRequest)request);
+                request = new HttpServletRequestWrapper((HttpServletRequest)request);
             }
-            _context.setAttribute("request"+r.hashCode(),value);
+            _context.setAttribute("request" + r.hashCode(), value);
 
             chain.doFilter(request, response);
         }
         finally
         {
-            request.setAttribute("testFilter", old_value);
-            _context.setAttribute("request"+r.hashCode(),old_value);
+            request.setAttribute("testFilter", oldValue);
+            _context.setAttribute("request" + r.hashCode(), oldValue);
         }
     }
 
-    /* ------------------------------------------------------------ */
     /*
      * @see javax.servlet.Filter#destroy()
      */
@@ -124,5 +120,4 @@ public class TestFilter implements Filter
     public void destroy()
     {
     }
-
 }
